/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(ub){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function sb(tb){var r=tb.a;var s=r.buffer;r.grow=qb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=tb.abort;var M=NaN;var N=Infinity;var O=tb.b;var P=tb.c;var Q=tb.d;var R=tb.e;var S=tb.f;var T=tb.g;var U=tb.h;var V=tb.i;var W=tb.j;var X=tb.k;var Y=tb.l;var Z=tb.m;var _=tb.n;var $=tb.o;var aa=tb.p;var ba=tb.q;var ca=tb.r;var da=tb.s;var ea=tb.t;var fa=tb.u;var ga=tb.v;var ha=tb.w;var ia=tb.x;var ja=tb.y;var ka=tb.z;var la=tb.A;var ma=tb.B;var na=tb.C;var oa=tb.D;var pa=tb.E;var qa=tb.F;var ra=tb.G;var sa=tb.H;var ta=tb.I;var ua=tb.J;var va=tb.K;var wa=tb.L;var xa=tb.M;var ya=tb.N;var za=tb.O;var Aa=tb.P;var Ba=tb.Q;var Ca=tb.R;var Da=tb.S;var Ea=tb.T;var Fa=tb.U;var Ga=tb.V;var Ha=tb.W;var Ia=tb.X;var Ja=tb.Y;var Ka=tb.Z;var La=tb._;var Ma=tb.$;var Na=tb.aa;var Oa=tb.ba;var Pa=tb.ca;var Qa=tb.da;var Ra=tb.ea;var Sa=tb.fa;var Ta=tb.ga;var Ua=tb.ha;var Va=tb.ia;var Wa=tb.ja;var Xa=tb.ka;var Ya=tb.la;var Za=tb.ma;var _a=tb.na;var $a=tb.oa;var ab=tb.pa;var bb=tb.qa;var cb=tb.ra;var db=tb.sa;var eb=tb.ta;var fb=tb.ua;var gb=5710800;var hb=0;var ib=0;var jb=0;
// EMSCRIPTEN_START_FUNCS
function Dt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=C(0),_=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=C(0),za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=C(0),Pa=0;ma=gb-16|0;gb=ma;ga=b;pa=c;na=ma+8|0;v[na>>2]=58036;v[na>>2]=57936;$=gb-32|0;gb=$;J=a;a:{b:{qa=a+24604|0;a=qa;if(!v[a+16>>2]){break b}b=v[a+20>>2];if(b>>>0>4|!(1<<b&22)){break b}a=v[a+28>>2];if(a>>>0>4){break b}a=23>>>a&1;break a}a=0}if(!a){aP($+16|0,33052,33072,207,45);b=$+16|0;a=gb-160|0;gb=a;v[a+88>>2]=0;f=eu(a+88|0);v[23048]=0;c=Q(2,a+120|0,56347)|0;e=v[23048];v[23048]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){v[23048]=0;T(6,a+104|0,1,33077);e=v[23048];v[23048]=0;if((e|0)==1){break i}v[23048]=0;T(3,a+136|0,c|0,a+104|0);e=v[23048];v[23048]=0;if((e|0)==1){break h}v[23048]=0;ea(33,f|0,b|0,1,56340,a+136|0);b=v[23048];v[23048]=0;if((b|0)==1){break g}vb(a+136|0);vb(a+104|0);vb(c);break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+136|0)}vb(a+104|0)}vb(c)}R(b|0);L()}gb=a+160|0}b=J+946300|0;a=J+906300|0;while(1){ra=v[a>>2];if(!ra){a=a+160|0;if((b|0)!=(a|0)){continue}}break}j:{if(!ga){break j}a=v[J+480208>>2];if(a&512){break j}Aa=J+8204|0;Ba=J+1074328|0;Ca=J+393352|0;ha=J+12|0;sa=J+1300300|0;Da=J+1074368|0;c=v[J+1074372>>2];while(1){k:{if(c){break k}aa=J;b=a|512;l:{if(a&256){break l}c=0;k=gb-48|0;gb=k;N=gb-32|0;gb=N;E=J;d=E;b=d+1074384|0;a=v[b>>2]+1|0;v[b>>2]=a;p=d+1074368|0;m:{n:{if(lk(p)>>>0>a>>>0){break n}i=d+1074308|0;e=d+1074984|0;f=d+1300264|0;m=d+1074416|0;j=d+484344|0;h=d+484360|0;g=d+1074440|0;r=d+480210|0;while(1){Ez(N+24|0,d,p,(v[d+480208>>2]&524288)>>>19|0);o:{p:{q:{r:{if(!(w[d+480208|0]&32)){b=x[g>>1];a=d;s:{if(uc(Qb(h))>>>0>b>>>0){b=x[sc(Qb(h),x[g>>1])>>1];break s}b=65535}u[a+1074438>>1]=b;t:{if(Te(j)>>>0<=(b&65535)>>>0){break t}if(ai(Yb(j,x[d+1074438>>1]))){break t}u[d+1074438>>1]=65534}if(x[d+1074438>>1]>=Te(j)>>>0){while(1){u:{v:{w:{x:{if(x[d+1074438>>1]!=65535){a=x[g>>1];if(uc(Qb(h))>>>0>a>>>0){break x}}a=x[Qb(h)+28>>1];if(a){break v}a=x[g>>1];if(uc(Qb(h))>>>0<a>>>0){break w}b=x[g>>1];if(!b){break w}while(1){a=b;b=a-1|0;if(!b){break w}if(x[sc(Qb(h),b)>>1]!=65535){continue}break}break v}b=x[g>>1]+1|0;u[g>>1]=b;break u}a=0}u[d+1074440>>1]=a;v[d+480208>>2]=v[d+480208>>2]&-524289;y:{if(uc(Qb(h))>>>0<=(a&65535)>>>0){break y}while(1){if(x[sc(Qb(h),x[g>>1])>>1]!=65534){break y}a=x[g>>1]+1|0;u[g>>1]=a;if(uc(Qb(h))>>>0>(a&65535)>>>0){continue}break}}a=x[g>>1];if(uc(Qb(h))>>>0<=a>>>0){break r}if(!Io(Qb(h),x[g>>1])){break r}b=x[g>>1]}a=d;z:{if(uc(Qb(h))>>>0>(b&65535)>>>0){b=x[sc(Qb(h),x[g>>1])>>1];break z}b=65535}u[a+1074438>>1]=b;A:{if(Te(j)>>>0<=(b&65535)>>>0){break A}if(ai(Yb(j,x[d+1074438>>1]))){break A}u[d+1074438>>1]=65534}if(x[d+1074438>>1]>=Te(j)>>>0){continue}break}}u[d+1074442>>1]=x[d+1074440>>1]}if(!oe(j,x[d+1074438>>1])){break p}if(y[d+1074416>>2]>=y[Yb(j,x[d+1074438>>1])+12>>2]){v[m>>2]=0}if(v[d+480208>>2]&32?v[d+480272>>2]!=-1:0){break o}if(!yu(f,x[g>>1],v[m>>2],Qq(N+16|0,e),w[N+24|0])){break o}a=v[d+480272>>2];if(a){if((a|0)>=1){v[d+480272>>2]=a-1}mk(f,1);yu(f,x[g>>1],v[m>>2],Qq(N+16|0,e),w[N+24|0]);break o}if(w[r|0]&64){if(uR(f,g,m,1)){break q}v[d+1074440>>2]=0;v[d+1074416>>2]=0;v[d+1074420>>2]=0;a=w[h+16|0];if((a|0)>=(Ei(h)-1|0)){Fi(h,0);mk(f,1);break p}Fi(h,w[h+16|0]+1&255);mk(f,1);break q}mk(f,1);break p}mk(f,1);break p}b=0;while(1){No((d+B(b,880)|0)+1074984|0,d,b&65535);b=b+1|0;if((b|0)!=256){continue}break}UO(d);v[d+1074408>>2]=v[d+480196>>2];v[d+1074412>>2]=v[d+480204>>2];v[d+1074448>>2]=v[d+480200>>2];u[d+1074442>>1]=x[d+1074440>>1];v[d+1074420>>2]=v[d+1074416>>2];b=f;o=uc(Qb(h));a=x[d+1074440>>1];if(o>>>0>a>>>0){Ma=d,Na=x[sc(Qb(h),x[d+1074440>>1])>>1],u[Ma+1074438>>1]=Na;a=x[d+1074440>>1]}yu(b,a&65535,v[d+1074416>>2],Qq(N+16|0,e),w[N+24|0]);if(oe(j,x[d+1074438>>1])){break o}}a=0;break m}Dz(d,p,(v[d+480208>>2]&32)>>>5|0);a=Wc(Yb(j,x[d+1074438>>1]),v[d+1074416>>2],0);b=x[d+480188>>1];if(b){o=(d+B(b,880)|0)+1074984|0;b=e;while(1){Db(N+16|0,i,82);B:{if(!Cb(N+16|0)|w[b+807|0]!=1){break B}l=w[a+3|0];if((l|0)!=3?(l|0)!=2:0){break B}Ma=b,Na=Vg(d,w[b+802|0],u[b+774>>1],v[b+704>>2]),v[Ma+700>>2]=Na}Db(N+16|0,i,91);C:{if(!Cb(N+16|0)){break C}if(ne(a)){break C}if(!ne(b+790|0)|w[b+793|0]!=19){break C}l=w[b+795|0];if((l&240)!=208|y[d+1074408>>2]>(l&15)>>>0){break C}Ma=b,Na=Vg(d,w[b+790|0],u[b+774>>1],0),v[Ma+700>>2]=Na}Db(N+16|0,i,92);D:{if(!Cb(N+16|0)){break D}Db(N+8|0,i,5);if(Cb(N+8|0)|v[d+1074408>>2]!=1|w[b+793|0]!=17){break D}v[d+1074412>>2]=B(w[b+795|0],1e4)}l=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+790|0]=l;t[b+791|0]=l>>>8;t[b+792|0]=l>>>16;t[b+793|0]=l>>>24;l=w[a+4|0]|w[a+5|0]<<8;t[b+794|0]=l;t[b+795|0]=l>>>8;l=v[b+676>>2];v[b+20>>2]=v[b+672>>2];v[b+24>>2]=l;v[b+88>>2]=v[b+88>>2]&-393217;Db(N+16|0,i,21);if(!Cb(N+16|0)){t[b+833|0]=0}v[b+864>>2]=0;t[b+807|0]=0;a=a+6|0;b=b+880|0;if((o|0)!=(b|0)){continue}break}}a=d;o=a+1074404|0;E:{F:{b=a+484344|0;if(Ul(b,x[a+1074438>>1])){if(VP(Yb(b,x[a+1074438>>1]))){break F}}v[a+1074400>>2]=v[a+480216>>2];a=v[a+480220>>2];break E}Ma=a+1074400|0,Na=v[Yb(b,x[a+1074438>>1])+16>>2],v[Ma>>2]=Na;a=v[Yb(b,x[a+1074438>>1])+20>>2]}v[o>>2]=a;if(!w[N+24|0]){break n}a=v[d+1074408>>2]+1|0;v[d+1074384>>2]=a;if(lk(p)>>>0<=a>>>0){continue}break}}if(!v[d+1074408>>2]){v[d+1074408>>2]=1}a=v[d+480208>>2];G:{if(v[d+1074384>>2]){v[d+480208>>2]=a&-4097;if(v[d+480180>>2]&1048580|(w[d+480210|0]&32?0:v[d+480180>>2]==1)){break G}if(y[d+1074384>>2]>=lk(p)>>>0|y[d+1074384>>2]%(v[d+1074392>>2]+v[d+1074408>>2]>>>0)){break G}v[d+480208>>2]=v[d+480208>>2]|4096;break G}v[d+480208>>2]=a&-528385|4096}m=0;n=gb-16|0;gb=n;u[d+1074436>>1]=65535;a=d+1074428|0;v[a>>2]=-1;v[a+4>>2]=-1;G=d+480208|0;M=d+1074368|0;if(x[d+480188>>1]){W=d+1075803|0;I=d+1300300|0;A=d+1074308|0;while(1){q=d+B(m,880)|0;i=q+1075779|0;r=w[i|0];p=q+1075777|0;b=w[p|0];j=q+1075778|0;h=w[j|0];X=q+1075776|0;g=w[X|0];S=q+1075775|0;f=w[S|0];a=v[d+1074384>>2];l=v[d+1074392>>2];o=v[d+1074408>>2];H=q+1075774|0;e=ru(H);K=q+1075837|0;t[K|0]=v[d+480208>>2]>>>12&1|w[K|0]&254;_=(a>>>0)%(l+o>>>0)|0;a=w[H|0];if((a|0)==252){a=w[S|0];l=Pq(H);o=zo(H);H:{if(!a|a-251>>>0<5){break H}a=v[(d+B(a,160)|0)+906140>>2];if(!a){break H}kb[v[v[a>>2]+44>>2]](a,l,C(C(o>>>0)*C(.0010010009864345193)))}a=w[H|0]}I:{if(b&255|z[q+1075848>>2]==C(0)?(a|0)!=251:0){break I}l=v[G>>2]&4096;J:{if(!l){a=w[q+1075858|0];break J}a=w[S|0];t[q+1075858|0]=a}if(!a|a-251>>>0<5){break I}a=(d+B(a,160)|0)+906140|0;if(!v[a>>2]){break I}K:{if(!l){j=x[q+1075856>>1];break K}j=nu(w[X|0],w[j|0]);u[q+1075856>>1]=j;Z=C(C(nu(w[p|0],w[i|0])>>>0)*C(.0010010009864345193));z[q+1075852>>2]=Z;i=v[a>>2];Ma=q+1075848|0,Oa=C(C(Z-C(kb[v[v[i>>2]+48>>2]](i,j)))/C(lk(M)>>>0)),z[Ma>>2]=Oa}i=v[d+1074384>>2];p=lk(M);a=v[a>>2];if((p|0)==(i+1|0)){kb[v[v[a>>2]+44>>2]](a,j,z[q+1075852>>2]);break I}kb[v[v[a>>2]+104>>2]](a,j,z[q+1075848>>2])}l=q+1074984|0;L:{M:{N:{O:{P:{if(!PP(w[H|0])){if(w[G+1|0]&16){break O}a=f;break P}a=gb-16|0;gb=a;u[a+12>>1]=0;v[a+8>>2]=0;Pi(a+8|0);b=x[a+12>>1];t[l+794|0]=b;t[l+795|0]=b>>>8;b=v[a+8>>2];t[l+790|0]=b;t[l+791|0]=b>>>8;t[l+792|0]=b>>>16;t[l+793|0]=b>>>24;gb=a+16|0;a=0;g=0;h=0;b=0;r=0;e=0;p=0;s=0;i=0;f=0;j=0;o=0;if(w[G+1|0]&16){break M}}IP(d,l);f=a;break N}if(!f){f=0;break N}v[q+1075748>>2]=0}j=0;a=b&255;Q:{R:{S:{if(a-19>>>0>=2){if((a|0)!=33){break S}Db(n+8|0,A,30);j=r>>>4|0;fA(d,m&65535,j+(r&15)|0,Cb(n+8|0));b=33;break R}T:{if(!(!(v[d+480180>>2]&16777250)|r)){r=w[q+1075819|0];break T}t[q+1075819|0]=r}a=r&240;if((a|0)==208){o=r&15;if(!o){if(v[d+480180>>2]&16777248){p=b;i=g;j=1;break Q}a=e;p=b;s=h;i=g;o=r;if(v[d+480180>>2]!=2){break M}break L}U:{if(o>>>0<v[d+1074392>>2]+v[d+1074408>>2]>>>0){break U}Db(n+8|0,A,14);if(!Cb(n+8|0)){break U}if(!f){break L}t[q+1075789|0]=f;break L}p=b;i=g;j=o;break Q}if(!(v[G>>2]&4096)|(a|0)!=224|(v[d+1074388>>2]?v[d+480180>>2]&16777250:0)){break S}a=r&15;if(v[d+480180>>2]&2?!a:0){break S}v[d+1074388>>2]=a+1}}p=b;i=g}a=e;s=h;o=r}V=p&255;e=(V|0)==19&v[d+480180>>2]==16&(o&240)==208;U=e?0:j;V:{if(!U|w[H|0]!=255|w[X|0]!=2){break V}Db(n+8|0,A,74);if(!Cb(n+8|0)){break V}t[X|0]=0}b=v[d+1074384>>2];Db(n+8|0,A,72);W:{if(Cb(n+8|0)){F=0;if(U>>>0>=y[d+1074408>>2]){break W}}Db(n+8|0,A,88);F=(U|0)==(_|0)|(b|0)==(U|0);if(!(!U|!Cb(n+8|0))){break W}F=(b|0)==(U|0)}Db(n+8|0,A,44);if(Cb(n+8|0)){t[K|0]=w[K|0]&254|(U|0)==(_|0)}_=o&15;b=e?_|144:o;Db(n+8|0,A,66);h=(!U|Cb(n+8|0)^1)&a;X:{Y:{if(!(v[d+1074384>>2]|(!f|!(v[G>>2]&2097152)))){v[q+1075644>>2]=0;if(F){break Y}if(!zi(l)){break X}t[q+1075789|0]=f;if(x[d+480190>>1]<f>>>0){break X}a=d+B(f,104)|0;v[q+1075672>>2]=x[a+484410>>1];u[q+1075758>>1]=t[a+484417|0];break X}if(!F){break X}}j=w[H|0];if(f){t[q+1075789|0]=f}Z:{_:{if(!ue(j)){break _}Db(n+8|0,A,67);if(!Cb(n+8|0)){break _}a=u[q+1075756>>1];$:{if(!f|h){break $}e=Nz(d,j,f);if(!e){break $}a=t[El(d,e)+36|0]}j=(a+j|0)-12>>>0>119?0:j;break Z}if(!(v[d+480180>>2]&25165856)|!x[d+480192>>1]){break Z}a=j;g=1;aa:{if(!a){break aa}g=ue(a)}if(!g){break Z}a=f;ba:{if(!a){a=w[q+1075790|0];if(!a){break ba}}if(v[(d+(a<<2)|0)+900380>>2]?x[d+480192>>1]>=a>>>0:0){break Z}j=0}f=0}if(!((V|0)!=25|b)){Db(n+8|0,A,55);a=Cb(n+8|0);f=a?0:f;j=a?0:j}Db(n+8|0,A,65);a=(f|0)!=0;e=!j;g=Cb(n+8|0);K=1;ca:{if(v[d+480180>>2]&16777248){break ca}Db(n+8|0,A,107);if(Cb(n+8|0)){break ca}Db(n,A,85);K=0;if(!Cb(n)){break ca}if(zi(l)){break ca}K=1;r=v[q+1075088>>2];if(!r){break ca}K=Od(r)^1}o=a&e;r=a&g;da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{if(!(v[d+480180>>2]&1048580)){break ka}la:{if((j|0)!=255){break la}if(!(f?0:!((V|0)==13|(i&255)==1))){Db(n+8|0,A,55);if(Cb(n+8|0)){break la}}a=v[q+1075640>>2];if(t[a+60|0]&1?a:0){break la}v[q+1075672>>2]=0;a=q+1075072|0;v[a>>2]=v[a>>2]|2097152;ma:{if(!(v[d+480208>>2]&4096)){break ma}Db(n+8|0,A,86);if(!Cb(n+8|0)){break ma}v[a>>2]=v[a>>2]|4096}f=0;j=0;e=0;a=0;g=0;o=1;if(r){break ea}break da}Db(n+8|0,A,59);if(!Cb(n+8|0)|v[G>>2]&4096){break ka}e=w[q+1075783|0]-w[q+1075756|0]|0;if(!j){break ia}if(j>>>0>250){K=0;r=1;e=0;break ia}if(!f){Db(n+8|0,A,98);r=0;if(Cb(n+8|0)){break ja}}K=1;r=1;break ja}e=0;g=0;if(!o){break ga}break ha}e=j}h=0}Db(n+8|0,A,65);if(!Cb(n+8|0)){break fa}j=e;g=1}a=j;e=g;o=1;if(r){break ea}break da}j=e;e=1;o=r}na:{oa:{if(!x[d+480192>>1]){if(x[d+480190>>1]<f>>>0){break na}a=(d+B(f,104)|0)+484380|0;break oa}a=v[q+1075088>>2];if(!a){break na}}pa:{if(u[a+34>>1]<0){break pa}if(v[d+480180>>2]==2){if(!Od(a)){break pa}}v[q+1075672>>2]=x[a+30>>1]}if(!o){break na}Mo(l,x[a+28>>1],d)}a=j;g=e}Db(n+8|0,A,71);if(!(!f|!Cb(n+8|0))){t[q+1075825|0]=32}qa:{if(!x[d+480192>>1]){break qa}Db(n+8|0,A,100);if(!f|!Cb(n+8|0)){break qa}if(ue(a&255)){break qa}e=v[G>>2];ra:{if(h){if(e&8){break ra}break qa}if(!(e&4)){break qa}}zm(l);v[q+1075680>>2]=65536;e=q+1075072|0;v[e>>2]=v[e>>2]|2097152}if(g){Db(n+8|0,A,11);sa:{if(Ma=!Cb(n+8|0),Na=0,Pa=v[d+480180>>2]!=268435456,Pa?Ma:Na){break sa}Db(n+8|0,A,87);j=0;if(Cb(n+8|0)){j=zi(l)^1}if(x[d+480192>>1]){if((j^-1)&v[q+1075640>>2]==v[(d+(f<<2)|0)+900380>>2]|x[d+480192>>1]<f>>>0){break sa}a=w[q+1075783|0];break sa}if((j^-1)&v[q+1075088>>2]==((d+B(f,104)|0)+484380|0)){break sa}a=w[q+1075783|0]}ta:{if(!x[d+480192>>1]|!(v[d+480180>>2]&1048588)){break ta}zm(l);t[q+1075804|0]=0;v[q+1075744>>2]=0;v[q+1075680>>2]=65536;e=q+1075072|0;v[e>>2]=v[e>>2]&-2101249|2097152;Db(n+8|0,A,86);if(!Cb(n+8|0)){break ta}v[e>>2]=v[e>>2]&-2049}f=K?f:0}j=a&255;ua:{if(j>>>0<251){break ua}Db(n+8|0,A,50);va:{if(!f|!Cb(n+8|0)){break va}e=Nz(d,w[q+1075785|0],f);if(!e){break va}e=d+B(e,104)|0;if(u[e+484414>>1]<0){break va}v[q+1075672>>2]=x[e+484410>>1]}Db(n+8|0,A,100);if(Ma=Cb(n+8|0),Na=0,Pa=v[G>>2]&4,Pa?Ma:Na){break ua}f=0}wa:{if(!ue(j)){break wa}t[q+1075788|0]=a;t[q+1075785|0]=a;if(!h){LP(d,m&65535,f,j,0)}e=q+1075770|0;a=u[e>>1];if(a){v[q+1075676>>2]=(a&32767)-1;if((a|0)<=-1){a=q+1075072|0;v[a>>2]=v[a>>2]|256}u[e>>1]=0}a=q+1075781|0;e=w[a|0];if(e){t[q+1075824|0]=e-1;t[a|0]=0}a=q+1075782|0;e=w[a|0];if(!e){break wa}t[q+1075823|0]=e-1;t[a|0]=0}xa:{ya:{za:{Aa:{Ba:{if(f){e=q+1075088|0;g=v[e>>2];yo(d,l,f,h,1,1);a=v[e>>2];Ca:{if(!a|!(w[a+35|0]&2)){break Ca}if(!Fd(I)){break Ca}Zq(v[I>>2],m&65535,v[e>>2]+68|0)}Da:{if(v[d+480180>>2]==1){if(h){Db(n+8|0,A,85);if(Cb(n+8|0)){break Da}}t[q+1075789|0]=0;break Da}Db(n+8|0,A,50);if(Cb(n+8|0)){if(!ue(j)){break Da}}t[q+1075789|0]=0}Db(n+8|0,A,42);if(Cb(n+8|0)){if(!ue(j)|(g|0)==v[e>>2]){break Aa}break Ba}if(!(!(v[d+480180>>2]&16777248)|(g|0)==v[e>>2])){a=0;if(ue(j)){break za}}Db(n+8|0,A,107);Ea:{if(!Cb(n+8|0)|(g|0)==v[e>>2]){break Ea}if(!h){if(ue(j)){break Ea}}a=q+1075060|0;if(y[a>>2]>=y[l+4>>2]){break Ea}v[a>>2]=0;break Aa}Db(n+8|0,A,85);if(!Cb(n+8|0)){break Aa}if(!zi(l)){break Ba}break Aa}if(!j){a=h;break xa}e=0;r=q+1075789|0;Fa:{if(!w[r|0]){break Fa}if(!ue(j)){break Fa}yo(d,l,w[r|0],h,v[q+1075088>>2]?0:!v[q+1075640>>2],!(v[d+480180>>2]&1048580));t[r|0]=0;e=1}a=h;break ya}v[l>>2]=0;v[l+4>>2]=0}a=h}e=0;if(!j){break xa}}h=q+1075088|0;g=v[h>>2];Ga:{if(!g|!(w[g+35|0]&2)){break Ga}if(!Fd(I)){break Ga}if(!e){if(MP(v[I>>2],m&65535)){break Ga}}Zq(v[I>>2],m&65535,v[h>>2]+68|0)}e=m&65535;ou(d,l,j,a,!(v[d+480180>>2]&1048580),0,e);if(!(!a|(!f|!(v[d+480180>>2]&1048580)))){f=q+1075072|0;v[f>>2]=v[f>>2]|2097152;zm(l);t[q+1075804|0]=0;v[q+1075744>>2]=0}if(!(v[q+1075072>>2]&512)){break xa}if(!Fd(I)){break xa}Ha:{switch(j-253|0){case 0:Db(n+8|0,A,99);if(Cb(n+8|0)){break xa}break;case 1:case 2:break Ha;default:break xa}}Db(n+8|0,A,110);if(Cb(n+8|0)){JA(v[I>>2],e,0,1,0)}nk(v[I>>2],e)}Ia:{Ja:{switch((i&255)-1|0){case 0:s=s>>>0<64?s:64;v[q+1075672>>2]=s<<2;f=q+1075072|0;v[f>>2]=v[f>>2]|2097152;break Ia;case 1:break Ja;default:break Ia}}Bm(d,l,s,6)}if(x[d+480192>>1]){tO(d,m&65535)}h=a}Db(n+8|0,A,77);if(Ma=Cb(n+8|0),Na=0,Pa=v[(d+(m<<5)|0)+480280>>2]&1024,Pa?Ma:Na){break L}a=v[d+1074384>>2];Db(n+8|0,A,75);g=a>>>0>=U>>>0;Ka:{La:{Ma:{Na:{if(!U|!Cb(n+8|0)){break Na}f=v[d+1074384>>2];if(!f){break Ma}g=1;if((f|0)!=(U|0)){break Na}g=!w[S|0]&(i&255)!=11}a=i&255;if(!g|a>>>0<3){break Ma}if((a|0)==11){mA(n+8|0,d,H,U);a=w[dc(n+8|0)|0];uo(d,l,v[n+8>>2]);if(a){break La}i=11;break Ma}Db(n+8|0,A,62);Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{if(!(!Cb(n+8|0)|s)){s=0;i=0;Ua:{switch(a-8|0){case 0:break Ta;case 1:break Ua;default:break Ma}}if(w[G+1|0]&16){break Ma}v[q+1075676>>2]=0;break Ma}Db(n+8|0,A,41);Va:{if(Cb(n+8|0)){break Va}if(s){t[q+1075820|0]=s;break Va}s=w[q+1075820|0]}Wa:{switch(a-3|0){case 0:case 1:Xa:{Ya:{if(s){break Ya}Db(n+8|0,A,41);if(!Cb(n+8|0)){break Ya}s=w[q+1075820|0];if(s){break Xa}s=0;break Ma}t[q+1075820|0]=s}xo(d,l,((a|0)==3?s<<4:s)&255);break Ma;case 2:if((U|0)!=v[d+1074384>>2]){Db(n+8|0,A,41);i=5;if(Cb(n+8|0)){break Ma}}Db(n+8|0,A,41);Oq(d,l,s,Cb(n+8|0));i=5;break Ma;case 3:if((U|0)!=v[d+1074384>>2]){Db(n+8|0,A,41);i=6;if(Cb(n+8|0)){break Ma}}Db(n+8|0,A,41);Nq(d,l,s,Cb(n+8|0));i=6;break Ma;case 12:break Oa;case 10:break Pa;case 9:break Qa;case 7:break Ra;case 6:break Sa;case 5:break Ta;case 4:break Wa;default:break Ma}}Db(n+8|0,A,53);if(Cb(n+8|0)){t[q+1075809|0]=s&15;i=7;break Ma}ul(l,s<<4);i=7;break Ma}ul(l,s);i=8;break Ma}Db(n+8|0,A,62);eA(d,l,s,Cb(n+8|0)^1);i=9;break Ma}Db(n+8|0,A,62);eA(d,l,s<<4&240,Cb(n+8|0)^1);i=10;break Ma}i=12;Db(n+8|0,A,12);HP(d,m&65535,s<<2&252,Cb(n+8|0));break Ma}Db(n+8|0,A,12);GP(d,m&65535,s<<2&252,Cb(n+8|0));i=13;break Ma}i=15;if(!F){break Ma}a=q+1075088|0;if(!v[a>>2]|s>>>0>9){break Ma}Za:{if(!s){f=v[q+1075648>>2];break Za}f=v[(v[a>>2]+(s<<2)|0)- -64>>2];v[q+1075648>>2]=f}Am(d,l,f)}f=b;_a:{$a:{ab:{bb:{switch(V-1|0){case 12:if(!(w[G+1|0]&16)){break La}a=d+B(m,880)|0;v[a+1075672>>2]=b>>>0<64?b<<2:256;a=a+1075072|0;v[a>>2]=v[a>>2]|2097152;break La;case 1:if(!b){f=0;if(v[d+480180>>2]&1){break Ka}}HP(d,m&65535,b,0);break La;case 2:if(!b){f=0;if(v[d+480180>>2]&1){break Ka}}GP(d,m&65535,b,0);break La;case 10:if(!b){f=0;if(v[d+480180>>2]==1){break Ka}}xo(d,l,b);break La;case 3:uo(d,l,b);break La;case 5:if(!(v[d+480180>>2]==1?!b:0)){xo(d,l,b)}uo(d,l,0);break La;case 4:ul(l,b);break La;case 6:if(!(v[d+480180>>2]==1?!b:0)){xo(d,l,b)}ul(l,0);break La;case 15:if(!(w[G+1|0]&16)){break La}break _a;case 16:Db(n+8|0,A,5);if(Cb(n+8|0)){if(!b){break La}if(v[G>>2]&4096){break _a}break La}f=Cm(d,x[d+1074438>>1],v[d+1074416>>2],m&65535,0);cb:{if(!(v[d+480180>>2]&16777250)){break cb}if(f){t[(d+B(m,880)|0)+1075821|0]=f;break cb}f=w[(d+B(m,880)|0)+1075821|0]}v[n+8>>2]=B(f,1e4);tc(n+8|0,B(v[v[d+8>>2]+24>>2],1e4));b=gb-16|0;gb=b;h=v[n+8>>2];v[b+8>>2]=h;a=d;e=v[a+8>>2];db:{if(h>>>0>=(v[a+480180>>2]&16392?1e4:32e4)>>>0){h=v[a+480208>>2];Db(b,a+1074308|0,92);if((Cb(b)|0)==((h&4096)>>>12|0)){break db}v[b>>2]=B(v[e+24>>2],1e4);v[a+1074412>>2]=v[(y[b>>2]<y[b+8>>2]?b:b+8|0)>>2];break db}if(w[a+480209|0]&16){break db}g=a+1074412|0;h=(h>>>0)/1e4|0;j=B(h&15,1e4);v[g>>2]=v[g>>2]+((h&240)==16?j:0-j|0);h=v[e+20>>2];e=v[e+24>>2];Db(b,a+1074308|0,8);Fp(g,B(h,1e4),Cb(b)?255e4:B(e,1e4))}gb=b+16|0;break Ka;case 9:if(!F|(v[d+480180>>2]==4?h:0)){break La}UP(d,l,m&65535,M);break La;case 43:if(!F){break La}f=Fpa(v[(d+B(m,880)|0)+1075060>>2],0,b,0);a=jb;j=a>>>8|0;Am(d,l,Xc((a&255)<<24|f>>>8,j));break La;case 0:if(v[d+1074384>>2]){break La}a=d+B(m,880)|0;eb:{if(w[a+1075783|0]?v[a+1075684>>2]:0){break eb}a=v[a+1075640>>2];if(a){if(uj(a)){break eb}}Db(n+8|0,A,13);if(Cb(n+8|0)){break eb}if(v[d+480180>>2]&16777248){break La}}if(!b){f=0;if(v[d+480180>>2]&5){break Ka}t[(d+B(m,880)|0)+1075791|0]=1;break Ka}a=d+B(m,880)|0;t[a+1075792|0]=b;t[a+1075791|0]=1;break La;case 14:if(v[d+480180>>2]&1048580){b=b&240?b:w[(d+B(m,880)|0)+1075793|0]&240|b;if(!(b&15)){b=w[(d+B(m,880)|0)+1075793|0]&15|b}b=b|256}f=b;Db(n+8|0,A,23);if(Cb(n+8|0)){a=d;g=m&65535;if(f){t[(d+B(m,880)|0)+1075793|0]=f;b=f}else{b=w[(d+B(m,880)|0)+1075793|0]}dA(a,g,b&255,(i&255)==15?s+1|0:0);break Ka}fb:{if(f){t[(d+B(m,880)|0)+1075793|0]=f;break fb}f=w[(d+B(m,880)|0)+1075793|0]}dA(d,m&65535,f,(i&255)==15?s+1|0:0);break Ka;case 17:if(!(w[G+1|0]&16)){break La}Db(n+8|0,A,22);gb:{hb:{if(Cb(n+8|0)){if(!b){b=0;break hb}if(w[G|0]&4){break hb}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;break hb}Db(n+8|0,A,71);if(!Cb(n+8|0)){break gb}}a=(d+B(m,880)|0)+1075825|0;t[a|0]=w[a|0]|128}a=d+B(m,880)|0;t[a+1075791|0]=18;if(!b){f=0;break Ka}t[a+1075826|0]=b;break La;case 22:if(!(w[G+1|0]&16)){break La}f=b<<!(v[d+480180>>2]&59593760);if(f>>>0<=128){v[d+1074448>>2]=f<<1;break Ka}if(v[d+480180>>2]&16777250){break Ka}v[d+1074448>>2]=256;break Ka;case 23:Db(n+8|0,A,9);if(Cb(n+8|0)){FP(d,b,(d+B(m,880)|0)+1075803|0);break La}FP(d,b,W);break La;case 8:if(!(w[G+1|0]&16)){break La}Bm(d,l,b,8);break La;case 28:eA(d,l,b,1);break La;case 7:XP(l,b);break La;case 25:YP(d,l,b);break La;case 18:a=d;i=a+1074368|0;h=m&65535;j=B(h,880);g=(i+j|0)+616|0;e=b&15;ib:{jb:{switch(b>>>4|0){case 0:if(!x[a+480188>>1]){break ib}f=(f&1)<<14;e=0;while(1){h=(a+B(e,880)|0)+1075072|0;v[h>>2]=(f|v[h>>2]&-16385)^16384;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break};break ib;case 1:if(v[a+480180>>2]&1048580?0:!e){break ib}xP(a,g,e);break ib;case 2:if(v[a+480180>>2]&1048580?0:!e){break ib}vP(a,g,e);break ib;case 3:a=(a+j|0)+1075072|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break ib;case 4:t[(a+j|0)+1075808|0]=f&7;break ib;case 5:if(!(w[a+480209|0]&16)){break ib}if(v[a+480180>>2]&69206025){f=a+B(h,880)|0;g=f+1075758|0;u[g>>1]=e<<28>>24;e=f+1075684|0;if(!v[e>>2]){break ib}if(!ne(f+1075774|0)){break ib}f=a;a=a+B(h,880)|0;Ma=e,Na=Vg(f,w[a+1075783|0],u[g>>1],v[a+1075688>>2]),v[Ma>>2]=Na;break ib}j=v[a+480180>>2];g=ne((a+B(h,880)|0)+1075774|0);if((j|0)==16){if(!g){break ib}f=a+B(h,880)|0;g=v[f+1075088>>2];if(!g){break ib}t[g+37|0]=e;u[f+1075758>>1]=e;f=f+1075684|0;if(!v[f>>2]){break ib}g=a;a=a+B(h,880)|0;Ma=f,Na=Vg(g,w[a+1075783|0],e,v[a+1075688>>2]),v[Ma>>2]=Na;break ib}if(!g){break ib}e=a+B(h,880)|0;f=(f<<4^-128)<<24>>24;u[e+1075758>>1]=f;h=e+1075684|0;if(!v[h>>2]){break ib}Ma=h,Na=Vg(a,w[e+1075783|0],f,v[e+1075688>>2]),v[Ma>>2]=Na;break ib;case 6:if(!(w[a+480209|0]&16)){break ib}pu(a,i,g,e);break ib;case 7:t[(a+j|0)+1075811|0]=f&7;break ib;case 8:if(!(w[a+480209|0]&16)){break ib}Bm(a,g,e,4);break ib;case 9:dA(a,h,e,0);break ib;case 10:if(v[a+480180>>2]&1048580?0:!e){break ib}Oq(a,g,e,0);break ib;case 11:if(v[a+480180>>2]&1048580?0:!e){break ib}Nq(a,g,e,0);break ib;case 12:fA(a,h,e,0);break ib;case 15:break jb;default:break ib}}if(v[a+480180>>2]==1){t[(a+B(h,880)|0)+1075832|0]=e;if(!(w[a+480209|0]&16)){break ib}IP(a,g);break ib}t[(a+B(h,880)|0)+1075830|0]=e}break La;case 19:Db(n+8|0,A,78);e=Cb(n+8|0);a=d;g=m&65535;f=b;kb:{if(b){break kb}f=b;if(!e){break kb}f=w[(d+B(m,880)|0)+1075792|0]}EP(a,g,f);break Ka;case 24:Db(n+8|0,A,55);if(Cb(n+8|0)){if(v[d+1074384>>2]!=(b|0)){break La}a=v[(d+B(m,880)|0)+1075640>>2];if(t[a+60|0]&1?a:0){break $a}if(!((w[X|0]?0:!w[S|0])|b)){a=(d+B(m,880)|0)+1075072|0;v[a>>2]=v[a>>2]|4096;break $a}a=d+B(m,880)|0;v[a+1075672>>2]=0;a=a+1075072|0;v[a>>2]=v[a>>2]|2097152;break $a}if(w[G+1|0]&16){break $a}break La;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break La}if(!(1<<a&880)){if(!a){break ab}if((a|0)!=1){break La}DP(d,l,b&15);break La}Db(n+8|0,A,58);if(Cb(n+8|0)){break La}EP(d,m&65535,b);break La;case 34:case 35:f=(p&255)==36;if(v[G>>2]&4096?0:!f){break La}a=m&65535;TP(d,a,M,f);f=ku(d,a);if(!f){break La}kb[v[v[f>>2]+80>>2]](f,(u[l+776>>1]+32768|0)/4|0,a);break La;case 20:if(!(v[G>>2]&4096)|b>>>0>64){break La}a=d+B(m,880)|0;v[a+1075732>>2]=b;a=a+1075072|0;v[a>>2]=v[a>>2]|2097152;break La;case 21:e=d;f=l;a=b;lb:{if(a){t[f+818|0]=a;break lb}a=w[f+818|0]}h=a&255;g=a&240;a=a&15;mb:{nb:{if(!(!g|(a|0)!=15)){a=h>>>4|0;if(!a){break mb}if(v[e+480208>>2]&4096){break nb}break mb}j=v[e+480208>>2]&4096;if(!(!a|(g|0)!=240)){if(!j){break mb}a=0-a|0;break nb}if(j){break mb}if(a){a=0-a|0;if(!g|!(v[e+480180>>2]&25690144)){break nb}break mb}a=h>>>4|0;if(!a){break mb}}Ma=f,Na=ac(v[f+748>>2]+a|0,0,64),v[Ma+748>>2]=Na}break La;case 26:WP(l,b);break La;case 29:if(!(w[G+1|0]&16)){break La}a=d+B(m,880)|0;v[a+1075708>>2]=b;Db(n+8|0,A,60);if(Ma=0,Na=Cb(n+8|0),Pa=w[a+1075714|0]&4,Pa?Ma:Na){break La}a=d+B(m,880)|0;v[a+1075724>>2]=b;v[a+1075716>>2]=b;break La;case 11:lA(d,M,m&65535);break La;case 13:a=kA(d,M,m&65535,b);if((a|0)==-1){break La}v[d+1074428>>2]=a;if(!(w[d+480208|0]&32)){break La}u[d+1074436>>1]=x[d+1074440>>1];break La;case 37:case 38:case 39:case 40:a=l;e=b;f=p&255;h=(f|0)==38|(f|0)==40;g=(p&254)==40;f=d;ob:{if(w[d+480209|0]&16){f=e&240;if(f){t[a+850|0]=f|w[a+850|0]&15}f=w[a+850|0];e=e&15;if(e){f=e|f&-16;t[a+850|0]=f}t[a+851|0]=(f&240)>>>4;break ob}e=w[a+851|0]-1|0;t[a+851|0]=e;pb:{if(e&255){break pb}e=w[a+850|0];t[a+851|0]=e>>>4;e=e&15;e=h?e:0-e|0;qb:{if(wj(a)){v[a+856>>2]=v[a+856>>2]+B(e,v[v[v[a+656>>2]+44>>2]+36>>2]);break qb}Ma=a,Na=Vg(f,ju(f,v[a+700>>2],0,0)+e|0,8363,0),v[Ma+700>>2]=Na}if(!g){break pb}v[a>>2]=0;v[a+4>>2]=0}}break La;case 41:jA(l,b);break La;case 42:break bb;default:break Ka}}if(v[d+1074384>>2]|_>>>0>2|b>>>0>31){break La}f=m;a=f;if((b&240)==16){f=0;a=x[d+480188>>1]-1|0}while(1){g=f&65535;e=(d+(g<<5)|0)+480280|0;j=v[e>>2];rb:{if((_|0)==1){j=j|67108864;h=v[(d+B(g,880)|0)+1075072>>2]|67108864;break rb}j=j&-67108865;h=v[(d+B(g,880)|0)+1075072>>2]&-67108865}v[e>>2]=j;v[(d+B(g,880)|0)+1075072>>2]=h;f=f+1|0;if((f&65535)>>>0<=(a&65535)>>>0){continue}break}break La}CP(d,l,b&15);break La}wo(d,l);break La}ZP(d,M,b)}f=b}Db(n+8|0,A,78);if(!(!f|!Cb(n+8|0))){a=f&255;t[l+842|0]=a;t[l+814|0]=a;t[l+813|0]=a;t[l+811|0]=a;t[l+809|0]=a;t[l+808|0]=a;t[l+828|0]=a>>>4;t[l+829|0]=a<<2&60}a=w[S|0];if(!a){break L}t[q+1075790|0]=a}m=m+1|0;if(m>>>0<x[d+480188>>1]){continue}break}}sb:{if(!(w[G+1|0]&16)){break sb}if(!SP(d,M,1)){break sb}v[G>>2]=v[G>>2]|524288}gb=n+16|0;a=1}gb=N+32|0;tb:{if(!a|!v[E+1074412>>2]){break tb}a=OO(E,E+1074368|0);v[E+1074372>>2]=a;v[E+1074396>>2]=a;b=Gd(x[E+480188>>1],1,31);N=E+1074328|0;ub:{if(w[N+34|0]){a=v[E+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}i=((B(v[E+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+33136|0]|0;break ub}i=v[E+480228>>2]}u[E+480212>>1]=0;n=E+1300300|0;s=E+1074308|0;M=E+480210|0;I=E+480209|0;p=0;while(1){l=E+B(p,880)|0;r=l+1075072|0;vb:{if(!(v[r>>2]&4096)|(v[l+1075008>>2]|(v[l+1075004>>2]|v[l+1075680>>2]))){break vb}Db(k+16|0,s,64);if(Cb(k+16|0)){break vb}v[l+1075060>>2]=0;a=l+1075076|0;v[a>>2]=0;v[a+4>>2]=0}b=x[E+480188>>1];wb:{xb:{a=v[r>>2];if(!(a&1024)){f=b>>>0>p>>>0;if(f|v[l+1075060>>2]){break xb}}if(b>>>0>p>>>0){BO(E,p&65535)}u[l+1075828>>1]=0;break wb}c=0;K=l+1075704|0;v[K>>2]=0;q=l+1075664|0;v[q>>2]=0;A=l+1074992|0;b=A;v[b>>2]=0;v[b+4>>2]=0;v[l+1075084>>2]=0;v[k+44>>2]=1065353216;u[k+42>>1]=0;G=l+1075684|0;c=v[G>>2]?v[l+1075060>>2]!=0:c;b=l+1074984|0;H=l+1075640|0;U=v[H>>2];yb:{zb:{Ab:{Bb:{if(!f){break Bb}if(w[(E+(p<<5)|0)+480288|0]){break zb}if(!U){break Bb}f=w[U+34|0]!=0|c;break Ab}f=c}if(!f){break yb}}v[k+8>>2]=v[l+1075672>>2];v[k+32>>2]=v[l+1075736>>2];Db(k+16|0,s,28);a=b;f=Cb(k+16|0)?k+32|0:k+8|0;e=gb-16|0;gb=e;d=E+1074308|0;Db(e+8|0,d,28);Cb:{if(Cb(e+8|0)){v[f>>2]=v[f>>2]+u[a+778>>1];Vd(f,0,64);break Cb}Db(e+8|0,d,1);h=Cb(e+8|0);d=u[a+778>>1];if(h){v[f>>2]=d+v[f>>2];Vd(f,0,256);break Cb}v[a+688>>2]=d+v[a+688>>2];Vd(a+688|0,0,256);v[f>>2]=v[a+688>>2];u[a+778>>1]=0}gb=e+16|0;f=gb-16|0;gb=f;e=E+1074308|0;Db(f+8|0,e,28);Db:{Eb:{if(!Cb(f+8|0)){Db(f,e,1);if(!Cb(f)){break Eb}}v[a+684>>2]=v[a+692>>2]+u[a+780>>1];Vd(a+684|0,0,256);break Db}v[a+692>>2]=v[a+692>>2]+u[a+780>>1];Vd(a+692|0,0,256);u[a+780>>1]=0;v[a+684>>2]=v[a+692>>2]}gb=f+16|0;d=gb-16|0;gb=d;f=E;Fb:{if(!(w[b+90|0]&4)|(v[f+480208>>2]&2101248)==2101248){break Fb}Gb:{if(v[k+8>>2]<=0){Db(d+8|0,f+1074308|0,21);if(!Cb(d+8|0)){break Gb}}h=5;if(!(v[f+480180>>2]&5)){Db(d+8|0,f+1074308|0,21);h=Cb(d+8|0)?5:6}g=Cz(f,w[a+827|0],w[a+822|0]);Hb:{if((w[a+827|0]&3)!=1){break Hb}Db(d+8|0,f+1074308|0,89);if(!Cb(d+8|0)){break Hb}g=w[a+821|0];j=w[a+822|0];e=j<<2&124;e=(!(w[a+90|0]&2)|w[f+480209|0]&16?g:w[a+825|0]+g|0)&32?e^127:e;g=j&32?0-e|0:e}e=k;if(v[f+480180>>2]!=131072){g=v[k+8>>2]+((B(w[a+829|0],g)|0)/(1<<h)|0)|0}else{h=v[k+8>>2];g=((B(w[a+829|0],B(h,64-g|0))|0)/-8192|0)+h|0}v[e+8>>2]=g}if(!(v[f+480180>>2]&16777248)|w[f+480208|0]&4?w[f+480209|0]&16:0){break Fb}Db(d+8|0,f+1074308|0,21);e=Cb(d+8|0);f=w[a+828|0];if(e){t[a+822|0]=w[a+822|0]+(f<<2);break Fb}t[a+822|0]=f+w[a+822|0]}gb=d+16|0;j=p&65535;e=j;d=gb-16|0;gb=d;a=E;f=a+1074308|0;Db(d+8|0,f,71);Ib:{if(Cb(d+8|0)){f=(a+B(e,880)|0)+1075825|0;g=t[f|0];if((g|0)>-1){break Ib}if(!(w[a+480209|0]&16|w[(a+B(e,880)|0)+1075791|0]!=18)){h=g&-33;t[f|0]=h;Jb:{Kb:{if((h|0)!=-64){h=g&223;if((h|0)!=128){break Kb}g=w[(a+B(e,880)|0)+1075826|0]>>>4|-64;break Jb}g=w[(a+B(e,880)|0)+1075826|0]&15|-128;break Jb}g=h-1|0}t[f|0]=g;f=(a+B(e,880)|0)+1075072|0;v[f>>2]=v[f>>2]|2097152}if((g&224)!=128){break Ib}v[k+8>>2]=0;break Ib}if(w[(a+B(e,880)|0)+1075791|0]!=18){break Ib}Db(d+8|0,f,22);Lb:{if(Cb(d+8|0)){m=a+B(e,880)|0;f=m+1075825|0;h=w[f|0];g=h<<24>>24;if(!((g|0)>-1|!v[m+1075060>>2])){Mb:{Nb:{if((h|0)!=192){if((h|0)!=128){break Nb}g=w[(a+B(e,880)|0)+1075826|0]>>>4|-64;break Mb}g=w[(a+B(e,880)|0)+1075826|0]&15|-128;break Mb}g=g-1|0}t[f|0]=g}if((g&192)!=128){break Lb}v[k+8>>2]=0;break Lb}f=w[(a+B(e,880)|0)+1075826|0];F=f>>>4|0;o=F+(f&15)|0;if(!(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){F=F+1|0;o=o+2|0}f=(a+B(e,880)|0)+1075825|0;g=w[f|0];if(!(v[a+480180>>2]&4)){h=(g&255)>>>0<o>>>0?g:0;if((h&255)>>>0>=F>>>0){v[k+8>>2]=0}t[f|0]=h+1;break Lb}Ob:{if(w[a+480209|0]&16){g=g&255?g-1|0:0;break Ob}t[f|0]=g+1}if(((g&255)>>>0)%(o>>>0)>>>0<F>>>0){break Lb}v[k+8>>2]=0}f=(a+B(e,880)|0)+1075072|0;v[f>>2]=v[f>>2]|2097152}f=a+B(e,880)|0;Pb:{if(w[f+1075791|0]!=18){break Pb}g=f+1075640|0;f=v[g>>2];if(!f|!w[f+34|0]|w[f+15|0]&2){break Pb}f=a+B(e,880)|0;if(v[f+1075072>>2]&134218752){break Pb}h=f+1075785|0;if(!ue(w[h|0])){break Pb}g=v[g>>2];f=v[(a+B(w[g+34|0],160)|0)+906140>>2];if(!f){break Pb}m=kb[v[v[f>>2]+100>>2]](f,w[h|0],e)|0;o=v[k+8>>2];if(!(!m|o)){kb[v[v[f>>2]+92>>2]](f,g,w[h|0]+255|0,0,e);break Pb}if(m|!o){break Pb}kb[v[v[f>>2]+92>>2]](f,g,w[h|0],x[(a+B(e,880)|0)+1075672>>1],e)}gb=d+16|0;Vd(k+8|0,0,256);a=v[k+8>>2]<<6;v[k+8>>2]=a;Qb:{Rb:{if(U){Db(k+16|0,s,31);if(Cb(k+16|0)){au(E,b)}e=gb-16|0;gb=e;f=E;a=b;Sb:{if(!Bz(f,a,0)){break Sb}d=v[a+656>>2];h=f+1074308|0;Db(e+8|0,h,31);Tb:{if(Cb(e+8|0)){f=v[a+724>>2];if(f){break Tb}break Sb}f=v[a+724>>2]}Db(e+8|0,h,31);g=d+48|0;o=f-Cb(e+8|0)|0;f=cr(g,o,256,64);m=w[d+65|0];Ub:{if((m|0)==255){break Ub}a=u[a+728>>1];if((a|0)==-1){break Ub}m=w[Mb(g,m)+2|0];g=x[Mb(g,w[d+65|0])>>1];Db(e+8|0,h,94);d=m<<2;f=(g|0)==(o|0)?d:f;if(Cb(e+8|0)){f=a+(f-d<<1)|0;break Ub}if(!m){f=0;break Ub}f=(B(a,f)|0)/(d|0)|0}Ma=k,Na=(B(v[k+8>>2],ac(f,0,512))|0)/256|0,v[Ma+8>>2]=Na}gb=e+16|0;AO(b,k+8|0);e=gb-16|0;gb=e;f=E;a=b;Vb:{if(!Bz(f,a,1)){break Vb}d=v[a+656>>2];h=f+1074308|0;Db(e+8|0,h,31);Wb:{if(Cb(e+8|0)){f=v[a+732>>2];if(f){break Wb}break Vb}f=v[a+732>>2]}Db(e+8|0,h,31);g=a;f=cr(d+68|0,f-Cb(e+8|0)|0,64,64)-32|0;a=v[a+684>>2];Ma=g,Na=ac(((B(f,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),v[Ma+684>>2]=Na}gb=e+16|0;a=b;f=v[a+656>>2];e=t[f+26|0];Xb:{if(!e){break Xb}d=w[a+799|0];if(!d){break Xb}Ma=a,Na=ac(v[a+684>>2]+((B(e,d+(w[f+27|0]^-1)|0)|0)/2|0)|0,0,256),v[Ma+684>>2]=Na}a=v[k+8>>2];break Rb}if(!(w[r+1|0]&16)){break Rb}v[l+1075680>>2]=0;v[k+8>>2]=0;break Qb}if(!a){break Qb}if(w[r+3|0]&8){v[q>>2]=0;break Qb}if(w[N+33|0]){f=B(v[k+32>>2],v[l+1075732>>2]);a=a<<8;Ma=q,Na=vc(Gpa(Fpa(f,f>>31,a,a>>31),jb,1048576,0),jb),v[Ma>>2]=Na;break Qb}f=B(v[k+32>>2],v[l+1075732>>2]);a=B(v[E+1074448>>2],a);Ma=q,Na=vc(Gpa(Fpa(f,f>>31,a,a>>31),jb,1048576,0),jb),v[Ma>>2]=Na}v[K>>2]=v[k+8>>2];Yb:{if(v[E+480180>>2]==2|v[G>>2]>=v[E+480260>>2]){break Yb}if(so(E)){break Yb}v[G>>2]=v[E+480260>>2]}Db(k+16|0,s,73);if(Cb(k+16|0)){ac(v[G>>2],1,31999)}a=v[G>>2];v[k+36>>2]=a;Zb:{if((v[r>>2]&1572864)!=1572864){break Zb}if(w[M|0]&32){if(!ru(l+1075774|0)|w[I|0]&16){break Zb}a=v[k+36>>2]}f=l+1075696|0;_b:{if(v[f>>2]==(a|0)){a=v[l+1075700>>2];break _b}v[f>>2]=a;g=a;a=l+1075758|0;f=l+1075688|0;a=Vg(E,ju(E,g,u[a>>1],v[f>>2]),u[a>>1],v[f>>2]);v[l+1075700>>2]=a}v[k+36>>2]=a}m=gb-16|0;gb=m;a=E;g=a+B(j,880)|0;f=v[g+1075640>>2];$b:{if(!f){break $b}e=w[f+34|0];if(!e|w[f+15|0]&2|(!v[(a+B(e,160)|0)+906140>>2]|v[(a+B(j,880)|0)+1075072>>2]&134218752)){break $b}e=a+B(j,880)|0;F=e+1075777|0;o=w[F|0];h=0;d=e+1075785|0;if(ue(w[d|0])){h=w[lc(f+108|0,w[d|0]-1|0)|0]}d=e+1075774|0;ac:{bc:{if((o|0)==1){f=0;cc:{dc:{switch((y[a+1074384>>2]%3|0)-1|0){case 0:f=w[(a+B(j,880)|0)+1075792|0]>>>4|0;break cc;case 1:break dc;default:break cc}}f=w[(a+B(j,880)|0)+1075792|0]&15}e=a+B(j,880)|0;t[e+1075787|0]=h;if(w[e+1075786|0]==(f+h|0)){break ac}if(!(w[a+480209|0]&16)){break bc}if(!ne(d)){break bc}break ac}f=0;if(w[d|0]|!w[(a+B(j,880)|0)+1075786|0]){break ac}}e=a+B(j,880)|0;tl(a,j,w[e+1075787|0]+f|0,x[e+1075672>>1])}e=(a+B(j,880)|0)+1075786|0;S=w[e|0];ec:{if(S){tl(a,j,S+255|0,0);break ec}if(!(w[a+480209|0]&16)|(o|0)!=1){break ec}if(ne(d)){break ec}if(!ue(h)){break ec}tl(a,j,h+255|0,0)}t[e|0]=w[F|0]==1?w[(a+B(j,880)|0)+1075787|0]+f|0:0}fc:{if(w[g+1075791|0]!=1){break fc}if(wj(g+1074984|0)){h=0;gc:{hc:{ic:{switch(y[a+1074384>>2]%3|0){case 1:h=w[(a+B(j,880)|0)+1075792|0]>>>4|0;break hc;case 0:break hc;case 2:break ic;default:break gc}}h=w[(a+B(j,880)|0)+1075792|0]&15}u[k+42>>1]=h}a=(a+B(j,880)|0)+1075837|0;t[a|0]=w[a|0]|12;break fc}if(!(!(w[a+480209|0]&16)|v[a+480180>>2]!=1048576)){f=a+B(j,880)|0;e=Vg(a,w[f+1075783|0],u[f+1075758>>1],v[f+1075688>>2]);v[k+36>>2]=e;v[f+1075684>>2]=e}h=a+1074308|0;Db(m+8|0,h,13);if(Cb(m+8|0)){h=w[(a+B(j,880)|0)+1075792|0];if(!h){break fc}e=65536;jc:{switch(((y[a+1074384>>2]%(v[a+1074392>>2]+v[a+1074408>>2]>>>0)>>>0)%3|0)-1|0){case 1:h=h<<4;case 0:e=v[((h&240)<<2)+38304>>2];break;default:break jc}}h=so(a);a=v[k+36>>2];d=a;a=a>>31;f=k;if(h){a=Fpa(d,a,e,e>>31)+32768|0;g=jb;a=Gpa(a,a>>>0<32768?g+1|0:g,65536,0)}else{g=a<<16|d>>>16;h=(e|0)/2|0;d=d<<16;a=h+d|0;g=g+(h>>31)|0;a=Gpa(a,a>>>0<d>>>0?g+1|0:g,e,e>>31)}e=jb;Ma=f,Na=vc(a,e),v[Ma+36>>2]=Na;break fc}Db(m+8|0,h,51);if(Cb(m+8|0)){if(w[a+480209|0]&16){break fc}kc:{lc:{f=v[a+1074408>>2];e=f-(y[a+1074384>>2]%(f>>>0)|0)|0;if((e|0)>16){break lc}if((e|0)==16){break fc}f=0;mc:{switch((e|0)%3|0){case 0:break fc;case 2:break lc;case 1:break mc;default:break kc}}f=w[(a+B(j,880)|0)+1075792|0]>>>4|0;break kc}f=w[(a+B(j,880)|0)+1075792|0]&15}g=f;f=a+B(j,880)|0;e=f+1075758|0;f=f+1075688|0;d=g+ju(a,v[k+36>>2],u[e>>1],v[f>>2])|0;e=Vg(a,d,u[e>>1],v[f>>2]);v[k+36>>2]=e;if(d>>>0<109){break fc}v[m+8>>2]=e;Ma=m,Na=Vg(a,109,0,v[f>>2]),v[Ma+4>>2]=Na;Ma=k,Na=v[Jc(m+8|0,m+4|0)>>2],v[Ma+36>>2]=Na;break fc}e=v[a+1074384>>2];if(v[a+480180>>2]!=1){f=w[(a+B(j,880)|0)+1075783|0]}else{f=a+B(j,880)|0;f=ju(a,v[k+36>>2],u[f+1075758>>1],v[f+1075688>>2])}nc:{oc:{switch((((v[a+480180>>2]&67633152?e+2|0:e)>>>0)%3|0)-1|0){case 0:f=(w[(a+B(j,880)|0)+1075792|0]>>>4|0)+f|0;break nc;case 1:break oc;default:break nc}}f=(w[(a+B(j,880)|0)+1075792|0]&15)+f|0}if(!(v[a+480180>>2]&67633408|w[(a+B(j,880)|0)+1075783|0]!=(f&255))){Db(m+8|0,h,82);if(!Cb(m+8|0)){break fc}}o=k;d=a;if(w[a+480210|0]&32){g=f&255;if((g|0)==85){v[k+36>>2]=2147483647;break fc}f=g>>>0>85?f-37|0:f}e=a+B(j,880)|0;Ma=o,Na=Vg(d,f&255,u[e+1075758>>1],v[e+1075688>>2]),v[Ma+36>>2]=Na;if(v[a+480180>>2]&71827712){v[e+1075684>>2]=v[k+36>>2];break fc}Db(m+8|0,h,82);if(!Cb(m+8|0)){break fc}t[(a+B(j,880)|0)+1075786|0]=f}gb=m+16|0;if(!(!(w[M|0]&33)|v[k+36>>2]==2147483647)){pc:{if(v[E+480180>>2]==2){a=452;f=3424;break pc}f=B(x[l+1075758>>1]>>>4&15,24);a=x[f+34038>>1];a=a>>>0<904?452:a>>>1|0;f=x[f+34016>>1]<<1}Vd(k+36|0,a,f);Vd(G,a,f)}Gz(E,b);a=v[r>>2]}qc:{if(!(a&256)|w[I|0]&64){break qc}Db(k+16|0,s,37);if(!Cb(k+16|0)){break qc}v[l+1075668>>2]=128}m=p&65535;BO(E,m);rc:{if(!c){break rc}a=zO(E,b,k+36|0);if((a|0)<0|!(w[r+1|0]&2)){break rc}if(!Fd(n)){break rc}_q(v[n>>2],m,a>>>2&255,1)}sc:{if(w[l+1075776|0]!=8){break sc}tc:{uc:{a=w[l+1075777|0];switch(a-5|0){case 1:break sc;case 0:case 2:break tc;default:break uc}}if((a|0)!=26){break sc}}if(v[E+480180>>2]==4){if(w[I|0]&16){break sc}a=l+1075805|0;t[a|0]=w[a|0]+w[l+1075809|0];break sc}if(!(v[E+480180>>2]&16777248)){break sc}ul(b,w[l+1075778|0]);yO(E,m,k+36|0,k+44|0)}yO(E,m,k+36|0,k+44|0);vc:{if(!c){break vc}v[k+32>>2]=0;c=E;f=k+36|0;j=gb-16|0;gb=j;a=b;g=v[a+104>>2];wc:{if(!g|!w[g+40|0]){break wc}G=wj(a);d=so(c);Db(j+8|0,c+1074308|0,21);e=d?39328:38304;h=d?38304:39328;if(!(G|!Cb(j+8|0)|v[c+480180>>2]==1048576)){if(!w[g+41|0]){break wc}o=w[a+820|0];v[j+4>>2]=v[a+760>>2]+w[g+39|0];Hl(j+4|0,w[g+40|0]<<8);F=v[j+4>>2];v[a+760>>2]=F;F=(F|0)/256|0;v[j+4>>2]=F;t[a+820|0]=w[a+820|0]+w[g+41|0];xc:{yc:{switch(w[g+38|0]-1|0){case 3:c=vO(vo(c))+-64|0;F=v[j+4>>2];break xc;case 2:c=64-(o+1>>>1|0)|0;break xc;case 1:c=(o+1>>>1|0)+-64|0;break xc;case 0:c=(o>>>1^-1)&64;break xc;default:break yc}}c=t[o+34608|0]}Hl(f,8388607);g=v[f>>2]<<8;v[f>>2]=g;F=B(c,F);c=(F|0)/64|0;a=c>>31;o=a^a+c;c=o>>>2|0;a=f;zc:{if((F|0)<=-64){c=v[(c<<2)+e>>2];g=vc(Gpa(Fpa(c,c>>31,g,g>>31),jb,65536,0),jb);c=v[f>>2];h=g-c|0;e=h;g=o&3;if(!g){break zc}e=v[(g<<2)+(d?38240:38176)>>2];g=vc(Gpa(Fpa(e,e>>31,c,c>>31),jb,65536,0),jb)+h|0;c=v[f>>2];e=g-c|0;break zc}c=v[h+(c<<2)>>2];g=vc(Gpa(Fpa(c,c>>31,g,g>>31),jb,65536,0),jb);c=v[f>>2];h=g-c|0;e=h;g=o&3;if(!g){break zc}e=v[(g<<2)+(d?38176:38240)>>2];g=vc(Gpa(Fpa(e,e>>31,c,c>>31),jb,65536,0),jb)+h|0;c=v[f>>2];e=g-c|0}v[a>>2]=(c+e|0)/256;v[k+32>>2]=e&255;break wc}Ac:{if(!(w[g+39|0]|v[c+480180>>2]&16777248)){v[a+760>>2]=w[g+40|0]<<8;break Ac}Bc:{Cc:{if(v[c+480180>>2]&16777248){F=w[g+39|0]<<1;o=v[a+760>>2];d=a+760|0;break Cc}if(w[a+89|0]&8){break Bc}o=((w[g+40|0]<<8&65280)>>>0)/w[g+39|0]|0;F=v[a+760>>2];d=a+760|0}v[d>>2]=o+F}Hl(a+760|0,w[g+40|0]<<8)}d=w[a+820|0]+w[g+41|0]|0;t[a+820|0]=d;d=d<<24>>24;Dc:{Ec:{switch(w[g+38|0]-1|0){case 3:t[a+820|0]=d+1;o=t[(d&63)+34544|0];break Dc;case 2:o=(64-(d>>>1|0)&127)+-64|0;break Dc;case 1:o=((d>>>1|0)- -64&127)+-64|0;break Dc;case 0:o=(d|0)>-1?-64:64;break Dc;default:break Ec}}d=w[a+820|0];o=0-t[d+34608|0]|0;if(v[c+480180>>2]!=1048576){break Dc}o=(64-t[(d+-64&255)+34608|0]|0)/2<<16>>16}d=o;F=B(d,v[a+760>>2]);o=(F|0)/256|0;if(G){z[k+44>>2]=C(C(C(d|0)*C(1220703143189894e-20))*C(w[g+40|0]))+z[k+44>>2];t[a+853|0]=w[a+853|0]|8;break wc}if(v[c+480180>>2]!=4){Fc:{if((F|0)<=-256){o=0-o|0;c=0-F>>>16|0;a=(c<<2)+e|0;break Fc}e=h;c=(F|0)/65536|0;a=e+(c<<2)|0}d=v[f>>2];a=v[a>>2];a=((B(v[((c<<2)+e|0)+4>>2]-a|0,(o|0)/4&63)|0)/64|0)+a|0;a=vc(Gpa(Fpa(d,d>>31,a,a>>31),jb,256,0),jb);v[f>>2]=a;v[k+32>>2]=a&255;v[f>>2]=v[f>>2]/256;break wc}v[f>>2]=v[f>>2]+((F|0)/16384|0)}gb=j+16|0;if(v[k+36>>2]<=v[E+480260>>2]){Db(k+16|0,s,81);if(Cb(k+16|0)){v[l+1075060>>2]=0}v[k+36>>2]=v[E+480260>>2]}Gc:{if(!wj(b)){break Gc}a=l+1075837|0;c=w[a|0];if(v[E+1074384>>2]|!(c&4)?!(c&8):0){break Gc}KS(b,z[k+44>>2],u[k+42>>1],E);c=w[a|0];if(!(c&8)){t[a|0]=c&251;break Gc}t[a|0]=c&247}Fz(k+16|0,E,b,v[k+36>>2],v[k+32>>2]);c=Fpa(v[k+16>>2],v[k+20>>2],v[E+480240>>2],0);j=jb;f=Gpa(c,j,65536,0);e=jb;a=k;c=c+65535|0;j=c>>>0<65535?j+1|0:j;c=!j&c>>>0<131071;f=c?1:f;v[a+16>>2]=f;a=c?0:e;v[k+20>>2]=a;v[A>>2]=f;v[A+4>>2]=a;if((v[r>>2]&134219264)!=512){break vc}if(!Fd(n)){break vc}Db(k+8|0,s,99);if(!(Ma=!(Cb(k+8|0)|!(w[r+1|0]&16)),Na=0,Pa=v[E+480180>>2]!=2,Pa?Ma:Na)){Hc:{if(w[r+1|0]&8?v[E+480180>>2]==2:0){break Hc}a=Fpa(v[k+24>>2],0,261625,0)+66904|0;e=jb;c=Xc(Ipa(a,a>>>0<66904?e+1|0:e,133808,0),jb);f=v[r>>2];a=1;Ic:{if(f&2048){break Ic}a=0;if(!(f&4096)){break Ic}a=!v[l+1075680>>2]}Db(k+8|0,s,110);if(Cb(k+8|0)?a:0){break Hc}f=v[n>>2];Db(k+8|0,s,95);JA(f,m,c,a,Cb(k+8|0))}c=v[n>>2];a=Fpa(B(v[l+1075736>>2],B(v[l+1075732>>2],v[K>>2])),0,63,0)+33554432|0;j=jb;j=a>>>0<33554432?j+1|0:j;_q(c,m,Xc((j&67108863)<<6|a>>>26,j>>>26|0)&255,0);a=l+1075668|0;d=a;c=v[a>>2];e=0;a=v[n>>2];f=zl(a,m);Jc:{if((f|0)==255){break Jc}if(ok(a)){break Jc}e=lc(Um(a+314|0,f),10);g=v[a>>2];f=Bu(f)|192;a=w[e|0]&-49;a=(c|0)<171?a|16:a;a=((c|0)>84?a|32:a)&255;Rh(g,f,a);e=(a>>>5&1)+(a<<27>>31)|0}v[d>>2]=(e<<7)+128}Kc:{a=v[H>>2];if(!a|(w[a+60|0]&7)!=1){break Kc}a=a+48|0;if(cd(a)){break Kc}c=v[xO(b,0)>>2];a=qo(a);if(c>>>0<x[a>>1]|w[a+2|0]){break Kc}Qh(v[n>>2],m,1);Db(k+8|0,s,109);a=Cb(k+8|0);c=v[r>>2];if(!a){c=c&-513;v[r>>2]=c}v[r>>2]=c|4096;v[l+1075680>>2]=0;break vc}Db(k+8|0,s,99);if(!Cb(k+8|0)|!(w[r+1|0]&16)|v[l+1075680>>2]){break vc}Qh(v[n>>2],m,1);v[r>>2]=v[r>>2]&-513}Lc:{if(!U){break Lc}Db(k+16|0,s,31);if(Cb(k+16|0)){break Lc}au(E,b)}g=l+1075004|0;j=l+1075008|0;v[r>>2]=v[r>>2]&-65537|((v[g>>2]|(v[j>>2]|v[q>>2]))!=0)<<16;a=l+1075656|0;v[a>>2]=0;v[a+4>>2]=0;e=l+1075828|0;f=w[e|0];c=f-4|0;t[e|0]=c>>>0>f>>>0?0:c;d=l+1075829|0;f=w[d|0];c=f-4|0;t[d|0]=c>>>0>f>>>0?0:c;Mc:{Nc:{Oc:{Pc:{Qc:{c=l+1075088|0;f=v[c>>2];Rc:{if(!f){break Rc}if(!Od(f)|!v[l+1075060>>2]){break Rc}if(zi(b)){break Qc}}h=l+1075e3|0;v[h>>2]=0;break Pc}h=l+1075e3|0;c=v[v[c>>2]+20>>2];v[h>>2]=c;if(c){break Oc}}if(!kk(b)|w[r+1|0]&24){break Nc}}o=v[q>>2];m=v[l+1075668>>2];c=(B(o,256-m|0)|0)/16384|0;f=c>>>0<127?c:127;c=t[e|0];if((c|0)<=-1){t[e|0]=f;ba=f}else{ba=c}c=f>>>1|0;if((ba&255)>>>0<c>>>0){t[e|0]=c}c=(B(m,o)|0)/16384|0;f=c>>>0<127?c:127;c=t[d|0];if((c|0)<=-1){t[d|0]=f;e=f}else{e=c}c=f>>>1|0;if((e&255)>>>0>=c>>>0){break Mc}t[d|0]=c;break Mc}if(w[e|0]>=129){t[e|0]=0}if(w[d|0]<129){break Mc}t[d|0]=0}Sc:{if(v[h>>2]){c=l+1075660|0;Tc:{if(y[E+24624>>2]>=2){v[k+16>>2]=v[l+1075668>>2];Vd(k+16|0,0,256);d=B(i,v[q>>2])>>>(w[N+34|0]?7:8)|0;j=c;Uc:{Vc:{Wc:{switch(w[N+32|0]){case 0:if(!(w[E+24616|0]&16)){break Vc}case 1:e=v[k+16>>2];if((e|0)<=127){v[a>>2]=d>>>1;f=(B(d,e)|0)/256|0;break Uc}v[a>>2]=(B(d,256-e|0)|0)/256;f=d>>>1|0;break Uc;case 3:break Wc;default:break Vc}}Hl(k+16|0,255);f=a;g=v[k+16>>2];e=d<<16;Xc:{if((g|0)<=0){break Xc}e=B(d,x[(0-g<<1)+40864>>1])}v[f>>2]=e>>>16;f=B(d,x[(g<<1)+40352>>1])>>>16|0;break Uc}e=v[k+16>>2];v[a>>2]=(B(d,256-e|0)|0)/256;f=(B(d,e)|0)/256|0}v[j>>2]=f;break Tc}f=B(i,v[q>>2])>>>8|0;v[a>>2]=f;v[c>>2]=f}h=l+1075780|0;f=h;Yc:{Zc:{e=v[H>>2];if(!e){break Zc}if(!xp(w[e+14|0])){break Zc}e=w[v[H>>2]+14|0];break Yc}if(xp(w[E+480268|0])){e=w[E+480268|0];break Yc}if(w[M|0]&128){e=255;if(v[E+24668>>2]){break Yc}}e=w[E+24648|0]}t[f|0]=e;d=v[r>>2];f=v[A>>2];g=v[A+4>>2];if(!(v[l+1075744>>2]|(d&131072|((f|0)!=0|(g|0)!=1)|(e|0)==255))){t[h|0]=0}e=a;j=v[a>>2];a=1<<v[N+28>>2];v[e>>2]=(j|0)/(a|0);a=v[c>>2]/(a|0)|0;v[c>>2]=a;if(!(!(d&256)|v[E+24624>>2]!=2)){v[c>>2]=0-a}if(d&128){v[A>>2]=0-f;v[A+4>>2]=0-(((f|0)!=0)+g|0)}d=E;f=gb-16|0;gb=f;a=b;v[a+28>>2]=0;v[a+32>>2]=0;h=a;_c:{$c:{g=v[a+88>>2];if(!(g&65536)){b=v[a+676>>2];c=v[a+672>>2];break $c}c=v[a+20>>2];m=v[a+672>>2];ad:{if((c|0)!=(m|0)){b=v[a+24>>2];e=v[a+676>>2];break ad}b=v[a+24>>2];e=v[a+676>>2];if((b|0)==(e|0)){break $c}}j=d+24604|0;g=f;e=(c|0)<(m|0)|(b|0)<(e|0);bd:{if(e){c=NS(j);break bd}c=MS(j)}v[g+12>>2]=c;Db(f,d+1074308|0,4);if(!(!Cb(f)|!(v[d+480180>>2]&4))){b=v[d+24620>>2];b=Fpa(b,b>>31,5,0)+500|0;g=jb;c=vc(Gpa(b,b>>>0<500?g+1|0:g,1e3,0),jb);v[f+12>>2]=c}b=!e;e=v[a+656>>2];cd:{if(!(b|!e)){b=c;e=x[e+12>>1];if(e){b=(B(e,v[d+24620>>2])>>>0)/1e5|0}j=(e|0)!=0;break cd}b=v[f+12>>2];j=0}m=b?b:1;g=v[a+676>>2];b=v[a+24>>2];o=g-b<<12;e=v[a+672>>2];F=v[a+20>>2];q=e-F<<12;if(!(w[a+90|0]&32|(!(b|F)|(j|!(e|g))))){v[f+12>>2]=v[d+1074372>>2];Vd(f+12|0,c,2048);g=v[a+676>>2];m=v[f+12>>2];e=v[a+672>>2]}d=(o|0)/(m|0)|0;v[a+32>>2]=d;j=(q|0)/(m|0)|0;v[a+28>>2]=j;b=((B(d,m)|0)/-4096|0)+g|0;v[a+24>>2]=b;c=((B(j,m)|0)/-4096|0)+e|0;v[a+20>>2]=c;if(d|j){v[a+100>>2]=m;g=v[a+88>>2];break _c}v[a+24>>2]=g;v[a+20>>2]=e;b=g;c=e;g=v[a+88>>2]&-65537;break _c}v[a+24>>2]=b;v[a+20>>2]=c;g=g&-65537}v[h+88>>2]=g&-2097153;v[a+40>>2]=b<<12;v[a+36>>2]=c<<12;gb=f+16|0;if(w[r+1|0]&2){break Sc}a=x[E+480212>>1];u[E+480212>>1]=a+1;u[(E+(a<<1)|0)+1074470>>1]=p;break Sc}v[g>>2]=0;v[j>>2]=0;v[l+1075060>>2]=0;if(v[l+1075076>>2]?0:!v[l+1075080>>2]){break Sc}a=x[E+480212>>1];u[E+480212>>1]=a+1;u[(E+(a<<1)|0)+1074470>>1]=p}v[l+1075652>>2]=v[r>>2]}p=p+1|0;if((p|0)!=256){continue}break}c=1;if(y[E+24608>>2]>x[E+480212>>1]){break tb}a=E+1074470|0;b=a;e=a+(v[E+24608>>2]<<1)|0;g=a+(x[E+480212>>1]<<1)|0;d=gb-16|0;gb=d;v[d+8>>2]=E;h=d+8|0;j=h;f=e-a|0;if((f|0)>=3){i=f>>1;f=(i-2|0)/2|0;while(1){yz(a,j,i,a+(f<<1)|0);p=(f|0)>0;f=f-1|0;if(p){continue}break}}if((e|0)!=(g|0)){f=e-b>>1;a=e;while(1){if(Cq(h,x[a>>1],x[b>>1])){zz(a,b);yz(b,h,f,b)}a=a+2|0;if((g|0)!=(a|0)){continue}break}}a=e-b|0;if((a|0)>=3){a=a>>>1|0;while(1){zz(b,e-2|0);yz(b,h,a-1|0,b);e=e-2|0;f=(a|0)>2;a=a-1|0;if(f){continue}break}}gb=d+16|0}gb=k+48|0;if(c){a=v[J+480208>>2];break k}b=v[J+480208>>2]|512;if(w[J+1300420|0]){break l}c=0;a=v[J+24620>>2]/10|0;f=vc(a,a>>31);dd:{if(!f){break dd}b=f>>>0<1048576?f:1048576;v[E+1074372>>2]=b;d=x[E+480212>>1];if(!d){break dd}e=E+1074368|0;while(1){a=e+B(x[(e+(c<<1)|0)+102>>1],880)|0;h=a+1288|0;v[h>>2]=0;v[h+4>>2]=0;v[a+716>>2]=b;h=v[a+640>>2]<<12;v[a+656>>2]=h;g=v[a+636>>2]<<12;v[a+652>>2]=g;v[a+704>>2]=v[a+704>>2]|65536;v[a+644>>2]=(0-g|0)/(b|0);v[a+648>>2]=(0-h|0)/(b|0);c=c+1|0;if((d|0)!=(c|0)){continue}break}}a=v[J+480208>>2];b=a|256;if(f){break l}b=a|512}a=b;v[aa+480208>>2]=a}if(a&512){Ma=J+1074384|0,Na=lk(Da),v[Ma>>2]=Na;break j}v[$+16>>2]=512;a=v[J+1074372>>2];v[$+12>>2]=3;v[$+24>>2]=ga;v[$+20>>2]=a;v[$+8>>2]=$+16;a=v[$+12>>2];v[$>>2]=v[$+8>>2];v[$+4>>2]=a;E=FX($);if(v[J+24632>>2]){b=J;c=na;j=0;a=gb-16|0;gb=a;f=E;d=f<<2;while(1){v[a>>2]=0;e=a;g=(b+(j<<11)|0)+16396|0;i=(g+d|0)-g>>2;if((i|0)>=1){while(1){v[g>>2]=v[e>>2];g=g+4|0;h=(i|0)>1;i=i-1|0;if(h){continue}break}}j=j+1|0;if((j|0)!=4){continue}break}j=0;while(1){v[a+(j<<2)>>2]=(b+(j<<11)|0)+16396;j=j+1|0;if((j|0)!=4){continue}break}kb[v[v[c>>2]+8>>2]](c,a,v[b+24632>>2],f);gb=a+16|0}k=J;ja=0;d=gb-112|0;gb=d;p=E;if(p){o=k+12|0;s=k+24592|0;F=k+24588|0;Oo(o,p,s,F);if(y[k+24624>>2]>=3){Oo(k+8204|0,p,k+24600|0,k+24596|0)}u[d+30>>1]=0;oa=k+1074308|0;Db(d+8|0,oa,33);a=Cb(d+8|0);i=x[k+480212>>1];if(i){Ea=a?2:1;Fa=k+24648|0;Y=k+24596|0;n=k+24600|0;q=k+8204|0;A=k+397460|0;G=k+397456|0;N=k+393352|0;ta=k+1074368|0;while(1){j=ta+(ja<<1)|0;a=B(x[j+102>>1],880);e=a+ta|0;S=e;ed:{fd:{if(v[e+632>>2]){break fd}b=a+k|0;if(v[b+1075080>>2]){break fd}if(!v[b+1075076>>2]){break ed}}m=a+k|0;a=w[m+1075780|0]+1|0;gd:{if((a&255)>>>0<=5){i=v[(a<<24>>24<<2)+28096>>2];break gd}i=0}I=m+1075072|0;g=v[I>>2];r=g&1;hd:{if(!(g&8388608)){b=F;f=s;c=g;a=o;if(!(!(g&16777216)&(w[k+24612|0]&32)>>>5)){break hd}}b=p;a=N;if(!v[a+4116>>2]){Oo(a+8|0,b,a+4104|0,a+4108|0)}v[a+4116>>2]=1;c=v[I>>2];b=A;f=G;a=a+8|0}if(!(!(c&256)|y[k+24624>>2]<3)){f=n;b=Y;a=q}h=e+616|0;ca=ym(k,x[j+102>>1],2,1);id:{if((!ca|0)==(ca>>>0<251|0)){break id}e=v[(k+B(ca,160)|0)+906140>>2];if(!e){break id}c=v[e+24>>2];if(!c){break id}b=e+36|0;f=e+40|0;if(!(t[e+28|0]&1)){Oo(c,p,f,b);v[e+28>>2]=v[e+28>>2]|1}a=c}fa=0;c=d+8|0;e=c;v[e>>2]=0;v[e+4>>2]=0;v[e+8>>2]=0;v[e+12>>2]=0;e=h;if(v[e+16>>2]){bF(c,e);l=v[e+12>>2];U=l;j=l>>31;H=l>>31;l=H+v[e+8>>2]|0;e=j+U|0;e=l>>>0<H>>>0?e+1|0:e;e=e^j;v[c+12>>2]=e>>>0>8191?2:16384/(e+1>>>0)|0}l=g>>>12&8|(g>>>5&2|(i|r));ua=m+1075789|0;Ga=m+1075772|0;Ha=m+1075680|0;Ia=m+1075016|0;Ja=m+1075012|0;Ka=m+1075660|0;La=m+1075656|0;K=m+1074992|0;X=m+1075080|0;V=m+1075076|0;va=m+1075008|0;wa=m+1075004|0;ka=m+1075088|0;da=m+1075068|0;H=m+1075060|0;la=m+1075064|0;_=m+1075084|0;U=c;c=p;while(1){jd:{e=v[_>>2];e=e?c>>>0>e>>>0?e:c:c;v[d+68>>2]=e;aa=v[la>>2];M=v[I>>2];i=v[K+4>>2];g=v[K>>2];v[d+56>>2]=g;v[d+60>>2]=i;kd:{ld:{if(!e|!(g|i)){break ld}r=v[H>>2];if(!r){break ld}v[S+632>>2]=v[d+8>>2];W=v[h+4>>2];j=W;e=v[h>>2];m=aa&M<<30>>31;md:{if((m|0)>(j|0)){if((i|0)<-1?1:(i|0)<=-1){v[d+104>>2]=0;g=m;v[d+108>>2]=g<<1;e=Hg(d+104|0,h);i=jb;j=i;v[h>>2]=e;v[h+4>>2]=j;if(!(j>>>0<g+v[H>>2]>>>1>>>0?(g|0)<=(j|0):0)){e=0;v[h>>2]=e;j=g;v[h+4>>2]=g}M=v[d+60>>2];W=v[d+56>>2];i=W;g=0-(M+((i|0)!=0)|0)|0;i=0-i|0;v[d+56>>2]=i;v[d+60>>2]=g;v[K>>2]=i;v[K+4>>2]=g;g=v[I>>2];nd:{if(g&4){i=g&-129;v[I>>2]=i;break nd}i=g|128;v[I>>2]=i;g=v[H>>2]-1|0;j=g;v[h>>2]=e;v[h+4>>2]=g;v[K>>2]=W;v[K+4>>2]=M}od:{if(!(i&2)){i=v[H>>2];break od}i=v[H>>2];if(j>>>0<i>>>0){break md}}e=h;v[e>>2]=0;v[e+4>>2]=i;break ld}if((W|0)>-1){break md}g=0;j=g;v[h>>2]=e;v[h+4>>2]=g;break md}if(r>>>0>W>>>0){break md}if(!(M&2)){break ld}if(M&4){if((i|0)>0?1:(i|0)>=0?g>>>0>=1:0){j=0-(((g|0)!=0)+i|0)|0;g=0-g|0;v[d+56>>2]=g;v[d+60>>2]=j;v[K>>2]=g;v[K+4>>2]=j}v[I>>2]=M|128;g=1-((e|0)!=0)|0;e=0-e|0;M=(r<<1)-(g+W|0)|0;g=M;j=g;v[h>>2]=e;v[h+4>>2]=g;if(r>>>0>g>>>0?g>>>0>aa>>>0:0){break md}v[d+104>>2]=Ea;g=r-v[Gb(H,d+104|0)>>2]|0;e=v[h>>2];v[h>>2]=e;j=g;v[h+4>>2]=g;break md}if((i|0)<-1?1:(i|0)<=-1){e=0-(((g|0)!=0)+i|0)|0;g=0-g|0;v[d+56>>2]=g;v[d+60>>2]=e;v[K>>2]=g;v[K+4>>2]=e}v[d+104>>2]=0;v[d+108>>2]=m-r;Sb(h,d+104|0);v[I>>2]=v[I>>2]|8192;e=v[h>>2];j=v[h+4>>2]}v[d+48>>2]=e;g=j;v[d+52>>2]=g;pd:{qd:{aa=g;if((g|0)<(m|0)){i=0;if((j|0)<0|v[d+60>>2]<0){break pd}break qd}if((j|0)>0?1:(j|0)>=0){break qd}i=0;break pd}i=0;if(aa>>>0>=y[H>>2]){break pd}xa=v[d+68>>2];v[d+44>>2]=xa;g=v[d+56>>2];i=v[d+60>>2];tc(d+68|0,v[d+20>>2]);Ma=d,Na=sw(d+56|0,v[d+68>>2]-1|0),v[Ma+32>>2]=Na;v[d+36>>2]=jb;W=i>>31;r=W+g|0;g=i;i=i>>31;g=g+i|0;g=r>>>0<W>>>0?g+1|0:g;ba=r;M=g;g=v[d+36>>2]+v[d+52>>2]|0;ia=v[d+48>>2];r=ia+v[d+32>>2]|0;g=r>>>0<ia>>>0?g+1|0:g;r=v[la>>2];ia=r>>>0<=aa>>>0&aa>>>0<r+16>>>0;if(!ia){v[I>>2]=v[I>>2]&-8193}W=W^ba;M=i^M;i=g;rd:{sd:{td:{if(!v[d+12>>2]){aa=v[d+60>>2];break td}g=v[d+16>>2];if(g>>>0<=aa>>>0){i=d;m=v[d+60>>2];ud:{if((m|0)<-1?1:(m|0)<=-1){v[d+96>>2]=e;v[d+100>>2]=j;v[d+104>>2]=0;v[d+108>>2]=g;Ma=d,Na=Hg(d+96|0,d+104|0),v[Ma+80>>2]=Na;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Ma=d,Na=Hg(d+80|0,d+72|0),v[Ma+88>>2]=Na;v[d+92>>2]=jb;g=wn(d+88|0,W,M);break ud}g=v[da>>2];v[d+104>>2]=e;v[d+108>>2]=j;v[d+96>>2]=0;v[d+100>>2]=g;Ma=d,Na=Hg(d+96|0,d+104|0),v[Ma+80>>2]=Na;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Ma=d,Na=Hg(d+80|0,d+72|0),v[Ma+88>>2]=Na;v[d+92>>2]=jb;g=wn(d+88|0,W,M)}v[i+44>>2]=g+1;v[S+632>>2]=v[d+12>>2];break rd}if(!(!ia|!(w[I+1|0]&32))){v[d+104>>2]=e;v[d+108>>2]=j;v[d+96>>2]=0;v[d+100>>2]=m+16;Ma=d,Na=Hg(d+96|0,d+104|0),v[Ma+80>>2]=Na;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Ma=d,Na=Hg(d+80|0,d+72|0),v[Ma+88>>2]=Na;v[d+92>>2]=jb;Ma=d,Na=wn(d+88|0,W,M)+1|0,v[Ma+44>>2]=Na;Ma=S,Na=v[d+12>>2]+B(v[da>>2]-m|0,Wi(v[ka>>2]))|0,v[Ma+632>>2]=Na;break rd}ba=v[d+60>>2];aa=ba;if((aa|0)<0?1:(aa|0)<=0?y[d+56>>2]<1:0){break td}if(xa>>>0<2|g>>>0>i>>>0){break sd}v[d+104>>2]=e;v[d+108>>2]=j;v[d+96>>2]=0;v[d+100>>2]=g;Ma=d,Na=Hg(d+96|0,d+104|0),v[Ma+80>>2]=Na;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Ma=d,Na=Hg(d+80|0,d+72|0),v[Ma+88>>2]=Na;v[d+92>>2]=jb;Ma=d,Na=wn(d+88|0,W,M)+1|0,v[Ma+44>>2]=Na;break rd}if((aa|0)>-1){break sd}if((i|0)>=(m|0)){break rd}v[d+96>>2]=e;v[d+100>>2]=j;v[d+104>>2]=0;v[d+108>>2]=r;Ma=d,Na=Hg(d+96|0,d+104|0),v[Ma+80>>2]=Na;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Ma=d,Na=Hg(d+80|0,d+72|0),v[Ma+88>>2]=Na;v[d+92>>2]=jb;Ma=d,Na=wn(d+88|0,W,M)+1|0,v[Ma+44>>2]=Na;break rd}g=v[H>>2];if((g|0)>(i|0)){break rd}v[d+104>>2]=e;v[d+108>>2]=j;v[d+96>>2]=0;v[d+100>>2]=g;Ma=d,Na=Hg(d+96|0,d+104|0),v[Ma+80>>2]=Na;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Ma=d,Na=Hg(d+80|0,d+72|0),v[Ma+88>>2]=Na;v[d+92>>2]=jb;Ma=d,Na=wn(d+88|0,W,M)+1|0,v[Ma+44>>2]=Na}Fp(d+44|0,1,v[d+68>>2]);i=v[d+44>>2]}if((i|0)>0){break kd}}v[S+632>>2]=0;v[H>>2]=0;v[h>>2]=0;v[h+4>>2]=0;v[_>>2]=0;r=0;e=v[h+96>>2];i=v[h+92>>2];if(e|i){if(c){while(1){g=jd((jd(0-i|0,31)&255)+i|0,8);j=jd((jd(0-e|0,31)&255)+e|0,8);m=r<<3;l=m+a|0;i=i-g|0;v[l>>2]=i+v[l>>2];g=(m|4)+a|0;e=e-j|0;v[g>>2]=e+v[g>>2];r=r+1|0;if((r|0)!=(c|0)){continue}break}}v[h+96>>2]=e;v[h+92>>2]=i}v[f>>2]=v[f>>2]+v[V>>2];v[b>>2]=v[b>>2]+v[X>>2];v[X>>2]=0;v[V>>2]=0;v[I>>2]=v[I>>2]&-129;break jd}vd:{wd:{if(y[k+24608>>2]<=x[d+30>>1]){break wd}if(v[_>>2]){e=l|4}else{if(!(v[va>>2]|v[wa>>2])){break wd}e=l}g=(i<<3)+a|0;j=g-8|0;v[V>>2]=0-v[j>>2];m=g-4|0;v[X>>2]=0-v[m>>2];kb[v[(e<<2)+27712>>2]](h,Fa,a,i);v[V>>2]=v[V>>2]+v[j>>2];v[X>>2]=v[X>>2]+v[m>>2];fa=1;a=g;break vd}Ma=d,Na=Fpa(v[K>>2],v[K+4>>2],i,i>>31),v[Ma+104>>2]=Na;v[d+108>>2]=jb;Sb(h,d+104|0);fa=0;v[X>>2]=0;v[V>>2]=0;a=(i<<3)+a|0}e=v[_>>2];xd:{if(!e){break xd}if(e>>>0<=i>>>0){v[_>>2]=0;v[wa>>2]=v[La>>2];v[va>>2]=v[Ka>>2];v[Ja>>2]=0;v[Ia>>2]=0;if(v[Ha>>2]|!(w[I+1|0]&16)){break xd}v[H>>2]=0;v[S+632>>2]=0;break xd}v[_>>2]=e-i}e=0;r=0;g=v[h+4>>2];r=g>>>0>=y[da>>2]?(w[I|0]&2)>>>1|0:r;j=g;g=v[H>>2];e=j>>>0<g>>>0|(!g|w[I|0]&2)?e:!x[Ga>>1];c=c-i|0;Db(d+104|0,oa,85);yd:{zd:{Ad:{Bd:{if(!Cb(d+104|0)){break Bd}g=w[ua|0];if(!g|g>>>0>x[k+480190>>1]){break Bd}i=!(e|r);j=v[ka>>2];e=k+B(w[ua|0],104)|0;g=e+484380|0;if(i|(j|0)==(g|0)){break Ad}v[ka>>2]=g;v[S+632>>2]=v[e+484400>>2];g=x[e+484414>>1];v[I>>2]=g|v[I>>2]&-768;j=g<<30>>31;g=v[e+484388>>2];v[H>>2]=j&g;e=v[e+484384>>2];v[la>>2]=e;v[da>>2]=g;v[h+4>>2]=e;bF(U,h);if(!v[S+632>>2]){break jd}if((c|0)>0){continue}break jd}if(r){break zd}break yd}if(!r|(g|0)!=(j|0)){break yd}}Db(d+104|0,oa,83);if(!Cb(d+104|0)|v[la>>2]){break yd}v[h>>2]=v[h>>2];v[h+4>>2]=0;e=v[v[ka>>2]+8>>2];v[H>>2]=e;v[da>>2]=e}if((c|0)>0){continue}}break}v[S+632>>2]=v[d+8>>2];u[d+30>>1]=x[d+30>>1]+fa;Cd:{if(!ca|!fa|ca>>>0>250){break Cd}a=v[(k+B(ca,160)|0)+906140>>2];if(!a){break Cd}kb[v[v[a>>2]+148>>2]](a)}i=x[k+480212>>1]}ja=ja+1|0;if(ja>>>0<(i&65535)>>>0){continue}break}}Ma=k,Na=x[Le(k+480214|0,d+30|0)>>1],u[Ma+480214>>1]=Na}gb=d+112|0;if(Fd(sa)){c=ha;a=E;b=(B(v[J+480232>>2],v[J+480236>>2])>>>0)/48|0;l=gb-16|0;gb=l;A=v[sa>>2];Dd:{if(!w[A+530|0]){break Dd}f=Fpa(b,0,6169,0);b=jb;g=b>>>16|0;n=Xc((b&65535)<<16|f>>>16,g);if(!a){break Dd}while(1){b=v[A>>2];f=v[b>>2];e=v[b+4>>2];if((f|0)<=(e|0)){d=b+14|0;h=b+12|0;while(1){v[b+8>>2]=v[b+12>>2];f=b;g=h;j=d;s=0;m=0;r=0;e=gb-16|0;gb=e;while(1){p=f+B(r,44)|0;Ed:{if(!w[p+56|0]){u[e+12>>1]=0;u[e+14>>1]=0;break Ed}o=v[p+32>>2];k=x[o+3840>>1];i=0;Fd:{if(!(k&3)){break Fd}i=(x[p+36>>1]>>>7&7)>>>(w[o+3844|0]^1)>>>(k&1)|0;i=k&4?0-i|0:i}k=i<<x[p+38>>1];i=e;o=v[p+52>>2];Gd:{if(o){G=x[o+32>>1];q=x[p+48>>1];o=fg(v[p+16>>2],v[p+40>>2],k<<16>>16,0,u[p+46>>1]);F=v[p+40>>2];Y=v[p+20>>2];if(!G){if(!q){k=k<<16>>16;o=fg(Y,F,k,o,0);o=fg(v[p+24>>2],v[p+40>>2],k,o,0);k=fg(v[p+28>>2],v[p+40>>2],k,o,0);break Gd}k=k<<16>>16;F=fg(Y,F,k,0,0);F=fg(v[p+24>>2],v[p+40>>2],k,F,0);k=fg(v[p+28>>2],v[p+40>>2],k,F,0)+o|0;break Gd}if(!q){k=k<<16>>16;o=fg(Y,F,k,o,0);F=fg(v[p+24>>2],v[p+40>>2],k,0,0);k=fg(v[p+28>>2],v[p+40>>2],k,F,0)+o|0;break Gd}k=k<<16>>16;F=fg(Y,F,k,0,0);k=(fg(v[p+24>>2],v[p+40>>2],k,F,0)+o|0)+fg(v[p+28>>2],v[p+40>>2],k,0,0)|0;break Gd}q=x[p+48>>1];k=k<<16>>16;o=fg(v[p+16>>2],v[p+40>>2],k,0,u[p+46>>1]);F=v[p+40>>2];Y=v[p+20>>2];if(!q){k=fg(Y,F,k,o,0);break Gd}k=fg(Y,F,k,0,0)+o|0}u[i+14>>1]=w[p+57|0]?k:0;u[e+12>>1]=w[p+58|0]?k:0}s=u[e+12>>1]+s|0;m=u[e+14>>1]+m|0;r=r+1|0;if((r|0)!=18){continue}break}i=g;g=(m|0)<32767?m:32767;u[i>>1]=(g|0)>-32768?g:-32768;g=(s|0)<32767?s:32767;u[j>>1]=(g|0)>-32768?g:-32768;u[f+3832>>1]=x[f+3832>>1]+1;g=(x[f+3834>>1]+1>>>0)%13440|0;u[f+3834>>1]=g;g=((g>>>0<6720?g:13440-g|0)|0)/256|0;u[f+3836>>1]=g;if(!w[f+3843|0]){u[f+3836>>1]=(g&65532)>>>2}g=x[f+3838>>1]+1|0;u[f+3838>>1]=g;if((g&65535)>>>0>=1024){u[f+3838>>1]=0;u[f+3840>>1]=x[f+3840>>1]+1&7}gb=e+16|0;f=v[b>>2];e=v[b+4>>2]-f|0;v[b+4>>2]=e;if((e|0)>=(f|0)){continue}break}}d=f-e|0;u[l+14>>1]=(B(u[b+12>>1],e)+B(d,u[b+8>>1])|0)/(f|0);u[l+12>>1]=(B(u[b+14>>1],e)+B(d,u[b+10>>1])|0)/(f|0);v[b+4>>2]=e+49716;v[c>>2]=v[c>>2]+B(n,u[l+14>>1]);v[c+4>>2]=v[c+4>>2]+B(n,u[l+12>>1]);c=c+8|0;a=a-1|0;if(a){continue}break}}gb=l+16|0}f=ha;e=E;d=Ca;Hd:{if(!v[d+4116>>2]){if(!v[d+4120>>2]){break Hd}Oo(d+8|0,e,d+4104|0,d+4108|0)}b=v[d>>2];c=v[d+4184>>2];a=B(b,c)>>>4|0;a=a>>>0<32767?a:32767;u[d+4202>>1]=a;u[d+4200>>1]=a;h=v[d+54052>>2];a=B(h,b)>>>4|0;a=a>>>0<65536?a:65536;g=a+127>>>3|0;u[d+54050>>1]=g;a=a+255>>>4|0;u[d+54048>>1]=a;u[d+54046>>1]=a;u[d+54044>>1]=g;a=f;g=d+8|0;j=g;c=(c|0)>(h|0)?c:h;b=36-b>>>1|0;b=b>>>0>8?b:8;c=16-(B((c|0)<32768?c:32768,(b|0)<16?16-b|0:0)>>15)|0;i=0;b=e;if(e){while(1){h=i<<3;p=h+a|0;v[p>>2]=v[p>>2]+B(c,v[h+j>>2]>>4);h=h|4;p=h+a|0;v[p>>2]=v[p>>2]+B(c,v[h+j>>2]>>4);i=i+1|0;if((b|0)!=(i|0)){continue}break}}j=d+4172|0;i=g;c=0;a=d;b=v[a+4144>>2];p=v[a+4140>>2];if(e){h=u[a+4188>>1];while(1){k=c<<3;m=(k|4)+i|0;l=v[m>>2];k=i+k|0;r=v[k>>2]>>12;p=(B(h,r-p|0)>>15)+r|0;v[k>>2]=p;k=l>>12;b=(B(h,k-b|0)>>15)+k|0;v[m>>2]=b;c=c+1|0;if((e|0)!=(c|0)){continue}break}}v[a+4144>>2]=b;v[a+4140>>2]=p;Id:{if(!e){b=v[j>>2];break Id}k=d+53996|0;b=e;a=j;m=v[a>>2]-1|0;h=x[a+22>>1];l=u[a+26>>1];n=u[a+18>>1];c=v[a+4>>2];s=x[a+20>>1];r=u[a+24>>1];q=u[a+16>>1];o=a+32928|0;while(1){p=ed(v[i>>2]);F=ed(v[i+4>>2]);s=ed((s<<16>>16)-p|0);h=ed((h<<16>>16)-F|0);s=Uc(ed((B(q,s)|0)/65536<<1)+p|0);h=Uc(ed((B(h,n)|0)/65536<<1)+F|0);p=o+(c<<2)|0;F=u[p+2>>1];A=u[p>>1];Y=Uc(((B(A,r)|0)/-65536|0)+s|0);p=c+1&127;c=o+(p<<2)|0;G=Uc(((B(l,F)|0)/-65536|0)+h|0);u[c+2>>1]=G;u[c>>1]=Y;m=m+1&8191;c=a+(m<<2)|0;Ma=c,Na=Uc(A+((B(r,Y)|0)/65536|0)|0),u[Ma+160>>1]=Na;Ma=c,Na=Uc(F+((B(l,G)|0)/65536|0)|0),u[Ma+162>>1]=Na;i=i+8|0;c=p;b=b-1|0;if(b){continue}break}u[a+22>>1]=h;u[a+20>>1]=s;v[a+4>>2]=p;i=v[d+4180>>2];N=d+37612|0;a=g;c=e;while(1){h=i&4095;m=N+(h<<2)|0;b=a;Y=i-v[d+53996>>2]&4095;h=4096-(h>>>0>Y>>>0?h:Y)|0;h=c>>>0>h>>>0?h:c;p=h>>>0<64?h:64;F=p;h=0;l=gb-32|0;gb=l;i=j;r=v[j>>2];while(1){v[l+(h<<2)>>2]=r+(v[(i+(h<<4)|0)+32>>2]^-1);h=h+1|0;if((h|0)!=7){continue}break}h=u[i+28>>1]/8|0;if(F){n=h<<16>>16;while(1){s=0;o=0;h=0;while(1){r=l+(h<<2)|0;q=v[r>>2]+1&8191;v[r>>2]=q;ba=o;o=i+(q<<2)|0;q=u[o+160>>1];r=i+(h<<4)|0;A=u[o+162>>1];o=(ba+B(q,u[r+44>>1])|0)+B(A,u[r+46>>1])|0;s=(B(q,u[r+40>>1])+s|0)+B(A,u[r+42>>1])|0;h=h+1|0;if((h|0)!=4){continue}break}r=0;h=4;A=Uc((s|0)/32768|0);G=Uc((o|0)/32768|0);s=0;while(1){o=l+(h<<2)|0;q=v[o>>2]+1&8191;v[o>>2]=q;ba=s;s=i+(q<<2)|0;q=u[s+160>>1];o=i+(h<<4)|0;U=u[s+162>>1];s=(ba+B(q,u[o+44>>1])|0)+B(U,u[o+46>>1])|0;r=(B(q,u[o+40>>1])+r|0)+B(U,u[o+42>>1])|0;h=h+1|0;if((h|0)!=7){continue}break}h=Uc(A+((r|0)/32768|0)|0);u[m>>1]=h;v[b>>2]=B(h,n);h=Uc(G+((s|0)/32768|0)|0);u[m+2>>1]=h;v[b+4>>2]=B(h,n);b=b+8|0;m=m+4|0;F=F-1|0;if(F){continue}break}}gb=l+32|0;m=N+(Y<<2)|0;b=a;i=k;s=v[i+4>>2];F=s&2047;h=p;if(h){l=i+8256|0;r=i- -64|0;o=i+24640|0;Y=i+16448|0;while(1){U=u[l+((s+1206&2047)<<2)>>1];M=u[(l+((s+754&2047)<<2)|0)+2>>1];G=u[(r+((s+1602&2047)<<2)|0)+2>>1];I=u[r+((s+1750&2047)<<2)>>1];n=u[m>>1];q=u[m+2>>1];A=o+((s+502&2047)<<2)|0;H=u[A>>1];K=ed(u[i+32>>1]-H|0);A=u[A+2>>1];S=ed(u[i+34>>1]-A|0);X=u[i+26>>1];V=o+((s+22&2047)<<2)|0;_=u[V>>1];W=ed(u[i+36>>1]-_|0);ca=u[i+28>>1];V=u[V+2>>1];da=ed(u[i+38>>1]-V|0);fa=u[i+30>>1];Ma=i,Na=Uc(ed((B(K,u[i+24>>1])|0)/65536<<1)+H|0),u[Ma+32>>1]=Na;Ma=i,Na=Uc(ed((B(S,X)|0)/65536<<1)+A|0),u[Ma+34>>1]=Na;Ma=i,Na=Uc(ed((B(W,ca)|0)/65536<<1)+_|0),u[Ma+36>>1]=Na;A=Uc(ed((B(da,fa)|0)/65536<<1)+V|0);u[i+38>>1]=A;H=ed((B(u[i+32>>1],u[i+16>>1])|0)/32768|0);A=ed((B(A,u[i+22>>1])|0)/32768|0);H=ed(H+((n|0)/4<<16>>16)|0);K=ed(A+((q|0)/4<<16>>16)|0);n=u[i+8>>1];S=ed(H+((B(n,I)|0)/-65536|0)|0);q=F<<2;X=q+r|0;A=u[i+10>>1];V=ed(K+((B(A,G)|0)/-65536|0)|0);u[X+2>>1]=V;u[X>>1]=S;I=ed(I+((B(n,S)|0)/65536|0)|0);S=q+Y|0;G=ed(G+((B(A,V)|0)/65536|0)|0);u[S+2>>1]=G;u[S>>1]=I;I=ed(I+H|0);H=ed(G+K|0);G=Y+((s+682&2047)<<2)|0;K=u[G+2>>1];S=u[G>>1];G=ed((B(K,u[i+42>>1])+B(S,u[i+40>>1])|0)/32768|0);s=Y+((s+426&2047)<<2)|0;X=u[s+2>>1];V=u[s>>1];s=ed((B(X,u[i+46>>1])+B(V,u[i+44>>1])|0)/32768|0);S=ed(ed(I+S|0)-G|0);K=ed(ed(H+K|0)-s|0);I=ed(ed(I+V|0)-G|0);H=ed(ed(H+X|0)-s|0);G=ed(G+((B(n,U)|0)/-65536|0)|0);X=l+q|0;V=ed(s+((B(A,M)|0)/-65536|0)|0);u[X+2>>1]=V;u[X>>1]=G;n=(B(n,G)|0)/65536|0;s=ed(n+U|0);q=q+o|0;A=(B(A,V)|0)/65536|0;G=ed(A+M|0);u[q+2>>1]=G;u[q>>1]=s;Ma=b,Na=(v[b>>2]+B(ed(s+S|0),u[i+48>>1])|0)+B(ed(G+K|0),u[i+50>>1])|0,v[Ma>>2]=Na;Ma=b,Na=(v[b+4>>2]+B(ed(ed(n)+I|0),u[i+52>>1])|0)+B(ed(ed(A)+H|0),u[i+54>>1])|0,v[Ma+4>>2]=Na;b=b+8|0;m=m+4|0;s=F+1|0;F=s&2047;h=h-1|0;if(h){continue}break}}v[i+4>>2]=F;i=p+v[d+4180>>2]&4095;v[d+4180>>2]=i;b=p+v[d+4172>>2]&8191;v[d+4172>>2]=b;a=(p<<3)+a|0;c=c-p|0;if(c){continue}break}}v[d+4172>>2]=b&8191;a=g;g=0;i=0;j=d;h=v[d+4160>>2];k=v[d+4156>>2];c=e;if(e){b=v[j+4164>>2];p=v[j+4168>>2];while(1){g=v[a>>2];o=h;i=v[a+4>>2];h=p-i|0;h=o+(((h|0)/1024|0)-h|0)|0;v[f+4>>2]=h+v[f+4>>2];b=b-g|0;b=(((b|0)/1024|0)-b|0)+k|0;v[f>>2]=b+v[f>>2];h=h+((h|0)/-512|0)|0;k=b+((b|0)/-512|0)|0;f=f+8|0;a=a+8|0;p=i;b=g;c=c-1|0;if(c){continue}break}}v[j+4168>>2]=i;v[j+4164>>2]=g;v[j+4160>>2]=h;v[j+4156>>2]=k;Jd:{if(v[d+4116>>2]){v[d+4120>>2]=v[d+4124>>2];break Jd}a=v[d+4120>>2];if(a>>>0>e>>>0){v[d+4120>>2]=a-e;break Jd}SL(d);v[d+4120>>2]=0}v[d+4116>>2]=0}if(ra){i=0;k=0;f=E<<2;d=J;o=x[d+480214>>1]!=0;a=d+1074328|0;Z=z[a>>2];ya=z[a+4>>2];while(1){h=(d+B(i,160)|0)+906300|0;a=v[h>>2];Kd:{if(!a|!v[a+24>>2]){break Kd}if(!ei(a+44|0)){break Kd}a=v[h>>2];if(!(kb[v[v[a>>2]+112>>2]](a)|0)){kb[v[v[a>>2]+108>>2]](a,1);kb[v[v[a>>2]+120>>2]](a)}c=a+44|0;b=Pd(c,0);c=Pd(c,1);Ld:{if(t[a+28|0]&1){ZA(v[a+24>>2],b,c,e,Z);break Ld}g=a+40|0;if(!(v[a+36>>2]?0:!v[g>>2])){Oo(v[a+24>>2],e,g,a+36|0);ZA(v[a+24>>2],b,c,e,Z);break Ld}Pb(b,0,f);Pb(c,0,f)}v[a+28>>2]=v[a+28>>2]&-2;if(rw(h)){break Kd}o=!(w[a+28|0]&4)|o}i=i+1|0;if((i|0)!=250){continue}break}m=d+12|0;h=d+12300|0;g=d+14348|0;ZA(m,h,g,e,Z);a=d+1074468|0;Y=w[a|0];t[a|0]=0;a=h;c=g;while(1){j=(d+B(k,160)|0)+906300|0;b=v[j>>2];Md:{if(!b|!v[b+24>>2]){break Md}if(!ei(b+44|0)){break Md}l=v[j>>2];Nd:{if(rw(j)){break Nd}b=v[j>>2];if(kb[v[v[b>>2]+144>>2]](b)|w[v[j>>2]+28|0]&2){break Nd}i=0;if(!k){break Md}while(1){if((Kk((d+B(i,160)|0)+906300|0)|0)==(k|0)){break Nd}i=i+1|0;if((k|0)!=(i|0)){continue}break}break Md}b=l+44|0;r=Pd(b,0);F=Pd(b,1);p=v[j>>2];s=(a|0)==(r|0);a=s?h:a;b=a;c=s?g:c;f=c;Od:{if(!(w[j+28|0]|w[j+29|0]<<8|(w[j+30|0]<<16|w[j+31|0]<<24))){break Od}b=a;i=Kk(j);f=c;if((i|0)==255){break Od}f=c;if(i>>>0<=k>>>0){break Od}i=v[(d+B(i,160)|0)+906300>>2];f=c;if(!i){break Od}if(!(w[p+28|0]&4)){kb[v[v[i>>2]+148>>2]](i)}i=i+44|0;f=c;if(!ei(i)){break Od}b=Pd(i,0);f=Pd(i,1)}Pd:{if(!rw(j)){break Pd}Qd:{if(!e){break Qd}i=0;if(s){break Qd}while(1){s=i<<2;n=s+r|0;ba=n;Z=z[n>>2];n=a+s|0;z[ba>>2]=Z+z[n>>2];q=s+F|0;s=c+s|0;z[q>>2]=z[q>>2]+z[s>>2];v[n>>2]=0;v[s>>2]=0;i=i+1|0;if((e|0)!=(i|0)){continue}break}}c=f;a=b;if(!(o&1)){break Pd}a=v[j>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}a=b;i=Kk(j);if(i>>>0>249|i>>>0<=k>>>0){break Pd}while(1){c=i&255;a=(d+B(c,160)|0)+906300|0;i=Kk(a);a=v[a>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}if(c>>>0<i>>>0?i>>>0<=249:0){continue}break}c=f;a=b}Rd:{Sd:{if(!((w[j+24|0]&2)>>>1|0)){if(!_E(j)|!(w[p+28|0]&4)){break Sd}}i=0;if(!e){break Rd}while(1){j=i<<2;l=j+b|0;z[l>>2]=z[l>>2]+z[j+r>>2];l=f+j|0;z[l>>2]=z[l>>2]+z[j+F>>2];i=i+1|0;if((e|0)!=(i|0)){continue}break}break Rd}if(Y){kb[v[v[l>>2]+128>>2]](l)}kb[v[v[l>>2]+60>>2]](l,b,f,e);v[p+32>>2]=e+v[p+32>>2];if(!_E(j)){break Rd}if((kb[v[v[l>>2]+156>>2]](l)|0)<1|y[p+32>>2]<v[d+24620>>2]<<2>>>0){break Rd}i=0;Td:{if(!e){break Td}while(1){Ud:{j=i<<2;Z=z[j+b>>2];if(Z>=C(1.1920928955078125e-7)|Z<=C(-1.1920928955078125e-7)){break Ud}Z=z[f+j>>2];if(Z>=C(1.1920928955078125e-7)|!(Z>C(-1.1920928955078125e-7))){break Ud}i=i+1|0;if((e|0)!=(i|0)){continue}break Td}break}v[p+32>>2]=0;break Rd}v[p+28>>2]=v[p+28>>2]|4}v[p+28>>2]=v[p+28>>2]&-3}k=k+1|0;if((k|0)!=250){continue}break}Vd:{if(!e){break Vd}b=1;while(1){f=m;Z=C(z[a>>2]*ya);Wd:{if(C(D(Z))<C(2147483648)){g=~~Z;break Wd}g=-2147483648}v[f>>2]=g;f=m;Z=C(z[c>>2]*ya);Xd:{if(C(D(Z))<C(2147483648)){g=~~Z;break Xd}g=-2147483648}v[f+4>>2]=g;if((b|0)==(e|0)){break Vd}m=m+8|0;c=c+4|0;a=a+4|0;b=b+1|0;continue}}}if(v[J+24624>>2]==1){b=ha;a=0;c=E;if(c){while(1){f=a<<3;v[b+(a<<2)>>2]=(v[b+(f|4)>>2]+v[b+f>>2]|0)/2;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}if(w[Ba+33|0]){f=E;h=gb-16|0;gb=h;Yd:{Zd:{b=J;_d:{if(!v[b+1074368>>2]){g=b+1074452|0;a=g;v[a>>2]=0;v[a+4>>2]=0;v[b+1074460>>2]=v[b+1074448>>2];break _d}e=v[b+1074460>>2];a=v[b+1074448>>2];$d:{if((e|0)==(a|0)){e=v[b+1074452>>2];break $d}v[b+1074460>>2]=a;c=b+24604|0;g=b+1074452|0;ae:{if((a|0)>(e|0)){e=NS(c);break ae}e=MS(c)}v[g>>2]=e;v[b+1074456>>2]=e}g=b+1074452|0;if((e|0)>=1){break Zd}}c=0;break Yd}d=(v[b+1074460>>2]<<12)-v[b+1074464>>2]|0;c=(d|0)/(e|0)|0;if(w[b+1074364|0]!=2){break Yd}v[h+12>>2]=50;v[h+8>>2]=1e4/(v[b+1074456>>2]+1|0);j=v[Wf(h+12|0,h+8|0)>>2];a=c>>31;if((j|0)>=(a+c^a)){break Yd}e=v[b+1074452>>2];i=v[b+1074456>>2];while(1){e=e+i|0;c=(d|0)/(e|0)|0;a=c>>31;if((j|0)<(a^a+c)){continue}break}v[g>>2]=e}be:{ce:{switch(v[b+24624>>2]-1|0){case 0:if((f|0)<1){break be}a=v[b+1074448>>2];i=a<<12;d=a;p=a>>31;e=b+12|0;a=0;while(1){de:{if(v[g>>2]>=1){j=v[b+1074464>>2]+c|0;v[b+1074464>>2]=j;k=v[e>>2];Ma=e,Na=vc(Gpa(Fpa(k,k>>31,j,j>>31),jb,1048576,0),jb),v[Ma>>2]=Na;v[b+1074452>>2]=v[b+1074452>>2]-1;break de}j=v[e>>2];Ma=e,Na=vc(Gpa(Fpa(j,j>>31,d,p),jb,256,0),jb),v[Ma>>2]=Na;v[b+1074464>>2]=i}e=e+4|0;a=a+1|0;if((f|0)!=(a|0)){continue}break};break be;case 1:if((f|0)<1){break be}a=v[b+1074448>>2];p=a<<12;d=a;j=a>>31;e=b+12|0;a=0;while(1){ee:{if(v[g>>2]>=1){i=v[b+1074464>>2]+c|0;v[b+1074464>>2]=i;k=v[e>>2];Ma=e,Na=vc(Gpa(Fpa(k,k>>31,i,i>>31),jb,1048576,0),jb),v[Ma>>2]=Na;i=v[b+1074464>>2];k=i;o=i>>31;i=v[e+4>>2];Ma=e,Na=vc(Gpa(Fpa(k,o,i,i>>31),jb,1048576,0),jb),v[Ma+4>>2]=Na;v[b+1074452>>2]=v[b+1074452>>2]-1;break ee}i=v[e>>2];Ma=e,Na=vc(Gpa(Fpa(i,i>>31,d,j),jb,256,0),jb),v[Ma>>2]=Na;i=v[e+4>>2];Ma=e,Na=vc(Gpa(Fpa(i,i>>31,d,j),jb,256,0),jb),v[Ma+4>>2]=Na;v[b+1074464>>2]=p}e=e+8|0;a=a+1|0;if((f|0)!=(a|0)){continue}break};break be;case 3:break ce;default:break be}}if((f|0)<1){break be}a=v[b+1074448>>2];k=a<<12;d=a;j=a>>31;e=b+12|0;a=b+8204|0;p=0;while(1){fe:{if(v[g>>2]>=1){i=v[b+1074464>>2]+c|0;v[b+1074464>>2]=i;m=v[e>>2];Ma=e,Na=vc(Gpa(Fpa(m,m>>31,i,i>>31),jb,1048576,0),jb),v[Ma>>2]=Na;i=v[b+1074464>>2];o=i;s=i>>31;i=v[e+4>>2];Ma=e,Na=vc(Gpa(Fpa(o,s,i,i>>31),jb,1048576,0),jb),v[Ma+4>>2]=Na;i=v[b+1074464>>2];o=i;s=i>>31;i=v[a>>2];Ma=a,Na=vc(Gpa(Fpa(o,s,i,i>>31),jb,1048576,0),jb),v[Ma>>2]=Na;i=v[b+1074464>>2];o=i;s=i>>31;i=v[a+4>>2];Ma=a,Na=vc(Gpa(Fpa(o,s,i,i>>31),jb,1048576,0),jb),v[Ma+4>>2]=Na;v[b+1074452>>2]=v[b+1074452>>2]-1;break fe}i=v[e>>2];Ma=e,Na=vc(Gpa(Fpa(i,i>>31,d,j),jb,256,0),jb),v[Ma>>2]=Na;i=v[e+4>>2];Ma=e,Na=vc(Gpa(Fpa(i,i>>31,d,j),jb,256,0),jb),v[Ma+4>>2]=Na;i=v[a>>2];Ma=a,Na=vc(Gpa(Fpa(i,i>>31,d,j),jb,256,0),jb),v[Ma>>2]=Na;i=v[a+4>>2];Ma=a,Na=vc(Gpa(Fpa(i,i>>31,d,j),jb,256,0),jb),v[Ma+4>>2]=Na;v[b+1074464>>2]=k}a=a+8|0;e=e+8|0;p=p+1|0;if((f|0)!=(p|0)){continue}break}}gb=h+16|0}if(v[qa>>2]!=128){c=J+12|0;f=J+8204|0;a=E;b=v[J+24604>>2];e=v[J+24624>>2];ge:{if((b|0)==128|e>>>0<2){break ge}sO(c,a,b);if(e>>>0<4){break ge}sO(f,a,b)}}f=pa;e=ha;a=v[J+24624>>2];if((a|0)==4){b=ha;c=Aa;a=E-1|0;if((a|0)>-1){while(1){d=a<<4;h=a<<3;g=h|4;v[b+(d|12)>>2]=v[g+c>>2];v[b+(d|8)>>2]=v[c+h>>2];v[b+(d|4)>>2]=v[b+g>>2];v[b+d>>2]=v[b+h>>2];d=(a|0)>0;a=a-1|0;if(d){continue}break}}a=v[J+24624>>2]}kb[v[v[pa>>2]+8>>2]](f,e,a,E);c=v[J+1074372>>2]-E|0;v[J+1074372>>2]=c;v[J+1074368>>2]=E+v[J+1074368>>2];za=E+za|0;ga=ga-E|0;if(!ga){break j}a=v[J+480208>>2];if(!(a&512)){continue}break}}gb=$+32|0;gb=ma+16|0;return za}function _na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;d=gb-480|0;gb=d;yc(b);f=gb-32|0;gb=f;h=d+288|0;Mr(f+24|0,h);j=xb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);i=xb(f+16|0);if((i|0)==(j|0)){Vb(e,xb(f+24|0))}gb=f+32|0;e=(i|0)==(j|0);if(!e){JW(h)}a:{b:{c:{if(!e){break c}if(!cX(d+288|0)){break c}if(!Nb(b,Xc(bX(d+288|0),jb))){break c}if(!c){g=1;break c}Ed(a,32);t[d+287|0]=0;j=Jb(d+272|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(v[d+288>>2]==778924148){v[23048]=0;S(599,a|0,16777216);e=v[23048];v[23048]=0;if((e|0)==1){break b}v[23048]=0;e=U(247,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}v[23048]=0;Q(248,b|0,e-4|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}v[23048]=0;s=U(376,b|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break F}break b}G:{H:{I:{J:{if((w[d+328|0]|w[d+329|0]<<8)>>>0<2185|(w[d+328|0]|w[d+329|0]<<8)>>>0>4095){break J}v[23048]=0;e=U(247,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}v[23048]=0;Q(248,b|0,e-4|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}v[23048]=0;s=U(376,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}if(s>>>0<256){break J}v[23048]=0;e=U(247,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}if(e>>>0<=s>>>0){break J}v[23048]=0;e=Q(248,b|0,s|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}if(!e){break J}v[23048]=0;e=U(600,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}if(!e){break J}v[23048]=0;S(599,a|0,16777216);e=v[23048];v[23048]=0;if((e|0)==1){break b}if((w[d+328|0]|w[d+329|0]<<8)>>>0>=4096){v[23048]=0;b=Q(2,d+88|0,18110)|0;c=v[23048];v[23048]=0;if((c|0)==1){break E}v[23048]=0;T(601,a|0,1,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);break d}a=P()|0;O()|0;vb(b);break a}if((w[d+328|0]|w[d+329|0]<<8)>>>0<2194){break J}v[23048]=0;e=Q(2,d+88|0,18206)|0;f=v[23048];v[23048]=0;if((f|0)==1){break I}v[23048]=0;T(601,a|0,4,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break H}vb(e)}if(v[a+480180>>2]!=32){break F}if(((w[d+328|0]|w[d+329|0]<<8)&61440)!=20480){break G}v[a+1074304>>2]=((w[d+328|0]|w[d+329|0]<<8)&4095)<<16;if(v[d+348>>2]!=1414548815){break F}t[d+287|0]=1;break F}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e);break a}if(!((w[d+328|0]|w[d+329|0]<<8)!=2184?(w[d+330|0]|w[d+331|0]<<8)!=2184:0)){t[d+287|0]=1;v[a+1074304>>2]=18284544;break F}if(!((w[d+328|0]|w[d+329|0]<<8)!=535|(w[d+330|0]|w[d+331|0]<<8)!=512|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)))){v[23048]=0;e=tv(d+352|0,255,64);f=v[23048];v[23048]=0;if((f|0)==1){break b}K:{if(e){v[a+1074304>>2]=18219008;v[23048]=0;g=Q(2,d+88|0,18352)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break K}a=P()|0;O()|0;break a}v[a+1074304>>2]=18284544;v[23048]=0;g=Q(2,d+88|0,18380)|0;e=v[23048];v[23048]=0;if((e|0)==1){break D}}Eb(j,g);vb(g);t[d+287|0]=1;break F}if(!((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=514|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)))){v[a+1074304>>2]=17367040;v[23048]=0;e=Q(2,d+88|0,18416)|0;f=v[23048];v[23048]=0;if((f|0)!=1){Eb(j,e);vb(e);t[d+287|0]=1;break F}a=P()|0;O()|0;break a}if((w[d+328|0]|w[d+329|0]<<8)!=768|(w[d+330|0]|w[d+331|0]<<8)!=768|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)|(w[d+320|0]|w[d+321|0]<<8)!=256)){break F}if(w[d+341|0]|w[d+340|0]!=128){break F}v[a+1074304>>2]=18285088;t[d+287|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+332|0]|w[d+333|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+332|0]|w[d+333|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+332|0]|w[d+333|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+332|0]|w[d+333|0]<<8)<<3&32768;v[23048]=0;Cp(d+200|0,3,d+288|4);e=v[23048];v[23048]=0;if((e|0)==1){break C}v[23048]=0;S(398,d+88|0,d+200|0);e=v[23048];v[23048]=0;if((e|0)==1){break C}Eb(a+1300308|0,d+88|0);vb(d+88|0);if(!(!(w[d+334|0]&4)|v[a+1074304>>2]-1>>>0<18285313)){v[a+480216>>2]=w[d+318|0];v[a+480220>>2]=w[d+319|0]}e=w[d+336|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+338|0]){v[a+480196>>2]=w[d+338|0]}t[d+88|0]=31;e=w[d+339|0];v[23048]=0;t[d+200|0]=e;e=Ff(d+88|0,d+200|0);f=v[23048];v[23048]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);t[d+88|0]=w[d+337|0];v[23048]=0;t[d+200|0]=128;e=$b(d+88|0,d+200|0);f=v[23048];v[23048]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];g=0;while(1){i=(d+288|0)+g|0;f=i- -64|0;L:{if(w[f|0]==255){break L}v[23048]=0;h=(g<<5)+a|0;e=h+480280|0;We(e);k=v[23048];v[23048]=0;if((k|0)==1){break B}C=h+480286|0,D=Gd(w[i+128|0],0,64),u[C>>1]=D;if(t[f|0]<=-1){v[e>>2]=v[e>>2]|1024}f=w[f|0]&127;if(f>>>0<=64){u[h+480284>>1]=f<<2;break L}if((f|0)!=100){break L}v[e>>2]=v[e>>2]|256}g=g+1|0;if((g|0)!=64){continue}break}v[23048]=0;Q(248,b|0,192)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}M:{if(!(v[a+480180>>2]!=16777216|(w[d+328|0]|w[d+329|0]<<8)>>>0<2187|(w[d+328|0]|w[d+329|0]<<8)>>>0>2189)){g=0;v[23048]=0;e=U(340,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break A}if(e){break d}v[23048]=0;e=U(376,b|0)|0;f=v[23048];v[23048]=0;N:{if((f|0)==1){break N}if(e>>>0>4e3){break d}f=Qb(a+484360|0);v[23048]=0;e=W(604,f|0,b|0,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break N}if(!e){break d}break M}a=P()|0;O()|0;break a}e=Qb(a+484360|0);f=w[d+320|0]|w[d+321|0]<<8;v[23048]=0;ga(560,e|0,b|0,f|0,255,254)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}}q=nc(d+256|0);o=nc(d+240|0);m=nc(d+224|0);e=w[d+322|0]|w[d+323|0]<<8;g=0;v[23048]=0;e=W(605,b|0,q|0,e|0)|0;f=v[23048];v[23048]=0;O:{if((f|0)==1){break O}if(!e){break y}e=w[d+324|0]|w[d+325|0]<<8;v[23048]=0;e=W(605,b|0,o|0,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break O}if(!e){break y}e=w[d+326|0]|w[d+327|0]<<8;v[23048]=0;e=W(605,b|0,m|0,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break O}if(!e){break y}v[d+220>>2]=-1;C=d,D=Rb(q),v[C+88>>2]=D;C=d,D=Ub(q),v[C+200>>2]=D;if(!Fb(d+88|0,d+200|0)){break z}while(1){e=v[d+88>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+220>>2])){v[d+220>>2]=e}Ag(d+88|0);if(Fb(d+88|0,d+200|0)){continue}break}break z}a=P()|0;O()|0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}C=d,D=Rb(o),v[C+88>>2]=D;C=d,D=Ub(o),v[C+200>>2]=D;if(Fb(d+88|0,d+200|0)){while(1){e=v[d+88>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+220>>2])){v[d+220>>2]=e}Ag(d+88|0);if(Fb(d+88|0,d+200|0)){continue}break}}C=d,D=Rb(m),v[C+88>>2]=D;C=d,D=Ub(m),v[C+200>>2]=D;if(Fb(d+88|0,d+200|0)){while(1){e=v[d+88>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+220>>2])){v[d+220>>2]=e}Ag(d+88|0);if(Fb(d+88|0,d+200|0)){continue}break}}P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if(t[d+334|0]&1){e=w[d+344|0]|w[d+345|0]<<8|(w[d+346|0]<<16|w[d+347|0]<<24);v[23048]=0;v[d+88>>2]=e;e=Gb(d+220|0,d+88|0);f=v[23048];v[23048]=0;if((f|0)==1){break _}v[d+220>>2]=v[e>>2]}e=0;$:{if((w[d+330|0]|w[d+331|0]<<8)!=532|(w[d+328|0]|w[d+329|0]<<8?(w[d+328|0]|w[d+329|0]<<8)!=532:0)|(w[d+319|0]|w[d+318|0])){break $}if(w[d+332|0]&192|(w[d+341|0]|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)))){break $}aa:{if(!(w[d+324|0]|w[d+325|0]<<8)|(w[d+322|0]|w[d+323|0]<<8)){break aa}if((v[b+8>>2]+(Lb(o)<<2)|0)+2>>>0>y[d+220>>2]){break aa}if(w[d+324|0]|w[d+325|0]<<8){while(1){v[23048]=0;f=U(376,b|0)|0;g=v[23048];v[23048]=0;ba:{if((g|0)!=1){if(!f){break ba}kg(b,((e&65535)<<2)+4|0);break aa}a=P()|0;O()|0;break g}e=e+1|0;if((e&65535)>>>0<(w[d+324|0]|w[d+325|0]<<8)>>>0){continue}break}}v[23048]=0;e=Q(2,d+88|0,18444)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Y}Eb(j,e);vb(e)}e=1;if(w[d+328|0]|w[d+329|0]<<8){break $}v[23048]=0;f=Q(2,d+88|0,18457)|0;g=v[23048];v[23048]=0;if((g|0)==1){break X}Eb(j,f);vb(f)}ca:{if(w[d+334|0]&2){v[23048]=0;f=U(340,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break W}v[23048]=0;g=f<<3;h=Q(250,b|0,g|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break W}if(!(!h|y[d+220>>2]<g+v[b+8>>2]>>>0)){v[23048]=0;g=a+1300408|0;S(606,g|0,f|0);h=v[23048];v[23048]=0;if((h|0)==1){break W}C=d,D=Rb(g),v[C+200>>2]=D;C=d,D=Ub(g),v[C+176>>2]=D;if(Fb(d+200|0,d+176|0)){while(1){g=v[d+200>>2];v[23048]=0;S(607,b|0,d+88|0);h=v[23048];v[23048]=0;if((h|0)==1){break V}v[23048]=0;JE(d+88|0,g);g=v[23048];v[23048]=0;if((g|0)==1){break V}v[d+200>>2]=v[d+200>>2]+48;if(Fb(d+200|0,d+176|0)){continue}break}}if(!(!f&e)){break ca}if(w[d+334|0]&4){v[23048]=0;e=Q(2,d+88|0,18468)|0;f=v[23048];v[23048]=0;if((f|0)!=1){Eb(j,e);vb(e);break ca}a=P()|0;O()|0;break g}v[23048]=0;e=Q(2,d+88|0,18485)|0;f=v[23048];v[23048]=0;if((f|0)!=1){Eb(j,e);vb(e);break ca}a=P()|0;O()|0;break g}kg(b,2);break ca}if(!e|(w[d+334|0]|w[d+335|0]<<8)>>>0>1){break ca}v[23048]=0;e=U(340,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Z}if(!e){v[23048]=0;e=Q(2,d+88|0,18444)|0;f=v[23048];v[23048]=0;if((f|0)!=1){Eb(j,e);vb(e);break ca}a=P()|0;O()|0;break g}kg(b,2)}da:{if(w[d+334|0]&8?0:!(w[d+332|0]&128)){break da}v[23048]=0;e=a+901404|0;f=Q(609,b|0,e|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break h}if(!f){break da}v[23048]=0;Ju(e);e=v[23048];v[23048]=0;if((e|0)==1){break h}}if((w[d+328|0]|w[d+329|0]<<8)>>>0<=531){v[23048]=0;Po(a+901404|0);e=v[23048];v[23048]=0;if((e|0)==1){break h}}v[23048]=0;z=U(270,d+200|0)|0;e=v[23048];v[23048]=0;ea:{fa:{ga:{ha:{ia:{ja:{if((e|0)!=1){v[23048]=0;e=Q(596,b|0,18491)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ja}if(e){v[23048]=0;e=U(376,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ia}v[23048]=0;T(341,d+88|0,b|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break ia}id(z,d+88|0);yb(d+88|0)}u[a+480188>>1]=1;v[23048]=0;e=Q(596,b|0,18496)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ja}if(e){v[23048]=0;e=U(376,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ha}v[23048]=0;T(341,d+88|0,b|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break ha}v[23048]=0;e=U(247,d+88|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ga}v[23048]=0;u[d+176>>1]=(e>>>0)/20;e=Vc(18502,d+176|0);f=v[23048];v[23048]=0;if((f|0)==1){break ga}e=x[e>>1];u[a+480188>>1]=e;if(e){g=0;while(1){v[23048]=0;W(612,d+88|0,((g<<5)+a|0)+480289|0,20)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ga}g=g+1|0;if((e|0)!=(g|0)){continue}break}}yb(d+88|0)}if(y[b+8>>2]>y[d+220>>2]){break fa}g=v[d+220>>2]-v[b+8>>2]|0;break ea}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(d+88|0);break i}v[23048]=0;g=U(511,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break U}}v[23048]=0;T(341,d+176|0,b|0,g|0);e=v[23048];v[23048]=0;if((e|0)==1){break U}v[23048]=0;A=Q(613,a|0,d+176|0)|0;e=v[23048];v[23048]=0;ka:{la:{if((e|0)==1){break la}if(!(t[d+334|0]&1)|!(w[d+342|0]|w[d+343|0]<<8)){break ka}e=w[d+344|0]|w[d+345|0]<<8|(w[d+346|0]<<16|w[d+347|0]<<24);v[23048]=0;e=Q(248,b|0,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break la}if(!e){break ka}e=w[d+342|0]|w[d+343|0]<<8;v[23048]=0;ba(551,a+1300332|0,b|0,e|0,4)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break ka}}a=P()|0;O()|0;break j}g=0;u[a+480192>>1]=0;if(w[d+332|0]&4){u[d+88>>1]=w[d+322|0]|w[d+323|0]<<8;v[23048]=0;u[d+72>>1]=255;e=Vc(d+88|0,d+72|0);f=v[23048];v[23048]=0;if((f|0)==1){break T}u[a+480192>>1]=x[e>>1]}ma:{na:{oa:{pa:{if(x[a+480192>>1]){while(1){e=Mb(q,g);qa:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break qa}e=Mb(q,g);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[23048]=0;e=Q(248,b|0,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break pa}if(!e){break qa}v[23048]=0;e=Q(250,b|0,554)|0;f=v[23048];v[23048]=0;if((f|0)==1){break pa}if(!e){break qa}v[23048]=0;e=W(436,a|0,g+1&65535,0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break oa}if(!e){break qa}f=w[d+330|0]|w[d+331|0]<<8;v[23048]=0;ba(614,a|0,b|0,e|0,f|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break oa}t[e+33|0]=w[d+341|0]}g=g+1|0;if(g>>>0<x[a+480192>>1]){continue}break}}v[d+172>>2]=0;if(w[d+324|0]|w[d+325|0]<<8){e=Mb(o,(w[d+324|0]|w[d+325|0]<<8)-1|0);v[d+172>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}u[d+88>>1]=w[d+324|0]|w[d+325|0]<<8;v[23048]=0;u[d+72>>1]=3999;e=Vc(d+88|0,d+72|0);f=v[23048];v[23048]=0;if((f|0)==1){break na}u[a+480190>>1]=x[e>>1];g=0;if(x[a+480190>>1]){break ma}f=0;h=0;break P}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}k=c&2;p=d+108|0;h=0;f=0;while(1){e=Mb(o,g);ra:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break ra}e=Mb(o,g);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[23048]=0;e=Q(248,b|0,e|0)|0;i=v[23048];v[23048]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{if((i|0)==1){break ya}if(!e){break ra}v[23048]=0;e=Q(615,b|0,d+88|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break ya}if(!e){break ra}v[23048]=0;l=g+1|0;e=B(l,104)+a|0;i=e+484380|0;r=Q(616,d+88|0,i|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break xa}v[23048]=0;Cp(d+56|0,3,p);n=v[23048];v[23048]=0;if((n|0)==1){break wa}v[23048]=0;S(398,d+72|0,d+56|0);n=v[23048];v[23048]=0;if((n|0)==1){break wa}v[23048]=0;Q(354,((l<<5)+a|0)+946300|0,d+72|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break va}vb(d+72|0);v[23048]=0;r=Q(248,b|0,r|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break xa}if(!r){break ra}e=x[e+484414>>1];if(!(e&512)){break ua}v[23048]=0;e=Q(617,b|0,d+72|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){if(!e){break ta}v[d+8>>2]=v[d+80>>2];v[23048]=0;e=v[d+76>>2];v[d>>2]=v[d+72>>2];v[d+4>>2]=e;T(618,i|0,1,d|0);e=v[23048];v[23048]=0;if((e|0)!=1){break ta}}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+72|0);break j}if(!(e&16384)){e=w[d+328|0]|w[d+329|0]<<8;v[23048]=0;KE(d+72|0,d+88|0,e);e=v[23048];v[23048]=0;if((e|0)==1){break Q}za:{if(k){e=0;v[23048]=0;W(384,d+72|0,i|0,b|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break za}break Q}e=1;f=w[d+75|0];if(f>>>0>18){break za}f=1<<f;Aa:{if(!(f&126991)){if(f&396800){break Aa}break za}if(!w[d+72|0]){break za}}e=v[i>>2];v[23048]=0;f=sv(d+72|0,e);e=v[23048];v[23048]=0;if((e|0)==1){break Q}e=0;v[23048]=0;Q(370,b|0,f|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Q}}if(w[d+75|0]!=1){break sa}h=v[i>>2]!=0|h;break sa}v[23048]=0;Q(621,b|0,d+52|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break R}e=v[d+52>>2];if(!(!k|!e)){e=Jb(d+72|0);v[23048]=0;W(462,b|0,e|0,v[d+52>>2])|0;f=v[23048];v[23048]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{if((f|0)!=1){v[23048]=0;S(622,d+40|0,18504);f=v[23048];v[23048]=0;if((f|0)==1){break Ha}v[d+36>>2]=l;v[23048]=0;T(13,d+24|0,0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break Ga}v[23048]=0;Y(623,d+56|0,d+40|0,d+36|0,d+24|0);f=v[23048];v[23048]=0;if((f|0)==1){break Fa}v[23048]=0;T(601,a|0,2,d+56|0);f=v[23048];v[23048]=0;if((f|0)==1){break Ea}vb(d+56|0);vb(d+24|0);Hb(d+40|0);vb(e);break ta}a=P()|0;O()|0;break Ba}a=P()|0;O()|0;break Ba}a=P()|0;O()|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;vb(d+56|0)}vb(d+24|0)}Hb(d+40|0)}vb(e);break j}v[23048]=0;Q(370,b|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break R}}e=0}f=v[b+8>>2];v[23048]=0;v[d+72>>2]=f;f=Jc(d+172|0,d+72|0);i=v[23048];v[23048]=0;if((i|0)==1){break S}v[d+172>>2]=v[f>>2];f=(e|0)!=0}g=g+1|0;if(g>>>0<x[a+480190>>1]){continue}break}break P}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}u[d+88>>1]=1;e=x[a+480190>>1];v[23048]=0;u[d+72>>1]=e;e=Le(d+88|0,d+72|0);g=v[23048];v[23048]=0;Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{if((g|0)!=1){u[a+480190>>1]=x[e>>1];Sa:{if(!(h&1)|(w[d+328|0]|w[d+329|0]<<8)!=516|(w[d+334|0]|w[d+335|0]<<8|(w[d+330|0]|w[d+331|0]<<8)!=512)){break Sa}if(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)|((w[d+332|0]|w[d+333|0]<<8)&65527)!=21|(w[d+336|0]!=128|w[d+337|0]!=48)){break Sa}if(w[d+341|0]|w[d+340|0]!=128|(w[d+342|0]|w[d+343|0]<<8)){break Sa}h=d+416|0;e=d+352|0;g=1;while(1){g=(w[e|0]|128)!=160?0:g;e=e+1|0;if((h|0)!=(e|0)){continue}break}h=d+480|0;e=d+416|0;while(1){g=w[e|0]==64&g;e=e+1|0;if((h|0)!=(e|0)){continue}break}e=20;while(1){g=!w[(d+e|0)+292|0]&g;e=e+1|0;if((e|0)!=26){continue}break}if(!g){break Sa}v[23048]=0;e=Q(2,d+88|0,18582)|0;g=v[23048];v[23048]=0;if((g|0)==1){break Ja}Eb(j,e);vb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;C=d,D=Lb(m),u[C+88>>1]=D;e=v[a+8>>2];v[23048]=0;e=Vc(d+88|0,e+10|0);g=v[23048];v[23048]=0;if((g|0)==1){break Ra}e=x[e>>1];u[d+52>>1]=e;if((Lb(m)|0)!=(e|0)){v[23048]=0;_(625,d+72|0);e=v[23048];v[23048]=0;if((e|0)==1){break Qa}e=Lb(m);v[23048]=0;v[d+56>>2]=e;Y(626,d+88|0,d+72|0,d+56|0,d+52|0);e=v[23048];v[23048]=0;if((e|0)==1){break Pa}v[23048]=0;T(601,a|0,2,d+88|0);e=v[23048];v[23048]=0;if((e|0)==1){break Oa}vb(d+88|0);Hb(d+72|0)}if(c&1){break Ma}u[d+52>>1]=0;break La}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Na}a=P()|0;O()|0;vb(d+88|0)}Hb(d+72|0);break j}if(!x[d+52>>1]){break La}e=0;while(1){c=Mb(m,e);Ta:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break Ta}c=Mb(m,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23048]=0;c=Q(248,b|0,c|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break Ka}if(!c){break Ta}v[23048]=0;c=U(340,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break k}v[23048]=0;i=U(340,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break l}if((i-1&65535)>>>0>1023){break Ta}v[23048]=0;g=Q(370,b|0,4)|0;h=v[23048];v[23048]=0;if((h|0)==1){break l}if(!g){break Ta}v[23048]=0;T(341,d+88|0,b|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break m}h=0;c=x[a+480188>>1];v[23048]=0;c=Q(627,d+72|0,c|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break o}while(1){Ua:{v[23048]=0;g=Q(250,d+88|0,1)|0;k=v[23048];v[23048]=0;Va:{Wa:{if((k|0)!=1){if(!g){break Ua}v[23048]=0;g=U(373,d+88|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break p}k=g<<24>>24;if(k){break Wa}h=h+1|0;break Va}break p}Xa:{g=k&127;l=g?g-1|0:0;g=l&65535;if(qc(c)>>>0>g>>>0){break Xa}v[23048]=0;t[d+56|0]=0;T(628,c|0,g+1|0,d+56|0);p=v[23048];v[23048]=0;if((p|0)!=1){break Xa}break p}if((k|0)<=-1){v[23048]=0;k=U(373,d+88|0)|0;p=v[23048];v[23048]=0;if((p|0)==1){break p}C=oc(c,g),D=k,t[C|0]=D}if(!(!(w[oc(c,g)|0]&15)|g>>>0<x[a+480188>>1])){u[a+480188>>1]=l+1}if(t[oc(c,g)|0]&1){v[23048]=0;Q(370,d+88|0,1)|0;k=v[23048];v[23048]=0;if((k|0)==1){break p}}if(w[oc(c,g)|0]&2){v[23048]=0;Q(370,d+88|0,1)|0;k=v[23048];v[23048]=0;if((k|0)==1){break p}}if(w[oc(c,g)|0]&4){v[23048]=0;Q(370,d+88|0,1)|0;k=v[23048];v[23048]=0;if((k|0)==1){break p}}if(!(w[oc(c,g)|0]&8)){break Va}v[23048]=0;Q(370,d+88|0,2)|0;g=v[23048];v[23048]=0;if((g|0)==1){break p}}if(h>>>0<i>>>0){continue}}break}g=v[b+8>>2];v[23048]=0;v[d+56>>2]=g;g=Jc(d+172|0,d+56|0);h=v[23048];v[23048]=0;if((h|0)==1){break p}v[d+172>>2]=v[g>>2];gc(c);yb(d+88|0)}e=e+1|0;if(e>>>0<x[d+52>>1]){continue}break}}Ya:{Za:{c=v[d+172>>2];if(!c){break Za}v[23048]=0;Q(248,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break q}if(!(f&1)){break Za}while(1){_a:{v[23048]=0;c=Q(250,b|0,4)|0;e=v[23048];v[23048]=0;if((e|0)==1){break _a}if(!c){break Za}v[23048]=0;c=Q(596,b|0,18688)|0;e=v[23048];v[23048]=0;if((e|0)==1){break _a}$a:{if(!c){v[23048]=0;c=Q(596,b|0,18693)|0;e=v[23048];v[23048]=0;if((e|0)==1){break _a}if(!c){break $a}}v[23048]=0;c=U(376,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Ya}kg(b,8);if(c&-2139062144){break $a}if(c&1616928864){break Za}}v[23048]=0;c=U(340,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break _a}v[23048]=0;Q(370,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break j}v[23048]=0;c=Q(629,a|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}c=c|w[d+287|0];t[d+287|0]=c;if(!(!c|A)){rv(a+1074308|0);t[a+1074364|0]=0}v[23048]=0;Y(630,a|0,b|0,0,d+287|0);c=v[23048];v[23048]=0;if((c|0)==1){break q}v[23048]=0;l=a+484344|0;S(385,l|0,x[d+52>>1]);c=v[23048];v[23048]=0;if((c|0)==1){break q}u[d+36>>1]=0;if(!x[d+52>>1]){break Ia}g=0;while(1){ab:{bb:{c=Mb(m,g);cb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Mb(m,x[d+36>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23048]=0;c=Q(248,b|0,c|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break cb}if(c){break bb}}v[23048]=0;c=W(386,l|0,x[d+36>>1],64)|0;e=v[23048];v[23048]=0;if((e|0)==1){break cb}if(!c){v[23048]=0;_(631,d+72|0);c=v[23048];v[23048]=0;db:{eb:{fb:{if((c|0)!=1){v[23048]=0;T(632,d+88|0,d+72|0,d+36|0);c=v[23048];v[23048]=0;if((c|0)==1){break fb}v[23048]=0;T(601,a|0,2,d+88|0);c=v[23048];v[23048]=0;if((c|0)==1){break eb}vb(d+88|0);Hb(d+72|0);break Ia}a=P()|0;O()|0;break j}a=P()|0;O()|0;break db}a=P()|0;O()|0;vb(d+88|0)}Hb(d+72|0);break j}c=Yb(l,x[d+36>>1]);v[23048]=0;S(633,c|0,z|0);c=v[23048];v[23048]=0;if((c|0)!=1){break ab}}a=P()|0;O()|0;break j}v[23048]=0;c=U(340,b|0)|0;e=v[23048];v[23048]=0;gb:{hb:{if((e|0)!=1){v[23048]=0;p=U(340,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break hb}v[23048]=0;e=Q(370,b|0,4)|0;f=v[23048];v[23048]=0;if((f|0)==1){break hb}if(!e){break ab}v[23048]=0;e=W(386,l|0,x[d+36>>1],p|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break hb}if(e){break gb}break ab}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[23048]=0;T(341,d+88|0,b|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=Yb(l,x[d+36>>1]);v[23048]=0;S(633,c|0,z|0);c=v[23048];v[23048]=0;ib:{if((c|0)!=1){c=x[a+480188>>1];v[23048]=0;k=Q(627,d+72|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){c=x[a+480188>>1];$h(d+40|0);v[23048]=0;i=W(634,d+56|0,c|0,d+40|0)|0;c=v[23048];v[23048]=0;jb:{if((c|0)!=1){C=d,D=Rb(Yb(l,x[d+36>>1])),v[C+24>>2]=D;r=0;kb:{if(!p){break kb}while(1){v[23048]=0;c=Q(250,d+88|0,1)|0;e=v[23048];v[23048]=0;lb:{if((e|0)!=1){mb:{if(!c){break kb}v[23048]=0;c=U(373,d+88|0)|0;e=v[23048];v[23048]=0;nb:{if((e|0)!=1){c=c<<24>>24;if(c){break nb}nX(d+24|0,x[a+480188>>1]);r=r+1|0;break lb}break mb}ob:{e=c&127;h=e?e-1&65535:0;if(qc(k)>>>0>h>>>0){break ob}v[23048]=0;t[d+40|0]=0;e=h+1|0;T(628,k|0,e|0,d+40|0);f=v[23048];v[23048]=0;if((f|0)==1){break mb}$h(d+40|0);v[23048]=0;T(635,i|0,e|0,d+40|0);e=v[23048];v[23048]=0;if((e|0)!=1){break ob}break mb}if((c|0)<=-1){v[23048]=0;c=U(373,d+88|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break mb}C=oc(k,h),D=c,t[C|0]=D}$h(d+40|0);e=d+40|0;if(h>>>0<x[a+480188>>1]){e=ad(d+24|0,h)}if(w[oc(k,h)|0]&16){C=e,D=w[ad(i,h)|0],t[C|0]=D}if(w[oc(k,h)|0]&32){C=e,D=w[ad(i,h)+1|0],t[C+1|0]=D}if(w[oc(k,h)|0]&64){C=e,D=w[ad(i,h)+2|0],t[C+2|0]=D;C=e,D=w[ad(i,h)+4|0],t[C+4|0]=D}if(t[oc(k,h)|0]<=-1){C=e,D=w[ad(i,h)+3|0],t[C+3|0]=D;C=e,D=w[ad(i,h)+5|0],t[C+5|0]=D}if(t[oc(k,h)|0]&1){v[23048]=0;c=U(373,d+88|0)|0;f=v[23048];v[23048]=0;g=e;pb:{qb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break qb}f=c;break pb}break mb}f=253;if((c-121&255)>>>0<132){break pb}f=(c&255)==253?0:c}t[g|0]=f;C=ad(i,h),D=f,t[C|0]=D}if(w[oc(k,h)|0]&2){v[23048]=0;c=U(373,d+88|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break mb}t[e+1|0]=c;C=ad(i,h),D=c,t[C+1|0]=D}if(w[oc(k,h)|0]&4){v[23048]=0;g=U(373,d+88|0)|0;f=v[23048];v[23048]=0;c=e;rb:{sb:{tb:{if((f|0)!=1){if(g>>>0>64){break tb}t[e+4|0]=g;f=1;break sb}break mb}if(!(g<<24>>24>-1|g>>>0>192)){f=2;t[e+2|0]=2;t[e+4|0]=g^128;break rb}if(g>>>0<=74){f=5;t[e+2|0]=5;t[e+4|0]=g-65;break rb}if(g>>>0<=84){f=6;t[e+2|0]=6;t[e+4|0]=g-75;break rb}if(g>>>0<=94){f=3;t[e+2|0]=3;t[e+4|0]=g-85;break rb}if(g>>>0<=104){f=4;t[e+2|0]=4;t[e+4|0]=g-95;break rb}if(g>>>0<=114){f=13;t[e+2|0]=13;t[e+4|0]=g-105;break rb}if(g>>>0<=124){f=12;t[e+2|0]=12;t[e+4|0]=g-115;break rb}f=g+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;f=11;break sb}f=g+53|0;n=f&255;if(n>>>0<=9){t[e+4|0]=f;f=8;t[e+2|0]=8;if(!n|v[a+1074304>>2]-1>>>0>18285139){break rb}f=7;break sb}f=g+33|0;if((f&255)>>>0>=10){f=w[e+2|0];break rb}t[e+4|0]=f;f=15}t[c+2|0]=f}C=ad(i,h),D=f,t[C+2|0]=D;c=w[e+4|0];C=ad(i,h),D=c,t[C+4|0]=D}if(!(w[oc(k,h)|0]&8)){break lb}v[23048]=0;S(452,d+16|0,d+88|0);c=v[23048];v[23048]=0;if((c|0)!=1){ub:{c=rd(d+16|0);t[e+3|0]=w[d+16|0];t[e+5|0]=w[c|0];v[23048]=0;Wu(e,1);c=v[23048];v[23048]=0;if((c|0)==1){break ub}c=w[e+3|0];C=ad(i,h),D=c,t[C+3|0]=D;c=w[e+5|0];C=ad(i,h),D=c,t[C+5|0]=D;break lb}}}}a=P()|0;O()|0;_m(i);break jb}if(p>>>0>r>>>0){continue}break}}_m(i);gc(k);yb(d+88|0);break ab}a=P()|0;O()|0}gc(k);break ib}a=P()|0;O()|0;break ib}a=P()|0;O()|0}yb(d+88|0);break j}a=P()|0;O()|0;break j}c=x[d+36>>1]+1|0;u[d+36>>1]=c;g=c&65535;if(g>>>0<x[d+52>>1]){continue}break}break Ia}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}c=a+1074304|0;vb:{wb:{xb:{if(v[a+1074304>>2]){break xb}if((w[d+328|0]|w[d+329|0]<<8)==2184){v[a+1074304>>2]=18284544;break xb}if(!v[c>>2]){break wb}}if(!hd(j)){break wb}v[23048]=0;e=Q(2,d+72|0,18750)|0;f=v[23048];v[23048]=0;yb:{zb:{Ab:{Bb:{Cb:{Db:{if((f|0)!=1){v[23048]=0;S(230,d+56|0,c|0);f=v[23048];v[23048]=0;if((f|0)==1){break Db}v[23048]=0;T(3,d+88|0,e|0,d+56|0);f=v[23048];v[23048]=0;if((f|0)==1){break Cb}Eb(j,d+88|0);vb(d+88|0);vb(d+56|0);vb(e);if(v[d+348>>2]==1414548815|((w[d+328|0]|w[d+329|0]<<8)&61440)!=20480){break yb}v[23048]=0;c=Q(2,d+88|0,18759)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Ab}v[23048]=0;Q(183,j|0,c|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break zb}vb(c);break vb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Bb}a=P()|0;O()|0;vb(d+56|0)}vb(e);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if(!eG(c)){break vb}v[23048]=0;c=Q(2,d+88|0,18783)|0;e=v[23048];v[23048]=0;Eb:{if((e|0)!=1){v[23048]=0;Q(183,j|0,c|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Eb}vb(c);break vb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}Fb:{switch((w[d+328|0]|w[d+329|0]<<8)>>>12|0){case 0:if(A){v[23048]=0;c=Q(2,d+88|0,18797)|0;e=v[23048];v[23048]=0;if((e|0)!=1){Eb(j,c);vb(c);break vb}a=P()|0;O()|0;break j}Gb:{if((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=512|(w[d+334|0]|w[d+335|0]<<8|(w[d+332|0]|w[d+333|0]<<8)!=9)){break Gb}if(w[d+319|0]|w[d+318|0]|(w[d+322|0]|w[d+323|0]<<8|((w[d+326|0]|w[d+327|0]<<8)+1|0)!=(w[d+320|0]|w[d+321|0]<<8))){break Gb}if(w[d+336|0]!=128|w[d+337|0]!=100|(w[d+338|0]!=1|w[d+340|0]!=128)){break Gb}if(w[d+341|0]|(w[d+342|0]|w[d+343|0]<<8)|(w[d+344|0]|w[d+345|0]<<8|(w[d+346|0]<<16|w[d+347|0]<<24)|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)))){break Gb}v[23048]=0;c=Q(2,d+88|0,18809)|0;e=v[23048];v[23048]=0;if((e|0)!=1){Eb(j,c);vb(c);break vb}a=P()|0;O()|0;break j}Hb:{if((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=512|(w[d+319|0]|w[d+318|0])){break Hb}if(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)){break Hb}v[a+1074304>>2]=16777381;v[23048]=0;c=Q(2,d+88|0,18828)|0;e=v[23048];v[23048]=0;if((e|0)!=1){Eb(j,c);vb(c);t[d+287|0]=1;break vb}a=P()|0;O()|0;break j}if(!((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=532|v[d+348>>2]!=1229080643)){v[23048]=0;c=Q(2,d+88|0,18851)|0;e=v[23048];v[23048]=0;if((e|0)!=1){Eb(j,c);vb(c);v[23048]=0;Q(459,a+1074308|0,38)|0;c=v[23048];v[23048]=0;if((c|0)==1){break q}break vb}a=P()|0;O()|0;break j}Ib:{if((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=532|(w[d+341|0]|(w[d+334|0]|w[d+335|0]<<8)>>>0>1)){break Ib}if(!x[a+480190>>1]|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)|((w[d+332|0]|w[d+333|0]<<8)&4294)!=4)){break Ib}v[23048]=0;c=Q(91,d+88|0,18864)|0;e=v[23048];v[23048]=0;Jb:{Kb:{if((e|0)!=1){v[23048]=0;e=Q(637,a+484527|0,c|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Kb}vb(c);if(!e){break Ib}v[23048]=0;c=Q(2,d+88|0,18877)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Jb}Eb(j,c);vb(c);break vb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0;break j}Lb:{if(w[d+328|0]|w[d+329|0]<<8){break Lb}if(!hd(j)){break Lb}v[23048]=0;c=Q(2,d+88|0,18891)|0;e=v[23048];v[23048]=0;if((e|0)!=1){Eb(j,c);vb(c);break vb}a=P()|0;O()|0;break j}if((w[d+330|0]|w[d+331|0]<<8)>>>0>767){break vb}if(!hd(j)){break vb}Mb:{Nb:{Ob:{Pb:{Qb:{if((w[d+330|0]|w[d+331|0]<<8)>>>0>=533){v[23048]=0;c=Q(2,d+88|0,18899)|0;e=v[23048];v[23048]=0;if((e|0)!=1){Eb(j,c);vb(c);break Qb}a=P()|0;O()|0;break j}if((w[d+328|0]|w[d+329|0]<<8)>>>0>=533){v[23048]=0;S(638,d+72|0,18920);c=v[23048];v[23048]=0;Rb:{if((c|0)!=1){c=w[d+328|0]|w[d+329|0]<<8;v[23048]=0;v[d+56>>2]=c-532;T(639,d+88|0,d+72|0,d+56|0);c=v[23048];v[23048]=0;if((c|0)==1){break Rb}Eb(j,d+88|0);vb(d+88|0);Hb(d+72|0);break Qb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+72|0);break j}v[23048]=0;S(460,d+72|0,18944);c=v[23048];v[23048]=0;if((c|0)==1){break Pb}v[d+40>>2]=w[d+329|0]&15;c=w[d+328|0];v[23048]=0;v[d+24>>2]=c;S(640,d+56|0,d+24|0);c=v[23048];v[23048]=0;if((c|0)==1){break Ob}v[23048]=0;Y(623,d+88|0,d+72|0,d+40|0,d+56|0);c=v[23048];v[23048]=0;if((c|0)==1){break Nb}Eb(j,d+88|0);vb(d+88|0);vb(d+56|0);Hb(d+72|0)}c=a+1300408|0;if(!cd(c)|!(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24))){break vb}e=w[d+328|0]|w[d+329|0]<<8;f=w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24);v[23048]=0;e=jw(e,f);f=v[23048];v[23048]=0;if((f|0)==1){break t}f=Gr(d+88|0);v[f+44>>2]=e;v[23048]=0;S(642,c|0,f|0);c=v[23048];v[23048]=0;if((c|0)!=1){break vb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Mb}a=P()|0;O()|0;vb(d+56|0)}Hb(d+72|0);break j;case 1:c=w[d+328|0]|w[d+329|0]<<8;e=w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24);v[23048]=0;T(643,d+88|0,c|0,e|0);c=v[23048];v[23048]=0;Sb:{if((c|0)!=1){Eb(j,d+88|0);vb(d+88|0);if((w[d+328|0]|w[d+329|0]<<8)>>>0>6091){break Sb}v[23048]=0;Q(459,a+1074308|0,7)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break Sb}break q}a=P()|0;O()|0;break j}if((w[d+328|0]|w[d+329|0]<<8)>>>0>6561){break vb}v[23048]=0;Q(459,a+1074308|0,38)|0;c=v[23048];v[23048]=0;if((c|0)==1){break q}break vb;case 4:v[23048]=0;S(644,d+72|0,18966);c=v[23048];v[23048]=0;Tb:{Ub:{Vb:{if((c|0)!=1){v[d+40>>2]=w[d+329|0]&15;c=w[d+328|0];v[23048]=0;v[d+24>>2]=c;S(640,d+56|0,d+24|0);c=v[23048];v[23048]=0;if((c|0)==1){break Vb}v[23048]=0;Y(623,d+88|0,d+72|0,d+40|0,d+56|0);c=v[23048];v[23048]=0;if((c|0)==1){break Ub}Eb(j,d+88|0);vb(d+88|0);vb(d+56|0);Hb(d+72|0);break vb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Tb}a=P()|0;O()|0;vb(d+56|0)}Hb(d+72|0);break j;case 6:v[23048]=0;c=Q(2,d+88|0,18797)|0;e=v[23048];v[23048]=0;if((e|0)!=1){Eb(j,c);vb(c);break vb}a=P()|0;O()|0;break j;case 7:if(!((w[d+328|0]|w[d+329|0]<<8)!=32767|(w[d+330|0]|w[d+331|0]<<8)!=533)){v[23048]=0;c=Q(2,d+88|0,18977)|0;e=v[23048];v[23048]=0;if((e|0)!=1){Eb(j,c);vb(c);break vb}a=P()|0;O()|0;break j}v[23048]=0;S(226,d+72|0,18986);c=v[23048];v[23048]=0;Wb:{if((c|0)!=1){v[d+56>>2]=w[d+329|0]&15;v[d+40>>2]=(w[d+328|0]|w[d+329|0]<<8)>>>4&15;c=w[d+328|0]|w[d+329|0]<<8;v[23048]=0;v[d+24>>2]=c&15;ea(227,d+88|0,d+72|0,d+56|0,d+40|0,d+24|0);c=v[23048];v[23048]=0;if((c|0)==1){break Wb}Eb(j,d+88|0);vb(d+88|0);Hb(d+72|0);break vb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+72|0);break j;case 13:break Fb;default:break vb}}v[23048]=0;c=Q(2,d+88|0,19001)|0;e=v[23048];v[23048]=0;if((e|0)==1){break s}Eb(j,c);vb(c)}Xb:{if(v[a+480180>>2]!=16777216|(w[d+328|0]|w[d+329|0]<<8)>>>0<2186){break Xb}v[23048]=0;c=Q(248,b|0,s|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}if(!c){break Xb}c=w[d+328|0]|w[d+329|0]<<8;v[23048]=0;T(645,a|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break q}}b=v[a+480180>>2];Yb:{if((b|0)==16777216){v[23048]=0;Q(2,d+88|0,19008)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break Yb}a=P()|0;O()|0;break j}v[23048]=0;S(460,d+72|0,18944);c=v[23048];v[23048]=0;if((c|0)==1){break x}v[d+40>>2]=w[d+331|0];c=w[d+330|0];v[23048]=0;v[d+24>>2]=c;S(640,d+56|0,d+24|0);c=v[23048];v[23048]=0;if((c|0)==1){break w}v[23048]=0;Y(623,d+88|0,d+72|0,d+40|0,d+56|0);c=v[23048];v[23048]=0;if((c|0)==1){break v}}Eb(a+1300344|0,d+88|0);vb(d+88|0);if((b|0)!=16777216){vb(d+56|0);Hb(d+72|0)}Zb:{if(v[a+480180>>2]==16777216){v[23048]=0;Q(2,d+88|0,19021)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break Zb}break r}v[23048]=0;Q(2,d+88|0,19026)|0;b=v[23048];v[23048]=0;if((b|0)==1){break r}}Eb(a+1300356|0,d+88|0);vb(d+88|0);Eb(a+1300368|0,j);v[a+1300404>>2]=v[a+1074304>>2]?8:5;yb(d+176|0);yb(z);g=1}Yh(m);Yh(o);Yh(q);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0;break u}a=P()|0;O()|0;vb(d+56|0)}Hb(d+72|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;gc(c);break n}a=P()|0;O()|0}yb(d+88|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0}yb(d+176|0)}yb(z);break g}a=P()|0;O()|0}Yh(m);Yh(o);Yh(q);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}vb(j)}gb=d+480|0;return g|0}a=P()|0;O()|0}vb(j);R(a|0);L()}function tma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=gb-1568|0;gb=d;yc(b);a:{if(!dh(b,d+1560|0)){break a}if(!LV(d+1560|0)){break a}if(!c){e=1;break a}g=w[d+1560|3];t[d+1559|0]=g;v[d+1552>>2]=-1;v[d+1548>>2]=1048576;if(g>>>0>=5){g=_f(b);v[d+1552>>2]=g;if(!Nb(b,g)){break a}v[d+160>>2]=134217727;J=d,K=v[Gb(d+160|0,d+1552|0)>>2]<<5,v[J+1548>>2]=K}D=nc(d+1536|0);e=d+1560|4;g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[23048]=0;v[d+160>>2]=g;g=Gb(d+1548|0,d+160|0);f=v[23048];v[23048]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((f|0)==1){break x}g=v[g>>2];v[23048]=0;S(767,D|0,g|0);g=v[23048];v[23048]=0;if((g|0)==1){break x}g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=0;v[23048]=0;g=W(768,b|0,D|0,g|0)|0;f=v[23048];v[23048]=0;y:{if((f|0)==1){break y}if(!g){break t}if(w[d+1559|0]>=5){v[23048]=0;Q(248,b|0,v[d+1552>>2]+12|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break y}}v[23048]=0;S(428,a|0,0);g=v[23048];v[23048]=0;if((g|0)==1){break y}v[23048]=0;sg(a);g=v[23048];v[23048]=0;if((g|0)==1){break y}v[23048]=0;me(d+1504|0,D);f=v[23048];v[23048]=0;g=a;z:{A:{B:{C:{if((f|0)!=1){h=Xd(d+1496|0);v[23048]=0;f=v[d+1508>>2];v[d+32>>2]=v[d+1504>>2];v[d+36>>2]=f;k=W(770,d+1512|0,d+32|0,h|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break C}Bc(h);v[23048]=0;W(573,k|0,a+1300308|0,-1)|0;f=v[23048];v[23048]=0;if((f|0)==1){break B}v[23048]=0;W(573,k|0,a+1300332|0,-1)|0;f=v[23048];v[23048]=0;if((f|0)==1){break B}v[23048]=0;f=Q(771,k|0,d+1072|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(!f|!w[d+1072|0]|t[d+1072|0]<0){break u}f=d+1081|0;if((w[f|0]|w[f+1|0]<<8)>>>0>255){break u}h=d+1083|0;if((w[h|0]|w[h+1|0]<<8)>>>0>3999){break u}u[a+480188>>1]=w[d+1072|0];j=a+484360|0;m=d+1072|3;ff(Qb(j),w[m|0]|w[m+1|0]<<8);u[a+480192>>1]=w[f|0]|w[f+1|0]<<8;u[a+480190>>1]=w[h|0]|w[h+1|0]<<8;f=d+1085|0;if(w[f|0]){break A}f=6;break z}f=P()|0;O()|0;break b}f=P()|0;O()|0;Bc(h);break b}f=P()|0;O()|0;break c}f=w[f|0]}v[g+480196>>2]=f;g=a;h=d+1086|0;f=125e4;D:{if(!w[h|0]){break D}f=B(w[h|0],1e4)}v[g+480204>>2]=f;m=d+1087|0;E:{if(t[m+1|0]&1){v[23048]=0;S(599,a|0,32);g=v[23048];v[23048]=0;if((g|0)!=1){break E}break d}if(w[m|0]&2){v[23048]=0;S(599,a|0,2);g=v[23048];v[23048]=0;if((g|0)==1){break d}break E}if(w[m|0]&128){v[23048]=0;S(599,a|0,1);g=v[23048];v[23048]=0;if((g|0)==1){break d}break E}if(w[m|0]&8){v[23048]=0;S(599,a|0,16);g=v[23048];v[23048]=0;if((g|0)==1){break d}break E}v[23048]=0;S(599,a|0,4);g=v[23048];v[23048]=0;if((g|0)==1){break d}}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[m|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[m|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[m|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[m+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[m+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[m+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[m+2|0]&8){v[23048]=0;W(458,a+1074308|0,5,1)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}}F:{g=v[a+480180>>2];G:{if((g|0)!=2){if((g|0)!=32){break G}t[d+160|0]=w[d+1091|0];v[23048]=0;t[d+80|0]=128;g=$b(d+160|0,d+80|0);f=v[23048];v[23048]=0;if((f|0)==1){break w}v[a+480200>>2]=w[g|0]<<1;break G}t[d+160|0]=w[d+1091|0];v[23048]=0;t[d+80|0]=64;g=$b(d+160|0,d+80|0);f=v[23048];v[23048]=0;if((f|0)==1){break F}v[a+480200>>2]=w[g|0]<<2}G=a+480188|0;h=d+1093|0;f=t[h|0];g=a;if(t[h|0]<=-1){f=f+52|0}else{F=Qw(+(f|0)*.15500000000000003);H:{if(F<4294967296&F>=0){f=~~F>>>0;break H}f=0}f=f+51|0}v[g+480228>>2]=f;v[23048]=0;u[d+160>>1]=64;g=Vc(G,d+160|0);f=v[23048];v[23048]=0;if((f|0)!=1){I:{f=x[g>>1];if(f){while(1){g=v[a+480180>>2];if((g|0)==32){t[d+160|0]=w[(d+e|0)+1094|0];v[23048]=0;t[d+80|0]=64;g=$b(d+160|0,d+80|0);h=v[23048];v[23048]=0;if((h|0)==1){break I}u[((e<<5)+a|0)+480286>>1]=w[g|0];g=v[a+480180>>2]}J:{if((g|0)==4){break J}g=(d+e|0)+1158|0;if(w[g|0]==127){v[((e<<5)+a|0)+480280>>2]=256;break J}if(w[g|0]==255){u[((e<<5)+a|0)+480284>>1]=256;break J}u[((e<<5)+a|0)+480284>>1]=w[g|0]}e=e+1|0;if((f|0)!=(e|0)){continue}break}}h=0;e=0;f=0;while(1){e=w[(d+f|0)+1222|0]!=0|e;f=f+1|0;if((f|0)!=16){continue}break}while(1){e=w[((h<<1)+d|0)+1239|0]!=0|e;h=h+1|0;if((h|0)!=128){continue}break}if(e&1){e=0;while(1){K:{g=(d+e|0)+1222|0;if(w[g|0]){v[23048]=0;_(772,d+80|0);f=v[23048];v[23048]=0;L:{M:{N:{O:{P:{if((f|0)!=1){g=w[g|0];v[23048]=0;v[d+104>>2]=g-1;S(773,d+1048|0,d+104|0);g=v[23048];v[23048]=0;if((g|0)==1){break P}v[23048]=0;T(491,d+160|0,d+80|0,d+1048|0);g=v[23048];v[23048]=0;if((g|0)==1){break O}v[23048]=0;Ye(d+1024|0,((e<<5)+a|0)+901692|0);g=v[23048];v[23048]=0;if((g|0)==1){break N}v[23048]=0;Q(450,d+1024|0,d+160|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break N}vb(d+160|0);vb(d+1048|0);Hb(d+80|0);break K}f=P()|0;O()|0;break c}f=P()|0;O()|0;break L}f=P()|0;O()|0;break M}f=P()|0;O()|0;vb(d+160|0)}vb(d+1048|0)}Hb(d+80|0);break c}v[23048]=0;g=Q(91,d+160|0,23944)|0;f=v[23048];v[23048]=0;Q:{if((f|0)!=1){v[23048]=0;Ye(d+80|0,((e<<5)+a|0)+901692|0);f=v[23048];v[23048]=0;if((f|0)==1){break Q}v[23048]=0;Q(450,d+80|0,g|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Q}vb(g);break K}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(g);break c}e=e+1|0;if((e|0)!=16){continue}break}e=0;while(1){g=(d+1072|0)+(e<<1)|0;f=g;R:{if(w[f+167|0]){v[23048]=0;_(774,d+80|0);h=v[23048];v[23048]=0;S:{T:{U:{V:{W:{X:{Y:{if((h|0)!=1){f=w[f+167|0];v[23048]=0;v[d+48>>2]=f-1;S(773,d+1048|0,d+48|0);f=v[23048];v[23048]=0;if((f|0)==1){break Y}g=w[g+166|0];v[23048]=0;t[d+1008|0]=g;S(775,d+1024|0,d+1008|0);g=v[23048];v[23048]=0;if((g|0)==1){break X}v[23048]=0;Y(776,d+160|0,d+80|0,d+1048|0,d+1024|0);g=v[23048];v[23048]=0;if((g|0)==1){break W}v[23048]=0;Ye(d+104|0,((e<<5)+a|0)+902204|0);g=v[23048];v[23048]=0;if((g|0)==1){break V}v[23048]=0;Q(450,d+104|0,d+160|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break V}vb(d+160|0);vb(d+1024|0);vb(d+1048|0);Hb(d+80|0);break R}f=P()|0;O()|0;break c}f=P()|0;O()|0;break S}f=P()|0;O()|0;break T}f=P()|0;O()|0;break U}f=P()|0;O()|0;vb(d+160|0)}vb(d+1024|0)}vb(d+1048|0)}Hb(d+80|0);break c}v[23048]=0;g=Q(91,d+160|0,23944)|0;f=v[23048];v[23048]=0;Z:{if((f|0)!=1){v[23048]=0;Ye(d+80|0,((e<<5)+a|0)+902204|0);f=v[23048];v[23048]=0;if((f|0)==1){break Z}v[23048]=0;Q(450,d+80|0,g|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Z}vb(g);break R}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(g);break c}e=e+1|0;if((e|0)!=128){continue}break}}e=Qb(j);g=d+1072|1;g=w[g|0]|w[g+1|0]<<8;v[23048]=0;ga(560,e|0,k|0,g|0,255,254)|0;e=v[23048];v[23048]=0;_:{$:{aa:{ba:{ca:{da:{if((e|0)!=1){q=d+1072|5;e=w[q|0]|w[q+1|0]<<8;g=w[d+1072|0];v[23048]=0;T(341,d+1048|0,k|0,B(e,g)<<1);e=v[23048];v[23048]=0;if((e|0)==1){break da}e=w[q|0]|w[q+1|0]<<8;v[23048]=0;T(341,d+1024|0,k|0,e<<1);e=v[23048];v[23048]=0;if((e|0)==1){break ca}e=d+1072|7;e=w[e|0]|w[e+1|0]<<8;v[23048]=0;A=Q(380,d+1008|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break ba}J=d,K=Rb(A),v[J+80>>2]=K;J=d,K=Ub(A),v[J+104>>2]=K;if(Fb(d+80|0,d+104|0)){while(1){e=v[d+80>>2];v[23048]=0;g=U(376,k|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break aa}v[23048]=0;T(341,d+160|0,k|0,g|0);g=v[23048];v[23048]=0;if((g|0)==1){break $}id(e,d+160|0);yb(d+160|0);sh(d+80|0);if(Fb(d+80|0,d+104|0)){continue}break}}e=v[a+480180>>2];i=1;r=c&1;if(!r){break _}g=w[q|0]|w[q+1|0]<<8;v[23048]=0;S(385,a+484344|0,g|0);g=v[23048];v[23048]=0;if((g|0)!=1){break _}f=P()|0;O()|0;break g}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}E=a+484344|0;ea:{fa:{ga:{ha:{ia:{ja:{if(w[q|0]|w[q+1|0]<<8){o=(e|0)==16?14:(e|0)==32?1:13;while(1){v[23048]=0;e=U(340,d+1024|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break ea}v[d+80>>2]=e;ka:{if(!r){break ka}v[23048]=0;e=W(386,E|0,l&65535,e|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break ea}if(!e){break ka}j=0;if(!w[d+1072|0]){break ka}while(1){v[23048]=0;e=U(340,d+1048|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break fa}la:{if(cf(A)>>>0<=e>>>0){break la}z=Dg(A,e);yc(z);e=Yb(E,l);v[23048]=0;e=Wc(e,0,j&65535);g=v[23048];v[23048]=0;if((g|0)==1){break h}g=0;if(!v[d+80>>2]){break la}while(1){v[23048]=0;p=U(373,z|0)|0;f=v[23048];v[23048]=0;ma:{na:{if((f|0)!=1){if(!p){break la}$h(d+160|0);h=0;s=p&15;if(s){break na}break ma}f=P()|0;O()|0;break g}while(1){oa:{v[23048]=0;S(777,z|0,d+104|0);f=v[23048];v[23048]=0;if((f|0)==1){break oa}pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{f=w[d+104|0];switch(f-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break ra;case 33:break va;case 30:case 31:break wa;case 29:break xa;case 28:break ya;case 26:break za;case 19:case 20:break Aa;case 17:break Ba;case 15:break Ca;case 14:break Da;case 10:break Ea;case 6:break Fa;case 5:break Ga;case 1:break Ha;case 0:break Ia;default:break Ja}}switch(f-48|0){case 4:break sa;case 1:case 2:break ta;case 0:break ua;default:break ra}}f=w[d+105|0];Ka:{if(f>>>0<=119){t[d+160|0]=f+o;break Ka}La:{switch(f-254|0){case 1:t[d+160|0]=255;break Ka;case 0:t[d+160|0]=254;break Ka;default:break La}}t[d+160|0]=253}v[23048]=0;f=uv(d+160|0);n=v[23048];v[23048]=0;if((n|0)==1){break oa}i=f&i;break pa}t[d+161|0]=w[d+105|0]+1;break pa}Ma:{if(w[d+162|0]){break Ma}f=v[a+480180>>2];if((f|0)!=32){if((f|0)!=4){break Ma}f=w[d+105|0];if(f&15){break Ma}t[d+162|0]=11;t[d+164|0]=f>>>4;break pa}f=0;n=w[d+105|0];while(1){if((n|0)==w[f+33824|0]){t[d+164|0]=f;t[d+162|0]=11;break pa}f=f+1|0;if((f|0)!=10){continue}break}}t[d+163|0]=4;t[d+165|0]=w[d+105|0];break pa}f=w[d+105|0];if(!(w[d+162|0]|f>>>0>9|v[a+480180>>2]!=32)){t[d+164|0]=f;t[d+162|0]=8;break pa}t[d+165|0]=f;t[d+163|0]=5;break pa}Na:{if(w[d+162|0]){break Na}Oa:{f=v[a+480180>>2];if((f|0)!=4){if((f|0)!=32){break Na}f=w[d+105|0];if((f|0)!=255){break Oa}t[d+164|0]=64;t[d+162|0]=2;break pa}f=w[d+105|0];if(f&15){break Na}break qa}if(!(f&3)){break qa}}t[d+163|0]=9;t[d+165|0]=w[d+105|0];break pa}f=w[d+105|0];if(!(w[d+162|0]|f>>>0>64|v[a+480180>>2]==1)){t[d+164|0]=f;t[d+162|0]=1;break pa}t[d+165|0]=f;t[d+163|0]=13;break pa}t[d+163|0]=14;f=w[d+105|0];t[d+165|0]=f;if(v[a+480180>>2]==32){break pa}t[d+165|0]=B((f&240)>>>4|0,10)+(f&15);break pa}f=w[d+105|0];t[d+165|0]=f;if(f>>>0<=31){t[d+163|0]=16;break pa}t[d+163|0]=17;break pa}n=w[d+105|0];if(n>>>0>=16){t[d+164|0]=n>>>4;t[d+162|0]=(f|0)==20?3:5;break pa}t[d+164|0]=n;t[d+162|0]=(f|0)==20?4:6;break pa}f=w[d+105|0];if(f>>>0>=16){t[d+162|0]=10;t[d+164|0]=f>>>4;break pa}t[d+164|0]=f;t[d+162|0]=9;break pa}t[d+163|0]=28;t[d+165|0]=w[d+105|0]|16;break pa}t[d+163|0]=28;t[d+165|0]=w[d+105|0]|32;break pa}t[d+164|0]=w[d+105|0];t[d+162|0]=w[f+23968|0];break pa}t[d+165|0]=w[d+105|0];f=w[d+163|0];t[d+163|0]=(f|0)==4?6:(f|0)==5?7:11;break pa}f=w[d+105|0];t[d+164|0]=(f>>>0)%10;if(f>>>0<=9){t[d+162|0]=5;break pa}if(f>>>0<=19){t[d+162|0]=6;break pa}if(f>>>0<=29){t[d+162|0]=3;break pa}if(f>>>0>39){break pa}t[d+162|0]=4;break pa}t[d+164|0]=w[d+105|0];t[d+162|0]=w[f+23968|0];break pa}f=w[d+105|0]+33|0;if((f&255)>>>0>9){break pa}t[d+164|0]=f;t[d+162|0]=15;break pa}if(f>>>0>=56){break pa}t[d+165|0]=w[d+105|0];t[d+163|0]=w[w[d+104|0]+23968|0];break pa}t[d+162|0]=2;t[d+164|0]=f>>>2}h=h+1|0;if(s>>>0>(h&255)>>>0){continue}break ma}break}f=P()|0;O()|0;break g}v[23048]=0;v[d+104>>2]=(p>>>4|0)+g;f=Gb(d+104|0,d+80|0);h=v[23048];v[23048]=0;if((h|0)==1){break ja}f=v[f>>2];if(f>>>0>g>>>0){while(1){h=v[d+160>>2];t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;h=x[d+164>>1];t[e+4|0]=h;t[e+5|0]=h>>>8;e=B(w[d+1072|0],6)+e|0;g=g+1|0;if((f|0)!=(g|0)){continue}break}g=f}if(y[d+80>>2]>g>>>0){continue}break}}j=j+1|0;if(w[d+1072|0]>(j&65535)>>>0){continue}break}}l=l+1|0;if(l>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}}if(!((i^-1|x[a+480188>>1]!=4)&1|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ia}p=0;break ha}f=P()|0;O()|0;break g}p=!((w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))&512);e=0;if(v[a+480180>>2]!=4){break ga}}e=x[a+480192>>1]}v[23048]=0;q=Q(778,d+992|0,e|0)|0;e=v[23048];v[23048]=0;g=1;if((e|0)!=1){Pa:{Qa:{Ra:{if(x[a+480192>>1]){f=1;while(1){Sa:{Ta:{Ua:{if(!p){v[23048]=0;h=W(436,a|0,f&65535,0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Ua}if(h){break Ta}}while(1){v[23048]=0;e=U(373,k|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break j}if(e){continue}break}if(w[d+1559|0]>=5){while(1){v[23048]=0;e=U(373,k|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){f=P()|0;O()|0;break i}if(e){continue}break}}v[23048]=0;Q(370,k|0,826)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break Sa}}f=P()|0;O()|0;break i}e=Jb(d+80|0);v[23048]=0;W(573,k|0,e|0,-1)|0;j=v[23048];v[23048]=0;if((j|0)==1){break Ra}v[23048]=0;Q(354,h+492|0,e|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break Ra}Va:{if(w[d+1559|0]<5){break Va}v[23048]=0;W(573,k|0,e|0,-1)|0;j=v[23048];v[23048]=0;if((j|0)==1){break Ra}v[23048]=0;Q(354,h+524|0,e|0)|0;j=v[23048];v[23048]=0;if((j|0)!=1){break Va}break Ra}v[23048]=0;j=Q(779,k|0,d+160|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break Ra}if(!j){break Qa}j=v[a+480180>>2];v[23048]=0;T(780,d+160|0,h|0,j|0);h=v[23048];v[23048]=0;if((h|0)==1){break Ra}if(v[a+480180>>2]==4){g=Mb(q,g-1|0);h=x[d+962>>1]|x[d+964>>1]<<16;t[g|0]=h;t[g+1|0]=h>>>8;t[g+2|0]=h>>>16;t[g+3|0]=h>>>24}vb(e)}f=f+1|0;g=f&65535;if(g>>>0<=x[a+480192>>1]){continue}break}}if(!p){break Pa}u[a+480192>>1]=0;break Pa}f=P()|0;O()|0;vb(e);break i}vb(e)}e=x[a+480190>>1];v[23048]=0;z=Q(781,d+144|0,e|0)|0;e=v[23048];v[23048]=0;j=1;if((e|0)!=1){j=w[d+1559|0]<=4?!(t[m|0]&1):j;s=c&2;c=0;Wa:{if(!x[a+480190>>1]){break Wa}h=1;g=1;while(1){e=c;l=Jb(d+128|0);v[23048]=0;W(573,k|0,l|0,-1)|0;c=v[23048];v[23048]=0;Xa:{Ya:{Za:{_a:{$a:{if((c|0)==1){break $a}v[23048]=0;Q(354,((h<<5)+a|0)+946300|0,l|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break $a}i=B(h,104)+a|0;if(w[d+1559|0]<5){break _a}v[23048]=0;W(573,k|0,l|0,-1)|0;c=v[23048];v[23048]=0;if((c|0)==1){break $a}v[23048]=0;Q(355,i+484423|0,l|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break _a}}f=P()|0;O()|0;break Za}v[23048]=0;c=Q(782,k|0,d+160|0)|0;f=v[23048];v[23048]=0;ab:{bb:{cb:{db:{eb:{fb:{gb:{if((f|0)==1){break gb}if(!c){break fb}c=v[a+480180>>2];v[23048]=0;f=i+484380|0;Y(783,d+160|0,f|0,c|0,j|0);c=v[23048];v[23048]=0;if((c|0)==1){break gb}p=0;hb:{if(((w[d+180|0]|w[d+181|0]<<8)&61440)!=28672|w[d+1559|0]<5){break hb}v[23048]=0;p=U(784,k|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break hb}f=P()|0;O()|0;break Za}if(!s){break Ya}C=w[d+180|0]|w[d+181|0]<<8;n=C&61440;if(!(n|(w[d+195|0]|w[d+196|0]<<8|(w[d+197|0]<<16|w[d+198|0]<<24)))){c=Sc(d+80|0,(w[d+180|0]|w[d+181|0]<<8)&1?16:8,(w[d+180|0]|w[d+181|0]<<8)&1024?3:1,0,0);v[23048]=0;W(384,c|0,f|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break Ya}f=P()|0;O()|0;break Za}if(!(((w[d+195|0]|w[d+196|0]<<8|(w[d+197|0]<<16|w[d+198|0]<<24))+h|0)<1|(w[d+195|0]|w[d+196|0]<<8|(w[d+197|0]<<16|w[d+198|0]<<24))>-1)){c=w[d+195|0]|w[d+196|0]<<8|(w[d+197|0]<<16|w[d+198|0]<<24);v[23048]=0;Q(785,f|0,(B(c+h|0,104)+a|0)+484380|0)|0;f=v[23048];v[23048]=0;c=e;if((f|0)!=1){break Xa}f=P()|0;O()|0;break Za}if((w[d+195|0]|w[d+196|0]<<8|(w[d+197|0]<<16|w[d+198|0]<<24))<1){break Ya}if(t[d+180|0]&1){c=i+484414|0;u[c>>1]=x[c>>1]|1}if(w[d+181|0]&4){c=i+484414|0;u[c>>1]=x[c>>1]|64}c=w[d+195|0]|w[d+196|0]<<8|(w[d+197|0]<<16|w[d+198|0]<<24);v[23048]=0;T(341,d+104|0,b|0,c|0);r=v[23048];v[23048]=0;ib:{jb:{I=d;kb:{lb:{if((r|0)!=1){r=ld(f);H=(n|0)==16384;if((n|0)!=8192?!H:0){break jb}v[23048]=0;o=U(247,d+104|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ib}v[d+80>>2]=o;c=v[d+80>>2];o=4/(r>>>0)|0;if(c>>>0>4294967295/(o>>>0)>>>0){break lb}o=B(c,o);break kb}f=P()|0;O()|0;break Za}o=-1}v[I+80>>2]=o;tc(f,o);if(!H){if((n|0)!=8192){break jb}v[23048]=0;c=U(446,f|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break bb}if(!c){break db}if(t[d+180|0]&1){c=v[i+484400>>2];f=v[f>>2];v[23048]=0;Y(786,d+104|0,c|0,f|0,r|0);f=v[23048];v[23048]=0;c=e;if((f|0)!=1){break cb}break bb}c=v[i+484400>>2];f=v[f>>2];v[23048]=0;Y(787,d+104|0,c|0,f|0,r|0);f=v[23048];v[23048]=0;c=e;if((f|0)==1){break bb}break cb}v[23048]=0;c=U(446,f|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break bb}if(!c){break db}if(t[d+180|0]&1){c=v[i+484400>>2];f=v[f>>2];v[23048]=0;Y(788,d+104|0,c|0,f|0,r|0);f=v[23048];v[23048]=0;c=e;if((f|0)==1){break bb}break cb}c=v[i+484400>>2];f=v[f>>2];v[23048]=0;Y(789,d+104|0,c|0,f|0,r|0);f=v[23048];v[23048]=0;c=e;if((f|0)==1){break bb}break cb}if((C&45056)==12288){c=KV(d+80|0,d+104|0,w[d+199|0]|w[d+200|0]<<8,p);f=Il(z,h-1|0);id(f,c);v[f+20>>2]=v[c+20>>2];yb(c);break db}if((n|0)!=32768){c=1;if((n|0)!=4096){break cb}h=Me(d+80|0,d+104|0);v[23048]=0;Q(790,d+72|0,d+104|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){mb:{if(!w[d+77|0]){break mb}c=x[d+74>>1]<<1;if((c&65535)>>>0>(w[d+199|0]|w[d+200|0]<<8)>>>0){break mb}c=(w[d+199|0]|w[d+200|0]<<8)-c|0;t[d+199|0]=c;t[d+200|0]=c>>>8;v[23048]=0;Q(248,d+104|0,x[d+72>>1])|0;c=v[23048];v[23048]=0;if((c|0)==1){break eb}v[23048]=0;c=U(511,d+104|0)|0;p=v[23048];v[23048]=0;if((p|0)==1){break eb}v[23048]=0;T(341,d+48|0,d+104|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break eb}id(h,d+48|0);yb(d+48|0)}v[23048]=0;c=ga(791,a|0,g&65535,h|0,1,1)|0;p=v[23048];v[23048]=0;if((p|0)==1){break eb}nb:{if(!c){v[23048]=0;c=v[23048];v[23048]=0;if((c|0)==1){break eb}c=1;break nb}ob:{if(!(w[d+199|0]|w[d+200|0]<<8)){break ob}c=w[d+199|0]|w[d+200|0]<<8;if(Oi(f)>>>0<=c>>>0){break ob}c=w[d+199|0]|w[d+200|0]<<8;p=Wi(f);i=i+484400|0;kh(zb(v[i>>2]),zb(v[i>>2])+(w[d+199|0]|w[d+200|0]<<8)|0,Oi(f)-(w[d+199|0]|w[d+200|0]<<8)|0);v[f>>2]=v[f>>2]-((c>>>0)/(p>>>0)|0)}c=v[d+168>>2];v[d+44>>2]=c;v[d+12>>2]=c;if(y[f>>2]>(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))>>>0){v[f>>2]=w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24)}c=e}yb(h);break cb}break eb}v[23048]=0;c=Q(617,d+104|0,d+80|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){if(!c){break db}v[d+24>>2]=v[d+88>>2];v[23048]=0;c=v[d+84>>2];v[d+16>>2]=v[d+80>>2];v[d+20>>2]=c;T(618,f|0,1,d+16|0);c=v[23048];v[23048]=0;if((c|0)!=1){break db}}f=P()|0;O()|0;break ab}f=P()|0;O()|0;break ab}f=P()|0;O()|0;break Za}vb(l);c=e;break Wa}f=P()|0;O()|0;yb(h);break ab}c=e}yb(d+104|0);break Xa}f=P()|0;O()|0}yb(d+104|0)}vb(l);break k}c=e}vb(l);g=g+1|0;h=g&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}if(!(!s|!x[a+480190>>1])){e=1;l=1;while(1){f=Il(z,e-1|0);v[23048]=0;b=U(328,f|0)|0;g=v[23048];v[23048]=0;pb:{qb:{rb:{if((g|0)!=1){if(!b){break pb}sb:{tb:{ub:{b=x[f+22>>1];vb:{if(!b){break vb}b=b+l&65535;if(!b){break vb}if(b>>>0<=x[a+480190>>1]){break ub}}v[23048]=0;U(247,f|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break tb}break l}g=x[f+20>>1];b=Il(z,b-1|0);yc(b);h=x[f+20>>1];v[23048]=0;h=Q(250,b|0,h|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break l}if(!h){break pb}v[d+80>>2]=0;v[d+104>>2]=0;v[23048]=0;T(793,d+160|0,b|0,g|0);g=v[23048];v[23048]=0;wb:{if((g|0)!=1){v[23048]=0;g=Wd(d+160|0);h=v[23048];v[23048]=0;if((h|0)==1){break wb}g=zb(g);h=Ii(v[d+160>>2]);v[23048]=0;j=ga(794,g|0,h|0,d+80|0,d+104|0,0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break wb}v[23048]=0;Q(370,b|0,v[d+80>>2])|0;b=v[23048];v[23048]=0;if((b|0)==1){break wb}Ac(d+160|0);g=1;break sb}f=P()|0;O()|0;break k}f=P()|0;O()|0;Ac(d+160|0);break k}yc(f);v[d+80>>2]=0;v[d+104>>2]=0;j=0;g=0}v[23048]=0;S(795,d+160|0,f|0);b=v[23048];v[23048]=0;xb:{yb:{if((b|0)!=1){v[23048]=0;i=Wd(d+160|0);b=v[23048];v[23048]=0;if((b|0)==1){break xb}b=v[d+160>>2];if(!g){g=zb(i);h=Ii(b);v[23048]=0;j=ga(794,g|0,h|0,d+80|0,d+104|0,0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break rb}v[23048]=0;Q(370,f|0,v[d+80>>2])|0;g=v[23048];v[23048]=0;if((g|0)==1){break rb}g=v[d+80>>2];b=b-g|0;i=g+i|0}if(j){break yb}c=1;break qb}f=P()|0;O()|0;break k}v[23048]=0;e=B(e,104)+a|0;g=e+484380|0;U(446,g|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break rb}p=e+484400|0;r=e+484414|0;h=0;e=v[d+104>>2];while(1){zb:{if(y[g>>2]<=h>>>0|(!b|(e|0)!=1?e:0)){break zb}if(!Od(g)){break zb}v[d+48>>2]=0;v[d+128>>2]=0;e=zb(i);n=Ii(b);v[23048]=0;e=la(796,j|0,e|0,n|0,d+48|0,d+72|0,d+128|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break rb}v[23048]=0;v[d+80>>2]=e;Q(370,f|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break rb}n=v[d+80>>2];Hl(d+128|0,Ii(v[g>>2]-h|0));Ab:{if(v[d+128>>2]<1){break Ab}if(v[d+48>>2]!=(ld(g)|0)){break Ab}e=0;if(v[d+48>>2]<=0){break Ab}while(1){Bb:{if(t[r|0]&1){o=v[p>>2];s=ld(g);C=v[v[d+72>>2]+(e<<2)>>2];v[23048]=0;ea(797,o+(B(h,s)<<1)|0,C|0,v[d+48>>2],v[d+128>>2],e|0);o=v[23048];v[23048]=0;if((o|0)!=1){break Bb}break rb}o=v[p>>2];s=ld(g);C=v[v[d+72>>2]+(e<<2)>>2];v[23048]=0;ea(798,o+B(h,s)|0,C|0,v[d+48>>2],v[d+128>>2],e|0);o=v[23048];v[23048]=0;if((o|0)==1){break rb}}e=e+1|0;if((e|0)<v[d+48>>2]){continue}break}}v[23048]=0;o=v[d+128>>2];e=cy(j);s=v[23048];v[23048]=0;if((s|0)==1){break rb}b=b-n|0;i=i+n|0;v[d+104>>2]=e;h=h+o|0;continue}break}v[23048]=0;dy(j);b=v[23048];v[23048]=0;if((b|0)!=1){break qb}break rb}break rb}f=P()|0;O()|0;break k}f=P()|0;O()|0;Ac(d+160|0);break k}Ac(d+160|0)}l=l+1|0;e=l&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}Cb:{if(v[a+480180>>2]!=4){break Cb}e=0;while(1){if(x[a+480192>>1]<=e>>>0){break Cb}b=w[Mb(q,e)|0];g=w[Mb(q,e)+1|0];f=w[Mb(q,e)+2|0];h=w[Mb(q,e)+3|0];v[23048]=0;e=e+1|0;ka(801,a|0,e&65535,b|0,g|0,f|0,h|0);b=v[23048];v[23048]=0;if((b|0)!=1){continue}break}f=P()|0;O()|0;break k}Db:{Eb:{Fb:{Gb:{if(!(w[m+2|0]&16)){break Gb}v[23048]=0;b=Q(250,k|0,1)|0;e=v[23048];v[23048]=0;if((e|0)==1){break m}if(!b){break Gb}v[23048]=0;b=U(373,k|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break n}if(!(!(b&1)|!x[G>>1])){e=0;while(1){v[23048]=0;b=U(376,k|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break Fb}t[((e<<5)+a|0)+480288|0]=b;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}while(1){v[23048]=0;b=Q(250,k|0,1)|0;e=v[23048];v[23048]=0;Hb:{if((e|0)!=1){if(!b){break Gb}v[23048]=0;b=U(373,k|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Eb}if(!b){break Gb}v[23048]=0;e=U(376,k|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break Db}v[23048]=0;T(341,d+160|0,k|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break Db}if(b>>>0>250){break Hb}v[23048]=0;S(646,d+160|0,(B(b,160)+a|0)+906140|0);b=v[23048];v[23048]=0;if((b|0)!=1){break Hb}f=P()|0;O()|0;yb(d+160|0);break k}f=P()|0;O()|0;break k}yb(d+160|0);continue}}f=a+901404|0;j=a+1074304|0;b=Jb(d+48|0);g=0;h=0;Ib:{Jb:{while(1){v[23048]=0;e=Q(250,k|0,8)|0;i=v[23048];v[23048]=0;if((i|0)==1){break Ib}if(!e){break Jb}v[23048]=0;e=U(376,k|0)|0;i=v[23048];v[23048]=0;Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{if((i|0)!=1){v[23048]=0;i=U(376,k|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break _b}v[23048]=0;T(341,d+80|0,k|0,i|0);i=v[23048];v[23048]=0;if((i|0)==1){break Zb}if((e|0)<=1397900629){if((e|0)==1229211981){break Xb}if((e|0)!=1229476432){break Lb}v[23048]=0;e=U(373,d+80|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break q}v[a+480216>>2]=e;v[23048]=0;e=U(373,d+80|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break q}v[a+480220>>2]=e;break Lb}if((e|0)==1397900630){break Yb}if((e|0)!=1414548815){break Lb}v[23048]=0;e=Q(596,d+80|0,24043)|0;i=v[23048];v[23048]=0;if((i|0)==1){break q}if(!e){break Vb}v[23048]=0;e=U(376,d+80|0)|0;i=v[23048];v[23048]=0;if((i|0)!=1){v[23048]=0;T(341,d+104|0,d+80|0,e|0);e=v[23048];v[23048]=0;if((e|0)!=1){break Wb}}f=P()|0;O()|0;break p}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}$b:{ac:{bc:{e=v[a+480180>>2];switch(e-2|0){case 1:break Lb;case 0:break Mb;case 2:break ac;default:break bc}}if((e|0)==16){break $b}if((e|0)!=32){break Lb}v[23048]=0;g=U(340,d+80|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}v[23048]=0;h=U(340,d+80|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break Lb}break q}v[d+160>>2]=32;v[23048]=0;e=U(247,d+80|0)|0;i=v[23048];v[23048]=0;cc:{if((i|0)==1){break cc}v[23048]=0;v[d+104>>2]=e;e=Gb(d+160|0,d+104|0);i=v[23048];v[23048]=0;if((i|0)==1){break cc}e=v[e>>2];v[23048]=0;T(802,d+80|0,b|0,e|0);e=v[23048];v[23048]=0;if((e|0)!=1){break Lb}}f=P()|0;O()|0;break p}v[23048]=0;e=U(373,d+80|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break Kb}v[23048]=0;S(803,d+104|0,24024);i=v[23048];v[23048]=0;dc:{if((i|0)!=1){v[d+128>>2]=e>>>4;v[23048]=0;v[d+72>>2]=e&15;Y(504,d+160|0,d+104|0,d+128|0,d+72|0);e=v[23048];v[23048]=0;if((e|0)==1){break dc}Eb(b,d+160|0);vb(d+160|0);Hb(d+104|0);break Lb}f=P()|0;O()|0;break p}f=P()|0;O()|0;Hb(d+104|0);break p}v[23048]=0;Q(609,d+80|0,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}v[23048]=0;Ju(f);e=v[23048];v[23048]=0;if((e|0)==1){break q}break Lb}v[23048]=0;e=U(247,d+104|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break Ub}u[d+160>>1]=e>>>5;e=Te(E);v[23048]=0;u[d+128>>1]=e;e=Vc(d+160|0,d+128|0);i=v[23048];v[23048]=0;if((i|0)==1){break Ub}i=x[e>>1];if(i){e=0;while(1){v[23048]=0;W(804,d+104|0,d+160|0,32)|0;l=v[23048];v[23048]=0;if((l|0)==1){break Ub}l=Yb(E,e);v[23048]=0;Q(805,l|0,d+160|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break Ub}e=e+1|0;if((i|0)!=(e|0)){continue}break}}yb(d+104|0)}v[23048]=0;e=Q(596,d+80|0,24048)|0;i=v[23048];v[23048]=0;if((i|0)==1){break q}if(!e){break Sb}v[23048]=0;e=U(376,d+80|0)|0;i=v[23048];v[23048]=0;if((i|0)!=1){v[23048]=0;T(341,d+160|0,d+80|0,e|0);e=v[23048];v[23048]=0;if((e|0)!=1){break Tb}}f=P()|0;O()|0;break p}f=P()|0;O()|0;yb(d+104|0);break p}v[23048]=0;e=U(247,d+160|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break Rb}u[d+104>>1]=(e>>>0)/20;e=x[a+480188>>1];v[23048]=0;u[d+128>>1]=e;e=Vc(d+104|0,d+128|0);i=v[23048];v[23048]=0;if((i|0)==1){break Rb}i=x[e>>1];if(i){e=0;while(1){v[23048]=0;W(612,d+160|0,((e<<5)+a|0)+480289|0,20)|0;l=v[23048];v[23048]=0;if((l|0)==1){break Rb}e=e+1|0;if((i|0)!=(e|0)){continue}break}}yb(d+160|0)}v[23048]=0;Q(629,a|0,d+80|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}v[23048]=0;Y(630,a|0,d+80|0,1,0);e=v[23048];v[23048]=0;if((e|0)==1){break q}if((g-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[23048]=0;T(645,a|0,d+80|0,g&65535);e=v[23048];v[23048]=0;if((e|0)==1){break q}}if(!v[j>>2]){break Lb}v[23048]=0;e=Q(2,d+104|0,24053)|0;i=v[23048];v[23048]=0;if((i|0)==1){break Qb}v[23048]=0;S(230,d+128|0,j|0);i=v[23048];v[23048]=0;if((i|0)==1){break Pb}v[23048]=0;T(3,d+160|0,e|0,d+128|0);i=v[23048];v[23048]=0;if((i|0)==1){break Ob}Eb(b,d+160|0);vb(d+160|0);vb(d+128|0);vb(e);break Lb}f=P()|0;O()|0;yb(d+160|0);break p}f=P()|0;O()|0;break p}f=P()|0;O()|0;break Nb}f=P()|0;O()|0;vb(d+128|0)}vb(e);break p}v[23048]=0;g=U(340,d+80|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}}yb(d+80|0);continue}break}f=P()|0;O()|0;break p}ec:{fc:{gc:{hc:{if(!((g&65504)!=4864|v[a+480180>>2]!=2?!((v[a+480180>>2]==32?(g-256&65535)>>>0<=275:0)|(v[a+480180>>2]==2?(g-12544&65535)>>>0<=275:0)):0)){v[23048]=0;Po(f);e=v[23048];v[23048]=0;if((e|0)==1){break hc}}if(!(t[m+2|0]&1)){break ec}e=v[a+1074304>>2];if(!e){if(x[a+480192>>1]){e=1;while(1){g=v[(((e&65535)<<2)+a|0)+900380>>2];if(g){v[23048]=0;f=ci(g,2);m=v[23048];v[23048]=0;if((m|0)==1){break gc}m=v[a+480180>>2];v[23048]=0;T(806,f|0,4,m|0);f=v[23048];v[23048]=0;if((f|0)==1){break fc}t[g+19|0]=w[g+19|0]+3>>>2}e=e+1|0;if(x[a+480192>>1]>=(e&65535)>>>0){continue}break}}e=v[a+1074304>>2]}if(e>>>0<=18350079){v[23048]=0;e=a+1074308|0;Q(459,e|0,27)|0;g=v[23048];v[23048]=0;if((g|0)==1){break hc}v[23048]=0;Q(459,e|0,57)|0;e=v[23048];v[23048]=0;if((e|0)==1){break hc}e=v[a+1074304>>2]}if(e>>>0<=19070975){v[23048]=0;Q(459,a+1074308|0,73)|0;e=v[23048];v[23048]=0;if((e|0)==1){break hc}e=v[a+1074304>>2]}if(e>>>0>19267583){break ec}v[23048]=0;Q(459,a+1074308|0,50)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break ec}}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}ic:{jc:{kc:{lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{if(hd(b)){v[23048]=0;S(233,d+80|0,24062);e=v[23048];v[23048]=0;wc:{if((e|0)!=1){v[23048]=0;T(763,d+160|0,d+80|0,d+1559|0);e=v[23048];v[23048]=0;if((e|0)==1){break wc}break vc}f=P()|0;O()|0;break o}f=P()|0;O()|0;Hb(d+80|0);break o}v[23048]=0;_(807,d+80|0);e=v[23048];v[23048]=0;if((e|0)==1){break uc}v[23048]=0;Y(808,d+160|0,d+80|0,d+1559|0,b|0);e=v[23048];v[23048]=0;if((e|0)==1){break tc}}Eb(b,d+160|0);vb(d+160|0);Hb(d+80|0);v[23048]=0;S(762,d+80|0,24083);e=v[23048];v[23048]=0;if((e|0)==1){break rc}v[23048]=0;T(763,d+160|0,d+80|0,d+1559|0);e=v[23048];v[23048]=0;if((e|0)==1){break qc}Eb(a+1300344|0,d+160|0);vb(d+160|0);Hb(d+80|0);v[23048]=0;e=Q(2,d+160|0,24099)|0;g=v[23048];v[23048]=0;if((g|0)==1){break pc}Eb(a+1300356|0,e);vb(e);e=v[a+480180>>2];if((e|0)>15){break sc}switch(e-1|0){case 1:break lc;case 3:break mc;case 0:break nc;default:break v}}f=P()|0;O()|0;break o}f=P()|0;O()|0;Hb(d+80|0);break o}if((e|0)==16){break oc}if((e|0)==32){break kc}if((e|0)!=16777216){break v}v[23048]=0;e=Q(2,d+160|0,24214)|0;g=v[23048];v[23048]=0;if((g|0)==1){break jc}Eb(a+1300392|0,e);vb(e);v[23048]=0;e=Q(2,d+160|0,24219)|0;g=v[23048];v[23048]=0;if((g|0)==1){break ic}Eb(a+1300380|0,e);vb(e);break v}f=P()|0;O()|0;break o}f=P()|0;O()|0;Hb(d+80|0);break o}f=P()|0;O()|0;break o}v[23048]=0;e=Q(2,d+160|0,24103)|0;g=v[23048];v[23048]=0;xc:{if((g|0)!=1){Eb(a+1300392|0,e);vb(e);v[23048]=0;e=Q(2,d+160|0,24107)|0;g=v[23048];v[23048]=0;if((g|0)==1){break xc}Eb(a+1300380|0,e);vb(e);break v}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}v[23048]=0;e=Q(2,d+160|0,24120)|0;g=v[23048];v[23048]=0;yc:{if((g|0)!=1){Eb(a+1300392|0,e);vb(e);v[23048]=0;e=Q(2,d+160|0,24124)|0;g=v[23048];v[23048]=0;if((g|0)==1){break yc}Eb(a+1300380|0,e);vb(e);break v}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}v[23048]=0;e=Q(2,d+160|0,24136)|0;g=v[23048];v[23048]=0;zc:{if((g|0)!=1){Eb(a+1300392|0,e);vb(e);v[23048]=0;e=Q(2,d+160|0,24139)|0;g=v[23048];v[23048]=0;if((g|0)==1){break zc}Eb(a+1300380|0,e);vb(e);break v}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}v[23048]=0;e=Q(2,d+160|0,24153)|0;g=v[23048];v[23048]=0;Ac:{if((g|0)!=1){Eb(a+1300392|0,e);vb(e);v[23048]=0;e=Q(2,d+160|0,24157)|0;g=v[23048];v[23048]=0;if((g|0)==1){break Ac}Eb(a+1300380|0,e);vb(e);break v}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}v[23048]=0;e=Q(2,d+160|0,24173)|0;g=v[23048];v[23048]=0;Bc:{Cc:{Dc:{Ec:{Fc:{if((g|0)!=1){Eb(a+1300392|0,e);vb(e);if(!(h&65535)){break Bc}v[23048]=0;S(460,d+80|0,24176);e=v[23048];v[23048]=0;if((e|0)==1){break Fc}v[d+128>>2]=(h&65280)>>>8;v[23048]=0;v[d+72>>2]=h&255;S(640,d+104|0,d+72|0);e=v[23048];v[23048]=0;if((e|0)==1){break Ec}v[23048]=0;Y(623,d+160|0,d+80|0,d+128|0,d+104|0);e=v[23048];v[23048]=0;if((e|0)==1){break Dc}Eb(a+1300380|0,d+160|0);vb(d+160|0);vb(d+104|0);Hb(d+80|0);break v}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}f=P()|0;O()|0;break Cc}f=P()|0;O()|0;vb(d+104|0)}Hb(d+80|0);break o}v[23048]=0;e=Q(2,d+160|0,24198)|0;g=v[23048];v[23048]=0;if((g|0)!=1){Eb(a+1300380|0,e);vb(e);break v}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}f=P()|0;O()|0;break o}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break i}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}Eb(a+1300368|0,b);Gc:{if(v[a+1074304>>2]){v[a+1300404>>2]=8;break Gc}if(v[a+480180>>2]==1){v[a+1300404>>2]=2;break Gc}v[a+1300404>>2]=5}e=1;if(c&1){v[23048]=0;c=Q(2,d+160|0,24232)|0;g=v[23048];v[23048]=0;if((g|0)==1){break s}v[23048]=0;T(601,a|0,2,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break r}vb(c)}vb(b);_B(z);Vh(q);kd(A);yb(d+1024|0);yb(d+1048|0)}yb(k)}gc(D);break a}f=P()|0;O()|0;break o}f=P()|0;O()|0;vb(c);break o}f=P()|0;O()|0}yb(d+80|0)}vb(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}_B(z);break i}f=P()|0;O()|0}Vh(q);break g}f=P()|0;O()|0}kd(A)}yb(d+1024|0)}yb(d+1048|0);break c}f=P()|0;O()|0}yb(k)}gc(D);R(f|0);L()}gb=d+1568|0;return e|0}function $ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=C(0),A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=C(0),ja=0,ka=0,la=0,ma=C(0);e=gb-448|0;gb=e;yc(b);a:{b:{c:{if(!dh(b,e+440|0)){break c}if(!PT(e+440|0)){break c}if((MT(b)|0)>-1){break c}if(!c){f=1;break c}Ed(a,16777216);v[a+480208>>2]=v[a+480208>>2]|1681e4;Vz(e+200|0,32);f=v[e+212>>2];d=a+1074316|0;v[d>>2]=v[e+208>>2];v[d+4>>2]=f;d=v[e+204>>2];v[a+1074308>>2]=v[e+200>>2];v[a+1074312>>2]=d;Cg(a+1074308|0,38);A=dd(e+424|0);E=dd(e+408|0);D=dd(e+392|0);m=dd(e+376|0);kg(b,4);h=a+480190|0;G=c&1;l=a+1300332|0;s=2500;o=!(c&2);d:{e:{f:{g:{h:{i:{while(1){v[23048]=0;c=Q(250,b|0,4)|0;d=v[23048];v[23048]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((d|0)!=1){t:{if(c){v[23048]=0;g=U(935,b|0)|0;c=v[23048];v[23048]=0;u:{if((c|0)==1){break u}f=0;v:{switch(g+21|0){case 20:v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){d=c&65535;if(x[a+480188>>1]|d-1>>>0>126){continue}u[a+480188>>1]=c;ka=a,la=ac(512/(d>>>0)|0,16,128),v[ka+480228>>2]=la;continue}a=P()|0;O()|0;break a;case 19:v[23048]=0;J=U(474,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break u}if(J>>>0<=1024){continue}break q;case 16:v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){if((c&65535)==4){continue}break q}a=P()|0;O()|0;break a;case 15:v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;w:{if((d|0)!=1){v[e+200>>2]=c;v[23048]=0;v[e+96>>2]=800;c=Gb(e+200|0,e+96|0);d=v[23048];v[23048]=0;if((d|0)==1){break w}v[a+480204>>2]=B(v[c>>2],12400);continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a;case 17:case 18:v[23048]=0;Q(370,b|0,4)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break u;case 31:v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break u}Z=1;s=Gd(c,0,1e4);continue;case 32:case 33:v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;x:{y:{if((d|0)!=1){Z=1;if(!c){continue}v[23048]=0;c=Q(2,e+200|0,26384)|0;d=v[23048];v[23048]=0;if((d|0)==1){break y}v[23048]=0;T(601,a|0,2,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break x}vb(c);continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a;case 14:v[23048]=0;Q(370,b|0,4)|0;c=v[23048];v[23048]=0;if((c|0)==1){break u}k=!x[h>>1]|k;continue;case 11:z:{if(!G){break z}if(!cd(A)){break z}v[23048]=0;S(936,e+200|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=A;d=c;if(v[c>>2]){Rd(d);sB(v[d>>2],nh(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+200|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Uu(e+200|0);continue}a=P()|0;O()|0;break a}v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break u}v[23048]=0;Q(370,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break u;case 3:case 4:case 10:if(Wg(m)>>>0<=x[h>>1]){continue}A:{if((k|o)&1){break A}if(!Zh(a)){break A}j=x[h>>1]+1|0;u[h>>1]=j;d=nc(e+360|0);v[23048]=0;c=U(270,e+200|0)|0;f=v[23048];v[23048]=0;B:{C:{D:{if((f|0)!=1){if((g|0)==-17){break D}if((g|0)!=-11){break C}v[23048]=0;f=U(474,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break B}v[23048]=0;T(341,e+96|0,b|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break B}id(c,e+96|0);yb(e+96|0);break j}a=P()|0;O()|0;break d}v[23048]=0;S(937,e+96|0,b|0);f=v[23048];v[23048]=0;E:{F:{if((f|0)!=1){ip(d,e+96|0);gc(e+96|0);v[23048]=0;me(e+352|0,d);f=v[23048];v[23048]=0;if((f|0)==1){break F}f=Xd(e+344|0);v[23048]=0;g=v[e+356>>2];v[e+8>>2]=v[e+352>>2];v[e+12>>2]=g;g=W(549,e+96|0,e+8|0,f|0)|0;p=v[23048];v[23048]=0;if((p|0)==1){break E}id(c,g);yb(g);Bc(f);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Bc(f);break e}v[23048]=0;S(938,e+96|0,b|0);f=v[23048];v[23048]=0;G:{H:{if((f|0)!=1){ip(d,e+96|0);gc(e+96|0);v[23048]=0;me(e+336|0,d);f=v[23048];v[23048]=0;if((f|0)==1){break H}f=Xd(e+328|0);v[23048]=0;g=v[e+340>>2];v[e>>2]=v[e+336>>2];v[e+4>>2]=g;g=W(549,e+96|0,e|0,f|0)|0;p=v[23048];v[23048]=0;if((p|0)==1){break G}id(c,g);yb(g);Bc(f);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Bc(f);break e}a=P()|0;O()|0;break e}v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break u}v[23048]=0;Q(370,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break u;case 9:if(!Zh(a)){continue}u[h>>1]=x[h>>1]+1;continue;case 8:I:{if(!G){break I}if(!cd(D)){break I}v[23048]=0;S(939,e+200|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=D;d=c;if(v[c>>2]){Rd(d);jC(v[d>>2],Ce(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+200|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Vh(e+200|0);continue}a=P()|0;O()|0;break a}v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break u}v[23048]=0;Q(370,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break u;case 7:if(cd(m)){v[23048]=0;S(940,e+200|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=m;d=c;if(v[c>>2]){Rd(d);pB(v[d>>2],qB(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+200|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Su(e+200|0);continue}a=P()|0;O()|0;break a}v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break u}v[23048]=0;Q(370,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break u;case 6:J:{if(!G){break J}if(!cd(E)){break J}v[23048]=0;S(941,e+200|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=E;d=c;if(v[c>>2]){Rd(d);rB(v[d>>2],hi(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+200|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Ru(e+200|0);continue}a=P()|0;O()|0;break a}v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break u}v[23048]=0;Q(370,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break u;case 5:v[23048]=0;S(942,e+200|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break t}K:{if(cd(e+200|0)){break K}c=v[e+200>>2];d=qc(e+200|0);v[23048]=0;ba(943,l|0,c|0,d|0,1)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break K}a=P()|0;O()|0;gc(e+200|0);break a}gc(e+200|0);continue;case 0:case 1:case 2:break v;default:break q}}v[23048]=0;c=U(474,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break u}v[23048]=0;Q(370,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}}a=P()|0;O()|0;break a}f=0;if(!J|!x[a+480188>>1]){break q}if(cd(m)){break q}if(G){if(cd(A)){break q}if(cd(D)){break q}if(cd(E)){break q}}if(Wg(m)>>>0>=256){v[23048]=0;S(944,m|0,255);b=v[23048];v[23048]=0;if((b|0)==1){break b}}ka=a,la=Wg(m),u[ka+480192>>1]=la;v[23048]=0;o=a+480192|0;b=Le(h,o);c=v[23048];v[23048]=0;if((c|0)==1){break b}u[h>>1]=x[b>>1];if(k&1){v[23048]=0;b=Q(2,e+200|0,26464)|0;c=v[23048];v[23048]=0;if((c|0)==1){break k}v[23048]=0;T(601,a|0,2,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break l}vb(b)}f=x[o>>1];k=1;while(1){d=f;f=0;c=1;b=1;L:{if(!d){break L}while(1){M:{g=Cl(m,c-1|0);f=g;d=1;N:{if(!w[g|0]){break N}d=t[f+128|0]<0}O:{if(d){break O}if((Qu(g)|0)==(k&1)){break O}l=0;d=g;P:{if(!Qu(d)){break P}if(Ib(w[d+6|0]|w[d+7|0]<<8)){break P}if(Ib(w[d+14|0]|w[d+15|0]<<8)>>>0>20){break P}l=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==4}Q:{R:{if(l){f=w[g+23|0];d=w[g+140|0];v[23048]=0;d=ga(945,g|0,a|0,(d&2)>>>1|0,(B(c,104)+a|0)+484380|0,s&65535)|0;l=v[23048];v[23048]=0;S:{T:{U:{if((l|0)!=1){if(!d){break S}v[23048]=0;d=Q(91,e+200|0,26500)|0;l=v[23048];v[23048]=0;if((l|0)==1){break U}v[23048]=0;Q(354,((c<<5)+a|0)+946300|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break T}vb(d);d=b;if(Wg(m)>>>0<=f>>>0){break Q}ka=g,la=w[Cl(m,f)+143|0]+w[g+143|0]|0,t[ka+143|0]=la;break R}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=f+1|0;break Q}l=0;V:{if(!Qu(g)){break V}if((Ib(w[d+6|0]|w[d+7|0]<<8)|0)!=1){break V}if((Ib(w[d+14|0]|w[d+15|0]<<8)|0)!=2){break V}l=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==10}d=b;if(!l){break Q}hc(e+200|0,g,128);if(Ib(w[e+220|0]|w[e+221|0]<<8)>>>0>=x[h>>1]){break R}v[23048]=0;f=Q(930,e+96|0,0)|0;d=v[23048];v[23048]=0;W:{X:{Y:{if((d|0)!=1){d=(B(Ib(w[e+220|0]|w[e+221|0]<<8),104)+a|0)+484484|0;if(Ib(w[e+236|0]|w[e+237|0]<<8)>>>0<x[a+480190>>1]){f=(B(Ib(w[e+236|0]|w[e+237|0]<<8),104)+a|0)+484484|0}v[23048]=0;d=ba(946,e+200|0,d|0,f|0,(B(c,104)+a|0)+484380|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Y}if(!d){break R}v[23048]=0;d=Q(91,e+360|0,26508)|0;f=v[23048];v[23048]=0;if((f|0)==1){break X}v[23048]=0;Q(354,((c<<5)+a|0)+946300|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break W}vb(d);t[g+139|0]=w[g+139|0]+12;break R}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=b}v[23048]=0;c=d&65535;d=W(436,a|0,b&65535,c|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break M}if(!d|c>>>0>x[h>>1]){break O}v[23048]=0;Y(947,g|0,d|0,(B(c,104)+a|0)+484380|0,a|0);c=v[23048];v[23048]=0;if((c|0)==1){break M}}b=b+1|0;c=b&65535;f=x[o>>1];if(c>>>0<=f>>>0){continue}break L}break}a=P()|0;O()|0;break a}b=k&1;k=0;if(b){continue}break}H=vk(e+96|0);o=vk(e+360|0);b=Lb(D);$=B(x[a+480188>>1],J);aa=Fv((b>>>0)/($>>>0)|0);v[23048]=0;K=a+484344|0;S(385,K|0,aa|0);b=v[23048];v[23048]=0;if((b|0)==1){a=P()|0;O()|0;break m}ca=a+484360|0;fn(Qb(ca));b=x[a+480188>>1];v[23048]=0;q=Q(948,e+80|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){ka=e,la=Rb(E),v[ka+72>>2]=la;ka=e,la=Ub(E),v[ka+64>>2]=la;if(!Fb(e+72|0,e- -64|0)){break s}Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{while(1){ga:{n=v[e+72>>2];b=n;ha:{if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==1){break ha}if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==65535){break ga}b=Ib(w[n|0]|w[n+1|0]<<8);if(Ie(A)>>>0<=b>>>0){break ha}c=Ib(w[n+2|0]|w[n+3|0]<<8);b=Ie(A);if(c>>>0>b>>>0){break ha}if(b-Ib(w[n+2|0]|w[n+3|0]<<8)>>>0<Ib(w[n|0]|w[n+1|0]<<8)>>>0){break ha}b=v[A>>2];_c(e+200|0,b,b+(Ie(A)<<5)|0);c=Ib(w[n|0]|w[n+1|0]<<8);b=Ib(w[n+2|0]|w[n+3|0]<<8);d=v[e+200>>2]+(c<<5)|0;b=(b|0)==-1?(v[e+204>>2]-v[e+200>>2]>>5)-c|0:b;v[e+56>>2]=d;v[e+60>>2]=d+(b<<5);ia:{M=Qb(ca);if(cd(M)){break ia}v[23048]=0;S(749,M|0,65534);b=v[23048];v[23048]=0;if((b|0)!=1){break ia}a=P()|0;O()|0;break n}b=v[e+56>>2];da=v[e+60>>2];if((b|0)==(da|0)){break ha}while(1){p=b;c=Ib(Ib(w[n+8|0]|w[n+9|0]<<8)+Ib(w[b+16|0]|w[b+17|0]<<8)&65535);t[b+16|0]=c;t[b+17|0]=c>>>8;ja:{ka:{la:{d=b;f=H;c=$d(f);ma:{if(c){wb(f);while(1){g=c+14|0;if(!Mu(d,g)){f=1;if(!Mu(g,d)){break ma}c=c+4|0}c=v[c>>2];if(c){continue}break}}f=0}if(f){v[23048]=0;c=Q(949,H|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break la}F=x[c>>1];break ka}F=0;if(!G){break ka}c=Ib(w[b+12|0]|w[b+13|0]<<8);v[23048]=0;F=W(585,K|0,c|0,0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break la}if((F|0)==65535){break ha}v[23048]=0;c=Q(949,H|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break la}u[c>>1]=F;c=b;if(Ib(w[c+8|0]|w[c+9|0]<<8)>>>0>=aa>>>0){break ja}d=b;if(Ib(w[d+10|0]|w[d+11|0]<<8)>>>0>=J>>>0){break ja}ea=b;l=Ib(w[b+14|0]|w[b+15|0]<<8);ka=e,la=Rb(D),v[ka+32>>2]=la;ka=e,la=So(e+32|0,B(Ib(w[c+8|0]|w[c+9|0]<<8),$)),v[ka+200>>2]=la;ka=e,la=So(e+200|0,B(Ib(w[d+10|0]|w[d+11|0]<<8),x[a+480188>>1])),v[ka+48>>2]=la;v[e+44>>2]=0;Pi(e+32|0);fa=b;if(Ib(w[b+12|0]|w[b+13|0]<<8)){N=0;while(1){c=Yb(K,F);v[23048]=0;V=Wc(c,N,0);c=v[23048];v[23048]=0;na:{oa:{if((c|0)!=1){r=0;k=0;if(x[a+480188>>1]){break oa}break na}a=P()|0;O()|0;break n}while(1){ka=e,la=Ub(D),v[ka+200>>2]=la;c=e+44|0;if(Fb(e+48|0,e+200|0)){c=v[e+48>>2]}ka=e,la=Ub(D),v[ka+200>>2]=la;if(Fb(e+48|0,e+200|0)){Ag(e+48|0)}d=B(r,6);h=c;f=255;pa:{if(t[c+1|0]<0|t[c+1|0]>84){break pa}f=w[h+1|0]+25|0}d=d+V|0;s=0;g=Wg(m);j=c;I=w[c+3|0];qa:{if(g>>>0<=I>>>0){break qa}s=I+1|0;if(t[Cl(m,I)+142|0]&1|f<<24>>24<0){break qa}f=lp(Ib(w[p+16|0]|w[p+17|0]<<8)+f<<24>>24)}ra:{if(!w[d|0]){break ra}if(!(w[j+3|0]|(w[c|0]|w[h+1|0]!=255))){if(!w[c+2|0]){break ra}}g=w[d+1|0];if(!g){break ra}if(Wg(m)>>>0<g>>>0){break ra}if(w[Cl(m,g-1|0)+132|0]!=2){break ra}Vm(d)}g=vh(q,r);sa:{if(k&1){k=v[e+32>>2];t[d|0]=k;t[d+1|0]=k>>>8;t[d+2|0]=k>>>16;t[d+3|0]=k>>>24;k=x[e+36>>1];t[d+4|0]=k;t[d+5|0]=k>>>8;ta:{if(w[d+3|0]){break ta}k=r-1|0;if(w[g+21|0]==w[vh(q,k)+21|0]){break ta}t[d+3|0]=21;k=w[vh(q,k)+21|0];t[g+21|0]=k;t[d+5|0]=k}k=0;ha=1;ua:{if(w[c|0]==9){break ua}if(w[c|0]==24|w[c|0]==25|(w[c+2|0]==249|w[c+2|0]==250?!w[c|0]:0)){break ua}ha=0}if(!ha){break sa}}k=d;va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(w[c|0]){case 5:h=w[g+17|0];break Ba;case 0:Da:{if(w[c+2|0]>=201){k=0;Ea:{switch(w[c+2|0]-242|0){case 11:t[d+4|0]=64;t[d+2|0]=1;t[g+16|0]=0;break xa;case 9:t[d+4|0]=1;t[d+2|0]=15;break xa;case 8:if((l&255)>>>0<2){break xa}l=l-1|0;break ya;case 7:if((l&255)==255){l=255;break xa}l=l+1|0;break ya;case 6:t[g+17|0]=f;if(w[g+18|0]!=(s&255)){break xa}t[d|0]=f;t[d+5|0]=255;t[d+3|0]=4;v[g+8>>2]=0;break xa;case 5:t[d+5|0]=242;t[d+3|0]=2;break xa;case 4:t[d+5|0]=242;t[d+3|0]=3;break xa;case 3:t[d+5|0]=244;t[d+3|0]=2;break xa;case 2:t[d+5|0]=244;t[d+3|0]=3;break xa;case 1:t[d+5|0]=248;t[d+3|0]=2;break xa;case 12:break Da;case 0:break Ea;default:break xa}}t[d+5|0]=248;t[d+3|0]=3;break xa}if(t[h+1|0]<=-1){k=0;if(w[c+2|0]>99){break xa}}if(t[h+1|0]>=0){t[g+17|0]=f;t[d|0]=f;t[g+18|0]=s;t[d+1|0]=s;v[g+8>>2]=0}if(!w[c+2|0]){k=0;break xa}c=w[c+2|0];v[23048]=0;c=Xm(+(c>>>0)*.64);f=v[23048];v[23048]=0;if((f|0)==1){break za}t[g+19|0]=c;i=z[g>>2];v[g>>2]=0;k=i!=C(0);break xa}t[d+4|0]=0;t[d+2|0]=1;t[g+16|0]=1;break xa;case 2:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(-.0333000011742115);break wa;case 12:t[e+200|0]=15;f=w[j+3|0];v[23048]=0;t[e+24|0]=f>>>3;f=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;Fa:{if((h|0)!=1){f=w[f|0];t[e+200|0]=15;c=w[c+2|0];v[23048]=0;t[e+24|0]=c>>>3;c=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;if((h|0)==1){break Fa}t[g+24|0]=w[c|0]|f<<4;break wa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 3:v[g+12>>2]=0;z[g+8>>2]=C(w[c+2|0])*C(.0333000011742115);break wa;case 4:v[g+12>>2]=0;z[g+8>>2]=C(w[c+2|0])*C(-.0333000011742115);break wa;case 10:case 11:case 15:t[d+3|0]=0;t[d+5|0]=0;break wa;case 13:t[e+200|0]=15;f=w[j+3|0];v[23048]=0;t[e+24|0]=f>>>3;f=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;Ga:{if((h|0)!=1){f=w[f|0];t[e+200|0]=15;c=w[c+2|0];v[23048]=0;t[e+24|0]=c;c=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;if((h|0)==1){break Ga}t[g+23|0]=w[c|0]|f<<4;break wa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 18:f=g;h=w[g+17|0]+w[c+2|0]&255;c=h>>>0<120?h:120;if(!h){c=1}t[f+17|0]=c;t[d|0]=c;t[d+5|0]=255;t[d+3|0]=4;break va;case 23:case 24:case 25:j=o;f=$d(j);Ha:{if(f){wb(j);while(1){k=f+13|0;if(!Lu(h,k)){j=1;if(!Lu(k,h)){break Ha}f=f+4|0}f=v[f>>2];if(f){continue}break}}j=0}if(j){t[d+3|0]=31;v[23048]=0;c=Q(950,o|0,c|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break za}t[d+5|0]=w[c|0];break wa}if(NT(o)>>>0>127){break wa}f=NT(o);h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23048]=0;v[e+28>>2]=h;v[e+16>>2]=h;h=W(951,e+16|0,(((f&255)<<5)+a|0)+902204|0,a|0)|0;j=v[23048];v[23048]=0;Ia:{if((j|0)==1){break Ia}if(!h){break wa}t[d+3|0]=31;v[23048]=0;h=Q(950,o|0,c|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break Ia}f=f|-128;t[h|0]=f;t[d+5|0]=f;if(w[c|0]!=25?w[c|0]!=24:0){break wa}ja=1;break wa}a=P()|0;O()|0;break n;case 16:if(!w[c+2|0]){break wa}t[d+3|0]=15;v[e+200>>2]=15;f=w[j+3|0];v[23048]=0;v[e+24>>2]=f+1;f=sd(e+200|0,e+24|0);h=v[23048];v[23048]=0;if((h|0)!=1){t[d+5|0]=v[f>>2];u[g+30>>1]=B(w[c+2|0],w[j+3|0]+1|0);break wa}a=P()|0;O()|0;break n;case 9:t[d+3|0]=16;f=d;if(w[c+2|0]){l=w[c+2|0]}else{l=4}t[f+5|0]=l;break wa;case 19:if(w[h+1|0]!=4?w[h+1|0]:0){break wa}t[e+23|0]=w[h+1|0]==4?w[j+3|0]:128;t[e+200|0]=w[c+2|0];v[23048]=0;t[e+24|0]=100;c=$b(e+200|0,e+24|0);f=v[23048];v[23048]=0;Ja:{Ka:{if((f|0)!=1){c=w[c|0];v[e+200>>2]=128;v[23048]=0;v[e+24>>2]=256-w[e+23|0];f=sd(e+200|0,e+24|0);j=v[23048];v[23048]=0;if((j|0)==1){break Ka}f=v[f>>2];v[23048]=0;t[e+200|0]=128;j=$b(e+200|0,e+23|0);k=v[23048];v[23048]=0;if((k|0)==1){break Ja}j=w[j|0];f=(B(c,f)|0)/128|0;k=f&255;if((k|0)!=w[g+20|0]){t[g+20|0]=f;t[d+3|0]=21;f=Xc(((B(k,w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[d+5|0]=f}if(w[h+1|0]!=4|(x[a+480188>>1]-1|0)<=(r|0)){break wa}f=r+1|0;h=vh(q,f);c=B(c,j)>>>7|0;if(w[h+20|0]==(c&255)){break wa}t[h+20|0]=c;c=B(f,6)+V|0;t[c+3|0]=21;f=Xc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[c+5|0]=f;break wa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 17:case 20:t[d+3|0]=0;break wa;case 7:c=w[c+2|0];t[g+25|0]=0;t[g+26|0]=0;t[g+22|0]=c;break wa;case 8:t[g+22|0]=w[g+22|0]+w[c+2|0];break wa;case 14:t[g+25|0]=w[j+3|0];t[g+26|0]=w[c+2|0];break wa;case 1:break Aa;case 6:break Ca;default:break wa}}t[g+18|0]=s;t[g+17|0]=f;t[d+1|0]=s;h=f}t[k|0]=h;La:{if(f<<24>>24>=0){t[g+18|0]=s;t[d+1|0]=s;break La}if(w[c|0]!=5){break La}t[d+4|0]=1;t[d+2|0]=11}if(w[g+26|0]?0:!(w[c+2|0]|w[g+22|0])){break wa}f=w[g+26|0];X=0;Ma:{if(!f){break Ma}X=+(f>>>0)*.25*(ji(+x[g+28>>1]*.006135923151542565+4.71238898038469)+-1)}t[d+3|0]=44;f=w[g+22|0];c=w[c+2|0];v[23048]=0;c=Xm(X+ +(c+f|0));f=v[23048];v[23048]=0;if((f|0)!=1){t[d+5|0]=c;break wa}a=P()|0;O()|0;break n}v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(.0333000011742115);break wa}a=P()|0;O()|0;break n}t[d+5|0]=l;t[d+3|0]=16}c=Xc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);if(!(w[g+21|0]==(c&255)?!k:0)){t[g+21|0]=c;t[d+5|0]=c;t[d+3|0]=21}if(r&1|t[h+1|0]<1|(x[a+480188>>1]-1|0)<=(r|0)){break wa}if(Wg(m)>>>0<=I>>>0){break wa}if(w[Cl(m,I)+132|0]!=1){break wa}f=r+1|0;c=B(f,6)+V|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[c|0]=h;t[c+1|0]=h>>>8;t[c+2|0]=h>>>16;t[c+3|0]=h>>>24;h=w[d+4|0]|w[d+5|0]<<8;t[c+4|0]=h;t[c+5|0]=h>>>8;t[c+1|0]=w[c+1|0]+1;ka=vh(q,f),la=w[g+19|0],t[ka+19|0]=la;ka=vh(q,f),ma=z[g>>2],z[ka>>2]=ma;ka=vh(q,f),ma=z[g+4>>2],z[ka+4>>2]=ma;ka=vh(q,f),ma=z[g+8>>2],z[ka+8>>2]=ma;ka=vh(q,f),ma=z[g+12>>2],z[ka+12>>2]=ma;ka=vh(q,f),la=x[g+30>>1],u[ka+30>>1]=la}c=w[d|0]}Na:{if(c&255){t[g+16|0]=0;break Na}k=0;if(w[g+16|0]){break sa}}Oa:{Pa:{Qa:{Ra:{Sa:{if(!x[g+30>>1]){break Sa}v[23048]=0;c=l&255;u[e+200>>1]=c;f=Le(g+30|0,e+200|0);h=v[23048];v[23048]=0;if((h|0)==1){break Ra}u[g+30>>1]=x[f>>1]-c;if(w[d+3|0]){break Sa}t[d+3|0]=15;t[d+5|0]=0}i=z[g>>2];if(i==C(0)){break Oa}c=l&255;i=C(z[g+4>>2]+C(i*C(c>>>0)));z[g+4>>2]=i;if(w[d+3|0]){break Oa}Ta:{Ua:{if(c>>>0>=2){f=c-1|0;y=C(f|0);if(y>i){break Ua}t[e+200|0]=15;v[23048]=0;c=e;i=C(i/y);Va:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Va}h=0}t[c+24|0]=h;c=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;if((h|0)!=1){c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(B(c,f)|0);t[d+3|0]=22;t[d+5|0]=c<<4;break Oa}a=P()|0;O()|0;break n}if(i<C(1)){break Ta}break Pa}if(!(i<C(1))){break Pa}if(i>C(1-c|0)){break Ta}t[e+200|0]=15;v[23048]=0;c=e;i=C(C(-i)/y);Wa:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Wa}h=0}t[c+24|0]=h;c=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;if((h|0)!=1){c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(B(c,f)|0);t[d+3|0]=22;t[d+5|0]=c;break Oa}a=P()|0;O()|0;break n}if(i>C(-1)){break Oa}t[e+200|0]=14;v[23048]=0;c=e;i=C(-i);Xa:{if(i<C(4294967296)&i>=C(0)){f=~~i>>>0;break Xa}f=0}t[c+24|0]=f;c=$b(e+200|0,e+24|0);f=v[23048];v[23048]=0;if((f|0)==1){break Qa}c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(c>>>0);t[d+3|0]=22;t[d+5|0]=c|240;break Oa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}t[e+200|0]=15;v[23048]=0;c=e;if(i<C(4294967296)&i>=C(0)){f=~~i>>>0}else{f=0}t[c+24|0]=f;c=$b(e+200|0,e+24|0);f=v[23048];v[23048]=0;if((f|0)!=1){c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(c>>>0);t[d+3|0]=22;t[d+5|0]=c<<4|15;break Oa}a=P()|0;O()|0;break n}Ya:{i=z[g+8>>2];if(i==C(0)){break Ya}c=l&255;i=C(z[g+12>>2]+C(i*C(c>>>0)));z[g+12>>2]=i;Za:{if(!w[d+3|0]){_a:{$a:{if(c>>>0>=2){f=c-1|0;y=C(f|0);if(y>i){break $a}t[e+200|0]=223;v[23048]=0;c=e;i=C(i/y);ab:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break ab}h=0}t[c+24|0]=h;c=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)|0);t[d+3|0]=2;t[d+5|0]=c;break Ya}a=P()|0;O()|0;break n}if(i<C(1)){break _a}break Za}if(!(i<C(1))){break Za}if(i>C(1-c|0)){break _a}t[e+200|0]=223;v[23048]=0;c=e;i=C(C(-i)/y);bb:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break bb}h=0}t[c+24|0]=h;c=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)|0);t[d+3|0]=3;t[d+5|0]=c;break Ya}a=P()|0;O()|0;break n}if(i>C(-1)){break Ya}t[e+200|0]=14;v[23048]=0;c=e;i=C(-i);cb:{if(i<C(4294967296)&i>=C(0)){f=~~i>>>0;break cb}f=0}t[c+24|0]=f;c=$b(e+200|0,e+24|0);f=v[23048];v[23048]=0;if((f|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(c>>>0);t[d+3|0]=3;t[d+5|0]=c|240;break Ya}a=P()|0;O()|0;break n}if(w[d+2|0]|c>>>0<2){break Ya}ia=C(i*C(.25));f=c-1|0;y=C(f|0);if(!(ia<y)){t[e+200|0]=9;v[23048]=0;c=e;i=C(i/y);db:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break db}h=0}t[c+24|0]=h>>>2;c=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)<<2);t[d+2|0]=12;t[d+4|0]=c;break Ya}a=P()|0;O()|0;break n}if(C(1-c|0)<ia){break Ya}t[e+200|0]=9;v[23048]=0;c=e;i=C(C(-i)/y);eb:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break eb}h=0}t[c+24|0]=h>>>2;c=$b(e+200|0,e+24|0);h=v[23048];v[23048]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)<<2);t[d+2|0]=13;t[d+4|0]=c;break Ya}a=P()|0;O()|0;break n}t[e+200|0]=15;v[23048]=0;c=e;if(i<C(4294967296)&i>=C(0)){f=~~i>>>0}else{f=0}t[c+24|0]=f;c=$b(e+200|0,e+24|0);f=v[23048];v[23048]=0;if((f|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(c>>>0);t[d+3|0]=2;t[d+5|0]=c|240;break Ya}a=P()|0;O()|0;break n}fb:{if(w[d+3|0]){break fb}c=w[g+23|0];if(c){t[d+3|0]=5;t[d+5|0]=c;break fb}c=w[g+24|0];if(!c){break fb}t[d+3|0]=8;t[d+5|0]=c}u[g+28>>1]=x[g+28>>1]+B(w[g+25|0],l&255)&1023;k=0;if(r&1){break sa}c=w[g+18|0];if(!c){break sa}if(Wg(m)>>>0<c>>>0){break sa}if(!(w[Cl(m,c-1|0)+142|0]&4)){break sa}v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+36>>1]=w[d+4|0]|w[d+5|0]<<8;if(!w[e+33|0]){k=1;break sa}k=1;if(w[Cl(m,w[g+18|0]-1|0)+132|0]!=1){break sa}t[e+33|0]=w[e+33|0]+1}r=r+1|0;if(r>>>0<x[a+480188>>1]){continue}break}}N=N+1|0;if(Ib(w[fa+12|0]|w[fa+13|0]<<8)>>>0>N>>>0){continue}break}}c=Yb(K,F);d=Ib(w[ea+14|0]|w[ea+15|0]<<8);v[23048]=0;d=De(e+200|0,16,d&255);f=v[23048];v[23048]=0;if((f|0)!=1){d=wh(Ve(d,0));v[23048]=0;Q(479,c|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break ka}}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}c=Ol(M);ka=e,la=Ib(w[b+4|0]|w[b+5|0]<<8),u[ka+200>>1]=la;v[23048]=0;u[e+32>>1]=1;d=Le(e+200|0,e+32|0);f=v[23048];v[23048]=0;if((f|0)==1){break fa}d=x[d>>1];v[23048]=0;ba(952,M|0,c|0,d|0,F&65535)|0;c=v[23048];v[23048]=0;if((c|0)==1){break fa}c=Ib(w[n+8|0]|w[n+9|0]<<8);c=Ib(Ib(w[p+16|0]|w[p+17|0]<<8)-c&65535);t[p+16|0]=c;t[p+17|0]=c>>>8}b=b+32|0;if((da|0)!=(b|0)){continue}break}}Ro(e+72|0);if(Fb(e+72|0,e- -64|0)){continue}}break}c=0;if(!ja){break r}v[23048]=0;_(484,a+906300|0);b=v[23048];v[23048]=0;if((b|0)==1){break ea}b=a+906316|0;v[b>>2]=1299020115;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[23048]=0;v[e+200>>2]=0;b=a+906332|0;iD(b,b+16|0,e+200|0);b=v[23048];v[23048]=0;if((b|0)==1){break da}v[23048]=0;b=Q(91,e+200|0,26518)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ca}v[23048]=0;Jv(a+906348|0,b);c=v[23048];v[23048]=0;if((c|0)==1){break ba}vb(b);v[23048]=0;b=Q(91,e+200|0,26523)|0;c=v[23048];v[23048]=0;if((c|0)==1){break aa}v[23048]=0;Iv(a+906380|0,b);c=v[23048];v[23048]=0;if((c|0)==1){break $}vb(b);v[23048]=0;b=Q(91,e+200|0,26535)|0;c=v[23048];v[23048]=0;if((c|0)==1){break _}v[23048]=0;Jv(a+906508|0,b);d=v[23048];v[23048]=0;c=1;if((d|0)==1){break Z}vb(b);break r}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break m}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}c=0}if(x[a+480188>>1]){b=0;while(1){v[23048]=0;cu(a,b&65535);d=v[23048];v[23048]=0;if((d|0)==1){break p}d=(b<<5)+a|0;u[d+480284>>1]=b<<8&256;if(c){t[d+480288|0]=1}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}v[23048]=0;b=Q(2,e+200|0,26543)|0;c=v[23048];v[23048]=0;gb:{hb:{ib:{jb:{if((c|0)!=1){Eb(a+1300344|0,b);vb(b);v[23048]=0;b=Q(2,e+200|0,26553)|0;c=v[23048];v[23048]=0;if((c|0)==1){break jb}Eb(a+1300356|0,b);vb(b);if(Z){break hb}v[23048]=0;b=Q(2,e+200|0,26543)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ib}break gb}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}if(Wg(m)>>>0<=128){v[23048]=0;b=Q(2,e+200|0,26560)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break gb}a=P()|0;O()|0;break n}v[23048]=0;b=Q(2,e+200|0,26574)|0;c=v[23048];v[23048]=0;if((c|0)==1){break o}}Eb(a+1300368|0,b);vb(b);v[a+1300404>>2]=2;vB(q);FT(o);ET(H);f=1}Su(m);Vh(D);Ru(E);Uu(A);break c}a=P()|0;O()|0;break n}a=P()|0;O()|0}vB(q)}FT(o);ET(H);break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}v[23048]=0;f=j&65535;g=W(954,a|0,f|0,c|0)|0;j=v[23048];v[23048]=0;kb:{lb:{mb:{nb:{if((j|0)==1){break nb}if(g){break kb}v[23048]=0;g=ga(955,a|0,f|0,c|0,0,0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break nb}if(g){break kb}v[23048]=0;g=ba(956,a|0,f|0,c|0,0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break nb}if(g){break kb}v[23048]=0;g=Q(957,(B(f,104)+a|0)+484380|0,c|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break nb}if(g){break kb}v[23048]=0;g=Q(2,e+96|0,26430)|0;j=v[23048];v[23048]=0;if((j|0)==1){break mb}v[23048]=0;T(601,a|0,2,g|0);j=v[23048];v[23048]=0;if((j|0)==1){break lb}vb(g);break kb}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(g);break e}ob:{pb:{qb:{g=B(f,104)+a|0;if(w[g+484414|0]&64){if(Zh(a)){break qb}}if(Wg(m)>>>0<=f>>>0){break pb}if(w[Cl(m,f)+132|0]!=2){break pb}if(!Zh(a)){break pb}u[h>>1]=x[h>>1]+1;break pb}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;v[23048]=0;j=g+484380|0;p=B(f&65535,104)+a|0;ba(958,j|0,p+484380|0,j|0,a|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ob}v[23048]=0;f=Q(91,e+96|0,26453)|0;j=v[23048];v[23048]=0;if((j|0)==1){break i}v[23048]=0;Q(355,p+484423|0,f|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break h}vb(f);v[23048]=0;f=Q(91,e+96|0,26458)|0;j=v[23048];v[23048]=0;if((j|0)==1){break g}v[23048]=0;Q(355,g+484423|0,f|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break f}vb(f)}yb(c);gc(d);k=0;continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(f);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(f)}yb(c)}gc(d);break a}gb=e+448|0;return f|0}a=P()|0;O()|0}Su(m);Vh(D);Ru(E);Uu(A);R(a|0);L()}function Lma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;d=gb-896|0;gb=d;yc(b);a:{if(!cW(b,d+840|0)){break a}if(!eW(d+840|0)){break a}if(!Nb(b,Xc(dW(d+840|0),jb))){break a}if(!c){e=1;break a}Ed(a,8);sg(a);t[d+839|0]=w[d+840|3]-48;Rc(b,Wb(w[d+848|0]|w[d+849|0]<<8|(w[d+850|0]<<16|w[d+851|0]<<24)));td(d+816|0,b,504);v[23048]=0;S(728,b|0,d+528|0);f=v[23048];v[23048]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((f|0)!=1){if(w[d+811|0]>63){break b}if(Ib(w[d+528|0]|w[d+529|0]<<8)<<16>>16<0){break b}Pb(d+448|0,0,80);n:{if(!Wb(w[d+872|0]|w[d+873|0]<<8|(w[d+874|0]<<16|w[d+875|0]<<24))){break n}f=Wb(w[d+872|0]|w[d+873|0]<<8|(w[d+874|0]<<16|w[d+875|0]<<24));v[23048]=0;f=Q(248,b|0,f|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){if(!f){break n}v[23048]=0;S(729,b|0,d+448|0);f=v[23048];v[23048]=0;if((f|0)!=1){break n}}g=P()|0;O()|0;break e}v[23048]=0;T(730,d+440|0,b|0,w[d+839|0]);f=v[23048];v[23048]=0;if((f|0)!=1){N=Df(d+440|0);f=x[d+440>>1];if((f-1&65535)>>>0>126){break b}u[a+480188>>1]=f;J=dd(d+424|0);o:{if(Wb(w[d+864|0]|w[d+865|0]<<8|(w[d+866|0]<<16|w[d+867|0]<<24))){f=Wb(w[d+864|0]|w[d+865|0]<<8|(w[d+866|0]<<16|w[d+867|0]<<24));v[23048]=0;Q(248,b|0,f|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){f=w[d+811|0];v[23048]=0;T(731,b|0,J|0,f|0);f=v[23048];v[23048]=0;if((f|0)!=1){break o}}g=P()|0;O()|0;break f}e=0;if(w[d+811|0]){break c}}f=w[d+811|0];u[a+480192>>1]=f;u[a+480190>>1]=f;e=1;V=1;if(w[d+839|0]>=2){V=t[d+792|0]>-1;f=x[a+480192>>1]}if(f&65535){G=c&2;H=!V;q=d- -64|2;I=d- -64|7;K=d- -64|6;s=d- -64|5;C=d- -64|4;m=d+32|4;z=1;o=1;while(1){v[23048]=0;l=o&65535;f=W(436,a|0,z&65535,l|0)|0;h=v[23048];v[23048]=0;p:{q:{r:{s:{if((h|0)!=1){if(!f){break d}g=v[((e<<2)+a|0)+900380>>2];u[d+36>>1]=0;v[d+32>>2]=0;v[23048]=0;p=U(270,d+136|0)|0;f=v[23048];v[23048]=0;t:{u:{v:{w:{if((f|0)!=1){e=e-1|0;f=Mb(J,e);x:{if(!Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break x}f=Mb(J,e);f=Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[23048]=0;f=Q(248,b|0,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}if(!f){break x}v[23048]=0;S(732,b|0,d+32|0);f=v[23048];v[23048]=0;if((f|0)==1){break q}f=Wb(w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24));v[23048]=0;T(341,d- -64|0,b|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break q}id(p,d- -64|0);yb(d- -64|0)}e=Ib(w[m|0]|w[m+1|0]<<8);f=Ib(w[m|0]|w[m+1|0]<<8)&15;j=e<<16>>16;if((j|0)>-1){break w}v[23048]=0;sr(g,0);e=v[23048];v[23048]=0;ca=1;if((e|0)!=1){break v}break q}g=P()|0;O()|0;break f}if(f>>>0>6){break v}h=w[f+19478|0];if(!f){f=h;break s}u[a+480190>>1]=(x[a+480190>>1]+h|0)-1;f=g+108|0;n=g+236|0;E=h-2|0;i=4;while(1){k=B(i,12);e=(E<<3)+i|0;A=w[e+19484|0]+o|0;r=w[e+19532|0];e=0;while(1){D=e+k|0;ka=ud(n,D),la=A,u[ka>>1]=la;D=lc(f,D);t[D|0]=r+w[D|0];e=e+1|0;if((e|0)!=12){continue}break}k=1;i=i+1|0;if((i|0)!=10){continue}break}f=h;break u}h=1;if((f|0)!=7){f=1;break s}k=0;v[23048]=0;FS(g,-24);e=v[23048];v[23048]=0;f=1;if((e|0)==1){break t}}E=1;break r}break q}g=P()|0;O()|0;break f}k=0;if(H|(j|0)<0){break r}k=g+108|0;i=7;while(1){n=B(i,12);A=B(i,-12)+72|0;e=0;while(1){r=lc(k,e+n|0);t[r|0]=A+w[r|0];e=e+1|0;if((e|0)!=12){continue}break}i=i+1|0;if((i|0)!=10){continue}break}k=0}v[23048]=0;S(735,d+816|0,d- -64|0);e=v[23048];v[23048]=0;if((e|0)!=1){y:{if(!(!w[C|0]|w[C|0]>16)){t[g+31|0]=w[C|0];E=1}if(!(!w[s|0]|w[s|0]>128)){t[g+30|0]=w[s|0]}z:{if(!f){break z}g=0;e=l;while(1){v[23048]=0;e=B(e,104)+a|0;S(372,e+484380|0,8);i=v[23048];v[23048]=0;if((i|0)==1){break q}t[d+392|0]=w[K|0];v[23048]=0;t[d+120|0]=64;i=$b(d+392|0,d+120|0);n=v[23048];v[23048]=0;if((n|0)==1){break q}u[e+484410>>1]=w[i|0]<<2;t[e+484416|0]=w[I|0];g=g+1|0;e=g&65535;if(e>>>0>=f>>>0){break z}e=e+l|0;continue}}if(!G|(j|0)<0){break p}n=Sc(d+392|0,8,1,1,0);A=Ib(w[q|0]|w[q+1|0]<<8);e=d- -64|0;g=Ib(w[e|0]|w[e+1|0]<<8);i=Ib(w[q|0]|w[q+1|0]<<8);v[23048]=0;e=U(247,p|0)|0;j=v[23048];v[23048]=0;if((j|0)!=1){if(Ib(w[m|0]|w[m+1|0]<<8)&16){Li(n,16);e=e>>>1|0}if(Ib(w[m|0]|w[m+1|0]<<8)&32){Bp(n,3);e=e>>>1|0}if(Ib(w[m|0]|w[m+1|0]<<8)&64){tf(n,2)}e=k?(e>>>0)/((-1<<f^-1)>>>0)|0:e;if(!f){break p}j=g+i|0;k=0;i=l;while(1){i=B(i,104)+a|0;r=i+484380|0;v[r>>2]=e;v[23048]=0;W(384,n|0,r|0,p|0)|0;r=v[23048];v[23048]=0;if((r|0)==1){break y}g=g<<1;j=j<<1;if(A>>>0>=2){v[i+484388>>2]=j;v[i+484384>>2]=g;i=i+484414|0;u[i>>1]=x[i>>1]|2}k=k+1|0;i=k&65535;if(i>>>0>=f>>>0){break p}e=e<<1;i=i+l|0;continue}}}}}g=P()|0;O()|0;yb(p);break f}yb(p);o=h+o|0;z=z+1|0;e=z&65535;if(e>>>0<=x[a+480192>>1]){continue}break}}f=d+448|4;A:{if(!Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break A}if(!Ib(w[d+456|0]|w[d+457|0]<<8)){break A}f=Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[23048]=0;f=Q(248,b|0,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}if(!f){break A}ka=d,la=Ib(w[d+456|0]|w[d+457|0]<<8),u[ka+136>>1]=la;f=w[d+811|0];v[23048]=0;u[d+64>>1]=f;f=Vc(d+136|0,d- -64|0);e=v[23048];v[23048]=0;if((e|0)==1){break h}m=x[f>>1];i=Ib(w[d+458|0]|w[d+459|0]<<8);if(!m){break A}k=d+136|5;z=d+136|3;j=d+136|1;h=d+72|0;o=d- -64|4;p=i>>>0<19;q=i>>>0<21;n=i>>>0<15;g=0;while(1){v[23048]=0;T(736,b|0,d+136|0,i|0);f=v[23048];v[23048]=0;B:{C:{D:{if((f|0)!=1){g=g+1|0;f=v[((g<<2)+a|0)+900380>>2];if(!w[d+136|0]){break B}s=tr(d- -64|0,0,64);tr(o,w[d+136|0]-1&65535,64);e=w[d+136|0];l=h;if(w[j|0]){e=e+(64/w[j|0]|0)|0}tr(l,e,0);v[d+420>>2]=3;v[d+416>>2]=s;v[23048]=0;e=v[d+420>>2];v[d>>2]=v[d+416>>2];v[d+4>>2]=e;e=f+48|0;S(737,e|0,d|0);l=v[23048];v[23048]=0;if((l|0)==1){break D}if(w[d+136|0]!=1){break C}ka=d,la=Rb(e),v[ka+64>>2]=la;Sd(d+408|0,d- -64|0);v[23048]=0;S(738,e|0,v[d+408>>2]);e=v[23048];v[23048]=0;if((e|0)!=1){break C}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}e=f;if(w[j|0]){l=w[j|0]<<9}else{l=32767}v[e>>2]=l;E=1;t[f+60|0]=w[f+60|0]|1}E:{if(p){break E}v[f+4>>2]=w[d+154|0]+1>>>1;if(q){break E}u[f+28>>1]=w[d+156|0]|w[d+157|0]<<8}f=B(x[ud(f+236|0,61)>>1],104)+a|0;t[f+484417|0]=w[z|0]<<4;F:{G:{if(!n){ka=f+484384|0,la=Wb(w[d+146|0]|w[d+147|0]<<8|(w[d+148|0]<<16|w[d+149|0]<<24)),v[ka>>2]=la;ka=f+484388|0,la=Wb(w[d+146|0]|w[d+147|0]<<8|(w[d+148|0]<<16|w[d+149|0]<<24))+Wb(w[d+150|0]|w[d+151|0]<<8|(w[d+152|0]<<16|w[d+153|0]<<24))|0,v[ka>>2]=la;break G}if(i>>>0<6){break F}}if(t[k|0]&1){e=f+484414|0;u[e>>1]=x[e>>1]|2}if(w[k|0]&8){e=f+484414|0;u[e>>1]=x[e>>1]|6}if(!(w[k|0]&4)){break F}u[f+484412>>1]=0}if((g|0)!=(m|0)){continue}break}}if(!Wb(w[d+468|0]|w[d+469|0]<<8|(w[d+470|0]<<16|w[d+471|0]<<24))){break i}if(!Ib(w[d+472|0]|w[d+473|0]<<8)){break i}f=Wb(w[d+468|0]|w[d+469|0]<<8|(w[d+470|0]<<16|w[d+471|0]<<24));v[23048]=0;f=Q(248,b|0,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}if(!f){break i}ka=d,la=Ib(w[d+472|0]|w[d+473|0]<<8),u[ka+136>>1]=la;f=w[d+811|0];v[23048]=0;u[d+64>>1]=f;f=Vc(d+136|0,d- -64|0);e=v[23048];v[23048]=0;if((e|0)!=1){h=x[f>>1];g=Ib(w[d+474|0]|w[d+475|0]<<8);if(!h){break i}i=0;H:while(1){I:{v[23048]=0;T(739,b|0,d+136|0,g|0);f=v[23048];v[23048]=0;if((f|0)==1){break j}v[23048]=0;OC(d+32|0,2,d+136|0);f=v[23048];v[23048]=0;if((f|0)==1){break k}v[23048]=0;S(398,d- -64|0,d+32|0);f=v[23048];v[23048]=0;if((f|0)==1){break k}i=i+1|0;l=((i<<2)+a|0)+900380|0;f=v[l>>2];v[23048]=0;Q(354,f+492|0,d- -64|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break l}vb(d- -64|0);f=v[l>>2];v[23048]=0;S(741,d- -64|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break m}ka=d,la=rr(d- -64|0),v[ka+32>>2]=la;ka=d,la=Xg(d- -64|0),v[ka+392>>2]=la;while(1){v[23048]=0;f=Nl(d+32|0,d+392|0);e=v[23048];v[23048]=0;J:{if((e|0)!=1){if(f){break J}pr(d- -64|0);if((h|0)!=(i|0)){continue H}break i}break I}v[23048]=0;f=Kl(d+32|0);e=v[23048];v[23048]=0;if((e|0)!=1){e=(x[f>>1]<<5)+a|0;j=e+946324|0;f=v[l>>2];k=v[f+520>>2];v[j>>2]=v[f+516>>2];v[j+4>>2]=k;k=v[f+512>>2];j=e+946316|0;v[j>>2]=v[f+508>>2];v[j+4>>2]=k;k=v[f+504>>2];j=e+946308|0;v[j>>2]=v[f+500>>2];v[j+4>>2]=k;j=v[f+496>>2];e=e+946300|0;v[e>>2]=v[f+492>>2];v[e+4>>2]=j;Fj(d+32|0);continue}break}}break}g=P()|0;O()|0;pr(d- -64|0);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break f}g=P()|0;O()|0;vb(d- -64|0);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}f=0;v[23048]=0;Po(a+901404|0);e=v[23048];v[23048]=0;if((e|0)==1){break g}t[a+901696|0]=w[19588];e=a+901692|0;h=w[19584]|w[19585]<<8|(w[19586]<<16|w[19587]<<24);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;yc(b);K=a+484360|0;K:{L:{M:{N:{O:{P:{Q:{R:{S:{if(!w[N|0]){break S}da=c&1;s=a+484344|0;C=a+1300332|0;D=a+1300308|0;fa=d+136|1;l=d+136|4;p=d+8|4;Z=d+8|2;_=d+56|2;ga=d+56|3;q=d+528|2;A=0;while(1){T:{v[23048]=0;Y(744,b|0,d+840|0,d+448|0,d+528|0);c=v[23048];v[23048]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((c|0)==1){break ea}c=A&255;if(c){v[23048]=0;e=U(466,K|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break ea}if((e|0)==255){break d}}m=Ej(K,c);n=vk(d+392|0);fn(m);if(w[d+839|0]>1){break ca}if(Ib(w[q|0]|w[q+1|0]<<8)>>>0>256|x[a+480188>>1]>16){break ba}aW(d+136|0,d+528|0);c=Ib(w[q|0]|w[q+1|0]<<8);v[23048]=0;T(745,m|0,d+136|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break aa}ka=d,la=Rb(m),v[ka+136>>2]=la;ka=d,la=Ub(m),v[ka+64>>2]=la;if(Fb(d+136|0,d- -64|0)){break da}break W}g=P()|0;O()|0;break f}while(1){c=v[d+136>>2];u[c>>1]=x[c>>1]+f;sf(d+136|0);if(Fb(d+136|0,d- -64|0)){continue}break}break W}aW(d+136|0,d+528|0);if(!Ib(w[d+148|0]|w[d+149|0]<<8)){break ba}if(Ib(w[d+148|0]|w[d+149|0]<<8)>>>0>64|x[a+480188>>1]>64){break ba}g=Wb(w[d+156|0]|w[d+157|0]<<8|(w[d+158|0]<<16|w[d+159|0]<<24));fa:{c=32;ga:{if(!Ib(w[d+160|0]|w[d+161|0]<<8)){break ga}ka=d,la=Ib(w[d+160|0]|w[d+161|0]<<8),u[ka+64>>1]=la;v[23048]=0;u[d+32>>1]=800;c=Vc(d- -64|0,d+32|0);e=v[23048];v[23048]=0;if((e|0)==1){break fa}c=Xc(((x[c>>1]<<5)+50>>>0)/100|0,0)}e=Wb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24));v[23048]=0;e=Q(248,b|0,e|0)|0;h=v[23048];v[23048]=0;ha:{if((h|0)==1){break ha}ia:{ja:{ka:{la:{ma:{na:{if(!e){break na}e=0;if(!x[a+480188>>1]){break na}while(1){v[23048]=0;h=U(373,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break ma}t[d+64|0]=h;v[23048]=0;t[d+32|0]=64;h=$b(d- -64|0,d+32|0);i=v[23048];v[23048]=0;if((i|0)==1){break la}u[((e<<5)+a|0)+480286>>1]=w[h|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}if(!Wb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))){break ja}e=Wb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[23048]=0;e=Q(248,b|0,e|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break ha}if(!e){break ja}e=0;if(!x[a+480188>>1]){break ia}while(1){v[23048]=0;h=U(746,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break ka}ka=((e<<5)+a|0)+480284|0,la=(ac(h,-16,16)<<3)+128|0,u[ka>>1]=la;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break ia}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}v[23048]=0;jh(a,1);e=v[23048];v[23048]=0;if((e|0)==1){break ha}}h=dd(d+120|0);e=Wb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));v[23048]=0;i=Q(248,b|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break $}j=1;e=0;if(!i){break X}i=Ib(w[q|0]|w[q+1|0]<<8);v[23048]=0;i=Q(250,b|0,i<<1)|0;k=v[23048];v[23048]=0;if((k|0)==1){break $}if(!i){break X}i=Ib(w[q|0]|w[q+1|0]<<8);v[23048]=0;i=W(747,b|0,h|0,i|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break $}if(!i){break X}ka=d,la=Rb(h),v[ka+8>>2]=la;ka=d,la=Ub(h),v[ka+112>>2]=la;if(!Fb(d+8|0,d+112|0)){break Y}while(1){e=v[d+8>>2];e=Ib(w[e|0]|w[e+1|0]<<8);oa:{if(Ib(w[d+150|0]|w[d+151|0]<<8)>>>0<e>>>0){break oa}i=Wb(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24));v[23048]=0;Q(248,b|0,i+(e<<2)|0)|0;e=v[23048];v[23048]=0;pa:{qa:{ra:{sa:{ta:{if((e|0)==1){break ta}v[23048]=0;e=U(474,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break ta}v[23048]=0;e=Q(248,b|0,e|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break ta}if(!e){break oa}v[23048]=0;e=Q(250,b|0,42)|0;i=v[23048];v[23048]=0;if((i|0)==1){break ta}if(!e){break oa}v[23048]=0;S(748,b|0,d- -64|0);e=v[23048];v[23048]=0;ua:{if((e|0)!=1){if(cd(m)){break ua}v[23048]=0;S(749,m|0,65534);e=v[23048];v[23048]=0;if((e|0)!=1){break ua}}g=P()|0;O()|0;break Z}e=Ib(w[d+104|0]|w[d+105|0]<<8);v[23048]=0;v[d+60>>2]=e;e=Q(250,b|0,e|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break sa}if(!e){v[23048]=0;e=U(511,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break sa}tc(d+60|0,e)}tc(d+60|0,65534);i=uc(m);v[23048]=0;S(750,m|0,i+v[d+60>>2]|0);e=v[23048];v[23048]=0;if((e|0)==1){break qa}e=0;if(!v[d+60>>2]){break ra}while(1){va:{v[23048]=0;j=U(465,b|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break va}j=j<<16>>16;if((j|0)>=0){v[23048]=0;S(749,m|0,f+j&65535);j=v[23048];v[23048]=0;if((j|0)==1){break va}}e=e+1|0;if(e>>>0<y[d+60>>2]){continue}break ra}break}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}wa:{if(!w[d+64|0]){break wa}v[23048]=0;T(6,d+32|0,2,d- -64|0);e=v[23048];v[23048]=0;xa:{if((e|0)!=1){v[23048]=0;S(467,m|0,d+32|0);e=v[23048];v[23048]=0;if((e|0)==1){break xa}vb(d+32|0);break wa}g=P()|0;O()|0;break Z}g=P()|0;O()|0;vb(d+32|0);break Z}if(!Wb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24))){break oa}e=Wb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24));v[23048]=0;e=Q(248,b|0,e|0)|0;j=v[23048];v[23048]=0;if((j|0)!=1){break pa}}g=P()|0;O()|0;break Z}if(!e){break oa}while(1){ya:{v[23048]=0;e=Q(751,b|0,d+56|0)|0;j=v[23048];v[23048]=0;za:{Aa:{if((j|0)!=1){if(!e){break oa}e=w[ga|0];v[23048]=0;T(341,d+32|0,b|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break Aa}ka=d,la=Fv(Ib(w[d+56|0]|w[d+57|0]<<8)+i|0),u[ka+30>>1]=la;if((Ib(w[d+56|0]|w[d+57|0]<<8)|0)==65535){break ya}e=x[d+30>>1];if(uc(m)>>>0>e>>>0){break za}yb(d+32|0);break oa}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}Ba:{if(w[_|0]==1){e=65535}else{if(w[_|0]!=2){break Ba}v[23048]=0;e=U(465,d+32|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break _}v[23048]=0;j=Q(752,n|0,d+30|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break _}u[j>>1]=e;e=65534}ka=sc(m,x[d+30>>1]),la=e,u[ka>>1]=la}yb(d+32|0);continue}break}yb(d+32|0)}jD(d+8|0);if(Fb(d+8|0,d+112|0)){continue}break}break Y}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}or(n);break d}g=P()|0;O()|0;break K}g=P()|0;O()|0;break Z}g=P()|0;O()|0;yb(d+32|0)}Hv(h);break K}j=0;e=1}Hv(h);if(e){i=c>>>(g>>>1&1)|0;break V}or(n);if(!j){break d}break U}v[23048]=0;jh(a,1);c=v[23048];v[23048]=0;Ca:{if((c|0)!=1){e=0;i=32;if(!x[a+480188>>1]){break V}while(1){t[d+136|0]=w[(d+e|0)+794|0];v[23048]=0;t[d+64|0]=64;c=$b(d+136|0,d- -64|0);h=v[23048];v[23048]=0;if((h|0)==1){break Ca}u[((e<<5)+a|0)+480286>>1]=w[c|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break V}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}e=w[d+791|0];$=w[d+791|0]&64;r=w[d+792|0]&32;G=(w[d+792|0]&31)+1|0;ka=a,la=ZV(Ib(w[d+788|0]|w[d+789|0]<<8),$>>>6|0,r>>>5|0,G),v[ka+480204>>2]=la;ka=a,la=Gd(w[d+793|0],1,32),v[ka+480196>>2]=la;if(r){v[a+480216>>2]=G;v[a+480220>>2]=G<<2}Da:{Ea:{if(w[d+810|0]){t[d+136|0]=w[d+810|0];v[23048]=0;t[d+64|0]=64;c=$b(d+136|0,d- -64|0);h=v[23048];v[23048]=0;if((h|0)==1){break Ea}v[a+480200>>2]=w[c|0]<<2}v[a+480228>>2]=i;v[a+480232>>2]=i;v[a+480208>>2]=v[a+480208>>2]&-3|(w[d+791|0]>>>4^-1)&2;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if(!Wb(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))){break Qa}c=Wb(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24));v[23048]=0;c=Q(248,b|0,c|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break Pa}if(!c){break Qa}c=Wb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24));v[23048]=0;W(462,b|0,D|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break Pa}if(w[N|0]<2){break Qa}v[23048]=0;T(13,d+136|0,2,D|0);c=v[23048];v[23048]=0;if((c|0)==1){break Oa}v[23048]=0;S(467,m|0,d+136|0);c=v[23048];v[23048]=0;if((c|0)==1){break Na}vb(d+136|0)}Ra:{if(Wb(w[d+464|0]|w[d+465|0]<<8|(w[d+466|0]<<16|w[d+467|0]<<24))>>>0<2){break Ra}c=Wb(w[d+460|0]|w[d+461|0]<<8|(w[d+462|0]<<16|w[d+463|0]<<24));v[23048]=0;c=Q(248,b|0,c|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break Pa}if(!c){break Ra}c=Wb(w[d+464|0]|w[d+465|0]<<8|(w[d+466|0]<<16|w[d+467|0]<<24));v[23048]=0;ba(551,C|0,b|0,c-1|0,4)|0;c=v[23048];v[23048]=0;if((c|0)==1){break Pa}}if(!Wb(w[d+504|0]|w[d+505|0]<<8|(w[d+506|0]<<16|w[d+507|0]<<24))){break Da}c=Wb(w[d+504|0]|w[d+505|0]<<8|(w[d+506|0]<<16|w[d+507|0]<<24));v[23048]=0;c=Q(248,b|0,c|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break Pa}if(!c){break Da}v[23048]=0;c=Q(250,b|0,12)|0;h=v[23048];v[23048]=0;if((h|0)==1){break Pa}if(!c){break Da}v[23048]=0;Q(370,b|0,6)|0;c=v[23048];v[23048]=0;if((c|0)==1){break Pa}v[23048]=0;c=U(465,b|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break Pa}if((c|0)!=1){break Da}v[23048]=0;c=U(474,b|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break La}if(!c){break Da}v[23048]=0;h=Q(250,b|0,c|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break La}if(h){break Ma}break Da}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}g=P()|0;O()|0;vb(d+136|0);break K}Dc(d+136|0,C);v[23048]=0;ba(551,C|0,b|0,c|0,4)|0;c=v[23048];v[23048]=0;if((c|0)==1){break Ga}if(!hd(d+136|0)){v[23048]=0;c=W(753,d+32|0,2,13)|0;h=v[23048];v[23048]=0;if((h|0)==1){break Ka}v[23048]=0;T(754,d- -64|0,d+136|0,c|0);h=v[23048];v[23048]=0;if((h|0)==1){break Ja}v[23048]=0;T(755,d+16|0,d- -64|0,C|0);h=v[23048];v[23048]=0;if((h|0)==1){break Ia}Eb(C,d+16|0);vb(d+16|0);vb(d- -64|0);vb(c)}vb(d+136|0);break Da}g=P()|0;O()|0;break K}g=P()|0;O()|0;break Fa}g=P()|0;O()|0;break Ha}g=P()|0;O()|0;vb(d- -64|0)}vb(c);break Fa}g=P()|0;O()|0}vb(d+136|0);break K}g=P()|0;O()|0;break K}Sa:{if(w[d+839|0]<2){break Sa}if(!Wb(w[d+516|0]|w[d+517|0]<<8|(w[d+518|0]<<16|w[d+519|0]<<24))){break Sa}j=0;if(!x[a+480188>>1]){break Sa}while(1){c=Wb(w[d+516|0]|w[d+517|0]<<8|(w[d+518|0]<<16|w[d+519|0]<<24));v[23048]=0;c=Q(248,b|0,c+(j<<2)|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break L}Ta:{if(!c){break Ta}v[23048]=0;c=U(474,b|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break L}v[23048]=0;c=Q(248,b|0,c|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break L}i=0;k=0;if(!c){break Ta}while(1){Ua:{v[23048]=0;c=Q(250,b|0,8)|0;h=v[23048];v[23048]=0;Va:{Wa:{Xa:{if((h|0)!=1){if(!c){break Ua}v[23048]=0;S(756,b|0,d+136|0);c=v[23048];v[23048]=0;if((c|0)==1){break Xa}if(!Wb(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){break Ua}switch((Wb(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))&536870911)-1|0){case 1:break Va;case 0:break Wa;default:continue}}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}i=Wb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));continue}k=Wb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));continue}break}if(!i|!k){break Ta}v[23048]=0;c=Q(248,b|0,i|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break M}if(!c){break Ta}v[23048]=0;W(612,b|0,((j<<5)+a|0)+480289|0,k|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break M}}j=j+1|0;if(j>>>0<x[a+480188>>1]){continue}break}}i=Ib(w[d+528|0]|w[d+529|0]<<8);v[23048]=0;c=f+i|0;S(385,s|0,c&65535);h=v[23048];v[23048]=0;if((h|0)==1){break R}if(i){ha=e&16;ia=f&65535;k=0;while(1){Ya:{if(!da){break Ya}e=Wb(w[d+856|0]|w[d+857|0]<<8|(w[d+858|0]<<16|w[d+859|0]<<24));v[23048]=0;e=Q(248,b|0,e+(k<<2)|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break P}if(!e){break Ya}v[23048]=0;e=U(474,b|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break P}v[23048]=0;e=Q(248,b|0,e|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break P}if(!e){break Ya}H=Jb(d+120|0);v[23048]=0;I=U(270,d- -64|0)|0;e=v[23048];v[23048]=0;Za:{_a:{if((e|0)!=1){e=w[d+839|0];if(e){break _a}v[23048]=0;S(757,b|0,d+136|0);e=v[23048];v[23048]=0;if((e|0)==1){break O}u[d+112>>1]=w[d+136|0];z=w[fa|0]+1|0;e=48;break Za}g=P()|0;O()|0;break N}h=t[d+790|0];v[23048]=0;S(758,b|0,d+8|0);g=v[23048];v[23048]=0;$a:{ab:{if((g|0)!=1){ka=d,la=Ib(w[d+8|0]|w[d+9|0]<<8),u[ka+112>>1]=la;z=Ib(w[Z|0]|w[Z+1|0]<<8)+1|0;if(!Wb(w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24))){break $a}g=v[b+8>>2];j=Wb(w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24));v[23048]=0;Q(248,b|0,j|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break O}v[23048]=0;S(759,b|0,d+136|0);j=v[23048];v[23048]=0;if((j|0)==1){break O}j=Wb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));v[23048]=0;j=Q(248,b|0,j|0)|0;o=v[23048];v[23048]=0;if((o|0)==1){break O}if(!j){break ab}j=Wb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24));v[23048]=0;W(462,b|0,H|0,j|0)|0;j=v[23048];v[23048]=0;if((j|0)!=1){break ab}break O}break O}bb:{if(!Wb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))){break bb}j=Wb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[23048]=0;j=Q(248,b|0,j|0)|0;o=v[23048];v[23048]=0;if((o|0)==1){break O}if(!j){break bb}v[23048]=0;j=U(474,b|0)|0;o=v[23048];v[23048]=0;if((o|0)==1){break O}v[23048]=0;j=Q(248,b|0,j|0)|0;o=v[23048];v[23048]=0;if((o|0)==1){break O}if(!j){break bb}v[23048]=0;T(341,d+32|0,b|0,B(x[d+112>>1],z)|0);j=v[23048];v[23048]=0;if((j|0)==1){break O}id(I,d+32|0);yb(d+32|0)}v[23048]=0;Q(248,b|0,g|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break O}}e=h+(e>>>0<3?48:24)|0}v[23048]=0;g=k+ia|0;j=W(386,s|0,g&65535,z|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break O}h=e;if(j){aa=Yb(s,g);v[23048]=0;Q(476,aa|0,H|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break O}og(d+112|0,x[a+480188>>1]);o=0;while(1){v[23048]=0;e=Wc(aa,o,0);g=v[23048];v[23048]=0;cb:{db:{if((g|0)!=1){j=0;if(x[d+112>>1]){break db}break cb}break O}while(1){eb:{if(!w[d+839|0]){v[23048]=0;S(760,d+136|0,b|0);g=v[23048];v[23048]=0;if((g|0)!=1){g=rd(d+136|0);X=Df(d+136|0);F=w[d+136|0];t[e+1|0]=F>>>3&16|w[g|0]>>>4|F>>>1&32;t[e+3|0]=w[g|0]&15;t[e+5|0]=w[X|0];g=F&63;g=g?g+h|0:0;break eb}break O}v[23048]=0;S(571,d+136|0,b|0);g=v[23048];v[23048]=0;fb:{gb:{if((g|0)!=1){F=rd(d+136|0);X=Df(d+136|0);ja=Ri(d+136|0);v[23048]=0;g=U(373,I|0)|0;M=v[23048];v[23048]=0;if((M|0)==1){break O}t[e+4|0]=g;M=w[d+136|0];g=M&127;if(!g){break gb}g=g+h|0;break fb}break O}g=0;if((M|0)!=128){break fb}t[e|0]=254}t[e+1|0]=w[F|0]&63;t[e+3|0]=w[X|0];t[e+5|0]=w[ja|0]}if(g-1>>>0<=119){t[e|0]=g}v[23048]=0;ea(761,e|0,($|0)!=0|0,(r|0)!=0|0,G|0,(ha|0)!=0|0);F=v[23048];v[23048]=0;if((F|0)!=1){E=(g|0)>84&V|E;e=e+6|0;j=j+1|0;if(x[d+112>>1]<=(j&65535)>>>0){break cb}continue}break}break O}o=o+1|0;if((z|0)!=(o|0)){continue}break}}yb(I);vb(H)}k=k+1|0;if((k|0)!=(i|0)){continue}break}}ka=d,la=rr(n),v[ka+64>>2]=la;ka=d,la=Xg(n),v[ka+32>>2]=la;hb:{ib:{if(Xf(d- -64|0,d+32|0)){while(1){c=Kl(d- -64|0);h=c;g=Df(c);jb:{kb:{lb:{c=x[c>>1];if(!c){e=0;break lb}v[23048]=0;c=Q(516,m|0,c-1&65535)|0;e=v[23048];v[23048]=0;if((e|0)==1){break ib}e=x[h>>1];if(!c){break lb}v[23048]=0;e=Q(586,m|0,e-1&65535)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break kb}break ib}if(x[g>>1]==(e+1|0)){break jb}v[23048]=0;e=W(585,s|0,1,0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ib}if((e|0)==65535){break jb}ka=sc(m,x[h>>1]),la=e,u[ka>>1]=la}c=Yb(s,e);h=yv(x[g>>1]);v[23048]=0;h=De(d+136|0,12,h);g=v[23048];v[23048]=0;if((g|0)==1){break hb}h=mp(Ve(h,v[Yb(s,e)+12>>2]-1|0));v[23048]=0;Q(479,c|0,h|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break hb}i=(i&65535)>>>0>e>>>0?i:e+1|0}Fj(d- -64|0);if(Xf(d- -64|0,d+32|0)){continue}break}c=f+i|0}if(!Wb(w[d+448|0]|w[d+449|0]<<8|(w[d+450|0]<<16|w[d+451|0]<<24))){break T}f=Wb(w[d+448|0]|w[d+449|0]<<8|(w[d+450|0]<<16|w[d+451|0]<<24));v[23048]=0;f=Q(248,b|0,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break R}if(!f){break T}or(n);f=c;break U}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}A=A+1|0;if(w[N|0]>(A&255)>>>0){continue}break S}break}or(n)}v[23048]=0;Fi(K,0);b=v[23048];v[23048]=0;if((b|0)==1){break Q}if(!(E&1)){j=x[a+480192>>1];if(j){e=1;while(1){b=(((e&65535)<<2)+a|0)+900380|0;c=v[b>>2];if(c){Zb(mv(c));j=x[a+480192>>1]}v[b>>2]=0;e=e+1|0;if((e&65535)>>>0<=(j&65535)>>>0){continue}break}}u[a+480192>>1]=0}mb:{nb:{ob:{pb:{qb:{rb:{sb:{if(ca){v[23048]=0;b=Q(2,d+136|0,19589)|0;c=v[23048];v[23048]=0;if((c|0)==1){break sb}v[23048]=0;T(601,a|0,2,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break rb}vb(b)}g=19636;switch(w[d+839|0]){case 3:break nb;case 2:break ob;case 1:break pb;case 0:break qb;default:break mb}}g=P()|0;O()|0;break f}g=P()|0;O()|0;vb(b);break f}g=x[a+480188>>1]>4?19637:19658;break mb}g=19672;break mb}g=19690;break mb}g=19708}v[23048]=0;S(762,d- -64|0,19735);b=v[23048];v[23048]=0;tb:{ub:{vb:{if((b|0)!=1){v[23048]=0;T(763,d+136|0,d- -64|0,d+839|0);b=v[23048];v[23048]=0;if((b|0)==1){break vb}Eb(a+1300344|0,d+136|0);vb(d+136|0);Hb(d- -64|0);v[23048]=0;b=Q(2,d+136|0,19751)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ub}Eb(a+1300356|0,b);vb(b);v[23048]=0;Q(225,a+1300368|0,g|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break tb}v[a+1300404>>2]=2;e=1;break c}g=P()|0;O()|0;break f}g=P()|0;O()|0;Hb(d- -64|0);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break K}g=P()|0;O()|0;break f}g=P()|0;O()|0;break K}g=P()|0;O()|0;yb(I)}vb(H);break K}g=P()|0;O()|0;break K}g=P()|0;O()|0}or(n);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0}Vh(J)}yb(d+816|0);R(g|0);L()}e=0}Vh(J)}yb(d+816|0)}gb=d+896|0;return e|0}function ug(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=C(0),p=0,r=0,s=0,E=0,F=C(0),H=0,I=0,J=C(0),K=0,M=0,N=0,S=0,Y=0;e=gb-2736|0;gb=e;a:{b:{if(Gp(c)){tc(b,268435456);M=v[c+8>>2];I=e+2712|0;d=I;v[d>>2]=0;v[d+4>>2]=0;nc(d+8|0);v[e+2708>>2]=0;s=e;c:{d:{e:{f:{g:{h:{i:{if(w[a+3|0]-4>>>0<=4){v[23048]=0;d=U(511,c|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break h}v[e+2708>>2]=d;break i}d=w[a+3|0];if(d>>>0>18){break i}d=1<<d;j:{if(!(d&126991)){if(d&396800){break j}break i}if(!w[a|0]){break i}}f=v[b>>2];v[23048]=0;f=sv(a,f);d=v[23048];v[23048]=0;if((d|0)==1){break g}v[23048]=0;T(793,e+544|0,c|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break g}f=e+544|0;d=v[f+4>>2];v[I>>2]=v[f>>2];v[I+4>>2]=d;ip(I+8|0,f+8|0);Ac(e+544|0);v[23048]=0;f=Wd(I);d=v[23048];v[23048]=0;if((d|0)==1){break h}v[e+2708>>2]=v[I>>2]}k:{d=w[a+3|0];if(d>>>0>18){break k}d=1<<d;l:{if(!(d&126991)){if(!(d&396800)){break k}d=1;break l}d=w[a|0]!=0}if(!d|y[b>>2]<262145){break k}d=v[e+2708>>2];g=w[a+3|0];v[23048]=0;v[e+520>>2]=((g|0)==11)<<4;g=Gb(e+520|0,e+2708|0);h=v[23048];v[23048]=0;if((h|0)!=1){v[e+544>>2]=d-v[g>>2];d=w[a+3|0];if(d>>>0>16){break f}m:{if(!(1<<d&126991)){if((d|0)==11){break m}break f}if(!(w[a|0]&7)){break f}}d=v[e+544>>2];if(d>>>0<=2147483647){d=d<<1;break e}d=-1;break e}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=7?!(w[a+3|0]==4|w[a+3|0]==5|w[a+3|0]==8):0)){v[e+544>>2]=v[e+2708>>2];v[23048]=0;d=Zm(a);g=v[23048];v[23048]=0;h=e;n:{o:{if((g|0)!=1){g=v[e+544>>2];d=8/(d>>>0)|0;if(g>>>0>4294967295/(d>>>0)>>>0){break o}d=B(d,g);break n}a=P()|0;O()|0;break a}d=-1}v[h+544>>2]=d;tc(b,d);break d}if(w[a+3|0]!=6){break d}d=0;if(y[e+2708>>2]<10){break c}v[23048]=0;Q(370,c|0,4)|0;d=v[23048];v[23048]=0;if((d|0)==1){break h}v[23048]=0;d=U(376,c|0)|0;g=v[23048];v[23048]=0;h=e;p:{q:{r:{if((g|0)!=1){v[e+520>>2]=d;d=v[e+2708>>2];v[23048]=0;v[e+2704>>2]=d;d=Gb(e+520|0,e+2704|0);g=v[23048];v[23048]=0;if((g|0)==1){break r}v[e+544>>2]=v[d>>2];kg(c,8);d=v[e+544>>2];if(d>>>0>50529027){break q}d=B(d,85);break p}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=-1}v[h+544>>2]=d;tc(b,(d>>>0)/(w[a|0]>>>3>>>0)|0);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}v[23048]=0;d=Zm(a);g=v[23048];v[23048]=0;s:{t:{if((g|0)!=1){u:{v:{switch(w[a+3|0]){default:g=0;break u;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:g=w[a|0];break u;case 9:g=16;break u;case 11:g=4;break u;case 10:case 17:case 18:break v}}g=8}d=B(g,d)>>>3|0;g=d-1|0;h=v[e+544>>2];if(g>>>0>-1-h>>>0){break t}g=g+h|0;break s}a=P()|0;O()|0;break a}g=-1}d=(g>>>0)/(d>>>0)|0}v[s+544>>2]=d;tc(b,d)}if(!v[b>>2]){d=0;break c}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[23048]=0;d=U(446,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}if(!d){d=0;v[b>>2]=0;break c}w:{x:{if(ke(a,Sc(e+544|0,8,1,0,11))){v[23048]=0;a=Q(1211,c|0,e+544|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){d=0;if(!a){break w}a=v[b>>2];v[23048]=0;v[e+520>>2]=a+1>>>1;a=U(511,c|0)|0;d=v[23048];v[23048]=0;y:{if((d|0)!=1){tc(e+520|0,a);a=zb(f);d=v[e+520>>2];if(d){break y}d=16;break w}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];f=0;while(1){f=w[e+544|w[a|0]&15]+f|0;t[b|0]=f;f=w[e+544|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=f;d=d-1|0;if(!d){break x}a=a+1|0;b=b+2|0;continue}}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=5?w[a+3|0]!=4:0)){a=w[a+3|0];v[23048]=0;a=ba(1212,e+1616|0,c|0,b|0,(a|0)==5|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break b}yb(a);d=v[c+8>>2]-M|0;break w}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[23048]=0;Q(370,c|0,4)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}v[23048]=0;a=U(376,c|0)|0;f=v[23048];v[23048]=0;z:{A:{B:{if((f|0)!=1){v[23048]=0;v[e+520>>2]=a;f=U(373,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break B}v[23048]=0;T(1213,e+544|0,c|0,a|0);a=v[23048];v[23048]=0;if((a|0)==1){break z}tc(e+520|0,v[e+544>>2]);v[23048]=0;a=v[e+520>>2];d=Wd(e+544|0);g=v[23048];v[23048]=0;if((g|0)!=1){g=v[e+544>>2];h=v[b+20>>2];b=Oi(b);v[23048]=0;ea(1214,d|0,g|0,h|0,b|0,f<<24>>24);b=v[23048];v[23048]=0;if((b|0)!=1){break A}}a=P()|0;O()|0;Ac(e+544|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=a+9|0;Ac(e+544|0);break w}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[e+2708>>2];d=x[Em(e+1608|0)>>1];v[23048]=0;d=PQ(b,f,a,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}C:{D:{E:{F:{G:{H:{I:{if(!(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16)){d=0;v[23048]=0;f=Q(250,c|0,8)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}if(!f){break w}v[23048]=0;f=U(376,c|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}v[e+2708>>2]=f;if(f>>>0<4){break w}v[23048]=0;T(341,e+520|0,c|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break C}g=Ok(e+544|0,e+520|0);yb(e+520|0);v[23048]=0;h=U(1216,g|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break E}if(!v[b>>2]){break G}j=w[a|0];r=(j|0)!=16;while(1){J:{if(r){break J}v[23048]=0;k=Q(252,g|0,8)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break J}a=V(15256)|0;break H}v[23048]=0;E=Q(252,g|0,1)|0;a=v[23048];v[23048]=0;if((a|0)==1){break I}v[23048]=0;a=Q(252,g|0,1)|0;f=v[23048];v[23048]=0;if((f|0)==1){break I}K:{L:{M:{if(!a){f=8;while(1){v[23048]=0;a=Q(252,g|0,1)|0;m=v[23048];v[23048]=0;if((m|0)==1){break K}if(a){break M}f=f+16|0;continue}}v[23048]=0;a=Q(252,g|0,3)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break L}break I}v[23048]=0;a=Q(252,g|0,4)|0;m=v[23048];v[23048]=0;if((m|0)==1){break I}a=a+f|0}i=(i&255)+(((E?-1:0)^a)&255)|0;N:{if((j|0)!=16){t[v[b+20>>2]+d|0]=i;break N}u[v[b+20>>2]+(d<<1)>>1]=k&255|i<<8}d=d+1|0;if(d>>>0<y[b>>2]){continue}break G}break}a=V(15256)|0;break H}if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){d=0;if(y[e+2708>>2]<5){break w}a=zb(zb(v[b+20>>2]));b=Oi(b);v[23048]=0;d=W(1217,c|0,a|0,b|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=16|(w[a+3|0]!=18?w[a+3|0]!=17:0)|(w[a+1|0]!=2?w[a+1|0]!=1:0))){d=v[b>>2];v[23048]=0;g=Zm(a);h=v[23048];v[23048]=0;if((h|0)!=1){v[e+544>>2]=B(d,g);tc(e+544|0,v[e+2708>>2]);b=v[b+20>>2];d=v[e+544>>2];g=w[a+3|0];a=v[e+544>>2];v[e+544>>2]=a-1;if((g|0)!=17){if(!a){break w}while(1){N=b,S=x[ud(31720,zb(w[f|0]))>>1],u[N>>1]=S;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;f=f+1|0;if(a){continue}break}break w}if(!a){break w}while(1){N=b,S=x[ud(31208,zb(w[f|0]))>>1],u[N>>1]=S;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;f=f+1|0;if(a){continue}break}break w}a=P()|0;O()|0;break a}if(!(w[a|0]!=8|w[a+1|0]!=1)){O:{P:{Q:{R:{S:{a=w[a+3|0];switch(a|0){case 2:break P;case 1:break Q;case 0:break R;default:break S}}d=0;switch(a-10|0){case 0:break O;case 2:break P;default:break w}}v[23048]=0;d=OQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=NQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}a=v[e+2708>>2];d=w[sA(e+512|0)|0];v[23048]=0;d=MQ(b,f,a,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=LQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=8|w[a+1|0]!=3)){T:{U:{V:{W:{g=w[a+3|0];switch(g|0){case 2:break T;case 1:break V;case 0:break W;default:break U}}v[23048]=0;d=KQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=JQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}d=0;if((g|0)!=12){break w}}d=v[e+2708>>2];g=w[sA(e+504|0)|0];v[23048]=0;d=IQ(b,f,d,g);f=v[23048];v[23048]=0;if((f|0)==1){break b}if(w[a+3|0]!=12){break w}f=v[b>>2]<<1;if((f|0)<1){break w}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break w}if(!(w[a|0]!=8|w[a+1|0]!=2)){d=0;X:{switch(w[a+3|0]){case 0:v[23048]=0;d=HQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 1:v[23048]=0;d=GQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 2:break X;default:break w}}a=v[e+2708>>2];d=w[sA(e+496|0)|0];v[23048]=0;d=FQ(b,f,a,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){Y:{Z:{_:{$:{a=w[a+3|0];switch(a|0){case 1:break _;case 0:break $;case 2:break Y;default:break Z}}v[23048]=0;d=EQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=DQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}d=0;if((a|0)!=12){break w}}a=v[e+2708>>2];d=x[Em(e+488|0)>>1];v[23048]=0;d=CQ(b,f,a,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){d=0;aa:{switch(w[a+3|0]){case 0:v[23048]=0;d=BQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 1:v[23048]=0;d=AQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 2:break aa;default:break w}}a=v[e+2708>>2];d=x[Em(e+480|0)>>1];v[23048]=0;d=zQ(b,f,a,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){ba:{ca:{da:{ea:{g=w[a+3|0];switch(g|0){case 2:break ba;case 1:break da;case 0:break ea;default:break ca}}v[23048]=0;d=yQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=xQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}d=0;if((g|0)!=12){break w}}d=v[e+2708>>2];g=x[Em(e+472|0)>>1];v[23048]=0;d=wQ(b,f,d,g);f=v[23048];v[23048]=0;if((f|0)==1){break b}if(w[a+3|0]!=12){break w}f=v[b>>2];if(f<<1<1){break w}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break w}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){d=0;fa:{switch(w[a+3|0]){case 0:v[23048]=0;d=vQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 1:v[23048]=0;d=uQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 2:break fa;default:break w}}a=v[e+2708>>2];d=x[Em(e+464|0)>>1];v[23048]=0;d=tQ(b,f,a,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){d=0;ga:{switch(w[a+3|0]){case 0:v[23048]=0;d=sQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 1:v[23048]=0;d=rQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 2:break ga;default:break w}}a=v[e+2708>>2];d=x[Em(e+456|0)>>1];v[23048]=0;d=qQ(b,f,a,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){d=0;ha:{switch(w[a+3|0]){case 0:v[23048]=0;d=pQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 1:v[23048]=0;d=oQ(b,f,v[e+2708>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w;case 2:break ha;default:break w}}a=v[e+2708>>2];d=x[Em(e+448|0)>>1];v[23048]=0;d=nQ(b,f,a,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=mQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=lQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=kQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=jQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=iQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=hQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=gQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=fQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=eQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=dQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=cQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=bQ(b,f,d);a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=W(1258,b|0,f|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=W(1259,b|0,f|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=W(1260,b|0,f|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=W(1261,b|0,f|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=W(1262,b|0,f|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=W(1263,b|0,f|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[23048]=0;d=W(1264,b|0,f|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[23048]=0;d=W(1265,b|0,f|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=24|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];ia:{if(!w[a+2|0]){v[e+8>>2]=v[e+440>>2];v[e+436>>2]=0;a=v[e+436>>2];v[e>>2]=v[e+432>>2];v[e+4>>2]=a;r=e+544|0;j=gb-16|0;gb=j;g=b;N=j,S=B(v[b>>2],ld(b)),v[N+12>>2]=S;tc(j+12|0,(d>>>0)/3|0);d=f;i=zb(d);f=v[e+4>>2];k=v[j+12>>2];ja:{if(!k){a=f;break ja}while(1){a=zb(w[i|0]);h=zb(w[i+1|0])<<16|a<<8|zb(w[i+2|0])<<24;ka:{if((h|0)<=-1){a=-2147483648;if((h|0)==-2147483648){break ka}h=0-h|0}a=f>>>0<h>>>0?h:f}i=i+3|0;f=a;k=k-1|0;if(k){continue}break}}la:{if(!a){break la}h=v[j+12>>2];if(!h){break la}k=a-1|0;E=a>>>1|0;f=a;i=v[g+20>>2];while(1){g=zb(w[d|0]);g=zb(w[d+1|0])<<16|g<<8|zb(w[d+2|0])<<24;m=g>>31;s=m<<31|g>>>1;g=E|g<<31;m=k&m>>31;N=i,S=jd(vc(Gpa(g-m|0,s-(g>>>0<m>>>0)|0,f,0),jb),16),u[N>>1]=S;d=d+3|0;i=i+2|0;h=h-1|0;if(h){continue}break}}if(r){v[r>>2]=a}gb=j+16|0;d=B(v[j+12>>2],3);break ia}v[e+24>>2]=v[e+424>>2];v[e+420>>2]=0;a=v[e+420>>2];v[e+16>>2]=v[e+416>>2];v[e+20>>2]=a;r=e+544|0;j=gb-16|0;gb=j;g=b;N=j,S=B(v[b>>2],ld(b)),v[N+12>>2]=S;tc(j+12|0,(d>>>0)/3|0);d=f;i=zb(d);f=v[e+20>>2];k=v[j+12>>2];ma:{if(!k){a=f;break ma}while(1){a=zb(w[i+2|0]);h=zb(w[i+1|0])<<16|a<<8|zb(w[i|0])<<24;na:{if((h|0)<=-1){a=-2147483648;if((h|0)==-2147483648){break na}h=0-h|0}a=f>>>0<h>>>0?h:f}i=i+3|0;f=a;k=k-1|0;if(k){continue}break}}oa:{if(!a){break oa}h=v[j+12>>2];if(!h){break oa}k=a-1|0;E=a>>>1|0;f=a;i=v[g+20>>2];while(1){g=zb(w[d+2|0]);g=zb(w[d+1|0])<<16|g<<8|zb(w[d|0])<<24;m=g>>31;s=m<<31|g>>>1;g=E|g<<31;m=k&m>>31;N=i,S=jd(vc(Gpa(g-m|0,s-(g>>>0<m>>>0)|0,f,0),jb),16),u[N>>1]=S;d=d+3|0;i=i+2|0;h=h-1|0;if(h){continue}break}}if(r){v[r>>2]=a}gb=j+16|0;d=B(v[j+12>>2],3)}if(!d){break w}a=v[e+544>>2];if((a|0)==-2147483648){break w}a=Fpa(x[b+32>>1],0,a,0)+1073741824|0;f=jb;f=a>>>0<1073741824?f+1|0:f;N=b,S=Gd(Xc((f&2147483647)<<1|a>>>31,f>>>31|0),1,64),u[N+32>>1]=S;u[b+34>>1]=x[b+34>>1]|8192;break w}if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];pa:{if(!w[a+2|0]){v[e+40>>2]=v[e+408>>2];v[e+404>>2]=0;a=v[e+404>>2];v[e+32>>2]=v[e+400>>2];v[e+36>>2]=a;r=e+544|0;j=gb-16|0;gb=j;g=b;N=j,S=B(v[b>>2],ld(b)),v[N+12>>2]=S;tc(j+12|0,d>>>2|0);d=f;i=zb(d);f=v[e+36>>2];k=v[j+12>>2];qa:{if(!k){a=f;break qa}while(1){a=zb(w[i|0]);h=a|zb(w[i+1|0])<<8|zb(w[i+2|0])<<16|zb(w[i+3|0])<<24;ra:{if((h|0)<=-1){a=-2147483648;if((h|0)==-2147483648){break ra}h=0-h|0}a=f>>>0<h>>>0?h:f}i=i+4|0;f=a;k=k-1|0;if(k){continue}break}}sa:{if(!a){break sa}h=v[j+12>>2];if(!h){break sa}k=a-1|0;E=a>>>1|0;f=a;i=v[g+20>>2];while(1){g=zb(w[d|0]);g=g|zb(w[d+1|0])<<8|zb(w[d+2|0])<<16|zb(w[d+3|0])<<24;m=g>>31;s=m<<31|g>>>1;g=E|g<<31;m=k&m>>31;N=i,S=jd(vc(Gpa(g-m|0,s-(g>>>0<m>>>0)|0,f,0),jb),16),u[N>>1]=S;d=d+4|0;i=i+2|0;h=h-1|0;if(h){continue}break}}if(r){v[r>>2]=a}gb=j+16|0;d=v[j+12>>2]<<2;break pa}v[e+56>>2]=v[e+392>>2];v[e+388>>2]=0;a=v[e+388>>2];v[e+48>>2]=v[e+384>>2];v[e+52>>2]=a;r=e+544|0;j=gb-16|0;gb=j;g=b;N=j,S=B(v[b>>2],ld(b)),v[N+12>>2]=S;tc(j+12|0,d>>>2|0);d=f;i=zb(d);f=v[e+52>>2];k=v[j+12>>2];ta:{if(!k){a=f;break ta}while(1){a=zb(w[i+3|0]);h=a|zb(w[i+2|0])<<8|zb(w[i+1|0])<<16|zb(w[i|0])<<24;ua:{if((h|0)<=-1){a=-2147483648;if((h|0)==-2147483648){break ua}h=0-h|0}a=f>>>0<h>>>0?h:f}i=i+4|0;f=a;k=k-1|0;if(k){continue}break}}va:{if(!a){break va}h=v[j+12>>2];if(!h){break va}k=a-1|0;E=a>>>1|0;f=a;i=v[g+20>>2];while(1){g=zb(w[d+3|0]);g=g|zb(w[d+2|0])<<8|zb(w[d+1|0])<<16|zb(w[d|0])<<24;m=g>>31;s=m<<31|g>>>1;g=E|g<<31;m=k&m>>31;N=i,S=jd(vc(Gpa(g-m|0,s-(g>>>0<m>>>0)|0,f,0),jb),16),u[N>>1]=S;d=d+4|0;i=i+2|0;h=h-1|0;if(h){continue}break}}if(r){v[r>>2]=a}gb=j+16|0;d=v[j+12>>2]<<2}if(!d){break w}a=v[e+544>>2];if((a|0)==-2147483648){break w}a=Fpa(x[b+32>>1],0,a,0)+1073741824|0;f=jb;f=a>>>0<1073741824?f+1|0:f;N=b,S=Gd(Xc((f&2147483647)<<1|a>>>31,f>>>31|0),1,64),u[N+32>>1]=S;u[b+34>>1]=x[b+34>>1]|8192;break w}if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[e+544>>2]=1065353216;d=v[e+2708>>2];wa:{if(!w[a+2|0]){v[e+372>>2]=0;v[e+376>>2]=1065353216;a=v[e+380>>2];v[e+72>>2]=v[e+376>>2];v[e+76>>2]=a;a=v[e+372>>2];v[e+64>>2]=v[e+368>>2];v[e+68>>2]=a;g=gb-16|0;gb=g;a=b;N=g,S=B(v[a>>2],ld(a)),v[N+8>>2]=S;tc(g+8|0,d>>>2|0);d=zb(f);o=z[(e- -64|0)+4>>2];i=v[g+8>>2];if(i){while(1){o=C(G(C(D((l(2,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),q()))),o));d=d+4|0;i=i-1|0;if(i){continue}break}}h=e+544|0;d=o==C(0);xa:{if(d){break xa}i=v[g+8>>2];if(!i){break xa}J=d?C(1):C(C(1)/o);d=v[a+20>>2];while(1){z[g+12>>2]=J*(l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q());le(g+12|0,C(-1));F=C(z[g+12>>2]*C(32768));z[g+12>>2]=F;a=d;F=Fe(F);ya:{if(C(D(F))<C(2147483648)){s=~~F;break ya}s=-2147483648}N=a,S=Uc(s),u[N>>1]=S;f=f+4|0;d=d+2|0;i=i-1|0;if(i){continue}break}}if(h){z[h>>2]=o}gb=g+16|0;d=v[g+8>>2]<<2;break wa}v[e+356>>2]=0;v[e+360>>2]=1065353216;a=v[e+364>>2];v[e+88>>2]=v[e+360>>2];v[e+92>>2]=a;a=v[e+356>>2];v[e+80>>2]=v[e+352>>2];v[e+84>>2]=a;g=gb-16|0;gb=g;a=b;N=g,S=B(v[a>>2],ld(a)),v[N+8>>2]=S;tc(g+8|0,d>>>2|0);d=zb(f);o=z[e+84>>2];i=v[g+8>>2];if(i){while(1){h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);o=C(G(C(D((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()))),o));d=d+4|0;i=i-1|0;if(i){continue}break}}h=e+544|0;d=o==C(0);za:{if(d){break za}i=v[g+8>>2];if(!i){break za}J=d?C(1):C(C(1)/o);d=v[a+20>>2];while(1){a=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);z[g+12>>2]=J*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());le(g+12|0,C(-1));F=C(z[g+12>>2]*C(32768));z[g+12>>2]=F;a=d;F=Fe(F);Aa:{if(C(D(F))<C(2147483648)){s=~~F;break Aa}s=-2147483648}N=a,S=Uc(s),u[N>>1]=S;f=f+4|0;d=d+2|0;i=i-1|0;if(i){continue}break}}if(h){z[h>>2]=o}gb=g+16|0;d=v[g+8>>2]<<2}if(!d){break w}o=z[e+544>>2];if(o==C(1)){break w}a=b;o=Fe(Ao(C(o*C(x[b+32>>1])),C(1),C(64)));f=65535;Ba:{if(!(o<C(65535))){break Ba}f=0;if(!(o>C(0))){break Ba}f=~~o>>>0;if(o<C(4294967296)&o>=C(0)){break Ba}f=0}u[a+32>>1]=f;u[b+34>>1]=x[b+34>>1]|8192;break w}if(!(w[a|0]!=64|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[e+544>>2]=0;v[e+548>>2]=1072693248;d=v[e+2708>>2];Ca:{if(!w[a+2|0]){v[e+336>>2]=0;v[e+340>>2]=1072693248;v[e+328>>2]=0;v[e+332>>2]=0;v[e+104>>2]=0;v[e+108>>2]=0;v[e+112>>2]=0;v[e+116>>2]=1072693248;a=v[e+348>>2];v[e+120>>2]=v[e+344>>2];v[e+124>>2]=a;a=v[e+324>>2];v[e+96>>2]=v[e+320>>2];v[e+100>>2]=a;k=e+544|0;i=gb-16|0;gb=i;g=b;N=i,S=B(v[b>>2],ld(b)),v[N+4>>2]=S;tc(i+4|0,d>>>3|0);h=zb(f);p=A[e+104>>3];a=v[i+4>>2];Da:{if(!a){break Da}d=a;while(1){j=(w[h+4|0]|w[h+5|0]<<8|(w[h+6|0]<<16|w[h+7|0]<<24))&2147483647;l(0,w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));l(1,j|0);p=G(+n(),p);h=h+8|0;d=d-1|0;if(d){continue}break}if(p==0){break Da}K=1/p;h=v[g+20>>2];while(1){d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,d|0);N=i,Y=+n()*K,A[N+8>>3]=Y;hg(i+8|0,-1,1);H=A[i+8>>3]*32768;A[i+8>>3]=H;d=h;H=fe(H);Ea:{if(D(H)<2147483648){g=~~H;break Ea}g=-2147483648}N=d,S=Uc(g),u[N>>1]=S;f=f+8|0;h=h+2|0;a=a-1|0;if(a){continue}break}}if(k){A[k>>3]=p}gb=i+16|0;d=v[i+4>>2]<<3;break Ca}v[e+304>>2]=0;v[e+308>>2]=1072693248;v[e+296>>2]=0;v[e+300>>2]=0;v[e+136>>2]=0;v[e+140>>2]=0;v[e+144>>2]=0;v[e+148>>2]=1072693248;a=v[e+316>>2];v[e+152>>2]=v[e+312>>2];v[e+156>>2]=a;a=v[e+292>>2];v[e+128>>2]=v[e+288>>2];v[e+132>>2]=a;r=e+544|0;i=gb-16|0;gb=i;g=b;N=i,S=B(v[b>>2],ld(b)),v[N+4>>2]=S;tc(i+4|0,d>>>3|0);h=zb(f);p=A[e+136>>3];a=v[i+4>>2];Fa:{if(!a){break Fa}d=a;while(1){k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);E=k<<24|k<<8&16711680;j=w[h+4|0]|w[h+5|0]<<8|(w[h+6|0]<<16|w[h+7|0]<<24);m=j<<24|k>>>8;l(0,((j&255)<<24|k>>>8)&-16777216|((j&16777215)<<8|k>>>24)&16711680|(j>>>8&65280|j>>>24));l(1,(m&65280|(j<<8|k>>>24)&255|E)&2147483647);p=G(+n(),p);h=h+8|0;d=d-1|0;if(d){continue}break}if(p==0){break Fa}K=1/p;h=v[g+20>>2];while(1){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=d<<24|d<<8&16711680;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);j=g<<24|d>>>8;l(0,((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24));l(1,j&65280|(g<<8|d>>>24)&255|k);N=i,Y=+n()*K,A[N+8>>3]=Y;hg(i+8|0,-1,1);H=A[i+8>>3]*32768;A[i+8>>3]=H;d=h;H=fe(H);Ga:{if(D(H)<2147483648){g=~~H;break Ga}g=-2147483648}N=d,S=Uc(g),u[N>>1]=S;f=f+8|0;h=h+2|0;a=a-1|0;if(a){continue}break}}if(r){A[r>>3]=p}gb=i+16|0;d=v[i+4>>2]<<3}if(!d){break w}p=A[e+544>>3];if(p==1){break w}a=b;p=fe(pA(p*+x[b+32>>1],1,64));f=65535;Ha:{if(!(p<65535)){break Ha}f=0;if(!(p>0)){break Ha}f=~~p>>>0;if(p<4294967296&p>=0){break Ha}f=0}u[a+32>>1]=f;u[b+34>>1]=x[b+34>>1]|8192;break w}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+280>>2]=939524096;v[23048]=0;a=v[e+284>>2];v[e+160>>2]=v[e+280>>2];v[e+164>>2]=a;d=ba(1266,b|0,f|0,d|0,e+160|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[e+272>>2]=939524096;v[23048]=0;a=v[e+276>>2];v[e+168>>2]=v[e+272>>2];v[e+172>>2]=a;d=ba(1267,b|0,f|0,d|0,e+168|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+264>>2]=939524096;v[23048]=0;a=v[e+268>>2];v[e+176>>2]=v[e+264>>2];v[e+180>>2]=a;d=ba(1268,b|0,f|0,d|0,e+176|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[e+256>>2]=939524096;v[23048]=0;a=v[e+260>>2];v[e+184>>2]=v[e+256>>2];v[e+188>>2]=a;d=ba(1269,b|0,f|0,d|0,e+184|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=14)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+248>>2]=872415232;v[23048]=0;a=v[e+252>>2];v[e+192>>2]=v[e+248>>2];v[e+196>>2]=a;d=ba(1266,b|0,f|0,d|0,e+192|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}v[e+240>>2]=872415232;v[23048]=0;a=v[e+244>>2];v[e+200>>2]=v[e+240>>2];v[e+204>>2]=a;d=ba(1267,b|0,f|0,d|0,e+200|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}d=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=14){break w}d=v[e+2708>>2];if(!w[a+2|0]){v[e+232>>2]=872415232;v[23048]=0;a=v[e+236>>2];v[e+208>>2]=v[e+232>>2];v[e+212>>2]=a;d=ba(1268,b|0,f|0,d|0,e+208|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break w}break b}v[e+224>>2]=872415232;v[23048]=0;a=v[e+228>>2];v[e+216>>2]=v[e+224>>2];v[e+220>>2]=a;d=ba(1269,b|0,f|0,d|0,e+216|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break w}a=V(15256)|0}if((O()|0)!=(da(15256)|0)){break D}Z(a|0)|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break F}}d=h+4|0;yb(g);break w}a=P()|0;O()|0;break D}a=P()|0;O()|0}yb(g);break a}a=P()|0;O()|0;break a}d=v[e+520>>2]+16|0}v[23048]=0;Q(248,c|0,d+M|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}}Ac(I)}gb=e+2736|0;return d|0}a=P()|0;O()|0}Ac(I);R(a|0);L()}function Hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=gb-1728|0;gb=e;yc(b);l=gb-32|0;gb=l;i=e+1600|0;dV(l+24|0,i);k=xb(l+24|0);g=v[l+28>>2];d=v[l+24>>2];v[l+8>>2]=d;v[l+12>>2]=g;v[l>>2]=d;v[l+4>>2]=g;d=b;fc(l+16|0,d,l);g=xb(l+16|0);if((g|0)==(k|0)){Vb(d,xb(l+24|0))}gb=l+32|0;d=(g|0)==(k|0);if(!d){cV(i)}a:{if(!d){break a}if(!fV(e+1600|0)){break a}if(!Nb(b,Xc(256,0))){break a}b:{if(!c){break b}Ed(a,1048576);sg(a);f=gb-16|0;gb=f;d=Tb(f,25180);Dc(e+1344|0,d);vb(d);gb=f+16|0;A=e+1608|0;v[e+160>>2]=w[A+1|0];d=w[A|0];v[23048]=0;v[e+16>>2]=d;S(640,e+88|0,e+16|0);d=v[23048];v[23048]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((d|0)!=1){v[23048]=0;Y(623,e+240|0,e+1344|0,e+160|0,e+88|0);d=v[23048];v[23048]=0;if((d|0)==1){break o}Eb(a+1300344|0,e+240|0);vb(e+240|0);vb(e+88|0);Hb(e+1344|0);d=Tb(e+240|0,25197);Eb(a+1300356|0,d);vb(d);df(e+88|0,2,e+1610|0);Fc(e+1344|0,e+88|0);v[23048]=0;T(13,e+240|0,8,e+1344|0);d=v[23048];v[23048]=0;if((d|0)==1){break j}Eb(a+1300368|0,e+240|0);vb(e+240|0);vb(e+1344|0);v[a+1300404>>2]=8;Jr(e+1344|0,2,e+1642|0);Fc(e+240|0,e+1344|0);Eb(a+1300308|0,e+240|0);vb(e+240|0);d=e+1712|0;u[a+480188>>1]=w[d|0]|w[d+1|0]<<8;d=Gd(w[e+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=d;F=e+1722|0;u[a+480192>>1]=w[F|0]|w[F+1|0]<<8;G=e+1724|0;u[a+480190>>1]=w[G|0]|w[G+1|0]<<8;d=Gd(w[e+1717|0],1,32);v[a+480216>>2]=d;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=d<<2;dw(b,e+1344|0);C=a+484360|0;s=e+1706|0;Sr(Qb(C),e+1344|0,w[s|0]|w[s+1|0]<<8,65535,65535);d=e+1708|0;ff(Qb(C),w[d|0]|w[d+1|0]<<8);td(e+1320|0,b,Fg(b));v[23048]=0;f=U(376,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break m}v[23048]=0;T(341,e+1296|0,b|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break m}D=x[a+480188>>1];v[23048]=0;z=Q(250,e+1320|0,274)|0;d=v[23048];v[23048]=0;if((d|0)==1){break l}if(z){u[a+480188>>1]=x[a+480188>>1]+8}l=c&1;if(!l){break k}d=e+1710|0;d=w[d|0]|w[d+1|0]<<8;v[23048]=0;S(385,a+484344|0,d|0);d=v[23048];v[23048]=0;if((d|0)!=1){break k}h=P()|0;O()|0;break e}h=P()|0;O()|0;break n}h=P()|0;O()|0;vb(e+88|0)}Hb(e+1344|0);break c}h=P()|0;O()|0;break d}h=P()|0;O()|0;break e}p=a+484344|0;o=e+1718|0;q=e+1710|0;if(!(w[q|0]|w[q+1|0]<<8)){break f}while(1){v[23048]=0;f=U(340,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break g}v[e+160>>2]=f;v[23048]=0;f=U(376,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break h}v[23048]=0;T(341,e+240|0,b|0,f+1&-2);d=v[23048];v[23048]=0;if((d|0)==1){break h}tc(e+160|0,1024);p:{if(!l){break p}d=v[e+160>>2];if(!d){break p}v[23048]=0;f=W(386,p|0,m&65535,d|0)|0;d=v[23048];v[23048]=0;q:{if((d|0)!=1){if(!f){break p}n=0;if(t[o|0]&1){r=0;while(1){v[23048]=0;f=Q(250,e+240|0,1)|0;d=v[23048];v[23048]=0;r:{if((d|0)!=1){if(!f){break p}v[23048]=0;f=U(373,e+240|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break i}k=0;if((f|0)!=255){break r}v[23048]=0;k=U(373,e+240|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;f=U(373,e+240|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break r}}break i}break i}s:{if(!(f&127)){break s}d=Yb(p,m);v[23048]=0;d=Wc(d,r,n&65535);g=v[23048];v[23048]=0;if((g|0)==1){break i}Lr(e+88|0);if(f&1){v[23048]=0;i=U(373,e+240|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break i}t[e+88|0]=i}if(f&2){v[23048]=0;i=U(373,e+240|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break i}t[e+89|0]=i}if(f&4){v[23048]=0;i=U(373,e+240|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break i}t[e+90|0]=i}if(f&8){v[23048]=0;i=U(373,e+240|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break i}t[e+91|0]=i}if(f&16){v[23048]=0;i=U(373,e+240|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break i}t[e+92|0]=i}if(f&32){v[23048]=0;i=U(373,e+240|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break i}t[e+93|0]=i}if(f&64){v[23048]=0;g=U(373,e+240|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break i}t[e+94|0]=g}v[23048]=0;i=Q(826,d|0,e+88|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break i}v[e+16>>2]=k;v[23048]=0;v[e+64>>2]=v[e+160>>2]+(r^-1);g=Gb(e+16|0,e- -64|0);f=v[23048];v[23048]=0;if((f|0)==1){break i}h=h|i;i=v[g>>2];if(!i){break s}j=1;f=d;while(1){f=B(x[a+480188>>1],6)+f|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=w[d+4|0]|w[d+5|0]<<8;t[f+4|0]=g;t[f+5|0]=g>>>8;if((i|0)==(j|0)){break s}j=j+1|0;continue}}r=(k+r|0)+1|0;d=v[e+160>>2];if(r>>>0>=d>>>0){while(1){n=n+1|0;r=r-d|0;if(d>>>0<=r>>>0){continue}break}}if((n&65535)>>>0<D>>>0){continue}break}break p}d=0;if(v[e+160>>2]){break q}break p}break i}while(1){f=Yb(p,m);v[23048]=0;k=Of(f,d);f=v[23048];v[23048]=0;t:{u:{if((f|0)!=1){f=0;if(D){break u}break t}break i}while(1){v:{v[23048]=0;S(827,e+240|0,e+88|0);g=v[23048];v[23048]=0;if((g|0)==1){break v}v[23048]=0;i=Q(826,k+B(f,6)|0,e+88|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break v}h=h|i;f=f+1|0;if((D|0)!=(f|0)){continue}break t}break}break i}d=d+1|0;if(d>>>0<y[e+160>>2]){continue}break}}yb(e+240|0);m=m+1|0;if(m>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}break f}h=P()|0;O()|0;vb(e+1344|0);break c}h=P()|0;O()|0;yb(e+240|0);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}d=e+1714|0;w:{if((w[d|0]|w[d+1|0]<<8)>>>0<=1|(w[d|0]|w[d+1|0]<<8)>>>0>4999){break w}if(h&1){d=w[d|0]|w[d+1|0]<<8;d=vc(((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);t[a+480224|0]=0;v[a+480204>>2]=d;break w}i=v[a+480216>>2];g=v[a+480196>>2];f=w[d|0]|w[d+1|0]<<8;t[a+480224|0]=2;d=a;E=2646e7/+(B(f,B(g,i))>>>0);x:{if(E<4294967296&E>=0){f=~~E>>>0;break x}f=0}v[d+480204>>2]=f}d=x[a+480188>>1];v[23048]=0;t[e+240|0]=0;H=W(828,e+1280|0,d|0,e+240|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){l=a+1300320|0;k=a+1300332|0;i=e+240|3;r=0;y:{z:{A:{B:{C:{while(1){v[23048]=0;f=Q(250,e+1296|0,8)|0;d=v[23048];v[23048]=0;D:{if((d|0)!=1){if(f){break D}if(x[a+480188>>1]){f=0;while(1){d=t[oc(H,f)|0];E:{if((d|0)<=(f|0)|(d|0)>=x[a+480188>>1]){break E}k=((d<<5)+a|0)+480288|0;i=w[k|0];if(!i){break E}g=((f<<5)+a|0)+480288|0;d=w[g|0];if(!d){t[g|0]=i;break E}h=(B(d-1&255,160)+a|0)+906300|0;if((Kk(h)|0)!=255){while(1){h=(B(Kk(h),160)+a|0)+906300|0;if((Kk(h)|0)!=255){continue}break}}g=h+28|0;d=w[k|0]-1&255;d=d>>>0<250?d+128|0:0;t[g|0]=d;t[g+1|0]=d>>>8;t[g+2|0]=d>>>16;t[g+3|0]=d>>>24}f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}v[e+232>>2]=0;v[e+236>>2]=0;v[e+224>>2]=0;v[e+228>>2]=0;v[e+216>>2]=0;v[e+220>>2]=0;v[e+208>>2]=0;v[e+212>>2]=0;F:{G:{H:{I:{J:{K:{if(z){v[23048]=0;S(829,e+1320|0,e+240|0);d=v[23048];v[23048]=0;L:{if((d|0)!=1){h=0;while(1){d=x[a+480192>>1];v[23048]=0;i=NO(a,d+1&65535);d=v[23048];v[23048]=0;M:{N:{O:{P:{Q:{R:{S:{if((d|0)!=1){d=h<<1;f=d+(e+224|0)|0;u[f>>1]=i;j=d+(e+208|0)|0;g=e+d|0;d=g+242|0;u[j>>1]=w[d|0]|w[d+1|0]<<8;if((i|0)==65535){break N}d=w[g+242|0]|w[g+243|0]<<8;v[23048]=0;f=W(436,a|0,i|0,d+1&65535)|0;d=v[23048];v[23048]=0;if((d|0)==1){break S}if(!f){break M}v[23048]=0;S(489,e+160|0,25214);d=v[23048];v[23048]=0;if((d|0)==1){break R}v[23048]=0;v[e+16>>2]=h+1;T(831,e+88|0,e+160|0,e+16|0);d=v[23048];v[23048]=0;if((d|0)==1){break Q}v[23048]=0;Q(354,f+492|0,e+88|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break P}vb(e+88|0);Hb(e+160|0);break M}h=P()|0;O()|0;break y}h=P()|0;O()|0;break y}h=P()|0;O()|0;break y}h=P()|0;O()|0;break O}h=P()|0;O()|0;vb(e+88|0)}Hb(e+160|0);break y}u[f>>1]=0}h=h+1|0;if((h|0)!=8){continue}break}break L}h=P()|0;O()|0;break y}d=w[e+240|0]|w[e+241|0]<<8;f=0;v[23048]=0;l=Q(380,e+160|0,d|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break F}if(w[e+240|0]|w[e+241|0]<<8){while(1){v[23048]=0;g=U(340,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break H}v[23048]=0;T(341,e+88|0,b|0,g<<5);d=v[23048];v[23048]=0;if((d|0)==1){break I}id(Dg(l,f),e+88|0);yb(e+88|0);f=f+1|0;if(f>>>0<(w[e+240|0]|w[e+241|0]<<8)>>>0){continue}break}}d=w[q|0]|w[q+1|0]<<8;m=0;v[23048]=0;z=W(832,e+88|0,d|0,25224)|0;d=v[23048];v[23048]=0;if((d|0)==1){break J}if(w[s|0]|w[s+1|0]<<8){while(1){i=e+m|0;T:{if(w[i+258|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break T}if(x[sc(Qb(C),m)>>1]>=(w[q|0]|w[q+1|0]<<8)>>>0){break T}d=x[sc(Qb(C),m)>>1];U:{if(x[sc(z,d)>>1]==65535){f=w[i+258|0];I=sc(z,d),J=f,u[I>>1]=J;break U}if(x[sc(z,d)>>1]==w[i+258|0]){break U}v[23048]=0;f=W(833,p|0,d|0,0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break K}if((f|0)==65535){break U}I=sc(Qb(C),m),J=f,u[I>>1]=J;d=f}v[23048]=0;g=oe(p,d);f=v[23048];v[23048]=0;if((f|0)==1){break K}if(!g){break T}k=Dg(l,w[i+258|0]);yc(k);v[23048]=0;g=U(247,k|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break K}if(!v[Yb(p,d)+12>>2]){break T}i=g>>>5|0;j=0;while(1){g=Yb(p,d);f=x[a+480188>>1];v[23048]=0;f=Wc(g,j,f-8&65535);g=v[23048];v[23048]=0;if((g|0)==1){break K}h=0;while(1){$h(e+16|0);g=x[e+20>>1];t[f+4|0]=g;t[f+5|0]=g>>>8;g=v[e+16>>2];t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;V:{if(i>>>0<=j>>>0){break V}v[23048]=0;Q(834,k|0,e+16|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break K}if(t[e+16|0]>-1){break V}t[f|0]=61;t[f+1|0]=w[(e+224|0)+(h<<1)|0];g=w[e+16|0]&31;t[e+64|0]=g;if(g){Af(e- -64|0,15);t[f+3|0]=20;t[f+5|0]=w[e+64|0]|208}t[f+2|0]=1;t[f+4|0]=w[e+17|0]+3>>>2}f=f+6|0;h=h+1|0;if((h|0)!=8){continue}break}j=j+1|0;if(j>>>0<y[Yb(p,d)+12>>2]){continue}break}}m=m+1|0;if(m>>>0<(w[s|0]|w[s+1|0]<<8)>>>0){continue}break}}Ze(z);kd(l)}W:{if(!(w[o|0]&2)){break W}D=w[o|0]&8?x[a+480188>>1]:D;if(!(w[q|0]|w[q+1|0]<<8)){break W}n=0;i=((D&65535)+((w[A|0]|w[A+1|0]<<8)>>>0>591?r:0)|0)+((w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24))>>>4&1)|0;while(1){f=0;X:{if(!i){break X}while(1){Y:{v[23048]=0;g=Q(250,b|0,4)|0;d=v[23048];v[23048]=0;if((d|0)==1){break Y}if(!g){break X}d=w[A|0]|w[A+1|0]<<8;v[23048]=0;S(835,d|0,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break Y}f=f+1|0;if((i|0)!=(f|0)){continue}break X}break}h=P()|0;O()|0;break y}n=n+1|0;if(n>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}}v[23048]=0;m=Q(380,e+192|0,255)|0;d=v[23048];v[23048]=0;Z:{_:{$:{aa:{ba:{ca:{if((d|0)!=1){r=e+88|7;C=e+88|1;z=e+88|4;s=e+88|2;l=e+88|3;d=0;while(1){f=d;v[23048]=0;S(836,b|0,e+160|0);d=v[23048];v[23048]=0;da:{ea:{fa:{ga:{if((d|0)!=1){v[23048]=0;g=U(376,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break ga}d=w[A|0]|w[A+1|0]<<8;v[23048]=0;g=(g|0)==32?428:g;g=g?d>>>0>513?g+4|0:g:g;T(341,e+240|0,b|0,g|0);d=v[23048];v[23048]=0;if((d|0)==1){break fa}d=f+1|0;p=Me(e+16|0,id(Dg(m,f),e+240|0));yb(e+240|0);if(f>>>0>=(w[F|0]|w[F+1|0]<<8)>>>0){break da}v[23048]=0;f=d&65535;j=W(436,a|0,f|0,f|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break ea}h=P()|0;O()|0;break _}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break Z}if(!j){break da}v[23048]=0;df(e+88|0,2,e+160|0);f=v[23048];v[23048]=0;ha:{ia:{ja:{if((f|0)==1){break ja}v[23048]=0;S(398,e+240|0,e+88|0);f=v[23048];v[23048]=0;if((f|0)==1){break ja}v[23048]=0;Q(354,j+492|0,e+240|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ia}vb(e+240|0);if(!g){break da}v[23048]=0;S(837,p|0,e+240|0);f=v[23048];v[23048]=0;if((f|0)==1){break aa}o=0;if((w[A|0]|w[A+1|0]<<8)>>>0<513){break ha}v[23048]=0;o=U(340,p|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break ha}h=P()|0;O()|0;break _}h=P()|0;O()|0;break _}h=P()|0;O()|0;vb(e+240|0);break _}n=3;ka:{if((w[A|0]|w[A+1|0]<<8)>>>0<514){break ka}v[23048]=0;n=U(376,p|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break ka}h=P()|0;O()|0;break _}v[j>>2]=w[e+342|0]|w[e+343|0]<<8;t[j+16|0]=w[((w[e+344|0]|w[e+345|0]<<8)&3)+25226|0];t[j+17|0]=w[(w[e+345|0]&3)+25226|0];t[j+18|0]=w[((w[e+344|0]|w[e+345|0]<<8)>>>12&3)+25230|0];D=0;la:{ma:{na:{oa:{while(1){pa:{if(!(n&1)){break pa}v[23048]=0;S(838,p|0,e+88|0);f=v[23048];v[23048]=0;if((f|0)==1){break oa}v[23048]=0;g=ci(j,w[D+25234|0]);f=v[23048];v[23048]=0;if((f|0)==1){break na}f=g;if(!(t[e+88|0]&1)|(D|0)!=3){h=w[g+12|0]&-17}else{h=w[g+12|0]|16}t[f+12|0]=h;t[g+12|0]=w[g+12|0]&254|t[e+88|0]&1;t[g+12|0]=w[g+12|0]&251|w[e+88|0]<<1&4;t[g+12|0]=w[g+12|0]&253|w[e+88|0]>>>1&2;t[e+64|0]=w[C|0];v[23048]=0;t[e+48|0]=16;i=$b(e- -64|0,e+48|0);f=v[23048];v[23048]=0;if((f|0)==1){break ma}f=w[i|0];v[23048]=0;S(568,g|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break ma}f=w[s|0];t[g+15|0]=f;t[g+16|0]=f;t[g+13|0]=w[l|0];t[g+14|0]=w[z|0];f=0;if(!Lb(g)){break pa}while(1){k=(e+88|0)+(f<<2)|0;i=w[k+8|0]|w[k+9|0]<<8;I=Mb(g,f),J=i,u[I>>1]=J;i=Gd(w[k+10|0]|w[k+11|0]<<8,0,64);I=Mb(g,f),J=i,t[I+2|0]=J;f=f+1|0;if(Lb(g)>>>0>f>>>0){continue}break}}n=n>>>1|0;D=D+1|0;if((D|0)!=4){continue}break}if(!(t[j+60|0]&1|w[j+16|0]==3)){v[j>>2]=32767}v[23048]=0;Zl(j,127,1);f=v[23048];v[23048]=0;if((f|0)==1){break ca}v[23048]=0;Yl(j,0,1);f=v[23048];v[23048]=0;if((f|0)==1){break ca}if(!o){break da}v[23048]=0;S(841,p|0,e+88|0);f=v[23048];v[23048]=0;if((f|0)==1){break $}if(!(o&2)){break la}f=w[s|0]|w[s+1|0]<<8;v[23048]=0;g=oA(a,+(f>>>0));f=v[23048];v[23048]=0;if((f|0)==1){break $}v[23048]=0;Zl(j,g,1);f=v[23048];v[23048]=0;if((f|0)==1){break $}f=w[z|0];v[23048]=0;Yl(j,f,1);f=v[23048];v[23048]=0;if((f|0)!=1){break la}break $}h=P()|0;O()|0;break _}h=P()|0;O()|0;break _}h=P()|0;O()|0;break _}t[j+25|0]=w[C|0]==1;if(!(o&4)){break da}t[j+31|0]=w[r|0]+1;t[j+34|0]=w[e+96|0]+1;if(t[e+96|0]<=-1){t[j+30|0]=w[e+103|0]+1}if(w[e+100|0]){f=0;k=j+108|0;while(1){g=f+1|0;v[e+64>>2]=g+t[e+100|0];eV(e- -64|0);i=v[e+64>>2];I=lc(k,f),J=i,t[I|0]=J;f=g;if(f>>>0<128){continue}break}}v[23048]=0;sr(j,0);f=v[23048];v[23048]=0;if((f|0)==1){break $}}yb(p);if((d|0)!=255){continue}break}z=PB(e+88|0);g=e+16|4;r=PB(e+160|0);h=0;qa:{ra:{while(1){v[23048]=0;S(836,b|0,e+240|0);d=v[23048];v[23048]=0;if((d|0)==1){break qa}v[23048]=0;f=U(376,b|0)|0;d=v[23048];v[23048]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{if((d|0)!=1){v[23048]=0;T(341,e- -64|0,b|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break za}if((w[G|0]|w[G+1|0]<<8)>>>0>h>>>0){v[23048]=0;df(e+48|0,2,e+240|0);d=v[23048];v[23048]=0;if((d|0)==1){break sa}v[23048]=0;S(398,e+16|0,e+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break sa}v[23048]=0;Q(354,((h<<5)+a|0)+946332|0,e+16|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break ya}vb(e+16|0)}if(!f|(w[G|0]|w[G+1|0]<<8)>>>0<=h>>>0){break ta}v[23048]=0;i=B(h+1|0,104)+a|0;f=i+484380|0;S(372,f|0,32);d=v[23048];v[23048]=0;if((d|0)==1){break xa}v[23048]=0;S(843,e- -64|0,e+16|0);d=v[23048];v[23048]=0;if((d|0)==1){break wa}v[f>>2]=w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24);v[i+484404>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if(w[e+24|0]>=2){d=i+484414|0;u[d>>1]=x[d>>1]|1;v[f>>2]=v[f>>2]>>>1}if(w[e+25|0]>=2){d=i+484414|0;u[d>>1]=x[d>>1]|64;v[f>>2]=v[f>>2]>>>1}j=2;Aa:{if(w[e+27|0]!=1){j=6;if(w[e+27|0]!=2){break Aa}}d=i+484414|0;u[d>>1]=x[d>>1]|j}v[i+484384>>2]=w[e+28|0]|w[e+29|0]<<8|(w[e+30|0]<<16|w[e+31|0]<<24);v[i+484388>>2]=w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24);u[i+484410>>1]=(w[e+36|0]|w[e+37|0]<<8)>>>7;if(w[e+38|0]!=128){break va}d=i+484414|0;n=x[d>>1]|256;u[d>>1]=n;break ua}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break Z}h=P()|0;O()|0;vb(e+16|0);break ra}h=P()|0;O()|0;break ra}h=P()|0;O()|0;break ra}u[i+484408>>1]=t[e+38|0]+128;n=x[i+484414>>1]}d=i+484414|0;u[d>>1]=n|32;t[i+484416|0]=w[e+39|0];if(w[e+26|0]&2){Db(e+48|0,r,h);ir(e+48|0)}if(w[e+26|0]&5){u[d>>1]=x[d>>1]|16384}if(!(w[e+26|0]&8)){break ta}Db(e+48|0,z,h);ir(e+48|0);f=0;while(1){d=f<<1;Ba:{if(x[d+(e+208|0)>>1]!=(h|0)){break Ba}d=v[((x[d+(e+224|0)>>1]<<2)+a|0)+900380>>2];if(!d){break Ba}t[d+14|0]=0}f=f+1|0;if((f|0)!=8){continue}break}}yb(e- -64|0);h=h+1|0;if((h|0)==256){break ba}continue}break}h=P()|0;O()|0}yb(e- -64|0);break Z}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break y}h=P()|0;O()|0;break _}Ca:{if(!(w[F|0]|w[F+1|0]<<8)){break Ca}n=0;Da:{Ea:{while(1){Fa:{d=Dg(m,n);v[23048]=0;f=U(247,d|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break Fa}Ga:{if(!f){n=n+1|0;break Ga}d=Dg(m,n);yc(d);v[23048]=0;S(837,d|0,e+240|0);d=v[23048];v[23048]=0;if((d|0)==1){break Ea}s=dd(e+16|0);d=w[e+240|0]|w[e+241|0]<<8;v[23048]=0;T(844,b|0,s|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break Da}n=n+1|0;o=v[((n<<2)+a|0)+900380>>2];if(!(!o|w[o+34|0])){v[o+4>>2]=32;v[23048]=0;sr(o,0);d=v[23048];v[23048]=0;if((d|0)==1){break Da}k=o+108|0;i=o+236|0;f=0;while(1){d=e+f|0;Ha:{if(w[d+242|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break Ha}l=qe(s,w[d+242|0]);d=w[l|0];C=d+1|0;g=f+12|0;I=ud(i,g),J=C,u[I>>1]=J;if(d>>>0>=x[a+480190>>1]){break Ha}d=B(C,104)+a|0;t[d+484418|0]=w[e+338|0]&3;t[d+484419|0]=w[e+339|0];t[d+484420|0]=w[e+340|0];t[d+484421|0]=w[e+341|0];u[d+484412>>1]=w[l+1|0]<<1;t[d+484417|0]=w[l+2|0];d=C-1|0;Db(e- -64|0,z,d);if(Cb(e- -64|0)){t[o+14|0]=0}Db(e- -64|0,r,d);if(!Cb(e- -64|0)){break Ha}I=lc(k,g),J=61,t[I|0]=J}f=f+1|0;if((f|0)!=96){continue}break}}An(s)}if((w[F|0]|w[F+1|0]<<8)>>>0>n>>>0){continue}break Ca}break}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break Z}h=P()|0;O()|0;An(s);break Z}Ia:{Ja:{if(!(c&2)|!x[a+480190>>1]){break Ja}h=1;Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{while(1){k=B(h,104)+a|0;i=k+484416|0;g=t[i|0];f=k+484417|0;c=t[f|0];v[23048]=0;d=k+484380|0;Jo(d,(+(c|0)*.0078125-+(g-49|0))*.08333333333333333);c=v[23048];v[23048]=0;if((c|0)==1){break Ia}t[f|0]=0;t[i|0]=0;Sa:{c=x[k+484414>>1];Ta:{if(!(c&16384)){c=Sc(e+240|0,c&1?16:8,c&64?3:1,0,12);v[23048]=0;W(384,c|0,d|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break Ta}h=P()|0;O()|0;break Z}v[23048]=0;d=U(376,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break Sa}v[23048]=0;Q(370,b|0,12)|0;c=v[23048];v[23048]=0;if((c|0)==1){break Sa}f=Jb(e+240|0);v[23048]=0;W(462,b|0,f|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break Ra}v[23048]=0;Q(355,k+484423|0,f|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break Ra}v[23048]=0;S(622,e- -64|0,25238);c=v[23048];v[23048]=0;if((c|0)==1){break Qa}v[e+12>>2]=h;c=wk(a);v[23048]=0;T(13,e+48|0,c|0,f|0);c=v[23048];v[23048]=0;if((c|0)==1){break Pa}v[23048]=0;Y(623,e+16|0,e- -64|0,e+12|0,e+48|0);c=v[23048];v[23048]=0;if((c|0)==1){break Oa}v[23048]=0;T(601,a|0,2,e+16|0);c=v[23048];v[23048]=0;if((c|0)==1){break Na}vb(e+16|0);vb(e+48|0);Hb(e- -64|0);vb(f)}if(x[a+480190>>1]<=h>>>0){break Ja}h=h+1|0;continue}break}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break Ka}h=P()|0;O()|0;break Ka}h=P()|0;O()|0;break La}h=P()|0;O()|0;break Ma}h=P()|0;O()|0;vb(e+16|0)}vb(e+48|0)}Hb(e- -64|0)}vb(f);break Z}kd(m);gc(H);yb(e+1296|0);yb(e+1320|0);break b}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break _}h=P()|0;O()|0}yb(p)}kd(m);break y}h=P()|0;O()|0;Ze(z);break G}h=P()|0;O()|0;break G}h=P()|0;O()|0;break G}h=P()|0;O()|0}kd(l);break y}h=P()|0;O()|0;break y}h=P()|0;O()|0;break y}v[23048]=0;m=U(376,e+1296|0)|0;f=v[23048];v[23048]=0;d=a;Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{if((f|0)!=1){v[23048]=0;g=U(376,e+1296|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break gb}v[23048]=0;T(341,e+88|0,e+1296|0,g|0);f=v[23048];v[23048]=0;if((f|0)==1){break gb}if((m|0)<=844387157){if((m|0)==4674381){break Ya}if((m|0)==5068115){break Xa}if(h&1|(m|0)!=726487106){break Va}t[a+480224|0]=2;v[23048]=0;E=+pa(846,e+88|0);f=v[23048];v[23048]=0;if((f|0)==1){break Ua}if(E==0){break Va}E=2646e7/(E*+(B(v[a+480216>>2],v[a+480196>>2])>>>0));if(!(E<4294967296&E>=0)){break fb}f=~~E>>>0;break eb}if((m|0)<=1314144591){if((m|0)==844387158){break Wa}if((m|0)!=1280004692){break Va}j=0;if(!x[a+480188>>1]){break Va}while(1){v[23048]=0;f=Q(250,e+88|0,1)|0;d=v[23048];v[23048]=0;if((d|0)==1){break B}if(!f){break Va}g=Jb(e+240|0);v[23048]=0;W(573,e+88|0,g|0,-1)|0;d=v[23048];v[23048]=0;if((d|0)==1){break cb}f=Ob(g);d=Bb(g);v[23048]=0;Xe(e+16|0,3,f,d);d=v[23048];v[23048]=0;if((d|0)==1){break bb}v[23048]=0;S(398,e+160|0,e+16|0);d=v[23048];v[23048]=0;if((d|0)==1){break bb}v[23048]=0;Q(449,((j<<5)+a|0)+480289|0,e+160|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break ab}vb(e+160|0);vb(g);j=j+1|0;if(j>>>0<x[a+480188>>1]){continue}break}break Va}if((m|0)==1397445204){break db}if((m|0)!=1314144592){break Va}f=0;if(!(w[q|0]|w[q+1|0]<<8)){break Va}while(1){v[23048]=0;g=Q(250,e+88|0,1)|0;d=v[23048];v[23048]=0;if((d|0)==1){break _a}if(!g){break Va}v[23048]=0;g=Ul(p,f&65535);d=v[23048];v[23048]=0;if((d|0)==1){break _a}if(!g){break Va}g=Jb(e+240|0);v[23048]=0;W(573,e+88|0,g|0,-1)|0;d=v[23048];v[23048]=0;if((d|0)==1){break Za}d=Yb(p,f);v[23048]=0;Q(476,d|0,g|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break Za}vb(g);f=f+1|0;if(f>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}break Va}h=P()|0;O()|0;break y}h=P()|0;O()|0;break y}f=0}v[d+480204>>2]=f;break Va}v[23048]=0;f=U(340,e+88|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break A}v[a+480232>>2]=f>>>9;v[a+480228>>2]=f>>>8;f=0;if(!x[a+480188>>1]){break Va}while(1){v[23048]=0;g=Q(848,e+88|0,e+240|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break C}if(g){u[((f<<5)+a|0)+480286>>1]=(w[e+240|0]|w[e+241|0]<<8)>>>10;d=w[i|0];I=oc(H,f),J=d,t[I|0]=J}f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}break Va}h=P()|0;O()|0;break $a}h=P()|0;O()|0;break $a}h=P()|0;O()|0;vb(e+160|0)}vb(g);break z}h=P()|0;O()|0;break z}h=P()|0;O()|0;vb(g);break z}v[23048]=0;Q(370,e+88|0,1)|0;d=v[23048];v[23048]=0;if((d|0)==1){break A}v[23048]=0;f=U(511,e+88|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break A}v[23048]=0;ba(551,k|0,e+88|0,f|0,2)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break Va}break A}v[23048]=0;Q(849,e+88|0,e+16|0)|0;d=v[23048];v[23048]=0;hb:{if((d|0)!=1){f=Jb(e+240|0);v[23048]=0;W(573,e+88|0,f|0,-1)|0;d=v[23048];v[23048]=0;if((d|0)==1){break hb}if(Br(f,25201)){v[23048]=0;T(13,e+160|0,8,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break hb}Eb(l,e+160|0);vb(e+160|0)}vb(f);break Va}h=P()|0;O()|0;break z}h=P()|0;O()|0;vb(f);break z}v[23048]=0;r=U(376,e+88|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break A}}yb(e+88|0);continue}break}h=P()|0;O()|0;break z}h=P()|0;O()|0;break z}h=P()|0;O()|0;break z}h=P()|0;O()|0}yb(e+88|0)}gc(H);break e}h=P()|0;O()|0}yb(e+1296|0)}yb(e+1320|0)}R(h|0);L()}f=1}gb=e+1728|0;return f|0}function qu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,U=0,V=0,X=0,Z=0,$=0,aa=0,ca=0,da=0,fa=0,ha=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;m=gb-192|0;gb=m;Z=dd(a);o=m+160|0;t[o+26|0]=0;u[o+24>>1]=0;v[o+16>>2]=0;v[o+20>>2]=-1;v[o+8>>2]=-1;v[o+12>>2]=-1;v[o>>2]=0;v[o+4>>2]=0;F=v[d+16>>2];X=w[d+6|0];$=b+484360|0;if(X>>>0>=Ei($)>>>0){X=w[$+16|0]}s=Ej($,X);v[23048]=0;q=Q(1270,m+120|0,b|0)|0;a=v[23048];v[23048]=0;a:{if((a|0)!=1){e=v[q+4>>2];v[23048]=0;G=W(1271,m+80|0,b|0,X|0)|0;a=v[23048];v[23048]=0;b:{if((a|0)!=1){a=x[d+4>>1];c:{d:{if(a>>>0>=uc(s)>>>0){break d}while(1){v[23048]=0;g=Q(516,s|0,a&65535)|0;h=v[23048];v[23048]=0;if((h|0)==1){break c}if(g){break d}v[d>>2]=0;a=a+1|0;u[d+4>>1]=a;if(uc(s)>>>0>(a&65535)>>>0){continue}break}}g=v[d>>2];v[e+52>>2]=g;v[e+48>>2]=g;v[o+16>>2]=g;u[e+74>>1]=a;u[e+72>>1]=a;u[o+24>>1]=a;H=m+72|0;Xd(H);ha=Ar(m- -64|0);ja=c&7;la=(ja|0)!=7;e:{if(la){break e}vl(H,1);vl(H,2);vl(H,3);vl(H,28);vl(H,38);vl(H,40);vl(H,39);vl(H,41);$P(ha,12);$P(ha,13);g=q+20|0;if(x[b+480188>>1]){a=0;while(1){if(w[((a<<5)+b|0)+480281|0]&4){sa=qe(g,a),ta=-1,v[sa>>2]=ta}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((F|0)!=2){break e}a=x[d+12>>1];if(uc(s)>>>0<=a>>>0){break e}a=x[sc(s,a)>>1];v[23048]=0;h=b+484344|0;f=oe(h,a);z=v[23048];v[23048]=0;if((z|0)==1){break c}if(!f){break e}z=Yb(h,a);f=v[d+8>>2];v[23048]=0;z=_P(z,f);I=v[23048];v[23048]=0;if((I|0)==1){break c}if(!z){break e}a=Yb(h,a);v[23048]=0;a=Wc(a,f,0);h=v[23048];v[23048]=0;if((h|0)==1){break c}if(!x[b+480188>>1]){break e}while(1){f:{g:{h:{switch(w[a|0]-253|0){case 0:if(x[b+480192>>1]){break g}break;case 1:case 2:break g;default:break h}}v[23048]=0;h=ne(a);f=v[23048];v[23048]=0;if((f|0)==1){break c}if(!h){break f}if(ru(a)){break f}}sa=qe(g,i),ta=-1,v[sa>>2]=ta}a=a+6|0;i=i+1|0;if(i>>>0<x[b+480188>>1]){continue}break}}U=e+74|0;M=e+48|0;z=e+80|0;oa=e+44|0;E=q+20|0;ka=q+8|0;aa=c&1;ca=e+20|0;D=b+1074308|0;ma=e+616|0;J=b+484344|0;da=32768;pa=(F|0)!=3;na=(F|0)!=2;a=0;i:{while(1){I=a;while(1){f=x[d+12>>1];qa=A[d+8>>3];while(1){v[23048]=0;Ez(m+32|0,b,e,j&1);a=v[23048];v[23048]=0;j:{if((a|0)!=1){g=w[m+32|0];if(A[q+32>>3]<qa|pa){break j}t[o+26|0]=1;break i}break c}h=x[e+72>>1];a=e;k:{if(uc(s)>>>0>h>>>0){h=x[sc(s,x[e+72>>1])>>1];break k}h=65535}u[a+70>>1]=h;v[23048]=0;a=oe(J,h&65535);h=v[23048];v[23048]=0;if((h|0)==1){break c}if(!(x[e+70>>1]==65535|na|a|(f|0)!=x[e+72>>1])){t[o+26|0]=1;break i}l:{if(x[e+70>>1]<Te(J)>>>0){break l}while(1){a=e;i=a;m:{n:{if(x[a+70>>1]!=65535){h=x[e+72>>1];if(uc(s)>>>0>h>>>0){break n}}if(x[s+28>>1]==x[e+72>>1]){break l}h=x[s+28>>1];break m}h=x[e+72>>1]+1|0}u[i+72>>1]=h;a=e;o:{if(uc(s)>>>0>(h&65535)>>>0){h=x[sc(s,x[e+72>>1])>>1];break o}h=65535}u[a+70>>1]=h;u[e+74>>1]=x[e+72>>1];v[23048]=0;a=oe(J,h&65535);h=v[23048];v[23048]=0;if((h|0)==1){break c}p:{if(a){break p}a=x[e+72>>1];h=Qq(m+32|0,ma);v[23048]=0;a=ga(1274,G|0,a|0,0,h|0,(g|0)!=0|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break c}if(!a){break p}if(F>>>0<2){a=x[e+72>>1];v[o+8>>2]=0;u[o+20>>1]=a;if(!F){break l}}v[23048]=0;a=ba(1275,G|0,U|0,M|0,1)|0;h=v[23048];v[23048]=0;if((h|0)==1){break c}if(!a){break l}A[o>>3]=A[q+32>>3];v[23048]=0;S(1276,Z|0,o|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}v[o+16>>2]=v[M>>2];u[o+24>>1]=x[U>>1];v[23048]=0;_(1277,q|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}a=x[e+74>>1];u[e+72>>1]=a;sa=e,ta=x[sc(s,a)>>1],u[sa+70>>1]=ta;v[e+52>>2]=v[e+48>>2];break l}if(x[e+70>>1]>=Te(J)>>>0){continue}break}}if(x[U>>1]==65535){break i}a=x[e+70>>1];v[23048]=0;a=oe(J,a);h=v[23048];v[23048]=0;if((h|0)==1){break c}if(!a){if(x[s+28>>1]==x[e+72>>1]){if(!F){break i}v[23048]=0;a=ba(1275,G|0,U|0,M|0,1)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}if(!a){break i}A[o>>3]=A[q+32>>3];v[23048]=0;S(1276,Z|0,o|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}v[o+16>>2]=v[M>>2];u[o+24>>1]=x[U>>1];v[23048]=0;_(1277,q|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}v[e+52>>2]=v[e+48>>2];continue}u[e+74>>1]=x[e+72>>1]+1;continue}break}if(y[e+48>>2]>=y[Yb(J,x[e+70>>1])+12>>2]){v[M>>2]=0}if(!(x[e+72>>1]!=x[d+12>>1]|na|v[M>>2]!=v[d+8>>2])){t[o+26|0]=1;break i}a=0;if(!((F|0)==3|y[G+28>>2]<da>>>0)){v[q+32>>2]=0;v[q+36>>2]=2146435072;v[G+28>>2]=0;da=da>>>(da>>>0>256)|0;a=1}h=v[e+48>>2];f=x[e+72>>1];i=Qq(m+32|0,ma);v[23048]=0;h=ga(1274,G|0,f|0,h|0,i|0,(g|0)!=0|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break c}if((a|h)==1){if(F>>>0<2){u[o+20>>1]=x[e+72>>1];v[o+8>>2]=v[e+48>>2];if(!F){break i}}v[23048]=0;a=ba(1275,G|0,U|0,M|0,1)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}if(!a){break i}A[o>>3]=A[q+32>>3];v[23048]=0;S(1276,Z|0,o|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}v[o+16>>2]=v[M>>2];u[o+24>>1]=x[U>>1];v[23048]=0;_(1277,q|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}v[e+52>>2]=v[e+48>>2];continue}u[o+22>>1]=x[e+72>>1];v[o+12>>2]=v[e+48>>2];v[23048]=0;Dz(b,e,0);a=v[23048];v[23048]=0;if((a|0)==1){break c}if(y[e+48>>2]>=y[Yb(J,x[e+70>>1])+12>>2]){v[M>>2]=0}if(g){continue}break}a=Yb(J,x[e+70>>1]);g=v[e+48>>2];v[23048]=0;a=Wc(a,g,0);g=v[23048];v[23048]=0;q:{r:{if((g|0)!=1){Db(m+32|0,D,77);f=Cb(m+32|0);i=0;if(x[b+480188>>1]){break r}break q}break c}while(1){s:{if(!(sa=!nA(a),ta=0,ua=!f|!(w[((i<<5)+b|0)+480281|0]&4),ua?sa:ta)){Vm((B(i,880)+e|0)+1406|0);break s}v[23048]=0;g=tg(a);h=v[23048];v[23048]=0;if((h|0)==1){break c}if(g){t:{if(!aa){break t}g=w[a+1|0];if(g-251>>>0<5|!g){break t}v[23048]=0;g=zo(a);h=v[23048];v[23048]=0;if((h|0)==1){break c}v[23048]=0;h=Pq(a);k=v[23048];v[23048]=0;if((k|0)==1){break c}u[m+8>>1]=h;t[m+32|0]=w[a+1|0];u[m+34>>1]=x[m+8>>1];v[23048]=0;h=Q(1282,ka|0,m+32|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break c}u[h>>1]=g}Vm((B(i,880)+e|0)+1406|0);break s}g=B(i,880)+e|0;h=g+1410|0;k=w[a+4|0]|w[a+5|0]<<8;t[h|0]=k;t[h+1|0]=k>>>8;g=g+1406|0;h=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[g|0]=h;t[g+1|0]=h>>>8;t[g+2|0]=h>>>16;t[g+3|0]=h>>>24;u:{switch(w[a+3|0]-16|0){case 0:g=w[a+5|0];v[23048]=0;T(1283,b|0,e|0,g|0);g=v[23048];v[23048]=0;if((g|0)==1){break c}break s;case 1:Db(m+32|0,D,5);if(!Cb(m+32|0)){break s}g=w[a+5|0];if(!g){break s}v[23048]=0;T(1283,b|0,e|0,g|0);g=v[23048];v[23048]=0;if((g|0)!=1){break s}break c;case 4:g=w[a+5|0];h=g&240;if((h|0)!=224){if((h|0)!=96){break s}v[e+24>>2]=v[e+24>>2]+(g&15);break s}if(v[ca>>2]){break s}g=w[a+5|0]&15;if(g?0:v[b+480180>>2]&2){break s}v[ca>>2]=g+1;break s;case 3:break u;default:break s}}g=w[a+5|0];if((g&240)!=224){break s}v[ca>>2]=(g&15)+1}a=a+6|0;i=i+1|0;if(i>>>0<x[b+480188>>1]){continue}break}}g=lk(e);v[23048]=0;v[m+32>>2]=1;a=Jc(ca,m+32|0);h=v[23048];v[23048]=0;v:{if((h|0)!=1){a=v[a>>2];u[e+68>>1]=65535;v[e+60>>2]=-1;v[e+64>>2]=-1;if(!x[b+480188>>1]){break v}N=g-1|0;h=g-a|0;V=B(h,1e4);i=0;while(1){w:{f=B(i,880)+e|0;a=f+1406|0;x:{if(nA(a)){break x}k=f+616|0;j=w[f+1411|0];fa=f+1409|0;n=w[fa|0];y:{z:{if(!aa){break z}l=w[a|0];p=f+1407|0;r=w[p|0];if(r){t[f+1417|0]=0;t[f+1421|0]=r;sa=qe(E,i),ta=255,t[sa+5|0]=ta}v[23048]=0;r=ne(a);K=v[23048];v[23048]=0;if((K|0)==1){break w}if(r){t[f+1417|0]=l}v[23048]=0;r=ne(a);K=v[23048];v[23048]=0;if((K|0)==1){break w}A:{if(w[p|0]?0:!r){break A}B:{p=f+1421|0;r=w[p|0];if(!r|r>>>0>x[b+480192>>1]){break B}r=v[((w[p|0]<<2)+b|0)+900380>>2];if(!r|!(t[r+15|0]&1)){break B}r=v[r+8>>2];v[23048]=0;Mo(k,r,b);r=v[23048];v[23048]=0;if((r|0)!=1){break B}break c}l=Nz(b,l,w[p|0]);if(!l){break A}l=B(l,104)+b|0;if(!(w[l+484414|0]&32)){break A}l=x[l+484408>>1];v[23048]=0;Mo(k,l,b);l=v[23048];v[23048]=0;if((l|0)!=1){break A}break c}C:{D:{E:{l=w[f+1408|0];switch(l-1|0){case 1:break z;case 2:case 3:break D;case 0:break E;default:break C}}sa=qe(E,i),ta=w[f+1410|0],t[sa+5|0]=ta;break z}a=w[f+1410|0];if(!a){break z}t[f+1452|0]=a;break z}if(!w[f+1410|0]|(l|0)!=11){break z}mA(m+32|0,b,a,0);a=dc(m+32|0);v[f+1372>>2]=v[m+32>>2]<<2;if(w[a|0]){break y}}F:{G:{switch(n-12|0){case 0:v[23048]=0;lA(b,e,i&65535);a=v[23048];v[23048]=0;if((a|0)!=1){break F}break w;case 2:v[23048]=0;a=kA(b,e,i&65535,j);l=v[23048];v[23048]=0;if((l|0)!=1){if((a|0)==-1){break F}v[e+60>>2]=a;break F}break c;case 5:Db(m+32|0,D,5);if(Cb(m+32|0)){break F}a=v[e+48>>2];l=x[e+70>>1];v[23048]=0;a=Cm(b,l,a,i&65535,0);l=v[23048];v[23048]=0;H:{I:{if((l|0)!=1){a=B(a,1e4);if(!aa|!(v[b+480180>>2]&16777250)){break H}if(a>>>0<1e4){break I}t[f+1453|0]=(a>>>0)/1e4;break H}break c}a=B(w[f+1453|0],1e4)}l=(a>>>0)/1e4|0;J:{if(a>>>0>319999){break J}p=B(V,l&15);a=v[e+44>>2];if((l&240)==16){a=a+p|0;break J}l=a-p|0;a=a>>>0<l>>>0?0:l}v[e+44>>2]=a;a=v[v[b+8>>2]+20>>2];l=v[v[b+8>>2]+24>>2];Db(m+32|0,D,8);Fp(oa,B(a,1e4),Cb(m+32|0)?255e4:B(l,1e4));break F;case 8:K:{switch((j&240)-144>>>4|0){case 0:if(j>>>0>145){break F}v[f+704>>2]=v[f+704>>2]&-257|((j|0)==145)<<8;break F;case 1:t[f+1454|0]=j&15;break F;case 2:pu(b,e,k,j&15);break F;case 6:break K;default:break F}}t[f+1462|0]=j&15;break F;case 7:a=j&240;if((a|0)!=240){if((a|0)!=96){break F}pu(b,e,k,j&15);break F}t[f+1462|0]=j&15;break F;case 1:case 3:case 4:case 6:break F;default:break G}}if((n|0)!=28|(j&240)!=160){break F}Db(m+32|0,D,58);if(Cb(m+32|0)){break F}t[f+1454|0]=j&15}if(!aa){break x}L:{M:{N:{O:{P:{Q:{R:{switch(n-2|0){case 0:if(!j){break y}Db(m+32|0,D,90);if(!Cb(m+32|0)){t[f+1430|0]=j}t[f+1429|0]=j;break y;case 1:if(!j){break y}Db(m+32|0,D,90);if(!Cb(m+32|0)){t[f+1429|0]=j}t[f+1430|0]=j;break y;case 2:if(!j){break y}v[f+1372>>2]=j<<2;break y;case 8:if(!j){break y}v[f+1280>>2]=j<<8;break y;case 4:case 9:if(!j){break y}t[f+1427|0]=j;break y;case 11:sa=qe(E,i),ta=j,t[sa+5|0]=ta;break y;case 21:a=j<<(!(v[b+480180>>2]&59593760)&j<<24>>24>-1)&255;if(a>>>0<=128){v[z>>2]=a<<1;break y}if(v[b+480180>>2]&16777250){break y}v[z>>2]=256;break y;case 22:Db(m+32|0,D,9);S:{if(Cb(m+32|0)){a=f+1435|0;if(j){t[a|0]=j;break S}j=w[a|0];break S}if(j){t[e+1435|0]=j;break S}j=w[e+1435|0]}a=z;n=j&240;l=j&15;T:{if(!(!n|(l|0)!=15)){p=v[z>>2]+(n>>>4<<!(v[b+480180>>2]&59593760)<<1)|0;break T}p=v[z>>2]-(l<<(v[b+480180>>2]&59593760?1:2))|0;if(!(!l|(n|0)!=240)){break T}p=v[z>>2]+B(h,(j>>>3&30)<<!(v[b+480180>>2]&59593760))|0;if(n){break T}p=v[z>>2]-B(h,l<<(v[b+480180>>2]&59593760?1:2))|0}v[a>>2]=p;Vd(z,0,256);break y;case 19:if(j>>>0>64){break y}v[f+1364>>2]=j;break y;case 20:a=f+1434|0;U:{if(j){t[a|0]=j;break U}j=w[a|0]}n=j&255;l=f+1364|0;a=v[l>>2];p=j&240;j=j&15;V:{if(!(!p|(j|0)!=15)){v[m+32>>2]=a+(n>>>4|0);break V}if(!(!j|(p|0)!=240)){v[m+32>>2]=a-j;break V}if(j){v[m+32>>2]=a-B(h,j);break V}v[m+32>>2]=a+B(h,n>>>4|0)}Vd(m+32|0,0,64);v[l>>2]=v[m+32>>2];break y;case 7:Bm(b,k,j,8);break y;case 25:break L;case 6:break M;case 24:break N;case 3:break O;case 5:break P;case 18:break Q;case 17:break R;default:break y}}if(!x[b+480188>>1]|j>>>0>15){break Q}n=(j&1)<<14;a=0;while(1){l=B(a,880)+e|0;v[l+704>>2]=(n|v[l+704>>2]&-16385)^16384;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((j&240)!=128){break y}Bm(b,k,j&15,4);break y}if(j){t[f+1427|0]=j}j=0}ul(k,j);break y}YP(b,k,j);break y}XP(k,j);break y}WP(k,j)}W:{X:{switch(w[f+1408|0]-2|0){case 0:Bm(b,k,w[f+1410|0],6);break W;case 5:Db(m+32|0,D,53);j=Cb(m+32|0);a=w[f+1410|0];if(j){t[f+1441|0]=a&15;break W}ul(k,a<<4);break W;case 6:break X;default:break W}}ul(k,w[f+1410|0])}Y:{Z:{_:{$:{a=w[fa|0];switch(a-5|0){case 3:break Z;case 0:case 2:break _;case 1:break x;default:break $}}switch(a-26|0){case 1:break Y;case 0:break _;default:break x}}aa:{if(v[b+480180>>2]&16777248){a=g;if(!(w[b+480208|0]&4)){break aa}}a=h}k=w[f+1441|0];Db(m+32|0,D,21);j=Cb(m+32|0);f=f+1437|0;a=B(a,k);t[f|0]=w[f|0]+(j?a<<2:a);break x}ba:{if(v[b+480180>>2]&16777248){a=g;if(!(w[b+480208|0]&4)){break ba}}a=h}k=w[f+1444|0];Db(m+32|0,D,21);j=Cb(m+32|0);f=f+1438|0;a=B(a,k);t[f|0]=w[f|0]+(j?a<<2:a);break x}a=f+1439|0;t[a|0]=w[a|0]+B(N,w[f+1447|0]);v[23048]=0;Gz(b,k);a=v[23048];v[23048]=0;if((a|0)==1){break w}}i=i+1|0;if(i>>>0<x[b+480188>>1]){continue}break v}break}break c}break c}if(v[e+40>>2]==65535?v[b+480180>>2]==4:0){break i}v[e+32>>2]=v[b+480216>>2];if(VP(Yb(J,x[e+70>>1]))){sa=e,ta=v[Yb(J,x[e+70>>1])+16>>2],v[sa+32>>2]=ta}v[23048]=0;a=Q(1289,b|0,e|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){h=B(a,g);A[q+32>>3]=+(h>>>0)/+y[b+24620>>2]+A[q+32>>3];v[e>>2]=h+v[e>>2];if(!(!x[b+480188>>1]|la)){j=0;fa=(I|0)!=0&(a|0)!=(I|0);while(1){ca:{if(v[qe(E,j)>>2]==-1){break ca}n=B(j,880)+e|0;V=n+1406|0;l=n+1316|0;if(!v[l>>2]){if(nA(V)){break ca}}r=1;da:{ea:{N=n+1409|0;switch(w[N|0]-4|0){case 0:case 2:break da;default:break ea}}r=w[n+1408|0]==11}if(w[n+1407|0]){v[n+1276>>2]=0}p=n+1411|0;k=w[p|0];v[23048]=0;K=ne(V);h=v[23048];v[23048]=0;fa:{if((h|0)==1){break fa}h=n+616|0;i=k&15;f=0;ga:{if(!K){break ga}ha:{if(!r){break ha}if(!w[qe(E,j)+4|0]){break ha}f=v[l>>2];v[23048]=0;ea(1290,m+32|0,b|0,h|0,f|0,0);f=v[23048];v[23048]=0;if((f|0)==1){break c}f=v[m+36>>2];v[n+624>>2]=v[m+32>>2];v[n+628>>2]=f}t[n+1420|0]=w[n+1417|0];K=n+1308|0;ra=v[K>>2];f=w[n+1421|0];if(f){v[23048]=0;yo(b,h,f,r,1,1);f=v[23048];v[23048]=0;if((f|0)==1){break c}}f=w[V|0];v[23048]=0;ia(1292,b|0,h|0,f|0,r|0,1,0,65535);f=v[23048];v[23048]=0;if((f|0)==1){break c}k=k>>>4|0;sa=qe(E,j),ta=1,t[sa+4|0]=ta;l=w[N|0];ia:{if(!((w[p|0]&240)!=208|(l-19&255)>>>0>1)){f=i;if(g>>>0>f>>>0){break ia}}f=(l|0)==33?g>>>0>k>>>0?k:0:0}if(!(!(v[b+480180>>2]&16777250)|(!f|y[ca>>2]<2))){f=B(v[e+20>>2]-1|0,v[e+24>>2]+v[e+40>>2]|0)+f|0}if(!r){sa=qe(E,j),ta=0,v[sa>>2]=ta}l=w[N|0];ja:{ka:{if((l|0)==9){break ka}la:{if((l|0)!=19){if((k|0)!=8|(l|0)!=20){break la}break ka}if((k|0)==8){break ka}}if(w[n+1408|0]!=2){break ja}}v[K>>2]=ra}ma:{na:{oa:{switch(l-42|0){default:if((l|0)!=10){break na}v[23048]=0;Y(1293,b|0,h|0,j&65535,e|0);k=v[23048];v[23048]=0;if((k|0)==1){break c}break ga;case 2:break ma;case 1:break na;case 0:break oa}}if(!v[n+720>>2]){break na}v[23048]=0;Y(1294,q|0,j&65535,I|0,-1);f=v[23048];v[23048]=0;if((f|0)==1){break c}f=w[p|0];v[23048]=0;jA(h,f);f=v[23048];v[23048]=0;if((f|0)==1){break c}f=v[e+40>>2]-1|0;break ga}if(w[n+1408|0]!=15){break ga}k=n+1410|0;if(w[k|0]>9){break ga}l=v[n+720>>2];if(!l){break ga}k=w[k|0];pa:{if(!k){l=v[n+1280>>2];break pa}l=v[(l+(k<<2)|0)- -64>>2];v[n+1280>>2]=l}v[23048]=0;Am(b,h,l);k=v[23048];v[23048]=0;if((k|0)!=1){break ga}break c}l=Fpa(w[p|0],0,v[n+692>>2],0);k=jb;K=k>>>8|0;k=Xc((k&255)<<24|l>>>8,K);v[23048]=0;Am(b,h,k);k=v[23048];v[23048]=0;if((k|0)==1){break c}}qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{switch(w[V|0]-253|0){case 0:if(x[b+480192>>1]){break za}break;case 1:case 2:break za;default:break Aa}}k=w[N|0];if((k-19&255)>>>0<=1){l=0;if((w[p|0]&240)!=192){break xa}if(g>>>0>i>>>0){break za}break xa}l=0;if((k|0)==33&(i|0)!=0&f+i>>>0<g>>>0){break za}if((k|0)!=25){break ya}}k=w[N|0];l=1}if((k|0)==13){break wa}}if(w[n+1408|0]==1){v[n+1304>>2]=w[n+1410|0]<<2}if(!v[n+720>>2]|l){break ta}l=0;if(k>>>0<=44){break va}break ua}v[n+1304>>2]=w[p|0]<<2;if(!v[n+720>>2]|l){break ta}k=13}Db(m+32|0,H,k);l=1;if(Cb(m+32|0)){break ua}l=0;if(w[N|0]!=19){break ua}i=w[p|0]&240;l=(i|0)==16|(i|0)==32}i=w[n+1408|0];if(i>>>0>15){break sa}Wk(m+32|0,ha,i);if(Cb(m+32|0)|l){break qa}break ra}if(!l){break ra}break qa}if(l){break qa}}if(fa){v[23048]=0;Y(1294,q|0,j&65535,I|0,-1);i=v[23048];v[23048]=0;if((i|0)==1){break fa}}i=w[N|0];Ba:{if(i>>>0<=18){if(!g|(((i|0)!=11?i-6>>>0>=2:0)|(v[b+480180>>2]==1?!w[p|0]:0))){break Ba}i=n+1469|0;k=0;while(1){t[i|0]=!k|w[i|0]&254;xo(b,h,w[p|0]);k=k+1|0;if((g|0)!=(k|0)){continue}break}break Ba}Ca:{switch(i-19|0){case 0:k=w[p|0];if(!(k&15)){if(!(v[b+480180>>2]&1048580)){break Ba}k=w[p|0]}i=n+1469|0;t[i|0]=w[i|0]|1;i=k&240;if((i|0)!=176){if((i|0)!=160){break Ba}Oq(b,h,k&15,0);break Ba}Nq(b,h,k&15,0);break Ba;case 1:Da:{Ea:{Fa:{i=w[p|0];switch(i-158|0){case 1:break Ea;case 0:break Fa;default:break Da}}v[23048]=0;Y(1294,q|0,j&65535,I|0,-1);i=v[23048];v[23048]=0;if((i|0)==1){break fa}v[n+704>>2]=v[n+704>>2]&-129;break Ba}v[23048]=0;Y(1294,q|0,j&65535,I|0,-1);i=v[23048];v[23048]=0;if((i|0)==1){break fa}v[n+704>>2]=v[n+704>>2]|128;if(!v[n+692>>2]|v[h+4>>2]){break Ba}v[23048]=0;i=ne(V);k=v[23048];v[23048]=0;if((k|0)==1){break fa}if(w[n+704|0]&2?!i:0){break Ba}k=v[n+692>>2]-1|0;v[h>>2]=-1;v[h+4>>2]=k;break Ba}if((i&240)!=112|i>>>0<115){break Ba}v[23048]=0;XA(h,i,b);i=v[23048];v[23048]=0;if((i|0)!=1){break Ba}break fa;default:break Ca}}if(i-35>>>0>=2){break Ba}v[23048]=0;i=j&65535;Y(1294,q|0,i|0,I|0,-1);k=v[23048];v[23048]=0;if((k|0)==1){break fa}v[23048]=0;Y(1298,b|0,i|0,e|0,0);i=v[23048];v[23048]=0;if((i|0)==1){break fa}}l=n+1469|0;t[l|0]=w[l|0]|1;Ga:{Ha:{Ia:{Ja:{i=n+1408|0;switch(w[i|0]-3|0){case 0:case 1:break Ha;case 3:break Ia;case 2:break Ja;default:break Ga}}i=w[n+1410|0];Db(m+32|0,D,41);Oq(b,h,i,Cb(m+32|0));break Ga}i=w[n+1410|0];Db(m+32|0,D,41);Nq(b,h,i,Cb(m+32|0));break Ga}k=w[n+1410|0];Ka:{if(k){break Ka}Db(m+32|0,D,41);k=0;if(!Cb(m+32|0)){break Ka}k=w[n+1452|0];if(!k){break Ga}}if(!g){break Ga}k=w[i|0]==3?k<<4:k;i=0;while(1){t[l|0]=!i|w[l|0]&254;xo(b,h,k&255);i=i+1|0;if((g|0)!=(i|0)){continue}break}}if(r){i=qe(E,j);h=v[i>>2];v[i>>2]=g+h;v[23048]=0;Y(1294,q|0,j&65535,a|0,(f+h|0)+1|0);h=v[23048];v[23048]=0;if((h|0)!=1){break ca}break c}h=qe(E,j);v[h>>2]=v[h>>2]+(g-f|0);break ca}v[23048]=0;YA(h);h=v[23048];v[23048]=0;if((h|0)==1){break fa}sa=qe(E,j),ta=0,v[sa>>2]=ta;break ca}break c}j=j+1|0;if(j>>>0<x[b+480188>>1]){continue}break}}j=SP(b,e,0);continue}break}break c}if(!(!x[b+480188>>1]|(ja|0)!=7)){d=0;while(1){La:{if(v[qe(E,d)>>2]==-1){break La}v[23048]=0;Y(1294,q|0,d&65535,I|0,-1);a=v[23048];v[23048]=0;if((a|0)!=1){break La}break c}d=d+1|0;if(d>>>0<x[b+480188>>1]){continue}break}}if(w[o+26|0]){u[o+20>>1]=x[e+72>>1];v[o+8>>2]=v[e+48>>2]}A[o>>3]=A[q+32>>3];v[23048]=0;S(1276,Z|0,o|0);a=v[23048];v[23048]=0;Ma:{if((a|0)==1){break Ma}Na:{Oa:{if(!aa){break Oa}Pa:{Qa:{if(!(F?!w[o+26|0]:0)){h=b+1074368|0;f=hc(h,e,614);a=0;while(1){g=B(a,880);d=(g+e|0)+616|0;g=hc((f+g|0)+616|0,d,88);v[g+88>>2]=v[d+88>>2];hc(g+92|0,d+92|0,576);v[g+668>>2]=v[d+668>>2];hc(g+672|0,d+672|0,52);to(g+724|0,d+724|0);to(g+732|0,d+732|0);to(g+740|0,d+740|0);hc(g+748|0,d+748|0,127);a=a+1|0;if((a|0)!=256){continue}break}iA(h);a=0;v[b+1074392>>2]=0;t[b+1074468|0]=1;d=b+1074384|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074420>>2]=v[b+1074416>>2];d=b+1300300|0;if(Fd(d)){e=v[d>>2];v[23048]=0;LA(e);e=v[23048];v[23048]=0;if((e|0)==1){break Ma}}if(x[b+480188>>1]){h=(ja|0)==7;while(1){e=B(a,880)+b|0;g=w[e+1075785|0];if(g){t[e+1075788|0]=g}g=qe(E,a);if(!(w[g+5|0]==255|h)){v[23048]=0;t[m+32|0]=64;g=$b(g+5|0,m+32|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}v[e+1075672>>2]=w[g|0]<<2}Ra:{g=e+1075088|0;f=v[g>>2];if(!f|!(w[f+35|0]&2)){break Ra}if(!Fd(d)){break Ra}f=v[d>>2];g=v[g>>2];v[23048]=0;i=f;f=a&65535;Zq(i,f,g+68|0);g=v[23048];v[23048]=0;if((g|0)!=1){g=v[d>>2];v[23048]=0;Qh(g,f,1);g=v[23048];v[23048]=0;if((g|0)!=1){break Ra}}break c}v[e+1075e3>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=PB(m+32|0);sa=m,ta=rr(ka),v[sa+24>>2]=ta;sa=m,ta=Xg(ka),v[sa+16>>2]=ta;if(!Xf(m+24|0,m+16|0)){break Qa}while(1){e=Kl(m+24|0);g=w[e|0]-1&255;a=v[(B(g,160)+b|0)+906300>>2];if(a){Db(m+8|0,d,g);if(!Cb(m+8|0)){v[23048]=0;S(1303,d|0,g|0);g=v[23048];v[23048]=0;if((g|0)==1){break Na}g=v[v[a>>2]+172>>2];v[23048]=0;S(g|0,a|0,-1);g=v[23048];v[23048]=0;if((g|0)==1){break Na}}g=x[e+2>>1];h=v[v[a>>2]+44>>2];e=x[e+4>>1];v[23048]=0;za(h|0,a|0,g|0,C(C(C(e>>>0)*C(.0010010009864345193))));a=v[23048];v[23048]=0;if((a|0)==1){break Na}}Fj(m+24|0);if(Xf(m+24|0,m+16|0)){continue}break}break Qa}if((c|0)==3){break Pa}v[b+1074408>>2]=v[b+480196>>2];v[b+1074412>>2]=v[b+480204>>2];v[b+1074448>>2]=v[b+480200>>2];break Pa}k=250;a=d;f=a;Sa:{Ta:{while(1){if(v[f>>2]){break Ta}f=f+4|0;k=k-32|0;if(k>>>0>31){continue}break}a=(v[a+28>>2]&67108863)!=0;break Sa}a=1}if(!a){break Pa}a=0;while(1){Db(m+8|0,d,a);Ua:{if(!Cb(m+8|0)){break Ua}e=v[(B(a,160)+b|0)+906300>>2];g=v[v[e>>2]+176>>2];v[23048]=0;_(g|0,e|0);e=v[23048];v[23048]=0;if((e|0)!=1){break Ua}break c}a=a+1|0;if((a|0)!=250){continue}break}}if(w[$+16|0]==(X|0)){break Oa}v[23048]=0;Fi($,X);a=v[23048];v[23048]=0;if((a|0)==1){break Ma}}if(c&9){c=G;b=b+1300264|0;d=b;a=b;if(v[a>>2]){Gc(a);sR(a);qR(a);dm(wb(a),v[a>>2],pg(a));sa=wb(a),ta=0,v[sa>>2]=ta;v[a>>2]=0;v[a+4>>2]=0}gp(d,c);v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];a=wb(c);sa=wb(d),ta=v[a>>2],v[sa>>2]=ta;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;a=b+12|0;Uq(a,v[dc(a)>>2]);b=c+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];dc(b);dc(a);v[a+8>>2]=v[b+8>>2];d=v[wb(a)>>2];c=dc(a);Va:{if(!d){v[a>>2]=c;break Va}sa=v[dc(a)>>2],ta=c,v[sa+8>>2]=ta;sa=b,ta=dc(b),v[sa>>2]=ta;sa=dc(b),ta=0,v[sa>>2]=ta;sa=wb(b),ta=0,v[sa>>2]=ta}}Mq(G);QP(q);gb=m+192|0;return}}}a=P()|0;O()|0;Mq(G);break b}a=P()|0;O()|0}QP(q);break a}a=P()|0;O()|0}Rm(Z);R(a|0);L()}function U5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0,q=C(0),r=0,s=0,A=C(0),D=0,E=0,F=0,G=0,H=C(0),I=0,J=0,K=0,M=C(0),N=C(0),O=0,P=C(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=C(0),$=0,aa=0,ba=0,ca=0,da=0,ea=C(0),fa=C(0),ga=C(0),ia=C(0),ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;aa=gb-16|0;gb=aa;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<1){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{l=b+e|0;if(w[l|0]!=79|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))!=(w[91480]|w[91481]<<8|(w[91482]<<16|w[91483]<<24))){break f}h=b+26|0;if((h|0)>=(a|0)){break e}p=b+27|0;j=e+h|0;c=w[j|0];if((a|0)<=(p+c|0)){break e}i=c+27|0;f=0;if(c){while(1){i=w[e+(f+p|0)|0]+i|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){f=by(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}c=23;while(1){f=by(f,0);if((c|0)!=26){c=c+1|0;continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=i-26;v[c+1424>>2]=w[l+22|0]|w[l+23|0]<<8|(w[l+24|0]<<16|w[l+25|0]<<24);if(w[e+(h+w[j|0]|0)|0]==255){f=-1}else{f=w[l+6|0]|w[l+7|0]<<8|(w[l+8|0]<<16|w[l+9|0]<<24)}v[c+1436>>2]=h;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<1){break b}}a=0;while(1){l=d+B(a,20)|0;j=l+1432|0;c=v[j>>2];f=0;i=v[l+1436>>2];h=b-i|0;m=l+1428|0;p=v[m>>2];h=(h|0)<(p|0)?h:p;if((h|0)>=1){while(1){c=by(c,w[e+(f+i|0)|0]);k=f+1|0;f=k;if((h|0)!=(k|0)){continue}break}}f=p-h|0;v[m>>2]=f;v[j>>2]=c;g:{if(!f){f=c;c=l+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=h+i|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;l=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=l;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!tJ(a)){v[f>>2]=0;b=0;break a}ja=gb-16|0;gb=ja;h=aa+4|0;p=h;l=a;c=l;v[c+1504>>2]=0;v[c+1508>>2]=0;h:{if(v[c+96>>2]){break h}g=c;i:{j:{k:{if(v[c+1380>>2]!=-1){break k}m=Pe(g);if(v[g+96>>2]){break i}if((m|0)!=79){break j}if((Pe(g)|0)!=103){break j}if((Pe(g)|0)!=103){break j}if((Pe(g)|0)!=83){break j}if(!oJ(g)){break i}if(!(t[g+1375|0]&1)){break k}t[g+1376|0]=0;v[g+1384>>2]=0;ec(g,32);break i}j=_x(g);break i}ec(g,30)}if(!j){break h}if(kc(c,1)){ec(c,35);break h}n=ja;l:{m:{if(!(v[c+84>>2]!=v[c+92>>2]?v[c+80>>2]:0)){g=kc(c,sm(v[c+408>>2]-1|0));if((g|0)==-1|(g|0)>=v[c+408>>2]){break h}v[ja+12>>2]=g;m=c+B(g,6)|0;if(!w[m+412|0]){i=v[c+112>>2];g=i>>1;break m}i=v[c+116>>2];g=i>>1;k=kc(c,1);J=kc(c,1);if(!w[m+412|0]|k){break m}v[p>>2]=i-v[c+112>>2]>>2;k=v[c+112>>2]+i>>2;break l}ha(69640,69696,3137,69728);L()}v[p>>2]=0;k=g}v[n+8>>2]=k;n:{if(!(!w[m+412|0]|J)){g=B(i,3);v[aa+8>>2]=g-v[c+112>>2]>>2;i=g+v[c+112>>2]>>2;break n}v[aa+8>>2]=g}v[ja+4>>2]=i;i=1}c=0;if(i){Z=v[h>>2];pa=v[aa+8>>2];oa=v[ja+4>>2];ra=h;p=0;O=gb-2368|0;gb=O;r=v[l+404>>2];qa=l+B(v[ja+12>>2],6)|0;D=w[qa+413|0];W=r+B(D,40)|0;ba=W;X=v[(l+(w[qa+412|0]<<2)|0)+104>>2];o:{p:{i=v[l+4>>2];q:{if((i|0)>0){while(1){c=w[(v[ba+4>>2]+B(p,3)|0)+2|0];Q=(O+1344|0)+(p<<2)|0;v[Q>>2]=0;g=w[(c+W|0)+9|0];if(!x[(l+(g<<1)|0)+132>>1]){ec(l,21);c=0;break q}h=v[l+260>>2];r:{s:{if(kc(l,1)){c=2;m=v[(l+(p<<2)|0)+996>>2];j=h+B(g,1596)|0;G=v[(w[j+1588|0]<<2)+69868>>2];g=sm(G)-1|0;za=m,Aa=kc(l,g),u[za>>1]=Aa;za=m,Aa=kc(l,g),u[za+2>>1]=Aa;i=0;if(w[j|0]){while(1){R=w[(i+j|0)+1|0];h=R+j|0;k=w[h+33|0];g=0;s=w[h+49|0];t:{if(!s){break t}h=v[l+124>>2]+B(w[h+65|0],2096)|0;if(v[l+1396>>2]<=9){hl(l)}n=v[l+1392>>2];g=u[(h+((n&1023)<<1)|0)+36>>1];u:{if((g|0)>=0){E=n;n=w[g+v[h+8>>2]|0];v[l+1392>>2]=E>>>n;S=v[l+1396>>2]-n|0;n=(S|0)<0;v[l+1396>>2]=n?0:S;g=n?-1:g;break u}g=rm(l,h)}if(!w[h+23|0]){break t}g=v[v[h+2088>>2]+(g<<2)>>2]}if(k){K=-1<<s^-1;h=c+k|0;while(1){n=0;k=u[((j+(R<<4)|0)+((g&K)<<1)|0)+82>>1];v:{if((k|0)<0){break v}k=v[l+124>>2]+B(k&65535,2096)|0;if(v[l+1396>>2]<=9){hl(l)}S=v[l+1392>>2];n=u[(k+((S&1023)<<1)|0)+36>>1];w:{if((n|0)>=0){E=S;S=w[n+v[k+8>>2]|0];v[l+1392>>2]=E>>>S;J=v[l+1396>>2]-S|0;S=(J|0)<0;v[l+1396>>2]=S?0:J;n=S?-1:n;break w}n=rm(l,k)}if(!w[k+23|0]){break v}n=v[v[k+2088>>2]+(n<<2)>>2]}g=g>>s;u[m+(c<<1)>>1]=n;c=c+1|0;if((h|0)!=(c|0)){continue}break}c=h}i=i+1|0;if(i>>>0<w[j|0]){continue}break}}if(v[l+1396>>2]!=-1){break s}}v[Q>>2]=1;break r}u[O+320>>1]=257;h=j+1592|0;c=v[j+1592>>2];if((c|0)>=3){g=2;while(1){c=j+338|0;i=g<<1;n=i+j|0;S=w[n+1088|0];s=S<<1;k=x[c+s>>1];Q=w[n+1089|0];R=Q<<1;K=u[m+s>>1];n=u[R+m>>1]-K|0;s=n>>31;c=(B(x[c+i>>1]-k|0,s^n+s)|0)/(x[c+R>>1]-k|0)|0;n=K+((n|0)<0?0-c|0:c)|0;s=i+m|0;i=x[s>>1];x:{y:{if(i){t[Q+(O+320|0)|0]=1;t[S+(O+320|0)|0]=1;t[(O+320|0)+g|0]=1;c=i<<16>>16;k=G-n|0;if((c|0)>=((n|0)>(k|0)?k:n)<<1){if((n|0)<(k|0)){break x}n=G+(i^-1)|0;break y}if(c&1){n=n-(c+1>>>1|0)|0;break y}n=(c>>1)+n|0;break y}t[(O+320|0)+g|0]=0}u[s>>1]=n}c=v[h>>2];g=g+1|0;if((c|0)>(g|0)){continue}break}}n=0;if((c|0)<=0){break r}while(1){if(!w[(O+320|0)+n|0]){u[m+(n<<1)>>1]=65535;c=v[h>>2]}n=n+1|0;if((n|0)<(c|0)){continue}break}}i=v[l+4>>2];p=p+1|0;if((i|0)>(p|0)){continue}break}}z:{A:{c=v[l+80>>2];if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){hc(O+320|0,O+1344|0,i<<2);h=x[W>>1];if(h){p=v[ba+4>>2];n=0;while(1){j=p+B(n,3)|0;g=w[j+1|0];j=(O+1344|0)+(w[j|0]<<2)|0;if(!(v[(O+1344|0)+(g<<2)>>2]?v[j>>2]:0)){v[(O+1344|0)+(g<<2)>>2]=0;v[j>>2]=0}n=n+1|0;if((h|0)!=(n|0)){continue}break}}S=X>>1;ma=r+B(D,40)|0;if(w[ma+8|0]){c=0;while(1){B:{if((i|0)<1){g=0;break B}j=v[ba+4>>2];n=0;g=0;while(1){if(w[(j+B(n,3)|0)+2|0]==(c|0)){m=g+O|0;h=n<<2;C:{if(v[h+(O+1344|0)>>2]){p=1;h=0;break C}p=0;h=v[(h+l|0)+800>>2]}t[m|0]=p;v[(O+256|0)+(g<<2)>>2]=h;g=g+1|0}n=n+1|0;if((n|0)!=(i|0)){continue}break}}da=O+256|0;D=O;I=gb-16|0;gb=I;h=l;J=v[h+4>>2];n=v[h+396>>2];m=w[(c+ma|0)+24|0];T=n+B(m,24)|0;j=v[T+4>>2];p=S;na=x[(h+(m<<1)|0)+268>>1];i=p<<((na|0)==2);k=i>>>0>j>>>0?j:i;j=v[T>>2];E=(k-(i>>>0>j>>>0?j:i)>>>0)/y[T+8>>2]|0;G=E<<2;i=B(J,G+4|0);V=v[v[h+124>>2]+B(w[T+13|0],2096)>>2];wa=v[h+92>>2];D:{if(v[h+80>>2]){i=Yn(h,i);J=v[h+4>>2];break D}i=Ad(i)}j=0;if((J|0)>=1){k=(J<<2)+i|0;while(1){v[(j<<2)+i>>2]=k;k=k+G|0;j=j+1|0;if((J|0)!=(j|0)){continue}break}}G=i;E:{F:{G:{H:{if((g|0)>=1){i=p<<2;j=0;while(1){if(!w[j+D|0]){Pb(v[da+(j<<2)>>2],0,i)}j=j+1|0;if((j|0)!=(g|0)){continue}break}if((g|0)==1|(na|0)!=2){break F}j=0;break H}if((na|0)!=2){break F}i=!g;break G}while(1){if(w[j+D|0]){j=j+1|0;if((j|0)!=(g|0)){continue}break E}break}i=(g|0)==(j|0)}if(i){break E}n=n+B(m,24)|0;s=n;Q=(g|0)!=2;D=(E|0)<1;R=(g|0)<3;k=0;while(1){I:{if(!Q){j=0;J=0;if(D){break I}while(1){i=v[T>>2]+B(v[T+8>>2],j)|0;v[I+12>>2]=i&1;v[I+8>>2]=i>>1;if(!k){m=v[h+124>>2]+B(w[T+13|0],2096)|0;if(v[h+1396>>2]<=9){hl(h)}r=v[h+1392>>2];i=u[(m+((r&1023)<<1)|0)+36>>1];J:{if((i|0)>=0){K=r;r=w[i+v[m+8>>2]|0];v[h+1392>>2]=K>>>r;K=v[h+1396>>2]-r|0;r=(K|0)<0;v[h+1396>>2]=r?0:K;i=r?-1:i;break J}i=rm(h,m)}i=w[m+23|0]?v[v[m+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break E}v[v[G>>2]+(J<<2)>>2]=v[v[n+16>>2]+(i<<2)>>2]}K:{if((V|0)<1){break K}i=0;if((j|0)>=(E|0)){break K}while(1){m=v[T+8>>2];r=u[(v[s+20>>2]+(w[v[v[G>>2]+(J<<2)>>2]+i|0]<<4)|0)+(k<<1)>>1];L:{if((r|0)>=0){if(nJ(h,v[h+124>>2]+B(r&65535,2096)|0,da,2,I+12|0,I+8|0,p,m)){break L}break E}m=v[T>>2]+(m+B(j,m)|0)|0;v[I+8>>2]=m>>1;v[I+12>>2]=m&1}j=j+1|0;i=i+1|0;if((V|0)<=(i|0)){break K}if((j|0)<(E|0)){continue}break}}J=J+1|0;if((j|0)<(E|0)){continue}break}break I}if(R){break I}j=0;J=0;if(D){break I}while(1){m=v[T>>2]+B(v[T+8>>2],j)|0;i=(m|0)/(g|0)|0;v[I+12>>2]=m-B(g,i);v[I+8>>2]=i;if(!k){m=v[h+124>>2]+B(w[T+13|0],2096)|0;if(v[h+1396>>2]<=9){hl(h)}r=v[h+1392>>2];i=u[(m+((r&1023)<<1)|0)+36>>1];M:{if((i|0)>=0){K=r;r=w[i+v[m+8>>2]|0];v[h+1392>>2]=K>>>r;K=v[h+1396>>2]-r|0;r=(K|0)<0;v[h+1396>>2]=r?0:K;i=r?-1:i;break M}i=rm(h,m)}i=w[m+23|0]?v[v[m+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break E}v[v[G>>2]+(J<<2)>>2]=v[v[n+16>>2]+(i<<2)>>2]}N:{if((V|0)<1){break N}i=0;if((j|0)>=(E|0)){break N}while(1){m=v[T+8>>2];r=u[(v[s+20>>2]+(w[v[v[G>>2]+(J<<2)>>2]+i|0]<<4)|0)+(k<<1)>>1];O:{if((r|0)>=0){if(nJ(h,v[h+124>>2]+B(r&65535,2096)|0,da,g,I+12|0,I+8|0,p,m)){break O}break E}m=v[T>>2]+(m+B(j,m)|0)|0;r=(m|0)/(g|0)|0;v[I+8>>2]=r;v[I+12>>2]=m-B(g,r)}j=j+1|0;i=i+1|0;if((V|0)<=(i|0)){break N}if((j|0)<(E|0)){continue}break}}J=J+1|0;if((j|0)<(E|0)){continue}break}}k=k+1|0;if((k|0)!=8){continue}break}break E}sa=n+B(m,24)|0;ca=sa;xa=(E|0)<1;J=0;while(1){if(!xa){i=0;ta=(g|0)<1;ya=ta|(J|0)!=0;p=0;while(1){j=0;if(!ya){while(1){if(!w[j+D|0]){m=v[h+124>>2]+B(w[T+13|0],2096)|0;if(v[h+1396>>2]<=9){hl(h)}n=v[h+1392>>2];k=u[(m+((n&1023)<<1)|0)+36>>1];P:{if((k|0)>=0){r=n;n=w[k+v[m+8>>2]|0];v[h+1392>>2]=r>>>n;s=v[h+1396>>2]-n|0;n=(s|0)<0;v[h+1396>>2]=n?0:s;k=n?-1:k;break P}k=rm(h,m)}k=w[m+23|0]?v[v[m+2088>>2]+(k<<2)>>2]:k;if((k|0)==-1){break E}v[v[G+(j<<2)>>2]+(i<<2)>>2]=v[v[sa+16>>2]+(k<<2)>>2]}j=j+1|0;if((j|0)!=(g|0)){continue}break}}Q:{if((V|0)<1){break Q}k=0;if((p|0)>=(E|0)){break Q}while(1){j=0;if(!ta){while(1){R:{if(w[j+D|0]){break R}n=j<<2;m=u[(v[ca+20>>2]+(w[v[v[n+G>>2]+(i<<2)>>2]+k|0]<<4)|0)+(J<<1)>>1];if((m|0)<0){break R}Q=h;m=v[h+124>>2]+B(m&65535,2096)|0;$=v[n+da>>2];Y=v[T+8>>2];n=v[T>>2]+B(Y,p)|0;S:{T:{U:{if(na){U=0;R=1;if((Y|0)<=0){break S}while(1){ka=$+(n<<2)|0;K=Y-U|0;s=0;o=C(0);F=lJ(Q,m);V:{if((F|0)<0){break V}r=m;s=v[m>>2];K=(s|0)<(K|0)?s:K;la=B(s,F);W:{X:{if(w[m+22|0]){F=0;if((K|0)>0){break X}break W}F=0;if((K|0)<=0){break W}while(1){s=ka+(F<<2)|0;z[s>>2]=z[s>>2]+z[v[r+28>>2]+(F+la<<2)>>2];s=1;F=F+1|0;if((K|0)!=(F|0)){continue}break}break V}while(1){s=ka+(F<<2)|0;o=C(z[v[r+28>>2]+(F+la<<2)>>2]+o);z[s>>2]=z[s>>2]+o;o=C(z[r+12>>2]+o);s=1;F=F+1|0;if((K|0)!=(F|0)){continue}break}break V}s=1}if(!s){break U}s=v[m>>2];n=s+n|0;U=s+U|0;if((Y|0)>(U|0)){continue}break}break S}U=0;r=(Y|0)/v[m>>2]|0;if((r|0)<=0){break T}ka=$+(n<<2)|0;while(1){la=ka+(U<<2)|0;F=Y-(n+U|0)|0;K=r;s=0;o=C(0);ua=lJ(Q,m);Y:{if((ua|0)<0){break Y}s=1;R=m;$=v[m>>2];va=(F|0)>($|0)?$:F;if((va|0)<1){break Y}$=B($,ua);F=0;while(1){s=la+(B(F,K)<<2)|0;A=C(z[v[R+28>>2]+(F+$<<2)>>2]+o);z[s>>2]=z[s>>2]+A;o=w[R+22|0]?A:o;s=1;F=F+1|0;if((va|0)!=(F|0)){continue}break}}if(!s){break U}U=U+1|0;if((r|0)!=(U|0)){continue}break}break T}R=0;break S}R=1}if(!R){break E}}j=j+1|0;if((j|0)!=(g|0)){continue}break}}p=p+1|0;k=k+1|0;if((V|0)<=(k|0)){break Q}if((p|0)<(E|0)){continue}break}}i=i+1|0;if((p|0)<(E|0)){continue}break}}J=J+1|0;if((J|0)!=8){continue}break}}if(!v[h+80>>2]){Zb(G)}v[h+92>>2]=wa;gb=I+16|0;c=c+1|0;if(c>>>0<w[ma+8|0]){i=v[l+4>>2];continue}break}c=v[l+80>>2]}if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){i=x[W>>1];if(i){h=(S|0)>1?S:1;g=l+800|0;while(1){c=i;i=c-1|0;if((X|0)>=2){p=v[ba+4>>2]+B(i,3)|0;j=v[g+(w[p+1|0]<<2)>>2];p=v[g+(w[p|0]<<2)>>2];n=0;while(1){m=n<<2;k=m+j|0;q=z[k>>2];m=m+p|0;o=z[m>>2];Z:{if(!(o<=C(0))){if(!(q<=C(0))){A=C(o-q);break Z}A=o;o=C(q+o);break Z}if(!(q<=C(0))){A=C(q+o);break Z}A=o;o=C(o-q)}z[m>>2]=o;z[k>>2]=A;n=n+1|0;if((h|0)!=(n|0)){continue}break}}if((c|0)>1){continue}break}}n=0;if(v[l+4>>2]<=0){break z}T=S<<2;while(1){g=n<<2;h=g+l|0;c=h;_:{if(v[g+(O+320|0)>>2]){Pb(v[c+800>>2],0,T);break _}g=X;i=v[c+800>>2];R=v[h+996>>2];p=1;c=l;h=w[(W+w[(v[W+4>>2]+B(n,3)|0)+2|0]|0)+9|0];$:{if(!x[(c+(h<<1)|0)+132>>1]){ec(c,21);break $}s=g>>1;G=v[c+260>>2]+B(h,1596)|0;c=B(w[G+1588|0],u[R>>1]);g=0;k=v[G+1592>>2];if((k|0)>=2){F=G+1592|0;I=G+1588|0;while(1){h=w[(p+G|0)+838|0]<<1;j=u[h+R>>1];if((j|0)>=0){j=B(w[I|0],j&65535);h=x[(h+G|0)+338>>1];if((h|0)!=(g|0)){m=i;k=g;D=j-c|0;r=h-g|0;Q=(D|0)/(r|0)|0;aa:{K=(h|0)>(s|0)?s:h;if((K|0)<=(g|0)){break aa}g=m+(k<<2)|0;z[g>>2]=z[g>>2]*z[((c&255)<<2)+70080>>2];g=k+1|0;if((K|0)<=(g|0)){break aa}k=(D|0)>-1?1:-1;E=D;D=D>>31;E=E+D^D;D=Q>>31;D=E-B(r,D+Q^D)|0;J=D;while(1){E=m+(g<<2)|0;ca=E;A=z[E>>2];E=(r|0)>(J|0);c=(c+Q|0)+(E?0:k)|0;z[ca>>2]=A*z[((c&255)<<2)+70080>>2];g=g+1|0;if((K|0)==(g|0)){break aa}J=D+(J-(E?0:r)|0)|0;continue}}k=v[F>>2];g=h}c=j}p=p+1|0;if((k|0)>(p|0)){continue}break}}if((g|0)<(s|0)){o=z[(c<<2)+70080>>2];while(1){c=i+(g<<2)|0;z[c>>2]=z[c>>2]*o;g=g+1|0;if((s|0)!=(g|0)){continue}break}}}}n=n+1|0;c=v[l+4>>2];if((n|0)<(c|0)){continue}break}break A}ha(69640,69696,3319,69888);L()}ha(69640,69696,3286,69888);L()}n=0;if((c|0)<=0){break z}while(1){ba=w[qa+412|0];G=X;V=G>>1;g=V<<2;s=l;na=v[l+92>>2];p=v[(l+(n<<2)|0)+800>>2];c=V<<2;W=p+c|0;ba:{if(v[l+80>>2]){m=Yn(s,g);break ba}m=Ad(g)}h=(m+c|0)-8|0;k=v[(s+(ba<<2)|0)+1068>>2];ca:{if(!V){g=k;break ca}c=p;g=k;while(1){z[h+4>>2]=C(z[g>>2]*z[c>>2])-C(z[g+4>>2]*z[c+8>>2]);z[h>>2]=C(z[g>>2]*z[c+8>>2])+C(z[g+4>>2]*z[c>>2]);g=g+8|0;h=h-8|0;c=c+16|0;if((W|0)!=(c|0)){continue}break}}if(h>>>0>=m>>>0){c=((V<<2)+p|0)-12|0;while(1){z[h+4>>2]=C(z[g+4>>2]*z[c>>2])-C(z[g>>2]*z[c+8>>2]);z[h>>2]=C(z[g>>2]*C(-z[c>>2]))-C(z[g+4>>2]*z[c+8>>2]);c=c-16|0;g=g+8|0;h=h-8|0;if(m>>>0<=h>>>0){continue}break}}da=G>>2;if((G|0)>=16){c=da<<2;h=c+m|0;j=c+p|0;g=(k+(V<<2)|0)-32|0;i=p;c=m;while(1){o=z[c>>2];A=z[h>>2];q=z[c+4>>2];H=z[h+4>>2];z[j+4>>2]=q+H;z[j>>2]=z[c>>2]+z[h>>2];q=C(H-q);o=C(A-o);z[i+4>>2]=C(z[g+16>>2]*q)-C(z[g+20>>2]*o);z[i>>2]=C(z[g+20>>2]*q)+C(z[g+16>>2]*o);o=z[c+8>>2];A=z[h+8>>2];q=z[c+12>>2];H=z[h+12>>2];z[j+12>>2]=q+H;z[j+8>>2]=z[c+8>>2]+z[h+8>>2];q=C(H-q);o=C(A-o);z[i+12>>2]=C(z[g>>2]*q)-C(z[g+4>>2]*o);z[i+8>>2]=C(z[g+4>>2]*q)+C(z[g>>2]*o);c=c+16|0;h=h+16|0;i=i+16|0;j=j+16|0;g=g-32|0;if(k>>>0<=g>>>0){continue}break}}D=sm(G);g=G>>4;j=V-1|0;c=G>>3;h=0-c|0;mJ(g,p,j,h,k);mJ(g,p,j-da|0,h,k);Y=G>>5;g=0-g|0;fq(Y,p,j,g,k,16);fq(Y,p,j-c|0,g,k,16);fq(Y,p,j-(c<<1)|0,g,k,16);fq(Y,p,j+B(c,-3)|0,g,k,16);i=2;if((D|0)>=10){c=D-4>>1;i=(c|0)>3?c:3;h=2;while(1){c=h;h=c+1|0;r=2<<c;if((r|0)>=1){Q=8<<c;R=G>>c+4;g=0;c=G>>c+2;K=0-(c>>1)|0;while(1){fq(R,p,j-B(c,g)|0,K,k,Q);g=g+1|0;if((r|0)!=(g|0)){continue}break}}if((h|0)!=(i|0)){continue}break}}ma=D-7|0;if((ma|0)>(i|0)){while(1){c=i;i=c+1|0;g=G>>c+6;if((g|0)>=1){R=2<<c;K=8<<c;$=K<<2;J=G>>c+2;T=0-(J>>1)|0;h=k;c=j;while(1){F=p;I=c;E=T;D=h;r=K;U=J;Q=R;if((Q|0)>=1){ka=D+B(r,12)|0;o=z[ka>>2];la=r<<3;A=z[la+D>>2];r=D+(r<<2)|0;q=z[r>>2];H=z[ka+4>>2];M=z[D+(la|4)>>2];ea=z[r+4>>2];fa=z[D+4>>2];ga=z[D>>2];D=F+(I<<2)|0;F=D+(E<<2)|0;r=0-U<<2;while(1){I=F-4|0;P=z[I>>2];ia=z[F>>2];_=z[D>>2];z[D>>2]=ia+_;E=D-4|0;N=z[E>>2];z[E>>2]=z[I>>2]+N;N=C(N-P);P=C(_-ia);z[I>>2]=C(N*ga)+C(P*fa);z[F>>2]=C(P*ga)-C(N*fa);I=F-12|0;ia=z[I>>2];E=D-8|0;N=z[E>>2];ca=E;E=F-8|0;_=z[E>>2];z[ca>>2]=_+N;U=D-12|0;P=z[U>>2];z[U>>2]=z[I>>2]+P;P=C(P-ia);N=C(N-_);z[I>>2]=C(P*q)+C(N*ea);z[E>>2]=C(N*q)-C(P*ea);I=F-20|0;ia=z[I>>2];E=D-16|0;N=z[E>>2];ca=E;E=F-16|0;_=z[E>>2];z[ca>>2]=_+N;U=D-20|0;P=z[U>>2];z[U>>2]=z[I>>2]+P;P=C(P-ia);N=C(N-_);z[I>>2]=C(P*A)+C(N*M);z[E>>2]=C(N*A)-C(P*M);I=F-28|0;ia=z[I>>2];E=D-24|0;N=z[E>>2];ca=E;E=F-24|0;_=z[E>>2];z[ca>>2]=_+N;U=D-28|0;P=z[U>>2];z[U>>2]=z[I>>2]+P;P=C(P-ia);N=C(N-_);z[I>>2]=C(P*o)+C(N*H);z[E>>2]=C(N*o)-C(P*H);F=r+F|0;D=D+r|0;I=(Q|0)>1;Q=Q-1|0;if(I){continue}break}}c=c-8|0;h=($<<2)+h|0;D=(g|0)>1;g=g-1|0;if(D){continue}break}}if((i|0)!=(ma|0)){continue}break}}c=p;g=G;if((0-(Y<<4)|0)<=-1){c=c+(j<<2)|0;h=c-(Y<<6)|0;o=z[k+(g>>3<<2)>>2];while(1){g=c-32|0;q=z[g>>2];H=z[c>>2];z[c>>2]=q+H;i=c-4|0;A=z[i>>2];k=i;i=c-36|0;M=z[i>>2];z[k>>2]=M+A;z[g>>2]=H-q;z[i>>2]=A-M;i=c-8|0;A=z[i>>2];k=i;i=c-40|0;H=z[i>>2];z[k>>2]=H+A;j=c-12|0;q=z[j>>2];k=j;j=c-44|0;M=z[j>>2];z[k>>2]=M+q;q=C(q-M);A=C(A-H);z[i>>2]=C(q+A)*o;z[j>>2]=C(q-A)*o;i=c-20|0;A=z[i>>2];j=c-52|0;q=z[j>>2];k=c-16|0;H=z[k>>2];E=k;k=c-48|0;M=z[k>>2];z[E>>2]=H+M;z[i>>2]=q+A;z[k>>2]=A-q;z[j>>2]=M-H;i=c-60|0;A=z[i>>2];j=c-28|0;q=z[j>>2];k=c-24|0;H=z[k>>2];E=k;k=c-56|0;M=z[k>>2];z[E>>2]=H+M;z[j>>2]=A+q;A=C(q-A);q=C(M-H);z[k>>2]=C(A+q)*o;z[i>>2]=C(q-A)*o;kJ(c);kJ(g);c=c+-64|0;if(h>>>0<c>>>0){continue}break}}k=V-4|0;g=(m+(da<<2)|0)-16|0;if(m>>>0<=g>>>0){h=m+(k<<2)|0;c=v[(s+(ba<<2)|0)+1100>>2];while(1){i=(x[c>>1]<<2)+p|0;z[h+12>>2]=z[i>>2];z[h+8>>2]=z[i+4>>2];z[g+12>>2]=z[i+8>>2];z[g+8>>2]=z[i+12>>2];i=(x[c+2>>1]<<2)+p|0;z[h+4>>2]=z[i>>2];z[h>>2]=z[i+4>>2];z[g+4>>2]=z[i+8>>2];z[g>>2]=z[i+12>>2];c=c+4|0;h=h-16|0;g=g-16|0;if(m>>>0<=g>>>0){continue}break}}h=m+(V<<2)|0;i=h-16|0;if(m>>>0<i>>>0){c=v[(s+(ba<<2)|0)+1084>>2];j=h;g=m;while(1){o=z[c+4>>2];D=j-4|0;A=z[D>>2];q=z[g+4>>2];H=C(A+q);M=z[c>>2];ea=z[g>>2];r=j-8|0;fa=z[r>>2];ga=C(ea-fa);N=C(C(o*H)-C(M*ga));A=C(q-A);z[g+4>>2]=N+A;o=C(C(M*H)+C(o*ga));q=C(fa+ea);z[g>>2]=o+q;z[D>>2]=N-A;z[r>>2]=q-o;o=z[c+12>>2];j=j-12|0;A=z[j>>2];q=z[g+12>>2];H=C(A+q);M=z[c+8>>2];ea=z[g+8>>2];fa=z[i>>2];ga=C(ea-fa);N=C(C(o*H)-C(M*ga));A=C(q-A);z[g+12>>2]=N+A;o=C(C(M*H)+C(o*ga));q=C(fa+ea);z[g+8>>2]=o+q;z[i>>2]=q-o;z[j>>2]=N-A;c=c+16|0;g=g+16|0;j=i;i=i-16|0;if(g>>>0<i>>>0){continue}break}}i=h-32|0;if(m>>>0<=i>>>0){g=v[(s+(ba<<2)|0)+1076>>2]+(V<<2)|0;c=(k<<2)+p|0;j=((G<<2)+p|0)-16|0;while(1){o=z[g-4>>2];A=z[h-8>>2];q=z[g-8>>2];H=z[h-4>>2];M=C(C(o*A)-C(q*H));z[p>>2]=M;z[c+12>>2]=-M;o=C(C(q*C(-A))-C(H*o));z[W>>2]=o;z[j+12>>2]=o;o=z[g-12>>2];A=z[h-16>>2];q=z[g-16>>2];H=z[h-12>>2];M=C(C(o*A)-C(q*H));z[p+4>>2]=M;z[c+8>>2]=-M;o=C(C(q*C(-A))-C(H*o));z[W+4>>2]=o;z[j+8>>2]=o;o=z[g-20>>2];A=z[h-24>>2];q=z[g-24>>2];H=z[h-20>>2];M=C(C(o*A)-C(q*H));z[p+8>>2]=M;z[c+4>>2]=-M;o=C(C(q*C(-A))-C(H*o));z[W+8>>2]=o;z[j+4>>2]=o;o=z[g-28>>2];A=z[i>>2];g=g-32|0;q=z[g>>2];H=z[h-28>>2];M=C(C(o*A)-C(q*H));z[p+12>>2]=M;z[c>>2]=-M;o=C(C(q*C(-A))-C(H*o));z[W+12>>2]=o;z[j>>2]=o;j=j-16|0;c=c-16|0;W=W+16|0;p=p+16|0;h=i;i=h-32|0;if(m>>>0<=i>>>0){continue}break}}if(!v[s+80>>2]){Zb(m)}v[s+92>>2]=na;n=n+1|0;if((n|0)<v[l+4>>2]){continue}break}}qJ(l);da:{if(w[l+1377|0]){v[l+1060>>2]=0-S;t[l+1377|0]=0;v[l+1064>>2]=1;v[l+1412>>2]=X-oa;break da}c=v[l+1412>>2];if(!c){break da}g=pa-Z|0;if((g|0)<=(c|0)){v[l+1412>>2]=c-g;v[ra>>2]=pa;Z=pa;break da}Z=c+Z|0;v[ra>>2]=Z;v[l+1412>>2]=0}g=v[l+1064>>2];c=l;ea:{fa:{ga:{if(v[c+1388>>2]==v[c+1404>>2]){ha:{if(!g|!(w[l+1375|0]&4)){break ha}g=v[l+1408>>2];h=v[l+1060>>2];if(g>>>0>=h+(oa-Z|0)>>>0){break ha}c=g-h|0;c=(c>>>0>g>>>0?0:c)+Z|0;c=(c|0)>(oa|0)?oa:c;v[aa+12>>2]=c;v[l+1060>>2]=c+v[l+1060>>2];break ea}v[l+1064>>2]=1;g=v[l+1408>>2]+(Z-S|0)|0;break ga}if(!g){break fa}g=v[l+1060>>2]}v[c+1060>>2]=(pa-Z|0)+g}if(v[l+84>>2]!=v[l+92>>2]?v[l+80>>2]:0){break p}v[aa+12>>2]=oa}c=1}gb=O+2368|0;break o}ha(69640,69696,3435,69888);L()}}gb=ja+16|0;if(!c){ia:{ja:{ka:{c=v[a+100>>2];switch(c-32|0){case 0:break ja;case 3:break ka;default:break ia}}v[a+100>>2]=0;while(1){if(za=0,Aa=(hh(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ia}v[a+100>>2]=0;while(1){if(za=0,Aa=(hh(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}p=aa;m=v[p+12>>2];G=v[p+4>>2];k=G;g=v[p+8>>2];i=0;la:{ma:{na:{oa:{c=a;j=v[c+992>>2];pa:{if(!j){h=v[c+4>>2];j=0;break pa}X=j<<1;h=c+1092|0;qa:{ra:{if((X|0)==v[c+112>>2]){break ra}h=0;if((X|0)!=v[l+116>>2]){break qa}h=l+1096|0}h=v[h>>2]}l=h;if(!l){break ma}h=v[c+4>>2];if((h|0)<=0){break oa}X=(j|0)<1;while(1){if(!X){n=c+(i<<2)|0;O=n;h=0;while(1){Z=v[n+800>>2]+(h+k<<2)|0;s=h<<2;z[Z>>2]=C(z[l+(j+(h^-1)<<2)>>2]*z[s+v[O+928>>2]>>2])+C(z[l+s>>2]*z[Z>>2]);h=h+1|0;if((j|0)!=(h|0)){continue}break}h=v[c+4>>2]}i=i+1|0;if((i|0)<(h|0)){continue}break}j=v[c+992>>2]}X=m-g|0;v[c+992>>2]=X;if((h|0)>=1){i=0;while(1){if((g|0)<(m|0)){n=c+(i<<2)|0;O=n;h=0;l=g;while(1){z[v[O+928>>2]+(h<<2)>>2]=z[v[n+800>>2]+(l<<2)>>2];h=h+1|0;l=g+h|0;if((h|0)!=(X|0)){continue}break}h=v[c+4>>2]}i=i+1|0;if((i|0)<(h|0)){continue}break}}if(!j){break ma}break na}v[c+992>>2]=m-g}h=c;i=v[c+1416>>2];c=((g|0)>(m|0)?m:g)-k|0;v[h+1416>>2]=i+c;break la}c=0}g=c;v[p+12>>2]=c;l=v[a+4>>2];if((l|0)>=1){c=0;while(1){h=(c<<2)+a|0;v[h+864>>2]=v[h+800>>2]+(G<<2);c=c+1|0;if((l|0)!=(c|0)){continue}break}}if(d){v[d>>2]=l}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}gb=aa+16|0;return b|0}function T5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=C(0),F=0,G=0,I=0,J=C(0),K=0,M=0,N=0,O=0,P=0,Q=0,R=C(0);s=gb-1520|0;gb=s;g=Pb(s+8|0,0,1512);if(e){f=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=f;e=f&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[s+56|0]=1;v[s+48>>2]=a+b;v[s+40>>2]=a;b=0;n=gb-1024|0;gb=n;f=s+8|0;t[f+1377|0]=1;a:{if(!mt(f)){break a}e=w[f+1375|0];if(!(e&2)){ec(f,34);break a}if(e&4){ec(f,34);break a}if(e&1){ec(f,34);break a}if(v[f+1116>>2]!=1){ec(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!ay(f,n+1018|0,6)|w[n+1018|0]!=102|(w[n+1019|0]!=105|w[n+1020|0]!=115)){break b}if(w[n+1021|0]!=104|w[n+1022|0]!=101|w[n+1023|0]!=97){break b}if((Pe(f)|0)!=100){break b}if(Pe(f)){break b}ec(f,38);break a}ec(f,34);break a}if((Pe(f)|0)!=1){ec(f,34);break a}if(!ay(f,n+1018|0,6)){ec(f,10);break a}if(!$x(n+1018|0)){ec(f,34);break a}if(jj(f)){ec(f,34);break a}e=Pe(f);v[f+4>>2]=e;if(!e){ec(f,34);break a}if(e>>>0>=17){ec(f,5);break a}e=jj(f);v[f>>2]=e;if(!e){ec(f,34);break a}jj(f);jj(f);jj(f);e=Pe(f);j=e>>>4|0;v[f+116>>2]=1<<j;g=e&15;v[f+112>>2]=1<<g;if(g-6>>>0>=8){ec(f,20);break a}if((e<<24)-1610612736>>24<=-1){ec(f,20);break a}if(g>>>0>j>>>0){ec(f,20);break a}if(!(Pe(f)&1)){ec(f,34);break a}if(!mt(f)){break a}if(!_x(f)){break a}if(!Zx(f)){break a}c:{d:{if((hh(f)|0)==3){while(1){P=(n+1018|0)+b|0,Q=hh(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!$x(n+1018|0)){ec(f,20);break c}g=Yx(f);e=ce(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=hh(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=Yx(f);v[f+24>>2]=b;b=ce(f,b<<2);v[f+28>>2]=b;e=v[f+24>>2];if(!(b?0:(e|0)>=1)){e:{if((e|0)>0){while(1){g=Yx(f);b=ce(f,g+1|0);j=h<<2;v[j+v[f+28>>2]>>2]=b;e=v[j+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=hh(f);t[v[j+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[j+v[f+28>>2]>>2]}t[e+g|0]=0;h=h+1|0;if((h|0)<v[f+24>>2]){continue}break}}if(!(hh(f)&1)){ec(f,20);break c}sJ(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=Zx(f);sJ(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!_x(f)){break a}if(!tJ(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){g=e<<24;h=1;while(1){g=g>>31&79764919^g<<1;if((h|0)!=8){h=h+1|0;continue}break}v[(e<<2)+461072>>2]=g;e=e+1|0;if((e|0)!=256){continue}break}if((hh(f)|0)==5){while(1){P=(n+1018|0)+b|0,Q=hh(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!$x(n+1018|0)){ec(f,20);break c}b=kc(f,8)+1|0;v[f+120>>2]=b;b=ce(f,B(b,2096));v[f+124>>2]=b;if(!b){ec(f,3);break c}Pb(b,0,B(v[f+120>>2],2096));f:{g:{h:{if(v[f+120>>2]>=1){while(1){b=v[f+124>>2];if((kc(f,8)&255)!=66){ec(f,20);break c}if((kc(f,8)&255)!=67){ec(f,20);break c}if((kc(f,8)&255)!=86){ec(f,20);break c}g=b+B(M,2096)|0;P=g,Q=kc(f,8)&255|kc(f,8)<<8,v[P>>2]=Q;P=g,Q=kc(f,8)&255|(kc(f,8)<<8&65280|kc(f,8)<<16),v[P+4>>2]=Q;o=g+4|0;e=g;j=kc(f,1);b=0;i:{if(j){break i}b=kc(f,1)}t[e+23|0]=b;if(!(v[g>>2]|!v[o>>2])){ec(f,20);break c}e=v[o>>2];j:{if(b&255){h=Yn(f,e);break j}h=ce(f,e);v[g+8>>2]=h}if(!h){ec(f,3);break c}k:{if(!j){b=0;l=0;e=v[o>>2];if((e|0)<=0){break k}while(1){l:{m:{if(w[g+23|0]){if(!kc(f,1)){break m}}e=kc(f,5)+1|0;t[b+h|0]=e;if((e&255)!=32){l=l+1|0;break l}ec(f,20);break c}t[b+h|0]=255}b=b+1|0;e=v[o>>2];if((b|0)<(e|0)){continue}break}break k}i=kc(f,5);l=0;b=0;e=v[o>>2];if((e|0)<1){break k}while(1){j=kc(f,sm(e-b|0));i=i+1|0;if((i|0)>=32){ec(f,20);break c}e=b+j|0;if((e|0)>v[o>>2]){ec(f,20);break c}Pb(b+h|0,i,j);b=e;e=v[o>>2];if((b|0)<(e|0)){continue}break}}n:{o:{if(w[g+23|0]){if(e>>2>(l|0)){break o}b=g;j=f;if(v[f+16>>2]<(e|0)){v[f+16>>2]=e;e=v[o>>2]}l=b;b=ce(j,e);v[l+8>>2]=b;if(!b){ec(f,3);break c}hc(b,h,v[o>>2]);ij(f,h,v[o>>2]);h=v[g+8>>2];t[g+23|0]=0;e=v[o>>2]}j=0;b=0;i=0;if((e|0)>=1){while(1){i=((w[b+h|0]-11&255)>>>0<244)+i|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}}v[g+2092>>2]=i;b=ce(f,e<<2);v[g+32>>2]=b;if(b){k=g+2092|0;break n}ec(f,3);break c}v[g+2092>>2]=l;k=g+2092|0;p:{if(!l){j=0;b=0;break p}b=ce(f,l);v[g+8>>2]=b;if(!b){ec(f,3);break c}b=Yn(f,v[k>>2]<<2);v[g+32>>2]=b;if(!b){ec(f,3);break c}j=Yn(f,v[k>>2]<<2);if(!j){break f}e=v[o>>2];b=v[k>>2]<<3}b=b+e|0;if(b>>>0<=y[f+16>>2]){break n}v[f+16>>2]=b}e=g;l=h;r=v[o>>2];q=j;i=0;b=gb-128|0;gb=b;A=Pb(b,0,128);q:{r:{s:{t:{if((r|0)<1){break t}while(1){if(w[i+l|0]!=255){break t}i=i+1|0;if((r|0)!=(i|0)){continue}break}break s}if((i|0)!=(r|0)){break r}}b=1;if(!v[e+2092>>2]){break q}ha(71210,69696,1088,71233);L()}b=i+l|0;jJ(e,0,i,0,w[b|0],q);p=w[b|0];if(p){b=1;while(1){v[A+(b<<2)>>2]=1<<32-b;m=(b|0)==(p|0);b=b+1|0;if(!m){continue}break}}I=1;m=i+1|0;if((r|0)<=(m|0)){b=1;break q}u:{v:{w:{while(1){x:{i=l+m|0;p=w[i|0];y:{if((p|0)==255){break y}b=p;if(!b){break u}while(1){K=A+(b<<2)|0;F=v[K>>2];if(!F){F=(b|0)>1;b=b-1|0;if(F){continue}break u}break}if(b>>>0>=32){break x}v[K>>2]=0;jJ(e,qm(F),m,I,p,q);I=I+1|0;i=w[i|0];if((i|0)==(b|0)){break y}if(i>>>0>31){break w}if((b|0)>=(i|0)){break y}while(1){p=A+(i<<2)|0;if(v[p>>2]){break v}v[p>>2]=F+(1<<32-i);i=i-1|0;if((i|0)>(b|0)){continue}break}}b=1;m=m+1|0;if((r|0)!=(m|0)){continue}break q}break}ha(71251,69696,1111,71233);L()}ha(71268,69696,1116,71233);L()}ha(71295,69696,1118,71233);L()}b=0}gb=A+128|0;if(!b){if(w[g+23|0]){ij(f,j,0)}ec(f,20);break c}b=v[k>>2];if(b){b=ce(f,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){ec(f,3);break c}b=ce(f,(v[k>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){ec(f,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;q=h;p=j;i=0;m=0;z:{b=g;if(w[b+23|0]){m=v[b+2092>>2];if((m|0)<=0){break z}while(1){e=i<<2;P=e+v[b+2084>>2]|0,Q=qm(v[e+v[b+32>>2]>>2]),v[P>>2]=Q;i=i+1|0;m=v[b+2092>>2];if((i|0)<(m|0)){continue}break}break z}if(v[b+4>>2]>=1){while(1){if(iJ(b,w[i+q|0])){P=v[b+2084>>2]+(m<<2)|0,Q=qm(v[v[b+32>>2]+(i<<2)>>2]),v[P>>2]=Q;m=m+1|0}i=i+1|0;if((i|0)<v[b+4>>2]){continue}break}}if(v[b+2092>>2]==(m|0)){break z}ha(71313,69696,1185,71336);L()}ZI(v[b+2084>>2],m,2212);v[v[b+2084>>2]+(v[b+2092>>2]<<2)>>2]=-1;A:{m=w[b+23|0];F=v[b+(m?2092:4)>>2];if((F|0)<1){break A}e=0;while(1){B:{l=e;i=b;if(m&255){l=v[p+(e<<2)>>2]}K=w[l+q|0];C:{if(!iJ(i,K)){break C}N=e<<2;l=qm(v[N+v[b+32>>2]>>2]);r=v[b+2084>>2];i=0;m=v[b+2092>>2];if((m|0)>=2){while(1){A=m>>>1|0;O=A+i|0;I=l>>>0<y[r+(O<<2)>>2];i=I?i:O;m=I?A:m-A|0;if((m|0)>1){continue}break}}m=i<<2;if((l|0)!=v[m+r>>2]){break B}if(w[b+23|0]){v[m+v[b+2088>>2]>>2]=v[p+N>>2];t[v[b+8>>2]+i|0]=K;break C}v[m+v[b+2088>>2]>>2]=e}e=e+1|0;if((F|0)==(e|0)){break A}m=w[b+23|0];continue}break}ha(71359,69696,1215,71336);L()}}if(w[g+23|0]){ij(f,j,v[k>>2]<<2);ij(f,v[g+32>>2],v[k>>2]<<2);ij(f,h,v[o>>2]);v[g+32>>2]=0}b=g;Pb(b+36|0,255,2048);e=v[b+(w[b+23|0]?2092:4)>>2];if((e|0)>=1){e=(e|0)<32767?e:32767;l=(e|0)>1?e:1;j=v[b+8>>2];e=0;while(1){D:{if(w[e+j|0]>10){break D}E:{if(w[b+23|0]){h=qm(v[v[b+2084>>2]+(e<<2)>>2]);break E}h=v[v[b+32>>2]+(e<<2)>>2]}if(h>>>0>1023){break D}while(1){u[(b+(h<<1)|0)+36>>1]=e;j=v[b+8>>2];h=(1<<w[j+e|0])+h|0;if(h>>>0<1024){continue}break}}e=e+1|0;if((l|0)!=(e|0)){continue}break}}b=kc(f,4);t[g+21|0]=b;b=b&255;if(b>>>0>=3){ec(f,20);break c}if(b){P=g,R=rJ(kc(f,32)),z[P+12>>2]=R;P=g,R=rJ(kc(f,32)),z[P+16>>2]=R;P=g,Q=kc(f,4)+1|0,t[P+20|0]=Q;P=g,Q=kc(f,1),t[P+22|0]=Q;h=v[g>>2];j=v[o>>2];F:{if(w[g+21|0]==1){G=H(Qw(+C(C(Wp(+C(j|0)))/C(h|0))));G:{if(D(G)<2147483648){b=~~G;break G}b=-2147483648}e=b;G=H(ey(+C(C(b|0)+C(1)),h));H:{if(D(G)<2147483648){b=~~G;break H}b=-2147483648}b=e+((b|0)<=(j|0))|0;E=C(b|0);I:{if(!(ey(+C(E+C(1)),h)<=+(j|0))){G=H(ey(+E,h));J:{if(D(G)<2147483648){e=~~G;break J}e=-2147483648}b=(e|0)>(j|0)?-1:b;break I}b=-1}if((b|0)>-1){break F}ec(f,20);break c}b=B(h,j)}v[g+24>>2]=b;if(!b){ec(f,20);break c}e=Yn(f,b<<1);if(!e){break g}b=0;i=v[g+24>>2];if((i|0)>0){while(1){h=kc(f,w[g+20|0]);if((h|0)==-1){ij(f,e,v[g+24>>2]<<1);ec(f,20);break c}u[e+(b<<1)>>1]=h;b=b+1|0;i=v[g+24>>2];if((b|0)<(i|0)){continue}break}}K:{if(w[g+21|0]==1){l=w[g+23|0];L:{if(l){b=v[k>>2];if(b){break L}break K}b=v[o>>2]}b=ce(f,B(v[g>>2],b)<<2);v[g+28>>2]=b;if(!b){ij(f,e,v[g+24>>2]<<1);ec(f,3);break c}p=v[(l?k:o)>>2];if((p|0)>=1){o=g+2088|0;E=C(0);q=0;while(1){k=q;k=l?v[v[o>>2]+(k<<2)>>2]:k;M:{j=v[g>>2];if((j|0)<1){break M}i=v[g+24>>2];b=1;h=0;while(1){J=C(C(z[g+12>>2]+E)+C(z[g+16>>2]*C(x[e+(((k>>>0)/(b>>>0)>>>0)%(i>>>0)<<1)>>1])));z[v[g+28>>2]+(B(j,q)+h<<2)>>2]=J;E=w[g+22|0]?J:E;h=h+1|0;j=v[g>>2];if((h|0)>=(j|0)){break M}i=v[g+24>>2];Fpa(i,0,b,0);if(!jb){b=B(b,i);continue}else{ij(f,e,i<<1);ec(f,20);break c}}}q=q+1|0;if((p|0)!=(q|0)){continue}break}}t[g+21|0]=2;i=v[g+24>>2];break K}b=ce(f,i<<2);v[g+28>>2]=b;i=v[g+24>>2];if(!b){break h}if((i|0)<1){break K}E=C(z[g+12>>2]+C(z[g+16>>2]*C(x[e>>1])));z[b>>2]=E;b=1;i=v[g+24>>2];if((i|0)<=1){break K}J=C(0);while(1){J=w[g+22|0]?E:J;E=C(C(z[g+12>>2]+J)+C(z[g+16>>2]*C(x[e+(b<<1)>>1])));z[v[g+28>>2]+(b<<2)>>2]=E;b=b+1|0;i=v[g+24>>2];if((b|0)<(i|0)){continue}break}}ij(f,e,i<<1)}M=M+1|0;if((M|0)<v[f+120>>2]){continue}break}}N:{e=kc(f,6)+1&255;if(!e){break N}b=1;while(1){if(!kc(f,16)){if((b|0)==(e|0)){break N}b=b+1|0;continue}break}ec(f,20);break c}b=kc(f,6)+1|0;v[f+128>>2]=b;b=ce(f,B(b,1596));v[f+260>>2]=b;if(b){q=0;if(v[f+128>>2]<=0){break d}l=0;O:while(1){b=kc(f,16);u[((q<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){ec(f,20);break c}if(!b){e=v[f+260>>2]+B(q,1596)|0;P=e,Q=kc(f,8),t[P|0]=Q;P=e,Q=kc(f,16),u[P+2>>1]=Q;P=e,Q=kc(f,16),u[P+4>>1]=Q;P=e,Q=kc(f,6),t[P+6|0]=Q;P=e,Q=kc(f,8),t[P+7|0]=Q;b=(kc(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){P=b+g|0,Q=kc(f,8),t[P|0]=Q;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}ec(f,4);break c}k=v[f+260>>2]+B(q,1596)|0;g=kc(f,5);t[k|0]=g;b=-1;h=0;e=0;if(g&255){while(1){g=kc(f,4);t[(e+k|0)+1|0]=g;g=g&255;b=(b|0)<(g|0)?g:b;e=e+1|0;if(e>>>0<w[k|0]){continue}break}while(1){g=h+k|0;P=g,Q=kc(f,3)+1|0,t[P+33|0]=Q;e=kc(f,2);t[g+49|0]=e;P:{if(e&255){e=kc(f,8);t[g+65|0]=e;if(v[f+120>>2]<=(e&255)){ec(f,20);break c}if(w[g+49|0]==31){break P}}e=0;while(1){Q:{j=kc(f,8)-1|0;u[((k+(h<<4)|0)+(e<<1)|0)+82>>1]=j;if(v[f+120>>2]<=j<<16>>16){break Q}e=e+1|0;if((e|0)<1<<w[g+49|0]){continue}break P}break}ec(f,20);break c}e=(b|0)!=(h|0);h=h+1|0;if(e){continue}break}}h=2;P=k,Q=kc(f,2)+1|0,t[P+1588|0]=Q;b=kc(f,4);v[k+1592>>2]=2;j=0;u[k+338>>1]=0;t[k+1589|0]=b;u[k+340>>1]=1<<b;p=k+1592|0;e=w[k|0];R:{if(e){b=k+1589|0;while(1){g=k+w[(j+k|0)+1|0]|0;if(w[g+33|0]){e=1;while(1){h=kc(f,w[b|0]);u[(k+(v[p>>2]<<1)|0)+338>>1]=h;h=v[p>>2]+1|0;v[p>>2]=h;if(w[g+33|0]>e>>>0){e=e+1|0;continue}break}e=w[k|0]}j=j+1|0;if(j>>>0<(e&255)>>>0){continue}break}if((h|0)<=0){break R}}e=0;while(1){b=x[(k+(e<<1)|0)+338>>1];g=(n+16|0)+(e<<2)|0;u[g+2>>1]=e;u[g>>1]=b;e=e+1|0;h=v[p>>2];if((e|0)<(h|0)){continue}break}}j=k+338|0;ZI(n+16|0,h,2211);e=0;h=v[p>>2];b=h-1|0;b=(b|0)>0?b:0;while(1){if((b|0)==(e|0)){e=0;S:{if((h|0)<=0){break S}while(1){t[(e+k|0)+838|0]=w[((n+16|0)+(e<<2)|0)+2|0];e=e+1|0;h=v[p>>2];if((e|0)<(h|0)){continue}break}e=2;if((h|0)<=2){break S}while(1){v[n+12>>2]=0;v[n+8>>2]=0;b=j;h=0;g=e;if((e|0)>=1){o=b+(g<<1)|0;r=-1;m=65536;while(1){A=b+(h<<1)|0;i=x[A>>1];if(!((r|0)>=(i|0)|x[o>>1]<=i>>>0)){v[n+12>>2]=h;i=x[A>>1];r=i}if(!((i|0)>=(m|0)|x[o>>1]>=i>>>0)){v[n+8>>2]=h;m=x[A>>1]}h=h+1|0;if((g|0)!=(h|0)){continue}break}}b=k+(e<<1)|0;t[b+1088|0]=v[n+12>>2];t[b+1089|0]=v[n+8>>2];e=e+1|0;h=v[p>>2];if((e|0)<(h|0)){continue}break}}l=(h|0)>(l|0)?h:l;q=q+1|0;if((q|0)<v[f+128>>2]){continue O}q=l<<1;break d}g=x[(n+16|0)+(e<<2)>>1];e=e+1|0;if((g|0)!=x[(n+16|0)+(e<<2)>>1]){continue}break}break}ec(f,20);break c}ec(f,3);break c}ij(f,e,i<<1);ec(f,3);break c}ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}ec(f,3);break c}ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}b=kc(f,6)+1|0;v[f+264>>2]=b;b=ce(f,B(b,24));v[f+396>>2]=b;if(!b){ec(f,3);break c}i=0;Pb(b,0,B(v[f+264>>2],24));T:{if(v[f+264>>2]>=1){while(1){b=v[f+396>>2];e=kc(f,16);u[((i<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){ec(f,20);break c}h=b+B(i,24)|0;P=h,Q=kc(f,24),v[P>>2]=Q;b=kc(f,24);v[h+4>>2]=b;if(b>>>0<y[h>>2]){ec(f,20);break c}P=h,Q=kc(f,24)+1|0,v[P+8>>2]=Q;P=h,Q=kc(f,6)+1|0,t[P+12|0]=Q;b=kc(f,8);t[h+13|0]=b;U:{V:{if(v[f+120>>2]>(b&255)){b=0;if(w[h+12|0]){break V}e=0;break U}ec(f,20);break c}while(1){g=kc(f,3);j=(n+16|0)+b|0;e=0;W:{if(!kc(f,1)){break W}e=kc(f,5)<<3}t[j|0]=e+g;b=b+1|0;e=w[h+12|0];if(b>>>0<e>>>0){continue}break}}b=ce(f,e<<4);v[h+20>>2]=b;if(!b){break T}if(w[h+12|0]){j=0;while(1){e=w[(n+16|0)+j|0];b=0;while(1){X:{if(e>>>b&1){g=kc(f,8);k=b<<1;l=j<<4;u[k+(l+v[h+20>>2]|0)>>1]=g;if(v[f+120>>2]>u[k+(l+v[h+20>>2]|0)>>1]){break X}ec(f,20);break c}u[(v[h+20>>2]+(j<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}j=j+1|0;if(j>>>0<w[h+12|0]){continue}break}}b=ce(f,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);v[h+16>>2]=b;if(!b){ec(f,3);break c}l=0;Pb(b,0,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];e=w[h+13|0];if(v[(b+B(e,2096)|0)+4>>2]>0){while(1){g=v[B(e,2096)+b>>2];b=ce(f,g);j=l<<2;v[j+v[h+16>>2]>>2]=b;Y:{e=v[j+v[h+16>>2]>>2];if(e){if((g|0)<1){break Y}b=g-1|0;t[e+b|0]=(l>>>0)%w[h+12|0];e=l;if((g|0)==1){break Y}while(1){g=b-1|0;k=w[h+12|0];e=(e|0)/(k|0)|0;t[g+v[j+v[h+16>>2]>>2]|0]=(e|0)%(k|0);k=(b|0)>1;b=g;if(k){continue}break}break Y}ec(f,3);break c}l=l+1|0;b=v[f+124>>2];e=w[h+13|0];if((l|0)<v[(b+B(e,2096)|0)+4>>2]){continue}break}}i=i+1|0;if((i|0)<v[f+264>>2]){continue}break}}b=kc(f,6)+1|0;v[f+400>>2]=b;b=ce(f,B(b,40));v[f+404>>2]=b;if(!b){ec(f,3);break c}j=0;Pb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>=1){while(1){b=v[f+404>>2];if(kc(f,16)){ec(f,20);break c}g=b+B(j,40)|0;b=ce(f,B(v[f+4>>2],3));v[g+4>>2]=b;if(!b){ec(f,3);break c}b=g;if(kc(f,1)){e=kc(f,4)+1|0}else{e=1}t[b+8|0]=e;Z:{if(kc(f,1)){b=kc(f,8)+1|0;u[g>>1]=b;_:{e=v[f+4>>2];b=b&65535;if((e|0)>=(b|0)){k=0;if(b){break _}break Z}ec(f,20);break c}while(1){e=kc(f,sm(e-1|0));b=B(k,3);t[b+v[g+4>>2]|0]=e;e=kc(f,sm(v[f+4>>2]-1|0));t[(b+v[g+4>>2]|0)+1|0]=e;e=v[f+4>>2];b=b+v[g+4>>2]|0;h=w[b|0];if((e|0)<=(h|0)){ec(f,20);break c}b=w[b+1|0];if((b|0)>=(e|0)){ec(f,20);break c}if((b|0)!=(h|0)){k=k+1|0;if(k>>>0>=x[g>>1]){break Z}continue}break}ec(f,20);break c}u[g>>1]=0}if(kc(f,2)){ec(f,20);break c}h=v[f+4>>2];$:{aa:{b=w[g+8|0];if(b>>>0<=1){e=0;if((h|0)>0){while(1){t[(v[g+4>>2]+B(e,3)|0)+2|0]=0;e=e+1|0;if((e|0)<v[f+4>>2]){continue}break}b=w[g+8|0]}if(!(b&255)){break $}break aa}e=0;if((h|0)<=0){break aa}while(1){ba:{b=kc(f,4);h=B(e,3);t[(h+v[g+4>>2]|0)+2|0]=b;if(w[(h+v[g+4>>2]|0)+2|0]>=w[g+8|0]){break ba}e=e+1|0;if((e|0)<v[f+4>>2]){continue}break aa}break}ec(f,20);break c}b=0;while(1){kc(f,8);h=b+g|0;e=h;P=e,Q=kc(f,8),t[P+9|0]=Q;h=kc(f,8);t[e+24|0]=h;if(v[f+128>>2]<=w[e+9|0]){ec(f,20);break c}if(v[f+264>>2]>(h&255)){b=b+1|0;if(b>>>0>=w[g+8|0]){break $}continue}break}ec(f,20);break c}j=j+1|0;if((j|0)<v[f+400>>2]){continue}break}}b=kc(f,6)+1|0;v[f+408>>2]=b;e=0;ca:{if((b|0)<=0){break ca}while(1){b=B(e,6)+f|0;P=b,Q=kc(f,1),t[P+412|0]=Q;P=b,Q=kc(f,16),u[P+414>>1]=Q;P=b,Q=kc(f,16),u[P+416>>1]=Q;g=kc(f,8);t[b+413|0]=g;if(x[b+414>>1]){ec(f,20);break c}if(x[b+416>>1]){ec(f,20);break c}if(v[f+400>>2]>(g&255)){e=e+1|0;if((e|0)>=v[f+408>>2]){break ca}continue}break}ec(f,20);break c}qJ(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>=1){while(1){e=(b<<2)+f|0;P=e,Q=ce(f,v[f+116>>2]<<2),v[P+800>>2]=Q;P=e,Q=ce(f,v[f+116>>2]<<1&2147483646),v[P+928>>2]=Q;g=ce(f,q);v[e+996>>2]=g;h=v[e+800>>2];if(!(g?!(!h|!v[e+928>>2]):0)){ec(f,3);break c}Pb(h,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!pJ(f,0,v[f+112>>2])){break a}if(!pJ(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];h=v[f+116>>2];v[f+108>>2]=h;g=(h|0)/2|0;q=f;l=h<<1&2147483646;r=l;p=v[f+264>>2];e=4;da:{if((p|0)<1){break da}i=v[f+396>>2];h=0;k=0;while(1){j=i+B(k,24)|0;o=v[j+4>>2];e=g>>>0>o>>>0?o:g;o=v[j>>2];j=(e-(g>>>0>o>>>0?o:g)>>>0)/y[j+8>>2]|0;h=(h|0)<(j|0)?j:h;k=k+1|0;if((p|0)!=(k|0)){continue}break}e=(h<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<l>>>0?r:e;v[q+12>>2]=e;ea:{fa:{if(!v[f+80>>2]){break fa}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break ea}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break fa}ec(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}ha(71140,69696,4182,71196);L()}ec(f,3)}b=0}gb=n+1024|0;ga:{ha:{if(!b){v[d>>2]=v[s+104>>2]?1:v[s+108>>2];break ha}b=ce(s+8|0,1512);if(b){P=c,Q=v[hc(b,s+8|0,1512)+32>>2]-a|0,v[P>>2]=Q;v[d>>2]=0;break ga}vJ(s+8|0)}b=0}gb=s+1520|0;return b|0}function zpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=gb-336|0;gb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{if(!dh(b,d+328|0)){break Q}if(!HY(d+328|0)){break Q}if(!c){r=1;break Q}s=Ni(d+304|0,b);v[23048]=0;S(453,d+288|0,s|0);b=v[23048];v[23048]=0;R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((b|0)!=1){v[23048]=0;T(454,d+144|0,d+288|0,1229866575);b=v[23048];v[23048]=0;if((b|0)==1){break ca}v[23048]=0;r=Q(455,d+144|0,d+272|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break ea}yb(d+144|0);if(!r){break R}v[23048]=0;S(428,a|0,524288);b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;sg(a);b=v[23048];v[23048]=0;if((b|0)!=1){break da}break c}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(d+144|0);break b}v[a+480208>>2]=12;G=a,H=Gd(Ib(w[d+280|0]|w[d+281|0]<<8),1,127),u[G+480188>>1]=H;G=d,H=Ib(w[d+272|0]|w[d+273|0]<<8),u[G+144>>1]=H;v[23048]=0;u[d+248>>1]=255;b=Vc(d+144|0,d+248|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+272|2;G=d,H=Ib(w[b|0]|w[b+1|0]<<8),u[G+144>>1]=H;v[23048]=0;u[d+248>>1]=3999;b=Vc(d+144|0,d+248|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}u[a+480190>>1]=x[b>>1];v[23048]=0;b=a+1074308|0;W(458,b|0,6,1)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}v[23048]=0;Q(459,b|0,21)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}v[23048]=0;Q(459,b|0,13)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;b=Q(2,d+144|0,16929)|0;e=v[23048];v[23048]=0;if((e|0)==1){break f}Eb(a+1300344|0,b);vb(b);v[23048]=0;b=Q(2,d+144|0,16945)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}Eb(a+1300356|0,b);vb(b);v[23048]=0;S(460,d+248|0,16949);b=v[23048];v[23048]=0;if((b|0)==1){break h}v[23048]=0;S(461,d+224|0,d+328|4);b=v[23048];v[23048]=0;if((b|0)==1){break j}v[23048]=0;S(461,d+200|0,d+328|5);b=v[23048];v[23048]=0;if((b|0)==1){break l}v[23048]=0;Y(209,d+144|0,d+248|0,d+224|0,d+200|0);b=v[23048];v[23048]=0;if((b|0)==1){break m}Eb(a+1300368|0,d+144|0);vb(d+144|0);vb(d+200|0);vb(d+224|0);Hb(d+248|0);v[a+1300404>>2]=2;v[23048]=0;T(454,d+248|0,d+288|0,1312902469);b=v[23048];v[23048]=0;if((b|0)==1){break n}v[23048]=0;b=U(247,d+248|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break p}v[23048]=0;f=a+1300308|0;W(462,d+248|0,f|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break p}b=0;v[23048]=0;T(454,d+224|0,d+288|0,1397706311);e=v[23048];v[23048]=0;if((e|0)==1){break q}e=a+484360|0;fn(Qb(e));fa:{g=d+272|4;g=Ib(w[g|0]|w[g+1|0]<<8);ga:{if(!g){break ga}while(1){v[23048]=0;i=Q(250,d+224|0,46)|0;h=v[23048];v[23048]=0;ha:{if((h|0)!=1){if(!i){break ga}v[23048]=0;S(463,d+224|0,d+144|0);i=v[23048];v[23048]=0;if((i|0)!=1){if(!hd(f)){break ha}v[23048]=0;Q(464,f|0,d+144|0)|0;i=v[23048];v[23048]=0;if((i|0)!=1){break ha}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}v[23048]=0;i=U(465,d+224|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break fa}if(!cd(Qb(e))){v[23048]=0;h=U(466,e|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break fa}if((h|0)==255){break ga}}h=Qb(e);v[23048]=0;T(6,d+200|0,2,d+144|0);k=v[23048];v[23048]=0;if((k|0)==1){break s}v[23048]=0;S(467,h|0,d+200|0);h=v[23048];v[23048]=0;if((h|0)==1){break t}vb(d+200|0);h=Qb(e);v[23048]=0;T(468,h|0,d+224|0,i|0);i=v[23048];v[23048]=0;if((i|0)==1){break fa}b=b+1|0;if(g>>>0>(b&65535)>>>0){continue}break}}v[23048]=0;Fi(e,0);b=v[23048];v[23048]=0;if((b|0)==1){break u}v[23048]=0;T(454,d+200|0,d+288|0,1229869908);b=v[23048];v[23048]=0;if((b|0)==1){break v}v[23048]=0;b=U(470,d+200|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}ia:{if(!b){break ia}if(x[a+480192>>1]){b=1;while(1){v[23048]=0;S(471,d+200|0,d+144|0);e=v[23048];v[23048]=0;ja:{ka:{la:{if((e|0)!=1){e=Ib(w[d+174|0]|w[d+175|0]<<8);v[23048]=0;e=W(436,a|0,b&65535,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break la}if(!e){break ja}if(Ib(w[d+174|0]|w[d+175|0]<<8)>>>0>3999){break ja}v[23048]=0;Mv(d+8|0,2,d+144|0);f=v[23048];v[23048]=0;if((f|0)!=1){v[23048]=0;S(398,d+56|0,d+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){break ka}}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}v[23048]=0;Q(354,e+492|0,d+56|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break x}vb(d+56|0);v[23048]=0;Mv(d+8|0,2,d+144|0);f=v[23048];v[23048]=0;if((f|0)==1){break y}v[23048]=0;S(398,d+56|0,d+8|0);f=v[23048];v[23048]=0;if((f|0)==1){break y}f=Ib(w[d+174|0]|w[d+175|0]<<8);v[23048]=0;Q(354,((f<<5)+a|0)+946300|0,d+56|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break z}vb(d+56|0);v[e>>2]=0;G=e,H=Ib(w[d+190|0]|w[d+191|0]<<8)+128&65535,v[G+8>>2]=H;tc(e+8|0,256);t[e+15|0]=w[e+15|0]|1;e=Ib(w[d+174|0]|w[d+175|0]<<8);v[23048]=0;e=B(e,104)+a|0;S(372,e+484380|0,0);f=v[23048];v[23048]=0;if((f|0)==1){break A}G=d,H=Ib(w[d+176|0]|w[d+177|0]<<8),u[G+56>>1]=H;v[23048]=0;u[d+8>>1]=64;f=Vc(d+56|0,d+8|0);g=v[23048];v[23048]=0;if((g|0)==1){break B}u[e+484410>>1]=x[f>>1]<<2;G=e+484404|0,H=Wb(w[d+178|0]|w[d+179|0]<<8|(w[d+180|0]<<16|w[d+181|0]<<24)),v[G>>2]=H;if(!Wb(w[d+186|0]|w[d+187|0]<<8|(w[d+188|0]<<16|w[d+189|0]<<24))){break ja}if(!(Ib(w[d+192|0]|w[d+193|0]<<8)&3)){break ja}f=Wb(w[d+182|0]|w[d+183|0]<<8|(w[d+184|0]<<16|w[d+185|0]<<24));v[e+484384>>2]=f;G=e+484388|0,H=Wb(w[d+186|0]|w[d+187|0]<<8|(w[d+188|0]<<16|w[d+189|0]<<24))+f|0,v[G>>2]=H;e=e+484414|0;u[e>>1]=x[e>>1]|2;if(!(Ib(w[d+192|0]|w[d+193|0]<<8)&2)){break ja}u[e>>1]=x[e>>1]|4}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}v[23048]=0;T(454,d+120|0,d+288|0,1447382614);b=v[23048];v[23048]=0;if((b|0)==1){break E}v[23048]=0;Y(473,d+120|0,0,a|0,0);b=v[23048];v[23048]=0;if((b|0)==1){break C}yb(d+120|0);v[23048]=0;T(454,d+96|0,d+288|0,1346719318);b=v[23048];v[23048]=0;if((b|0)==1){break E}v[23048]=0;Y(473,d+96|0,1,a|0,w[d+332|0]>2|0);b=v[23048];v[23048]=0;if((b|0)==1){break D}yb(d+96|0);if(!x[a+480192>>1]){break ia}b=1;while(1){e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}yb(d+200|0);v[23048]=0;T(454,d+144|0,d+288|0,1346458708);b=v[23048];v[23048]=0;if((b|0)==1){break F}v[23048]=0;b=U(328,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break H}if(!(c&1)|b^1){break ba}v[23048]=0;T(454,d+200|0,d+288|0,1347305805);b=v[23048];v[23048]=0;if((b|0)==1){break I}v[23048]=0;Q(370,d+200|0,1)|0;b=v[23048];v[23048]=0;if((b|0)==1){break K}e=0;k=d+272|6;b=Ib(w[k|0]|w[k+1|0]<<8);v[23048]=0;m=a+484344|0;S(385,m|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break K}f=dd(d+80|0);if(!Ib(w[k|0]|w[k+1|0]<<8)){break aa}z=d+8|5;A=d+8|3;C=d+8|4;D=d+8|2;E=d+8|1;b=0;while(1){v[23048]=0;y=U(465,d+144|0)|0;g=v[23048];v[23048]=0;ma:{na:{oa:{pa:{qa:{if((g|0)!=1){v[23048]=0;g=U(474,d+144|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break qa}v[23048]=0;T(341,d+56|0,d+144|0,g|0);g=v[23048];v[23048]=0;if((g|0)==1){break pa}v[23048]=0;g=W(386,m|0,e&65535,y|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break oa}if(!g){break ma}o=Jb(d+40|0);v[23048]=0;T(475,d+200|0,o|0,-1);g=v[23048];v[23048]=0;if((g|0)!=1){g=Yb(m,e);v[23048]=0;Q(476,g|0,o|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){break na}}break N}b=P()|0;O()|0;break L}b=P()|0;O()|0;break L}b=P()|0;O()|0;break L}b=P()|0;O()|0;break M}g=Yb(m,e);v[23048]=0;p=Of(g,0);g=v[23048];v[23048]=0;if((g|0)==1){break N}Rd(f);n=0;ra:{while(1){v[23048]=0;g=Q(250,d+56|0,1)|0;i=v[23048];v[23048]=0;sa:{ta:{ua:{if((i|0)!=1){if(!g){break ra}v[23048]=0;h=U(373,d+56|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break N}if(h){break ta}G=d,H=Rb(f),v[G+32>>2]=H;G=d,H=Ub(f),v[G+24>>2]=H;if(Fb(d+32|0,d+24|0)){break ua}break sa}break N}while(1){va:{g=v[d+32>>2];i=Yb(m,e);h=w[g+1|0];g=w[g|0];v[23048]=0;g=De(d+8|0,g,h);h=v[23048];v[23048]=0;if((h|0)==1){break va}g=Ve(g,n);v[23048]=0;Q(479,i|0,g|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break va}jD(d+32|0);if(Fb(d+32|0,d+24|0)){continue}break sa}break}break N}$h(d+8|0);q=x[a+480188>>1];v[23048]=0;g=U(373,d+56|0)|0;i=v[23048];v[23048]=0;wa:{if((i|0)==1){break wa}i=B(h-1|0,6)+p|0;xa:{if(!(g&1)){break xa}v[23048]=0;j=U(373,d+56|0)|0;l=v[23048];v[23048]=0;ya:{if((l|0)!=1){if(!j){break xa}if((j|0)!=31){break ya}t[(h>>>0>q>>>0?d+8|0:i)|0]=255;break xa}break N}if(j>>>0>253){break xa}t[(h>>>0>q>>>0?d+8|0:i)|0]=(B(j>>>4|0,12)+(j&15)|0)+13}if(g&2){v[23048]=0;j=U(373,d+56|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break wa}t[(h>>>0>q>>>0?E:i+1|0)|0]=j}if(!(g&60)){continue}t[d+7|0]=0;t[d+6|0]=0;t[d+5|0]=0;t[d+4|0]=0;if(g&4){v[23048]=0;j=U(373,d+56|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break N}t[d+6|0]=j}if(g&8){v[23048]=0;j=U(373,d+56|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break N}t[d+4|0]=j}if(g&16){v[23048]=0;j=U(373,d+56|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break N}t[d+7|0]=j}if(g&32){v[23048]=0;g=U(373,d+56|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break N}t[d+5|0]=g}FY(d+7|0,d+5|0);FY(d+6|0,d+4|0);g=w[d+6|0];if(!(w[d+7|0]==13|g?(g|0)!=13:0)){th(d+7|0,d+6|0);th(d+5|0,d+4|0)}v[23048]=0;oo(d+24|0,d+7|0,d+5|0,d+6|0,d+4|0);g=v[23048];v[23048]=0;za:{if((g|0)==1){break za}v[23048]=0;g=ez(w[d+24|0],w[d+25|0]);j=v[23048];v[23048]=0;if((j|0)==1){break za}Aa:{if(!g){break Aa}G=d,H=Rb(f),v[G+32>>2]=H;Sd(d,d+32|0);v[23048]=0;T(482,f|0,v[d>>2],d+24|0);g=v[23048];v[23048]=0;if((g|0)!=1){break Aa}break N}g=h>>>0>q>>>0;t[(g?D:i+2|0)|0]=w[d+7|0];t[(g?C:i+4|0)|0]=w[d+5|0];h=w[d+6|0];t[(g?A:i+3|0)|0]=h;t[(g?z:i+5|0)|0]=w[d+4|0];if((h|0)==43){F=1;continue}if((h|0)!=31){continue}b=1;continue}break N}break N}Rd(f);n=n+1|0;if(y>>>0<=n>>>0){break ra}g=Yb(m,e);v[23048]=0;p=Of(g,n);g=v[23048];v[23048]=0;if((g|0)!=1){continue}break}break N}vb(o)}yb(d+56|0);e=e+1|0;if(Ib(w[k|0]|w[k+1|0]<<8)>>>0>e>>>0){continue}break}break $}b=P()|0;O()|0;break r}b=P()|0;O()|0;break b}f=0;if(c&4){break _}break S}b=0}Hv(f);yb(d+200|0);if(!(c&4)){break Z}f=0;p=(b|0)!=0;if(!F){break _}e=x[a+480188>>1];if(!e){f=1;break _}b=0;while(1){f=1;g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;if((e|0)!=(b|0)){continue}break}}v[d+56>>2]=-1778364416;v[d+60>>2]=-16756736;v[23048]=0;T(454,d+200|0,d+288|0,1146310725);b=v[23048];v[23048]=0;Ba:{Ca:{Da:{if((b|0)!=1){v[23048]=0;b=U(470,d+200|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Ba}if(!b){break Ca}v[23048]=0;g=U(465,d+200|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break X}if(g){break Da}e=f;break Y}b=P()|0;O()|0;break G}b=0;e=f;while(1){v[23048]=0;i=U(373,d+200|0)|0;h=v[23048];v[23048]=0;Ea:{Fa:{if((h|0)!=1){if(x[a+480188>>1]<=b>>>0){break Ea}if(!f){break Fa}h=((b<<5)+a|0)+480280|0;v[h>>2]=v[h>>2]&-67108865|((i|0)!=0)<<26;break Ea}break X}if(i){break Ea}e=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((g|0)!=(b|0)){continue}break}break Y}yb(d+200|0);if(!f){break U}break V}break X}if(!b){break S}break T}v[23048]=0;Q(483,d+200|0,d+56|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break W}}b=P()|0;O()|0;yb(d+200|0);break G}yb(d+200|0);if(!(e&1)){break U}}v[23048]=0;_(484,a+906300|0);b=v[23048];v[23048]=0;Ga:{Ha:{Ia:{Ja:{Ka:{La:{if((b|0)==1){break La}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[23048]=0;v[d+200>>2]=0;b=a+906332|0;iD(b,b+16|0,d+200|0);b=v[23048];v[23048]=0;if((b|0)==1){break Ka}v[23048]=0;e=Q(91,d+200|0,16971)|0;b=v[23048];v[23048]=0;if((b|0)==1){break Ja}v[23048]=0;Jv(a+906348|0,e);b=v[23048];v[23048]=0;if((b|0)==1){break Ia}vb(e);v[23048]=0;e=Q(91,d+200|0,16976)|0;b=v[23048];v[23048]=0;if((b|0)==1){break Ha}v[23048]=0;Iv(a+906380|0,e);b=v[23048];v[23048]=0;if((b|0)==1){break Ga}vb(e);v[23048]=0;b=a+906304|0;S(488,b|0,8);e=v[23048];v[23048]=0;if((e|0)==1){break La}DY(d+200|0,w[d+57|0],w[d+59|0],w[d+61|0],w[d+63|0]);e=v[d+204>>2];b=v[b>>2];f=v[d+200>>2];t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24;break U}b=P()|0;O()|0;break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;vb(e);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;vb(e);break G}if(!p){break S}}b=0;Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{while(1){hb:{v[d+40>>2]=B(b,127)>>>5;v[23048]=0;S(489,d+56|0,16997);e=v[23048];v[23048]=0;if((e|0)==1){break hb}v[23048]=0;S(490,d+8|0,d+40|0);e=v[23048];v[23048]=0;if((e|0)==1){break gb}v[23048]=0;T(491,d+200|0,d+56|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break fb}v[23048]=0;e=(b<<5)+a|0;Ye(d+80|0,e+902204|0);f=v[23048];v[23048]=0;if((f|0)==1){break eb}v[23048]=0;Q(450,d+80|0,d+200|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break eb}vb(d+200|0);vb(d+8|0);Hb(d+56|0);v[23048]=0;S(489,d+56|0,17006);f=v[23048];v[23048]=0;if((f|0)==1){break bb}v[23048]=0;S(490,d+8|0,d+40|0);f=v[23048];v[23048]=0;if((f|0)==1){break ab}v[23048]=0;T(491,d+200|0,d+56|0,d+8|0);f=v[23048];v[23048]=0;if((f|0)==1){break $a}v[23048]=0;Ye(d+80|0,e+903228|0);f=v[23048];v[23048]=0;if((f|0)==1){break _a}v[23048]=0;Q(450,d+80|0,d+200|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break _a}vb(d+200|0);vb(d+8|0);Hb(d+56|0);v[23048]=0;S(489,d+56|0,17015);f=v[23048];v[23048]=0;if((f|0)==1){break Xa}v[23048]=0;S(490,d+8|0,d+40|0);f=v[23048];v[23048]=0;if((f|0)==1){break Wa}v[23048]=0;T(491,d+200|0,d+56|0,d+8|0);f=v[23048];v[23048]=0;if((f|0)==1){break Va}v[23048]=0;Ye(d+80|0,e+904252|0);f=v[23048];v[23048]=0;if((f|0)==1){break Ua}v[23048]=0;Q(450,d+80|0,d+200|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Ua}vb(d+200|0);vb(d+8|0);Hb(d+56|0);v[23048]=0;S(489,d+56|0,17024);f=v[23048];v[23048]=0;if((f|0)==1){break Ra}v[23048]=0;S(490,d+8|0,d+40|0);f=v[23048];v[23048]=0;if((f|0)==1){break Qa}v[23048]=0;T(491,d+200|0,d+56|0,d+8|0);f=v[23048];v[23048]=0;if((f|0)==1){break Pa}v[23048]=0;Ye(d+80|0,e+905276|0);e=v[23048];v[23048]=0;if((e|0)==1){break Oa}v[23048]=0;Q(450,d+80|0,d+200|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Oa}vb(d+200|0);vb(d+8|0);Hb(d+56|0);b=b+1|0;if((b|0)!=32){continue}break S}break}b=P()|0;O()|0;break G}b=P()|0;O()|0;break cb}b=P()|0;O()|0;break db}b=P()|0;O()|0;vb(d+200|0)}vb(d+8|0)}Hb(d+56|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;break Ya}b=P()|0;O()|0;break Za}b=P()|0;O()|0;vb(d+200|0)}vb(d+8|0)}Hb(d+56|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;break Sa}b=P()|0;O()|0;break Ta}b=P()|0;O()|0;vb(d+200|0)}vb(d+8|0)}Hb(d+56|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;break Ma}b=P()|0;O()|0;break Na}b=P()|0;O()|0;vb(d+200|0)}vb(d+8|0)}Hb(d+56|0);break G}v[23048]=0;T(454,d+200|0,d+288|0,1397575756);b=v[23048];v[23048]=0;if((b|0)==1){break O}v[23048]=0;b=U(328,d+200|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break P}f=1;if(!(!x[a+480190>>1]|(!(c&2)|b^1))){b=1;while(1){v[23048]=0;c=U(474,d+200|0)|0;e=v[23048];v[23048]=0;ib:{if((e|0)!=1){v[23048]=0;e=U(474,d+200|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break P}if(!(c&7)){break ib}f=(B(f,104)+a|0)+484380|0;v[f>>2]=e;c=Sc(d+56|0,c&4?32:c&2?16:8,1,1,0);v[23048]=0;W(384,c|0,f|0,d+200|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break ib}break P}break P}b=b+1|0;f=b&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}yb(d+200|0);yb(d+144|0);yb(d+224|0);yb(d+248|0)}Cd(d+288|0);yb(s)}gb=d+336|0;return r|0}b=P()|0;O()|0;yb(d+200|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;vb(o)}yb(d+56|0)}Hv(f);break J}b=P()|0;O()|0}yb(d+200|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0}yb(d+144|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break w}b=P()|0;O()|0;yb(d+96|0);break w}b=P()|0;O()|0;yb(d+120|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(d+56|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(d+56|0)}yb(d+200|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;vb(d+200|0);break r}b=P()|0;O()|0}yb(d+224|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}yb(d+248|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+200|0);break k}b=P()|0;O()|0}vb(d+224|0);break i}b=P()|0;O()|0}Hb(d+248|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}Cd(d+288|0)}yb(s);R(b|0);L()}function Uka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=gb-352|0;gb=d;yc(b);a:{if(!Dr(b,d+336|0)){break a}if(!HU(d+336|0)){break a}q=Ni(d+312|0,b);o=_g(d+296|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(!c){v[23048]=0;S(883,d|0,q|0);b=v[23048];v[23048]=0;if((b|0)==1){break r}break t}v[23048]=0;S(884,d|0,q|0);b=v[23048];v[23048]=0;if((b|0)==1){break s}}GU(o,d);Cd(d);v[23048]=0;T(885,d|0,o|0,1413891155);b=v[23048];v[23048]=0;u:{v:{if((b|0)!=1){v[23048]=0;e=Q(886,d|0,25707)|0;b=v[23048];v[23048]=0;if((b|0)==1){break v}yb(d);if(!c){break b}if(!(e^1)){break u}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;yb(d);break c}v[23048]=0;S(428,a|0,4194304);b=v[23048];v[23048]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[23048]=0;T(885,d+272|0,o|0,1280592212);b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;b=U(247,d+272|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break g}v[23048]=0;W(658,d+272|0,a+1300308|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}l=a+484360|0;fn(Qb(l));k=dd(d+256|0);t[d+255|0]=0;v[23048]=0;T(887,d+240|0,o|0,1196314451);b=v[23048];v[23048]=0;if((b|0)==1){break i}s=d,y=Rb(d+240|0),v[s+232>>2]=y;s=d,y=Ub(d+240|0),v[s+224>>2]=y;w:{x:{y:{z:{A:{B:{if(!Fb(d+232|0,d+224|0)){break B}n=d+12|0;j=d+24|0;m=d+44|0;while(1){f=Ni(d+200|0,v[d+232>>2]);v[23048]=0;e=Q(888,d+200|0,d+184|0)|0;b=v[23048];v[23048]=0;C:{D:{E:{F:{G:{H:{if((b|0)!=1){b=1;if(!(e&w[d+193|0]==1)){break C}s=a,y=Gd(w[d+194|0],x[a+480188>>1],127),u[s+480188>>1]=y;v[23048]=0;i=U(889,d|0)|0;b=v[23048];v[23048]=0;I:{J:{K:{L:{if((b|0)!=1){uf(d+168|0,d+184|0,9,1);v[23048]=0;S(398,d+120|0,d+168|0);b=v[23048];v[23048]=0;if((b|0)==1){break L}_c(d+160|0,m,10);v[23048]=0;Q(450,d+160|0,d+120|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break K}vb(d+120|0);if(cd(Qb(l))){break I}v[23048]=0;b=U(466,l|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break D}e=P()|0;O()|0;break k}e=P()|0;O()|0;break l}e=P()|0;O()|0;vb(d+120|0);break l}e=P()|0;O()|0;break l}b=Qb(l);v[23048]=0;T(6,d+120|0,5,m|0);e=v[23048];v[23048]=0;M:{N:{O:{if((e|0)!=1){v[23048]=0;S(467,b|0,d+120|0);b=v[23048];v[23048]=0;if((b|0)==1){break O}vb(d+120|0);v[23048]=0;S(884,d+168|0,f|0);b=v[23048];v[23048]=0;if((b|0)==1){break N}s=d,y=Rb(d+168|0),v[s+152>>2]=y;s=d,y=Ub(d+168|0),v[s+144>>2]=y;if(Fb(d+152|0,d+144|0)){break M}break G}e=P()|0;O()|0;break l}e=P()|0;O()|0;vb(d+120|0);break l}e=P()|0;O()|0;break l}P:{Q:{while(1){R:{b=v[d+152>>2];h=Me(d+120|0,wb(b));f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+160>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+164>>2]=f;b=1;S:{f=w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24);if((f|0)!=1212960847){if((f|0)!=1312903248){break S}e=0;if(!x[a+480188>>1]){break S}T:{while(1){v[23048]=0;f=Q(250,h|0,2)|0;g=v[23048];v[23048]=0;if((g|0)==1){break T}if(!f){break S}v[23048]=0;S(452,d+96|0,h|0);f=v[23048];v[23048]=0;U:{V:{W:{X:{if((f|0)!=1){f=rd(d+96|0);switch(w[d+96|0]){case 4:break V;case 2:break W;case 0:break X;default:break U}}break H}f=w[f|0];s=oc(d,e),y=f^128,t[s|0]=y;ve(d+104|0,j,e);Ef(d+104|0,0);break U}s=oc(d,e),y=128,t[s|0]=y;ve(d+104|0,j,e);Ef(d+104|0,1);break U}s=oc(d,e),y=128,t[s|0]=y;ve(d+104|0,j,e);Ef(d+104|0,0)}e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break S}break H}if(Qm(d+160|0)>>>0<9){break S}e=0;v[23048]=0;Q(370,h|0,2)|0;b=v[23048];v[23048]=0;g=65535;if((b|0)==1){break R}while(1){v[23048]=0;b=Q(250,h|0,1)|0;f=v[23048];v[23048]=0;Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((f|0)!=1){f=1;if(!b){break $}v[23048]=0;p=U(373,h|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break H}b=0;switch(p|0){case 14:break Z;case 13:break _;case 0:break $;case 12:break aa;case 8:break ba;case 7:break ca;case 4:break da;case 1:break ea;default:break S}}break H}if(x[d+36>>1]==65535){s=d,y=Ol(Qb(l)),u[s+36>>1]=y}b=Ol(Qb(l));v[23048]=0;u[d+38>>1]=b;b=Q(890,h|0,d+255|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break H}fa:{ga:{switch(b-254|0){case 1:v[23048]=0;b=65535;f=v[23048];v[23048]=0;if((f|0)!=1){break fa}break H;case 0:break ga;default:break fa}}v[23048]=0;b=65534;f=v[23048];v[23048]=0;if((f|0)==1){break H}}f=Qb(l);v[23048]=0;S(749,f|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break H}g=(g&65535)==65535?e:g;break Y}v[23048]=0;b=U(340,h|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break H}if(b>>>0>=(g&65535)>>>0){u[d+40>>1]=b-g}ff(Qb(l),x[d+40>>1]);break Y}v[23048]=0;b=U(373,h|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break H}t[d+43|0]=b;break Y}v[23048]=0;b=U(373,h|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break H}t[d+42|0]=b;break Y}v[23048]=0;b=Q(849,h|0,d+104|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break H}f=0;if(!(b&!w[d+104|0])|w[d+105|0]!=255|(w[d+106|0]|w[d+107|0])){break $}if(w[d+108|0]!=1){break $}if(!w[d+109|0]){break Y}}b=f;break S}v[23048]=0;S(760,d+112|0,h|0);b=v[23048];v[23048]=0;ha:{ia:{ja:{ka:{if((b|0)!=1){f=rd(d+112|0);p=Df(d+112|0);b=d+112|0;if(w[b|0]>=qc(d)>>>0){break Y}switch(w[p|0]){case 4:break ia;case 2:break ja;case 0:break ka;default:break ha}}break H}f=w[f|0];s=oc(d,w[b|0]),y=f^128,t[s|0]=y;ve(d+104|0,j,w[b|0]);Ef(d+104|0,0);break ha}s=oc(d,w[b|0]),y=128,t[s|0]=y;ve(d+104|0,j,w[b|0]);Ef(d+104|0,1);break ha}s=oc(d,w[b|0]),y=128,t[s|0]=y;ve(d+104|0,j,w[b|0]);Ef(d+104|0,0)}la:{if(r){break la}r=0;if(!hr(k)){break Y}if(w[oc(FU(k),w[b|0])|0]!=w[oc(d,w[b|0])|0]){break la}ve(d+104|0,FU(k)+24|0,w[b|0]);f=Cb(d+104|0);ve(d+96|0,j,w[b|0]);if((Cb(d+96|0)|0)==(f|0)){break Y}}r=1;break Y}v[23048]=0;S(452,d+104|0,h|0);b=v[23048];v[23048]=0;if((b|0)==1){break P}b=rd(d+104|0);f=d+104|0;p=w[f|0];if(qc(n)>>>0<=p>>>0){break Y}b=w[b|0];s=oc(n,w[f|0]),y=(b>>>2|0)+1|0,t[s|0]=y}e=e+1|0;continue}}yb(h);if(!b){break Q}np(d+152|0);if(Fb(d+152|0,d+144|0)){continue}break G}break}break H}b=1;break E}break H}e=P()|0;O()|0;break k}e=P()|0;O()|0;yb(h);break F}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break E}b=Qb(l);v[23048]=0;_(893,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){b=0;v[23048]=0;S(894,k|0,i|0);f=v[23048];v[23048]=0;if((f|0)!=1){break E}}e=P()|0;O()|0}Cd(d+168|0);break l}Cd(d+168|0)}Yu(i)}yb(d+200|0);if(!b){sh(d+232|0);if(Fb(d+232|0,d+224|0)){continue}break B}break}e=0;if((b|0)!=2){break A}}e=0;v[23048]=0;Fi(l,0);b=v[23048];v[23048]=0;if((b|0)==1){break q}if(cd(k)){break A}if(c&2){v[23048]=0;T(887,d+200|0,o|0,1347244868);b=v[23048];v[23048]=0;if((b|0)==1){break w}s=d,y=Rb(d+200|0),v[s+184>>2]=y;s=d,y=Ub(d+200|0),v[s+160>>2]=y;e=w[d+255|0];if(Fb(d+184|0,d+160|0)){f=a+480190|0;h=d+13|0;j=d+17|0;while(1){b=v[d+184>>2];ma:{na:{oa:{pa:{qa:{if(!e){v[23048]=0;g=Q(895,b|0,d|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break qa}if(!g){break ma}g=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=g+1;if(g>>>0>3998){break oa}v[23048]=0;g=Le(f,d+104|0);i=v[23048];v[23048]=0;if((i|0)==1){break qa}u[a+480190>>1]=x[g>>1];v[23048]=0;S(896,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);g=v[23048];v[23048]=0;if((g|0)==1){break qa}EU(d+168|0,h);v[23048]=0;S(398,d+120|0,d+168|0);g=v[23048];v[23048]=0;ra:{if((g|0)!=1){v[23048]=0;Q(354,((x[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break ra}vb(d+120|0);break oa}e=P()|0;O()|0;break na}e=P()|0;O()|0;vb(d+120|0);break na}v[23048]=0;g=Q(897,b|0,d|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break pa}if(!g){break ma}g=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=g+1;if(g>>>0>3998){break oa}v[23048]=0;g=Le(f,d+104|0);i=v[23048];v[23048]=0;if((i|0)==1){break pa}u[a+480190>>1]=x[g>>1];v[23048]=0;S(898,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);g=v[23048];v[23048]=0;if((g|0)==1){break pa}EU(d+168|0,j);v[23048]=0;S(398,d+120|0,d+168|0);g=v[23048];v[23048]=0;sa:{if((g|0)!=1){v[23048]=0;Q(354,((x[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break sa}vb(d+120|0);break oa}e=P()|0;O()|0;break na}e=P()|0;O()|0;vb(d+120|0);break na}e=P()|0;O()|0;break na}e=P()|0;O()|0;break na}if((x[d+104>>1]-1&65535)>>>0>3998){break ma}g=Sc(d,8,1,0,2);v[23048]=0;W(384,g|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break ma}e=P()|0;O()|0}kd(d+200|0);break j}sh(d+184|0);if(Fb(d+184|0,d+160|0)){continue}break}}kd(d+200|0)}b=0;s=a,y=w[Pm(k,0)+43|0],v[s+480196>>2]=y;s=a,y=B(w[Pm(k,0)+42|0],1e4),v[s+480204>>2]=y;ff(Qb(l),x[Pm(k,0)+40>>1]);if(x[a+480188>>1]){while(1){v[23048]=0;f=(b<<5)+a|0;e=f+480280|0;We(e);h=v[23048];v[23048]=0;if((h|0)==1){break x}s=f+480286|0,y=w[oc(Pm(k,0)+12|0,b)|0],u[s>>1]=y;s=f+480284|0,y=w[oc(Pm(k,0),b)|0],u[s>>1]=y;ve(d,Pm(k,0)+24|0,b);f=Cb(d);v[e>>2]=v[e>>2]&-257|(f?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}ta:{if(w[d+255|0]){v[23048]=0;Q(2,d|0,25716)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break ta}break m}v[23048]=0;Q(2,d|0,25760)|0;b=v[23048];v[23048]=0;if((b|0)==1){break m}}Eb(a+1300344|0,d);vb(d);v[23048]=0;b=Q(2,d|0,25794)|0;f=v[23048];v[23048]=0;e=1;if((f|0)==1){break y}Eb(a+1300356|0,b);vb(b);v[a+1300404>>2]=5;if(!(c&1)|!x[a+480188>>1]){break A}v[23048]=0;T(887,d+200|0,o|0,1146045008);b=v[23048];v[23048]=0;if((b|0)==1){break n}b=cf(d+200|0);v[23048]=0;j=a+484344|0;S(385,j|0,b&65535);b=v[23048];v[23048]=0;if((b|0)==1){break p}s=d,y=Rb(d+200|0),v[s+120>>2]=y;s=d,y=Ub(d+200|0),v[s+168>>2]=y;if(Fb(d+120|0,d+168|0)){while(1){h=v[d+120>>2];v[23048]=0;b=U(247,h|0)|0;c=v[23048];v[23048]=0;ua:{va:{wa:{if((c|0)==1){break wa}v[23048]=0;c=U(376,h|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break wa}if((b|0)!=(c|0)){break ua}v[23048]=0;b=Q(899,h|0,8)|0;c=v[23048];v[23048]=0;if((c|0)==1){break wa}if(b){break va}break ua}e=P()|0;O()|0;break o}v[23048]=0;n=Q(890,h|0,d+255|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){v[23048]=0;g=U(340,h|0)|0;b=v[23048];v[23048]=0;xa:{if((b|0)==1){break xa}v[23048]=0;b=W(386,j|0,n|0,g|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break xa}i=0;if(!(b&(g|0)!=0)){break ua}while(1){ya:{b=Yb(j,n);v[23048]=0;c=Of(b,i);b=v[23048];v[23048]=0;za:{Aa:{Ba:{if((b|0)!=1){v[23048]=0;b=U(340,h|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Ba}if(b>>>0<3){break za}v[23048]=0;T(341,d|0,h|0,b-2|0);b=v[23048];v[23048]=0;if((b|0)!=1){break Aa}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}while(1){v[23048]=0;b=Q(250,d|0,3)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ya}if(b){v[23048]=0;S(452,d+184|0,d|0);b=v[23048];v[23048]=0;Ca:{Da:{Ea:{Fa:{if((b|0)!=1){e=d+184|0;b=rd(d+184|0);u[d+160>>1]=x[a+480188>>1]-1;b=w[b|0];v[23048]=0;u[d+104>>1]=b;b=Vc(d+160|0,d+104|0);f=v[23048];v[23048]=0;if((f|0)==1){break ya}f=x[b>>1];b=t[e|0];if((b|0)>-1){break Ca}v[23048]=0;b=U(373,d|0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break ya}if(w[d+255|0]){break Ea}if((b|0)!=255){break Fa}b=254;break Da}break ya}if(b>>>0>128){break Da}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Da}b=b>>>0<85?b+36|0:b}t[c+B(f,6)|0]=b;b=w[e|0]}if(b&64){v[23048]=0;b=U(373,d|0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break ya}t[(c+B(f,6)|0)+1|0]=b+1;b=w[e|0]}if(b&32){v[23048]=0;b=U(373,d|0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break ya}t[d+160|0]=b;b=c+B(f,6)|0;t[b+2|0]=1;v[23048]=0;t[d+104|0]=127;m=$b(d+160|0,d+104|0);p=v[23048];v[23048]=0;if((p|0)==1){break ya}t[b+4|0]=w[m|0]+1>>>1;b=w[e|0]}if(!(b&16)){continue}v[23048]=0;S(452,d+160|0,d|0);b=v[23048];v[23048]=0;if((b|0)==1){break ya}b=c+B(f,6)|0;e=w[rd(d+160|0)|0];t[b+5|0]=e;Ga:{switch(w[d+160|0]-1|0){case 0:t[(c+B(f,6)|0)+3|0]=11;if(!w[d+255|0]){t[b+5|0]=e<<3|15;continue}t[b+5|0]=e<<4|15;continue;case 1:t[(c+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=e<<4;continue}t[b+5|0]=e<<3&240;continue;case 2:t[(c+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=e|240;continue}t[b+5|0]=e>>>1|240;continue;case 3:t[(c+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=e&15;continue}if(e>>>0<=1){t[b+5|0]=e|240;continue}t[b+5|0]=e>>>1&15;continue;case 10:t[(c+B(f,6)|0)+3|0]=2;s=b,y=Xu(e,w[d+255|0])|240,t[s+5|0]=y;continue;case 11:t[(c+B(f,6)|0)+3|0]=2;s=b,y=Xu(e,w[d+255|0]),t[s+5|0]=y;continue;case 12:t[(c+B(f,6)|0)+3|0]=3;s=b,y=Xu(e,w[d+255|0])|240,t[s+5|0]=y;continue;case 13:t[(c+B(f,6)|0)+3|0]=3;s=b,y=Xu(e,w[d+255|0]),t[s+5|0]=y;continue;case 14:t[(c+B(f,6)|0)+3|0]=4;if(w[d+255|0]){continue}t[b+5|0]=(e&252)>>>2;continue;case 16:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&1|16;continue;case 15:t[(c+B(f,6)|0)+3|0]=6;t[b+5|0]=e&240;continue;case 17:t[(c+B(f,6)|0)+3|0]=6;t[b+5|0]=(e&240)>>>4;continue;case 18:t[(c+B(f,6)|0)+3|0]=20;continue;case 20:t[(c+B(f,6)|0)+3|0]=5;continue;case 21:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|48;continue;case 22:t[(c+B(f,6)|0)+3|0]=7;t[b+5|0]=e|240;continue;case 23:t[(c+B(f,6)|0)+3|0]=7;continue;case 30:t[(c+B(f,6)|0)+3|0]=8;continue;case 31:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|64;continue;case 40:t[(c+B(f,6)|0)+3|0]=10;v[23048]=0;f=U(373,d|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break ya}t[b+5|0]=f;v[23048]=0;Q(370,d|0,1)|0;b=v[23048];v[23048]=0;if((b|0)!=1){continue}break ya;case 41:t[(c+B(f,6)|0)+3|0]=15;continue;case 42:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|192;continue;case 43:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|208;continue;case 50:t[(c+B(f,6)|0)+3|0]=12;t[b+5|0]=(e&254)>>>1;v[23048]=0;Q(370,d|0,1)|0;b=v[23048];v[23048]=0;if((b|0)!=1){continue}break ya;case 51:t[(c+B(f,6)|0)+3|0]=14;t[b+5|0]=0;continue;case 52:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|176;continue;case 53:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|224;continue;case 60:t[(c+B(f,6)|0)+3|0]=16;continue;case 61:t[(c+B(f,6)|0)+3|0]=17;continue;case 70:t[(c+B(f,6)|0)+3|0]=1;continue;case 71:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|32;continue;case 72:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|128;continue;default:break Ga}}t[(c+B(f,6)|0)+3|0]=0;continue}break}yb(d)}i=i+1|0;if((g|0)!=(i|0)){continue}break ua}break}e=P()|0;O()|0;yb(d);break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}sh(d+120|0);if(Fb(d+120|0,d+168|0)){continue}break}}if(hr(k)>>>0>=2){f=0;while(1){b=Ej(l,f&255);c=Pm(k,f);e=x[sc(b,x[c+36>>1])>>1];v[23048]=0;e=oe(j,e);h=v[23048];v[23048]=0;Ha:{Ia:{if((h|0)!=1){if(!e){break Ha}e=x[c+36>>1];v[23048]=0;e=Q(586,b|0,e|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break Ia}}e=P()|0;O()|0;break o}if(!(!r|!x[a+480188>>1])){g=c+24|0;b=0;while(1){ve(d,g,b);i=Cb(d);h=Yb(j,e);Ja:{if(i){v[23048]=0;i=De(d,20,145);n=v[23048];v[23048]=0;if((n|0)!=1){i=wh(kp(Ve(i,0),b&65535));v[23048]=0;Q(479,h|0,i|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){break Ja}}e=P()|0;O()|0;break o}i=w[oc(c,b)|0];v[23048]=0;i=De(d,9,i);n=v[23048];v[23048]=0;if((n|0)!=1){i=wh(kp(Ve(i,0),b&65535));v[23048]=0;Q(479,h|0,i|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){break Ja}}e=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=Yb(j,e);h=w[c+43|0];v[23048]=0;h=De(d,16,h);g=v[23048];v[23048]=0;if((g|0)==1){break z}h=wh(Ve(h,0));v[23048]=0;Q(479,b|0,h|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break z}b=Yb(j,e);c=w[c+42|0];v[23048]=0;c=De(d,17,c);e=v[23048];v[23048]=0;if((e|0)!=1){c=wh(Ve(c,0));v[23048]=0;Q(479,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break Ha}}e=P()|0;O()|0;break o}f=f+1|0;if(hr(k)>>>0>f>>>0){continue}break}}kd(d+200|0);e=1}kd(d+240|0);BU(k);yb(d+272|0);break b}e=P()|0;O()|0;break o}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break j}e=P()|0;O()|0}kd(d+200|0);break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}Yu(i)}yb(d+200|0)}kd(d+240|0);break h}e=P()|0;O()|0}BU(k);break f}e=P()|0;O()|0}yb(d+272|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}Cd(o);yb(q);R(e|0);L()}Cd(o);yb(q)}gb=d+352|0;return e|0}function Boa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-272|0;gb=d;yc(b);f=gb-32|0;gb=f;l=d+248|0;wv(f+24|0,l);h=xb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;fc(f+16|0,b,f);i=xb(f+16|0);if((i|0)==(h|0)){Vb(e,xb(f+24|0))}gb=f+32|0;e=(h|0)==(i|0);if(!e){EX(l)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!e){break u}if(!GX(d+248|0)){break u}if(!c){g=1;break u}Ed(a,1024);sg(a);v[a+480208>>2]=v[a+480208>>2]|12;Cg(a+1074308|0,21);if(Ib(w[d+264|0]|w[d+265|0]<<8)){E=a,F=B(Ib(w[d+264|0]|w[d+265|0]<<8),1e4),v[E+480204>>2]=F}if(Ib(w[d+262|0]|w[d+263|0]<<8)){E=a,F=Ib(w[d+262|0]|w[d+263|0]<<8),v[E+480196>>2]=F}if(!w[d+258|0]){jh(a,1)}e=d+248|4;lD(b,a+1300308|0,Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-14|0);b=Ni(d+144|0,b);v[23048]=0;S(558,d+232|0,b|0);e=v[23048];v[23048]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){yb(b);v[23048]=0;T(559,d+144|0,d+232|0,1395544366);b=v[23048];v[23048]=0;if((b|0)==1){break E}v[23048]=0;b=U(470,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break L}if(!b){break F}v[23048]=0;b=U(465,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break L}v[23048]=0;e=U(465,d+144|0)|0;f=v[23048];v[23048]=0;N:{if((f|0)==1){break N}v[23048]=0;Q(370,d+144|0,4)|0;f=v[23048];v[23048]=0;if((f|0)==1){break N}f=a+484360|0;h=Qb(f);v[23048]=0;ga(560,h|0,d+144|0,b|0,65535,65535)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break M}}break L}a=P()|0;O()|0;yb(b);break a}ff(Qb(f),e);yb(d+144|0);v[23048]=0;T(559,d+144|0,d+232|0,1346458708);b=v[23048];v[23048]=0;if((b|0)==1){break K}v[23048]=0;b=U(470,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break J}if(!b){break H}v[23048]=0;b=U(465,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break J}u[a+480188>>1]=b;if((b-1&65535)>>>0>31){break H}v[23048]=0;b=U(465,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break J}v[23048]=0;p=a+484344|0;S(385,p|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break J}v[23048]=0;l=U(474,d+144|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break J}switch(l-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}a=P()|0;O()|0;yb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+144|0);break b}if(!l){break G}}yb(d+144|0);break A}yb(d+144|0);v[23048]=0;T(559,d+208|0,d+232|0,1398157625);b=v[23048];v[23048]=0;if((b|0)==1){break D}v[23048]=0;b=U(470,d+208|0)|0;e=v[23048];v[23048]=0;O:{if((e|0)==1){break O}if(!b){break B}v[23048]=0;Q(370,d+208|0,2)|0;b=v[23048];v[23048]=0;if((b|0)==1){break O}v[23048]=0;e=U(474,d+208|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}b=a;f=b;r=(+(e>>>0)*2.3283064365386963e-10+ +(y[b+480204>>2]/1e4>>>0))*1e4;P:{if(r<4294967296&r>=0){b=~~r>>>0;break P}b=0}v[f+480204>>2]=b;v[23048]=0;Q(561,d+208|0,d+144|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}e=(d+144|0)+(b<<1)|0;E=d,F=Ib(w[e|0]|w[e+1|0]<<8),v[E+80>>2]=F;v[23048]=0;v[d+64>>2]=180;e=sd(d+80|0,d- -64|0);f=v[23048];v[23048]=0;if((f|0)!=1){e=v[e>>2]-90|0;f=e>>31;E=((b<<5)+a|0)+480284|0,F=vc(Gpa(e<<7|45,f<<7|e>>>25,90,0),jb)+128|0,u[E>>1]=F;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}yb(d+144|0);break A}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[23048]=0;Q(370,d+208|0,16)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;b=Q(250,d+208|0,2)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}if(b){v[23048]=0;b=U(465,d+208|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}u[d+80>>1]=b;v[23048]=0;u[d+64>>1]=256;b=Vc(d+80|0,d- -64|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[23048]=0;Q(370,d+208|0,128)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;b=Q(561,d+208|0,d+80|0)|0;e=v[23048];v[23048]=0;Q:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break Q}e=(d+80|0)+(b<<1)|0;E=d,F=Ib(w[e|0]|w[e+1|0]<<8),v[E+64>>2]=F;v[23048]=0;v[d+40>>2]=128;e=sd(d- -64|0,d+40|0);f=v[23048];v[23048]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}yb(d+208|0);v[23048]=0;T(559,d+144|0,d+232|0,1413830740);b=v[23048];v[23048]=0;R:{S:{if((b|0)!=1){v[23048]=0;b=U(470,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}if(!b){break R}v[23048]=0;S(562,d+144|0,d+80|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}if((Ib(w[d+90|0]|w[d+91|0]<<8)|0)!=65535){break S}v[23048]=0;Q(370,d+144|0,1)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break S}break d}a=P()|0;O()|0;break b}v[23048]=0;b=U(511,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;ba(551,a+1300332|0,d+144|0,b|0,2)|0;b=v[23048];v[23048]=0;if((b|0)==1){break d}}yb(d+144|0);v[23048]=0;T(559,d+80|0,d+232|0,1229869908);b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;b=U(470,d+80|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){if(b){v[23048]=0;b=U(465,d+80|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}T:{e=b<<16>>16;h=e&32767;if(h>>>0>3999){break T}v[23048]=0;b=Q(250,d+80|0,B(h,(e>>>14&2)+50|0)|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break y}if(!b){break T}u[a+480190>>1]=h;g=a+480190|0;if(!h){break z}i=d+162|0;b=1;j=(e|0)>-1;U:{V:{while(1){W:{e=b;f=d;X:{Y:{Z:{if(!j){v[23048]=0;e=U(465,d+80|0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break Z}e=e+1|0}u[f+40>>1]=e;v[23048]=0;S(563,d+80|0,d+144|0);e=v[23048];v[23048]=0;if((e|0)!=1){if((x[d+40>>1]-1&65535)>>>0>3998){break X}v[23048]=0;e=Le(g,d+40|0);f=v[23048];v[23048]=0;if((f|0)!=1){break Y}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}u[a+480190>>1]=x[e>>1];e=x[d+40>>1];f=Wb(w[d+266|0]|w[d+267|0]<<8|(w[d+268|0]<<16|w[d+269|0]<<24));v[23048]=0;Y(564,d+144|0,(B(e,104)+a|0)+484380|0,f|0,l|0);e=v[23048];v[23048]=0;if((e|0)==1){break W}v[23048]=0;Fk(d- -64|0,2,i);e=v[23048];v[23048]=0;if((e|0)==1){break V}v[23048]=0;S(398,d+208|0,d- -64|0);e=v[23048];v[23048]=0;if((e|0)==1){break V}v[23048]=0;Q(354,((x[d+40>>1]<<5)+a|0)+946300|0,d+208|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break U}vb(d+208|0)}e=b&65535;b=b+1|0;if(e>>>0<h>>>0){continue}break z}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+208|0);break f}yb(d+80|0);break A}break w}a=P()|0;O()|0;break f}break v}v[23048]=0;b=U(465,d+80|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break x}}a=P()|0;O()|0;break f}if((b|0)==4){u[d+144>>1]=x[g>>1];v[23048]=0;u[d+208>>1]=255;b=Vc(d+144|0,d+208|0);e=v[23048];v[23048]=0;if((e|0)==1){break h}u[a+480192>>1]=x[b>>1];v[23048]=0;T(559,d+208|0,d+232|0,1229278806);b=v[23048];v[23048]=0;if((b|0)==1){break i}h=d- -64|4;g=d- -64|3;i=d- -64|5;j=d- -64|7;while(1){v[23048]=0;b=Q(250,d+80|0,15)|0;e=v[23048];v[23048]=0;_:{if((e|0)!=1){$:{if(b){v[23048]=0;S(566,d+80|0,d- -64|0);b=v[23048];v[23048]=0;aa:{if((b|0)!=1){b=d- -64|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>=x[a+480192>>1]){continue}b=d- -64|0;b=B(Ib(w[b|0]|w[b+1|0]<<8),104)+a|0;t[b+484524|0]=w[d+72|0];e=w[j|0];t[b+484523|0]=255;t[b+484525|0]=e;b=d- -64|0;b=Ib(w[b|0]|w[b+1|0]<<8);e=d- -64|0;e=Ib(w[e|0]|w[e+1|0]<<8);v[23048]=0;e=W(436,a|0,b+1&65535,e+1&65535)|0;b=v[23048];v[23048]=0;if((b|0)==1){break $}if(!e){continue}E=d,F=Ib(w[i|0]|w[i+1|0]<<8),u[E+144>>1]=F;v[23048]=0;u[d+40>>1]=4095;b=Vc(d+144|0,d+40|0);f=v[23048];v[23048]=0;if((f|0)==1){break $}v[e>>2]=x[b>>1];if(w[g|0]==255){continue}b=w[g|0];v[23048]=0;b=Q(248,d+208|0,B(b,34)+2|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break $}if(!b){continue}v[23048]=0;S(567,d+208|0,d+144|0);b=v[23048];v[23048]=0;if((b|0)==1){break $}t[e+60|0]=w[e+60|0]|1;b=Ib(w[d+144|0]|w[d+145|0]<<8);v[d+60>>2]=3;v[d+44>>2]=16;v[d+48>>2]=240;v[d+40>>2]=b;v[d+56>>2]=d+40;b=v[d+60>>2];v[d+8>>2]=v[d+56>>2];v[d+12>>2]=b;b=FX(d+8|0);v[23048]=0;f=e+48|0;S(568,f|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break $}b=0;if(Lb(f)){break aa}break _}break $}while(1){ba:{t[d+40|0]=64;m=(d+144|0)+(b<<1)|0;o=w[m+2|0];v[23048]=0;t[d+32|0]=o;o=$b(d+40|0,d+32|0);n=v[23048];v[23048]=0;if((n|0)==1){break ba}o=w[o|0];E=Mb(f,b),F=o,t[E+2|0]=F;m=w[m+3|0];E=Mb(f,b),F=m,u[E>>1]=F;b=b+1|0;if(Lb(f)>>>0>b>>>0){continue}break _}break}break $}yb(d+208|0);break w}}a=P()|0;O()|0;yb(d+208|0);break f}if(w[h|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[h|0];t[e+63|0]=b;t[e- -64|0]=b}if(cd(f)){continue}t[e+60|0]=w[e+60|0]|2;b=Lb(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue}}}yb(d+80|0);v[23048]=0;T(569,d+80|0,d+232|0,1145131092);b=v[23048];v[23048]=0;if((b|0)==1){break j}E=d,F=Rb(d+80|0),v[E+32>>2]=F;E=d,F=Ub(d+80|0),v[E+24>>2]=F;if(Fb(d+32|0,d+24|0)){A=c&1;m=d+208|4;o=(l|0)!=841887798;C=(l|0)!=841887796;while(1){h=v[d+32>>2];v[23048]=0;Q(370,h|0,4)|0;b=v[23048];v[23048]=0;ca:{da:{ea:{if((b|0)!=1){v[23048]=0;e=U(465,h|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break l}v[23048]=0;i=U(465,h|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break m}i=o?i:(i>>>0)/y[a+480196>>2]|0;if(!A|e>>>0>255){break ca}v[23048]=0;b=W(386,p|0,e|0,i|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break m}if(!b){break ca}if(o){break da}v[23048]=0;Q(370,h|0,4)|0;b=v[23048];v[23048]=0;if((b|0)==1){break m}j=0;if(!x[a+480188>>1]){break ca}while(1){v[23048]=0;b=U(465,h|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ea}v[23048]=0;T(341,d+144|0,h|0,b+(b&1)&65535);b=v[23048];v[23048]=0;if((b|0)==1){break n}v[d+208>>2]=0;v[d+212>>2]=0;f=0;fa:{while(1){v[23048]=0;b=Q(250,d+144|0,6)|0;g=v[23048];v[23048]=0;if((g|0)==1){break o}if(!(b&y[d+208>>2]<i>>>0)){break fa}b=Yb(p,e);v[23048]=0;b=Wc(b,v[d+208>>2],j&65535);g=v[23048];v[23048]=0;ga:{ha:{if((g|0)!=1){v[23048]=0;S(570,d+40|0,d+144|0);g=v[23048];v[23048]=0;if((g|0)==1){break o}g=rd(d+40|0);s=Df(d+40|0);q=Ri(d+40|0);n=dc(d+40|0);D=d+45|0;k=t[d+40|0];if((k-1&255)>>>0>95){break ha}t[b|0]=k+13;if(!v[d+212>>2]){break ga}t[b+3|0]=19;v[23048]=0;v[d+64>>2]=15;k=sd(m,d- -64|0);z=v[23048];v[23048]=0;if((z|0)==1){break o}t[b+5|0]=w[k|0]|208;break ga}break o}if((k|0)>-1){break ga}if(v[d+212>>2]){t[b+3|0]=19;v[23048]=0;v[d+64>>2]=15;k=sd(m,d- -64|0);z=v[23048];v[23048]=0;if((z|0)!=1){t[b+5|0]=w[k|0]|192;break ga}break o}t[b|0]=254}if(w[g|0]){t[b+2|0]=1;v[23048]=0;t[d+64|0]=64;g=$b(g,d- -64|0);k=v[23048];v[23048]=0;if((k|0)==1){break o}t[b+4|0]=w[g|0]}g=w[s|0];if(g){t[b+1|0]=g}g=w[q|0];if(g|w[n|0]){t[b+3|0]=g;t[b+5|0]=w[n|0];v[23048]=0;Mf(b);b=v[23048];v[23048]=0;if((b|0)==1){break o}}b=w[D|0];if(b&128){v[23048]=0;g=U(373,d+144|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break o}b=g|b<<8&32512}g=v[a+480196>>2];v[23048]=0;f=b+f|0;it(d- -64|0,f,g);b=v[23048];v[23048]=0;if((b|0)!=1){b=v[d+68>>2];v[d+208>>2]=v[d+64>>2];v[d+212>>2]=b;continue}break}break o}yb(d+144|0);j=j+1|0;if(x[a+480188>>1]>(j&65535)>>>0){continue}break}break ca}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}b=Yb(p,e);v[23048]=0;b=Wc(b,0,0);e=v[23048];v[23048]=0;if((e|0)==1){break s}j=0;if(!i){break ca}while(1){g=0;ia:{if(!x[a+480188>>1]){break ia}while(1){ja:{v[23048]=0;S(571,d+144|0,h|0);e=v[23048];v[23048]=0;if((e|0)==1){break ja}ka:{if(!C){v[d+208>>2]=v[d+144>>2];n=rd(d+208|0);k=Df(d+208|0);s=Ri(d+208|0);e=t[d+208|0];if((e|0)>=1){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}f=b;e=w[n|0];q=e>>>2|0;if(q){t[b+2|0]=1;t[b+4|0]=q-1;e=w[n|0]}t[f+1|0]=e<<4&48|w[k|0]>>>4;t[b+3|0]=w[k|0]&15;t[b+5|0]=w[s|0];break ka}e=v[d+144>>2];v[d+20>>2]=e;v[23048]=0;v[d+16>>2]=e;kr(d+16|0,b);e=v[23048];v[23048]=0;if((e|0)==1){break ja}e=lc(d+144|0,0);t[b+1|0]=w[b+1|0]|w[e|0]&48}v[23048]=0;Mf(b);e=v[23048];v[23048]=0;if((e|0)==1){break ja}e=w[b+3|0];la:{if(e>>>0>11){break la}e=1<<e;ma:{if(!(e&2240)){if(!(e&12)){break la}if(!w[b+5|0]){break ma}break la}e=w[b+5|0];f=e&240;if(f){t[b+5|0]=f;break la}if(e){break la}}t[b+3|0]=0}b=b+6|0;g=g+1|0;if(x[a+480188>>1]>(g&65535)>>>0){continue}break ia}break}a=P()|0;O()|0;break k}j=j+1|0;if((j|0)!=(i|0)){continue}break}}sh(d+32|0);if(Fb(d+32|0,d+24|0)){continue}break}}kd(d+80|0);v[23048]=0;T(559,d+144|0,d+232|0,1346458702);b=v[23048];v[23048]=0;if((b|0)==1){a=P()|0;O()|0;break b}v[23048]=0;b=U(470,d+144|0)|0;e=v[23048];v[23048]=0;na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{if((e|0)!=1){if(b){e=Jb(d+80|0);b=0;Ba:{while(1){Ca:{v[23048]=0;f=Q(250,d+144|0,1)|0;h=v[23048];v[23048]=0;if((h|0)==1){break Ca}if(!f){break Ba}if(Te(p)>>>0<=b>>>0){break Ba}v[23048]=0;W(573,d+144|0,e|0,32)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Ca}f=Yb(p,b);v[23048]=0;Q(476,f|0,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Ca}b=b+1|0;continue}break}a=P()|0;O()|0;vb(e);break Aa}vb(e)}yb(d+144|0);v[23048]=0;T(559,d+144|0,d+232|0,1414679374);b=v[23048];v[23048]=0;if((b|0)==1){break za}v[23048]=0;b=U(470,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break va}if(!b){break wa}e=Jb(d+80|0);b=0;while(1){v[23048]=0;f=Q(250,d+144|0,1)|0;h=v[23048];v[23048]=0;if((h|0)==1){break ya}if(!f|x[a+480188>>1]<=b>>>0){break xa}v[23048]=0;W(573,d+144|0,e|0,32)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ya}v[23048]=0;Q(449,((b<<5)+a|0)+480289|0,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ya}b=b+1|0;continue}}a=P()|0;O()|0}yb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(e);break ua}vb(e)}yb(d+144|0);v[23048]=0;T(569,d+144|0,d+232|0,1145129300);b=v[23048];v[23048]=0;if((b|0)==1){break ta}E=d,F=Rb(d+144|0),v[E+80>>2]=F;E=d,F=Ub(d+144|0),v[E+208>>2]=F;if(Fb(d+80|0,d+208|0)){e=c&2;while(1){b=v[d+80>>2];v[23048]=0;c=U(465,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=Sc(d- -64|0,f&1?16:8,f&64?2:1,1,0);v[23048]=0;W(384,f|0,c+484484|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break p}}sh(d+80|0);if(Fb(d+80|0,d+208|0)){continue}break}}kd(d+144|0);b=Jb(d+80|0);if((l|0)!=841887798){break ra}v[23048]=0;c=Q(2,d+144|0,17387)|0;e=v[23048];v[23048]=0;if((e|0)==1){break sa}Eb(b,c);vb(c);break qa}a=P()|0;O()|0}yb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break q}v[23048]=0;T(559,d+144|0,d+232|0,1447383635);c=v[23048];v[23048]=0;Da:{Ea:{Fa:{Ga:{Ha:{if((c|0)!=1){v[23048]=0;c=U(470,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break pa}if(!c){break Ea}v[23048]=0;c=U(474,d+144|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Ha}v[23048]=0;S(460,d- -64|0,17407);e=v[23048];v[23048]=0;if((e|0)==1){break Ga}v[d+40>>2]=c>>>4;v[23048]=0;v[d+32>>2]=c&15;Y(574,d+208|0,d- -64|0,d+40|0,d+32|0);c=v[23048];v[23048]=0;if((c|0)==1){break Fa}Eb(b,d+208|0);vb(d+208|0);Hb(d- -64|0);break Da}a=P()|0;O()|0;break q}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;Hb(d- -64|0);break r}v[23048]=0;c=Q(2,d+208|0,17429)|0;e=v[23048];v[23048]=0;if((e|0)==1){break t}Eb(b,c);vb(c)}yb(d+144|0)}v[23048]=0;c=Q(2,d+144|0,17429)|0;e=v[23048];v[23048]=0;if((e|0)==1){break oa}Eb(a+1300344|0,c);vb(c);v[23048]=0;c=Q(2,d+144|0,17445)|0;e=v[23048];v[23048]=0;if((e|0)==1){break na}Eb(a+1300356|0,c);vb(c);Eb(a+1300368|0,b);v[a+1300404>>2]=2;vb(b);g=1;break v}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}Cd(d+232|0)}gb=d+272|0;return g|0}a=P()|0;O()|0;break r}a=P()|0;O()|0;break k}yb(d+144|0)}vb(b);break b}a=P()|0;O()|0;kd(d+144|0);break b}a=P()|0;O()|0;yb(d+144|0);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0}kd(d+80|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}yb(d+80|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+144|0);break b}a=P()|0;O()|0;yb(d+208|0)}Cd(d+232|0)}R(a|0);L()}function MI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,Q=0;s=gb-48|0;gb=s;a:{if(c>>>0<=2){c=c<<2;I=v[c+75676>>2];H=v[c+75664>>2];while(1){c=v[b+4>>2];b:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=pd(b)}if(pm(c)){continue}break}n=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}n=(c|0)==45?-1:1;c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=pd(b)}e:{f:{while(1){if(t[f+75594|0]==(c|32)){g:{if(f>>>0>6){break g}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=pd(b)}f=f+1|0;if((f|0)!=8){continue}break f}break}if((f|0)!=3){if((f|0)==8){break f}if(!d|f>>>0<4){break e}if((f|0)==8){break f}}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(!d|f>>>0<4){break f}while(1){if(c){v[b+4>>2]=v[b+4>>2]-1}f=f-1|0;if(f>>>0>3){continue}break}}b=s;k=gb-16|0;gb=k;i=(p(C(C(n|0)*C(N))),j(2));c=i&2147483647;h:{if(c-8388608>>>0<=2130706431){d=c;c=c>>>7|0;f=d<<25;d=c+1065353216|0;break h}f=i;d=f>>>7|0;f=f<<25;d=d|2147418112;if(c>>>0>=2139095040){break h}f=0;d=0;if(!c){break h}d=c;c=E(c);Uf(k,d,0,0,0,c+81|0);h=v[k>>2];g=v[k+4>>2];f=v[k+8>>2];d=v[k+12>>2]^65536|16265-c<<16}v[b>>2]=h;v[b+4>>2]=g;v[b+8>>2]=f;v[b+12>>2]=i&-2147483648|d;gb=k+16|0;h=v[s+8>>2];g=v[s+12>>2];l=v[s>>2];i=v[s+4>>2];break a}i:{j:{k:{if(f){break k}f=0;while(1){if(t[f+75603|0]!=(c|32)){break k}l:{if(f>>>0>1){break l}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=pd(b)}f=f+1|0;if((f|0)!=3){continue}break}break j}m:{switch(f|0){case 0:n:{if((c|0)!=48){break n}f=v[b+4>>2];o:{if(f>>>0<y[b+104>>2]){v[b+4>>2]=f+1;f=w[f|0];break o}f=pd(b)}if((f&-33)==88){f=gb-432|0;gb=f;i=v[b+104>>2];c=b;b=v[c+4>>2];p:{if(i>>>0>b>>>0){v[c+4>>2]=b+1;b=w[b|0];break p}b=pd(c)}q:{r:{while(1){if((b|0)!=48){s:{if((b|0)!=46){break q}b=v[c+4>>2];if(b>>>0>=y[c+104>>2]){break s}v[c+4>>2]=b+1;b=w[b|0];break r}}else{b=v[c+4>>2];if(b>>>0<y[c+104>>2]){k=1;v[c+4>>2]=b+1;b=w[b|0]}else{k=1;b=pd(c)}continue}break}b=pd(c)}e=1;if((b|0)!=48){break q}while(1){b=m;m=b-1|0;u=u-(b>>>0<1)|0;b=v[c+4>>2];t:{if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0];break t}b=pd(c)}if((b|0)==48){continue}break}k=1}i=1073676288;while(1){u:{z=b|32;v:{w:{J=b-48|0;if(J>>>0<10){break w}if(z-97>>>0>5?(b|0)!=46:0){break u}if((b|0)!=46){break w}if(e){break u}e=1;m=h;u=g;break v}b=(b|0)>57?z-87|0:J;x:{if((g|0)<0?1:(g|0)<=0?h>>>0<=7:0){x=b+(x<<4)|0;break x}if((g|0)<0?1:(g|0)<=0?h>>>0<=28:0){Pg(f+48|0,b);Dd(f+32|0,F,G,l,i,0,0,0,1073414144);F=v[f+32>>2];G=v[f+36>>2];l=v[f+40>>2];i=v[f+44>>2];Dd(f+16|0,F,G,l,i,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2]);qg(f,q,r,A,D,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2]);A=v[f+8>>2];D=v[f+12>>2];q=v[f>>2];r=v[f+4>>2];break x}if(!b|o){break x}Dd(f+80|0,F,G,l,i,0,0,0,1073610752);qg(f- -64|0,q,r,A,D,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2]);A=v[f+72>>2];D=v[f+76>>2];o=1;q=v[f+64>>2];r=v[f+68>>2]}b=h+1|0;k=b>>>0<1?g+1|0:g;h=b;g=k;k=1}b=v[c+4>>2];if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0]}else{b=pd(c)}continue}break}y:{z:{A:{if(!k){if(!v[c+104>>2]){if(d){break z}break A}b=v[c+4>>2];v[c+4>>2]=b-1;if(!d){break A}v[c+4>>2]=b-2;if(!e){break z}v[c+4>>2]=b-3;break z}if((g|0)<0?1:(g|0)<=0?h>>>0<=7:0){l=h;i=g;while(1){x=x<<4;k=l+1|0;i=k>>>0<1?i+1|0:i;l=k;if((k|0)!=8|i){continue}break}}B:{if((b&-33)==80){l=LI(c,d);b=jb;i=b;if(l|(b|0)!=-2147483648){break B}if(d){l=0;i=0;if(!v[c+104>>2]){break B}v[c+4>>2]=v[c+4>>2]-1;break B}q=0;r=0;oi(c,0,0);c=0;b=0;break y}l=0;i=0;if(!v[c+104>>2]){break B}v[c+4>>2]=v[c+4>>2]-1}if(!x){fj(f+112|0,+(n|0)*0);q=v[f+112>>2];r=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break y}b=e?m:h;c=(e?u:g)<<2|b>>>30;b=l+(b<<2)|0;c=c+i|0;c=b>>>0<l>>>0?c+1|0:c;h=b-32|0;g=c-(b>>>0<32)|0;b=g;if((b|0)>0?1:(b|0)>=0?h>>>0>0-I>>>0:0){v[115529]=68;Pg(f+160|0,n);Dd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Dd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);q=v[f+128>>2];r=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break y}b=I-226|0;c=h>>>0>=b>>>0;b=b>>31;if((b|0)<(g|0)?1:(g|0)>=(b|0)?c:0){if((x|0)>-1){while(1){qg(f+416|0,q,r,A,D,0,0,0,-1073807360);c=SS(q,r,A,D,1073610752);b=(c|0)<0;qg(f+400|0,q,r,A,D,b?q:v[f+416>>2],b?r:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=h;h=b-1|0;g=g-(b>>>0<1)|0;A=v[f+408>>2];D=v[f+412>>2];q=v[f+400>>2];r=v[f+404>>2];x=x<<1|(c|0)>-1;if((x|0)>-1){continue}break}}b=h;c=I;d=(b-c|0)+32|0;c=g-((c>>31)+(b>>>0<c>>>0)|0)|0;c=d>>>0<32?c+1|0:c;b=d;c=((c|0)<0?1:(c|0)<=0?b>>>0<H>>>0:0)?(b|0)>0?b:0:H;C:{if((c|0)>=113){Pg(f+384|0,n);m=v[f+392>>2];u=v[f+396>>2];F=v[f+384>>2];G=v[f+388>>2];g=0;b=0;break C}fj(f+352|0,Qi(1,144-c|0));Pg(f+336|0,n);F=v[f+336>>2];G=v[f+340>>2];m=v[f+344>>2];u=v[f+348>>2];OI(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],F,G,m,u);K=v[f+376>>2];L=v[f+380>>2];g=v[f+372>>2];b=v[f+368>>2]}c=!(x&1)&((hn(q,r,A,D,0,0,0,0)|0)!=0&(c|0)<32);Tn(f+320|0,c+x|0);Dd(f+304|0,F,G,m,u,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);qg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,g,K,L);Dd(f+288|0,c?0:q,c?0:r,c?0:A,c?0:D,F,G,m,u);qg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Jx(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],b,g,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];g=v[f+252>>2];if(!hn(b,c,d,g,0,0,0,0)){v[115529]=68}NI(f+224|0,b,c,d,g,h);q=v[f+224>>2];r=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break y}v[115529]=68;Pg(f+208|0,n);Dd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Dd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);q=v[f+176>>2];r=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2];break y}oi(c,0,0)}fj(f+96|0,+(n|0)*0);q=v[f+96>>2];r=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2]}v[s+16>>2]=q;v[s+20>>2]=r;v[s+24>>2]=b;v[s+28>>2]=c;gb=f+432|0;h=v[s+24>>2];g=v[s+28>>2];l=v[s+16>>2];i=v[s+20>>2];break a}if(!v[b+104>>2]){break n}v[b+4>>2]=v[b+4>>2]-1}m=b;f=c;x=n;b=0;n=0;e=gb-8976|0;gb=e;K=H+I|0;L=0-K|0;D:{E:{while(1){if((f|0)!=48){F:{if((f|0)!=46){break D}c=v[m+4>>2];if(c>>>0>=y[m+104>>2]){break F}v[m+4>>2]=c+1;f=w[c|0];break E}}else{c=v[m+4>>2];if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0]}else{f=pd(m)}n=1;continue}break}f=pd(m)}o=1;if((f|0)!=48){break D}h=-1;g=-1;while(1){c=v[m+4>>2];G:{if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0];break G}f=pd(m)}if((f|0)==48){c=h;h=c-1|0;g=g-(c>>>0<1)|0;continue}break}n=1}v[e+784>>2]=0;H:{I:{k=(f|0)==46;c=f-48|0;J:{K:{L:{if(!(c>>>0>9?!k:0)){while(1){M:{if(k&1){if(!o){h=l;g=i;o=1;break M}k=!n;break L}k=i;i=l+1|0;k=i>>>0<1?k+1|0:k;l=i;i=k;if((b|0)<=2044){J=(f|0)==48?J:l;k=(e+784|0)+(b<<2)|0;n=k;if(z){c=(B(v[k>>2],10)+f|0)-48|0}v[n>>2]=c;n=1;f=z+1|0;c=(f|0)==9;z=c?0:f;b=b+c|0;break M}if((f|0)==48){break M}v[e+8960>>2]=v[e+8960>>2]|1;J=18396}c=v[m+4>>2];N:{if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0];break N}f=pd(m)}k=(f|0)==46;c=f-48|0;if(k|c>>>0<10){continue}break}}h=o?h:l;g=o?g:i;if(!(!n|(f&-33)!=69)){c=LI(m,d);f=jb;k=f;if(c|(f|0)!=-2147483648){d=g+k|0;h=c+h|0;d=h>>>0<c>>>0?d+1|0:d;g=d;break I}if(!d){break J}if(!v[m+104>>2]){break I}v[m+4>>2]=v[m+4>>2]-1;break I}k=!n;if((f|0)<0){break K}}if(!v[m+104>>2]){break K}v[m+4>>2]=v[m+4>>2]-1}if(!k){break I}v[115529]=28}l=0;i=0;oi(m,0,0);c=0;b=0;break H}c=v[e+784>>2];if(!c){fj(e,+(x|0)*0);l=v[e>>2];i=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break H}if(!((h|0)!=(l|0)|(g|0)!=(i|0)|((i|0)>0?1:(i|0)>=0?l>>>0>9:0)|(c>>>H|0?(H|0)<=30:0))){Pg(e+48|0,x);Tn(e+32|0,c);Dd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);l=v[e+16>>2];i=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break H}if((g|0)>0?1:(g|0)>=0?h>>>0>(I|0)/-2>>>0:0){v[115529]=68;Pg(e+96|0,x);Dd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Dd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);l=v[e+64>>2];i=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break H}c=I-226|0;d=h>>>0<c>>>0;c=c>>31;if((c|0)>(g|0)?1:(g|0)<=(c|0)?d:0){v[115529]=68;Pg(e+144|0,x);Dd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Dd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);l=v[e+112>>2];i=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break H}if(z){if((z|0)<=8){d=(e+784|0)+(b<<2)|0;c=v[d>>2];while(1){c=B(c,10);z=z+1|0;if((z|0)!=9){continue}break}v[d>>2]=c}b=b+1|0}O:{o=h;if((J|0)>(h|0)|(J|0)>=9|(h|0)>17){break O}if((o|0)==9){Pg(e+192|0,x);Tn(e+176|0,v[e+784>>2]);Dd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);l=v[e+160>>2];i=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break H}if((o|0)<=8){Pg(e+272|0,x);Tn(e+256|0,v[e+784>>2]);Dd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Pg(e+224|0,v[(0-o<<2)+75664>>2]);$E(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);l=v[e+208>>2];i=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break H}c=(B(o,-3)+H|0)+27|0;d=v[e+784>>2];if(d>>>c|0?(c|0)<=30:0){break O}Pg(e+352|0,x);Tn(e+336|0,d);Dd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Pg(e+304|0,v[(o<<2)+75592>>2]);Dd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);l=v[e+288>>2];i=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break H}while(1){c=b;b=c-1|0;if(!v[(e+784|0)+(b<<2)>>2]){continue}break}z=0;b=(o|0)%9|0;P:{if(!b){b=0;break P}d=(o|0)>-1?b:b+9|0;Q:{if(!c){b=0;c=0;break Q}h=v[(0-d<<2)+75664>>2];i=1e9/(h|0)|0;k=0;f=0;b=0;while(1){g=k;k=(e+784|0)+(f<<2)|0;l=v[k>>2];n=(l>>>0)/(h>>>0)|0;g=g+n|0;v[k>>2]=g;g=!g&(b|0)==(f|0);b=g?b+1&2047:b;o=g?o-9|0:o;k=B(i,l-B(h,n)|0);f=f+1|0;if((f|0)!=(c|0)){continue}break}if(!k){break Q}v[(e+784|0)+(c<<2)>>2]=k;c=c+1|0}o=(o-d|0)+9|0}while(1){l=(e+784|0)+(b<<2)|0;R:{while(1){if((o|0)!=36|y[l>>2]>10384592?(o|0)>=36:0){break R}f=c+2047|0;h=0;while(1){k=0;f=f&2047;n=(e+784|0)+(f<<2)|0;g=v[n>>2];d=g>>>3|0;g=h+(g<<29)|0;i=d;i=g>>>0<h>>>0?i+1|0:i;h=g;g=i;if(!g&h>>>0>=1000000001|g){k=Ipa(h,g,1e9,0);h=h-Fpa(k,jb,1e9,0)|0}v[n>>2]=h;d=h?c:f;h=(b|0)==(f|0);d=(f|0)!=(c-1&2047)?c:h?c:d;if(!h){f=f-1|0;h=k;c=d;continue}break}z=z-29|0;if(!k){continue}break}b=b-1&2047;if((d|0)==(b|0)){c=(e+784|0)+((d+2046&2047)<<2)|0;h=c;i=v[c>>2];c=d-1&2047;v[h>>2]=i|v[(e+784|0)+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=k;continue}break}S:{T:while(1){d=c+1&2047;g=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(o|0)>45?9:1;U:{while(1){n=b;f=0;V:{while(1){W:{b=f+n&2047;if((b|0)==(c|0)){break W}b=v[(e+784|0)+(b<<2)>>2];i=v[(f<<2)+75616>>2];if(b>>>0<i>>>0){break W}if(b>>>0>i>>>0){break V}f=f+1|0;if((f|0)!=4){continue}}break}if((o|0)!=36){break V}h=0;g=0;f=0;l=0;i=0;while(1){b=f+n&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}Dd(e+768|0,h,g,l,i,0,0,1342177280,1075633366);Tn(e+752|0,v[(e+784|0)+(b<<2)>>2]);qg(e+736|0,v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2],v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2]);l=v[e+744>>2];i=v[e+748>>2];h=v[e+736>>2];g=v[e+740>>2];f=f+1|0;if((f|0)!=4){continue}break}Pg(e+720|0,x);Dd(e+704|0,h,g,l,i,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);l=v[e+712>>2];i=v[e+716>>2];h=0;g=0;q=v[e+704>>2];r=v[e+708>>2];o=z+113|0;d=o-I|0;f=(d|0)<(H|0);b=f?(d|0)>0?d:0:H;if((b|0)<=112){break U}m=0;break S}z=h+z|0;b=c;if((n|0)==(c|0)){continue}break}k=1e9>>>h|0;l=-1<<h^-1;f=0;b=n;while(1){i=f;f=(e+784|0)+(n<<2)|0;m=v[f>>2];i=i+(m>>>h|0)|0;v[f>>2]=i;i=!i&(b|0)==(n|0);b=i?b+1&2047:b;o=i?o-9|0:o;f=B(k,l&m);n=n+1&2047;if((n|0)!=(c|0)){continue}break}if(!f){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=f;c=d;continue T}v[g>>2]=v[g>>2]|1;b=d;continue}break}break}fj(e+656|0,Qi(1,225-b|0));OI(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],q,r,l,i);F=v[e+696>>2];G=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];fj(e+640|0,Qi(1,113-b|0));FE(e+672|0,q,r,l,i,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);h=v[e+672>>2];g=v[e+676>>2];m=v[e+680>>2];u=v[e+684>>2];Jx(e+624|0,q,r,l,i,h,g,m,u);qg(e+608|0,A,D,F,G,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);l=v[e+616>>2];i=v[e+620>>2];q=v[e+608>>2];r=v[e+612>>2]}k=n+4&2047;X:{if((k|0)==(c|0)){break X}k=v[(e+784|0)+(k<<2)>>2];Y:{if(k>>>0<=499999999){if((n+5&2047)==(c|0)?!k:0){break Y}fj(e+496|0,+(x|0)*.25);qg(e+480|0,h,g,m,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);m=v[e+488>>2];u=v[e+492>>2];h=v[e+480>>2];g=v[e+484>>2];break Y}if((k|0)!=5e8){fj(e+592|0,+(x|0)*.75);qg(e+576|0,h,g,m,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);m=v[e+584>>2];u=v[e+588>>2];h=v[e+576>>2];g=v[e+580>>2];break Y}M=+(x|0);if((n+5&2047)==(c|0)){fj(e+528|0,M*.5);qg(e+512|0,h,g,m,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);m=v[e+520>>2];u=v[e+524>>2];h=v[e+512>>2];g=v[e+516>>2];break Y}fj(e+560|0,M*.75);qg(e+544|0,h,g,m,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);m=v[e+552>>2];u=v[e+556>>2];h=v[e+544>>2];g=v[e+548>>2]}if((b|0)>111){break X}FE(e+464|0,h,g,m,u,0,0,0,1073676288);if(hn(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break X}qg(e+448|0,h,g,m,u,0,0,0,1073676288);m=v[e+456>>2];u=v[e+460>>2];h=v[e+448>>2];g=v[e+452>>2]}qg(e+432|0,q,r,l,i,h,g,m,u);Jx(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,F,G);l=v[e+424>>2];i=v[e+428>>2];q=v[e+416>>2];r=v[e+420>>2];Z:{if((-2-K|0)>=(o&2147483647)){break Z}v[e+408>>2]=l;v[e+412>>2]=i&2147483647;v[e+400>>2]=q;v[e+404>>2]=r;Dd(e+384|0,q,r,l,i,0,0,0,1073610752);k=SS(v[e+400>>2],v[e+404>>2],v[e+408>>2],v[e+412>>2],1081081856);c=(k|0)<0;l=c?l:v[e+392>>2];i=c?i:v[e+396>>2];q=c?q:v[e+384>>2];r=c?r:v[e+388>>2];z=((k|0)>-1)+z|0;if(O=!((hn(h,g,m,u,0,0,0,0)|0)!=0&(c?f:f&(b|0)!=(d|0))),P=0,Q=(z+110|0)<=(L|0),Q?O:P){break Z}v[115529]=68}NI(e+368|0,q,r,l,i,z);l=v[e+368>>2];i=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[s+32>>2]=l;v[s+36>>2]=i;v[s+40>>2]=b;v[s+44>>2]=c;gb=e+8976|0;h=v[s+40>>2];g=v[s+44>>2];l=v[s+32>>2];i=v[s+36>>2];break a;case 3:break j;default:break m}}if(v[b+104>>2]){v[b+4>>2]=v[b+4>>2]-1}break i}_:{c=v[b+4>>2];$:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break $}c=pd(b)}if((c|0)==40){f=1;break _}g=2147450880;if(!v[b+104>>2]){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];aa:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break aa}c=pd(b)}if(!(c-97>>>0>=26?!(c-48>>>0<10|c-65>>>0<26|(c|0)==95):0)){f=f+1|0;continue}break}g=2147450880;if((c|0)==41){break a}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(d){if(!f){break a}while(1){f=f-1|0;if(c){v[b+4>>2]=v[b+4>>2]-1}if(f){continue}break}break a}}v[115529]=28;oi(b,0,0)}g=0}v[a>>2]=l;v[a+4>>2]=i;v[a+8>>2]=h;v[a+12>>2]=g;gb=s+48|0}function lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-496|0;gb=d;yc(b);g=d+416|0;i=WV(b,g);if(!i){kC(g)}a:{if(!i){break a}if(!fT(d+416|0)){break a}if(!Nb(b,Xc(eT(d+416|0),jb))){break a}b:{if(!c){break b}Ed(a,4);sg(a);t[a+1074364|0]=4;l=Jb(d+400|0);c:{d:{k=d+454|0;e:{if(!(zd(k,26896,20)|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24))!=276)){e=48;if((w[d+474|0]|w[d+475|0]<<8)>>>0<260){break e}v[23048]=0;g=tv(d+433|0,0,20);i=v[23048];v[23048]=0;if((i|0)==1){break d}e=g?1154:34;break e}if(!zd(k,26917,20)){e=1;break e}v[23048]=0;Mj(d+384|0,3,k);g=v[23048];v[23048]=0;f:{g:{h:{if((g|0)==1){break h}v[23048]=0;S(398,d+40|0,d+384|0);g=v[23048];v[23048]=0;if((g|0)==1){break h}v[23048]=0;T(13,d+112|0,5,d+40|0);g=v[23048];v[23048]=0;if((g|0)==1){break g}Eb(l,d+112|0);vb(d+112|0);vb(d+40|0);if((w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))!=1852141647|(w[k+4|0]|w[k+5|0]<<8|(w[k+6|0]<<16|w[k+7|0]<<24))!=542396493){break f}e=1048;break e}c=P()|0;O()|0;break c}c=P()|0;O()|0;vb(d+40|0);break c}if(!zd(k,26947,12)){e=16;if((x[d+466>>1]|x[d+468>>1]<<16)==538976288&(x[d+470>>1]|x[d+472>>1]<<16)==538976288){break e}t[a+1074364|0]=5;break e}if(!zd(k,26961,20)){e=48;break e}if(!zd(k,26982,15)){v[23048]=0;g=a+1074308|0;Q(459,g|0,54)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}v[23048]=0;Q(459,g|0,51)|0;g=v[23048];v[23048]=0;e=16;if((g|0)==1){break d}break e}if(!zd(k,26998,14)){v[23048]=0;Q(459,a+1074308|0,57)|0;g=v[23048];v[23048]=0;e=16;if((g|0)!=1){break e}break d}e=zd(k,27013,11)?16:256}v[23048]=0;s=d+433|0;Mj(d+40|0,3,s);g=v[23048];v[23048]=0;i:{if((g|0)==1){break i}v[23048]=0;S(398,d+112|0,d+40|0);g=v[23048];v[23048]=0;if((g|0)==1){break i}Eb(a+1300308|0,d+112|0);vb(d+112|0);v[a+480260>>2]=1;v[a+480264>>2]=31999;q=a+484360|0;ff(Qb(q),w[d+482|0]|w[d+483|0]<<8);u[a+480188>>1]=w[d+484|0]|w[d+485|0]<<8;u[d+112>>1]=w[d+488|0]|w[d+489|0]<<8;v[23048]=0;u[d+40>>1]=255;g=Vc(d+112|0,d+40|0);i=v[23048];v[23048]=0;if((i|0)!=1){u[a+480192>>1]=x[g>>1];if(w[d+492|0]|w[d+493|0]<<8){v[a+480196>>2]=w[d+492|0]|w[d+493|0]<<8}if(w[d+494|0]|w[d+495|0]<<8){F=a,G=Gd(B(w[d+494|0]|w[d+495|0]<<8,1e4),32e4,1e7),v[F+480204>>2]=G}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+490|0]|w[d+491|0]<<8)<<4&16;g=(w[d+490|0]|w[d+491|0]<<8)<<3&32768;v[a+480208>>2]=g|v[a+480208>>2]&-32769;i=Qb(q);f=w[d+480|0]|w[d+481|0]<<8;v[23048]=0;ga(560,i|0,b|0,f|0,65535,65535)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}h=(e|0)==34?g>>>15|0?146:e:e;if(!(h&1024|(w[d+480|0]|w[d+481|0]<<8))){g=Qb(q);v[23048]=0;T(985,g|0,1,0);g=v[23048];v[23048]=0;if((g|0)==1){break d}}g=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[23048]=0;Q(248,b|0,g+60|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}if((w[d+474|0]|w[d+475|0]<<8)>>>0>=260){v[23048]=0;T(986,b|0,d+416|0,a|0);g=v[23048];v[23048]=0;if((g|0)==1){break d}}t[d+383|0]=0;z=c&2;o=nc(d+384|0);j:{k:{if(x[a+480192>>1]){D=d+58|0;E=d+145|0;f=d+141|0;e=1;g=-1;m=1;l:{while(1){v[23048]=0;i=U(376,b|0)|0;j=v[23048];v[23048]=0;m:{n:{o:{p:{q:{r:{if((j|0)!=1){kg(b,4);v[23048]=0;T(987,b|0,d+112|0,(i?i:263)|0);i=v[23048];v[23048]=0;if((i|0)==1){break l}s:{if((h|0)==1){if((w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))==245){v[a+1074304>>2]=16777381;v[23048]=0;i=Q(2,d+40|0,27025)|0;h=v[23048];v[23048]=0;if((h|0)!=1){Eb(l,i);vb(i);h=17;break s}c=P()|0;O()|0;break j}h=16;if((w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))!=263){break s}v[a+1074304>>2]=16777395;v[23048]=0;i=Q(2,d+40|0,27051)|0;h=v[23048];v[23048]=0;if((h|0)!=1){Eb(l,i);vb(i);h=17;break s}c=P()|0;O()|0;break j}if(w[d+139|0]|w[d+140|0]<<8){break s}if(!(!(h&2)|(w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))!=263|(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)))){h=h|16;break s}if(!(!(h&256)|(w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))==29)){h=h&-257;break s}if(!(h&160)){break s}h=(w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))==33?h:0}v[23048]=0;i=W(436,a|0,m&65535,0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break l}if(!i){break m}j=((e<<2)+a|0)+900380|0;i=v[j>>2];v[23048]=0;S(988,d+112|0,i|0);i=v[23048];v[23048]=0;if((i|0)==1){break l}i=w[d+138|0];t:{if((g|0)==-1){g=i;break t}if(!(h&32)|(g|0)==(i|0)){break t}h=h&-161|128}if(!(w[d+139|0]|w[d+140|0]<<8)){break m}i=w[d+353|0];e=w[d+354|0];p=w[d+355|0]|w[d+356|0]<<8;n=w[d+359|0];r=w[d+139|0]|w[d+140|0]<<8;v[23048]=0;T(989,d+96|0,a|0,r|0);r=v[23048];v[23048]=0;if((r|0)==1){break r}h=n|(p|(e|i))?h&-4:h;e=12;while(1){i=x[ud(v[j>>2]+236|0,e)>>1];if(uc(d+96|0)>>>0>i>>>0){i=x[sc(d+96|0,x[ud(v[j>>2]+236|0,e)>>1])>>1];F=ud(v[j>>2]+236|0,e),G=i,u[F>>1]=G}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+474|0]|w[d+475|0]<<8)>>>0>259){Lb(o);wq(o);iw(o)}i=w[d+139|0]|w[d+140|0]<<8;v[23048]=0;i=Q(990,d+80|0,i|0)|0;e=v[23048];v[23048]=0;u:{if((e|0)!=1){e=0;if(w[d+139|0]|w[d+140|0]<<8){break u}break q}c=P()|0;O()|0;break o}v:{w:{x:{y:{while(1){v[23048]=0;Q(991,b|0,d+40|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break v}v[23048]=0;YN(d+24|0,d+40|0);j=v[23048];v[23048]=0;z:{if((j|0)==1){break z}v[23048]=0;S(993,o|0,d+24|0);j=v[23048];v[23048]=0;if((j|0)==1){break z}j=w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24);F=Mb(i,e),G=j,v[F>>2]=G;p=w[d+57|0];if(uc(d+96|0)>>>0>e>>>0){j=x[sc(d+96|0,e)>>1];v[23048]=0;n=(B(j,104)+a|0)+484380|0;S(994,d+40|0,n|0);r=v[23048];v[23048]=0;if((r|0)==1){break y}v[23048]=0;ZN(E,n);n=v[23048];v[23048]=0;if((n|0)==1){break y}v[23048]=0;Fk(d+8|0,3,D);n=v[23048];v[23048]=0;if((n|0)==1){break x}v[23048]=0;S(398,d+24|0,d+8|0);n=v[23048];v[23048]=0;if((n|0)==1){break x}v[23048]=0;Q(354,((j<<5)+a|0)+946300|0,d+24|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break w}vb(d+24|0);h=(h&2)>>>1|0?(w[d+54|0]&3)==3?h|4:h:h}A=p|A;e=e+1|0;if(e>>>0>=(w[d+139|0]|w[d+140|0]<<8)>>>0){break q}continue}break}c=P()|0;O()|0;break p}c=P()|0;O()|0;break p}c=P()|0;O()|0;break p}c=P()|0;O()|0;vb(d+24|0);break p}c=P()|0;O()|0;break p}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}if((w[d+474|0]|w[d+475|0]<<8)>>>0<260){break n}e=0;if(!(w[d+139|0]|w[d+140|0]<<8)){break n}A:{while(1){B:{p=w[Mb(o,e)+3|0];j=v[Mb(i,e)>>2];v[23048]=0;T(341,d+40|0,b|0,((p|0)==11?(j+1>>>1|0)+16|0:j)|0);j=v[23048];v[23048]=0;if((j|0)==1){break B}if(!(!z|uc(d+96|0)>>>0<=e>>>0)){p=x[sc(d+96|0,e)>>1];j=Mb(o,e);j=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);v[23048]=0;v[d+4>>2]=j;v[d>>2]=j;j=ba(996,(B(p,104)+a|0)+484380|0,d|0,d+40|0,d+383|0)|0;p=v[23048];v[23048]=0;if((p|0)==1){break A}C=j^1|C}yb(d+40|0);e=e+1|0;if(e>>>0<(w[d+139|0]|w[d+140|0]<<8)>>>0){continue}break n}break}c=P()|0;O()|0;break p}c=P()|0;O()|0;yb(d+40|0)}Qc(i)}Ze(d+96|0);break j}Qc(i);Ze(d+96|0)}m=m+1|0;e=m&65535;if(e>>>0<=x[a+480192>>1]){continue}break}i=!(A&255);break k}c=P()|0;O()|0;break j}g=-1;i=1}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{if(!(!(h&2)|!i)){v[23048]=0;f=tv(s,0,20);e=v[23048];v[23048]=0;if((e|0)==1){break T}h=f?h|16:h}U:{if((w[d+474|0]|w[d+475|0]<<8)>>>0>259){break U}if(c&3){v[23048]=0;T(986,b|0,d+416|0,a|0);c=v[23048];v[23048]=0;if((c|0)==1){break T}}if(!z|!x[a+480190>>1]){break U}e=1;c=1;while(1){f=Mb(o,e-1|0);v[23048]=0;W(384,f|0,(B(e,104)+a|0)+484380|0,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break I}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}if(C&1){v[23048]=0;f=Q(2,d+112|0,27076)|0;c=v[23048];v[23048]=0;if((c|0)==1){break S}v[23048]=0;T(601,a|0,2,f|0);c=v[23048];v[23048]=0;if((c|0)==1){break R}vb(f)}v[23048]=0;c=Q(596,b|0,27159)|0;f=v[23048];v[23048]=0;if((f|0)==1){break T}if(c){v[23048]=0;c=U(376,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break T}v[23048]=0;ba(551,a+1300332|0,b|0,c|0,0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break T}h=h|16}v[23048]=0;c=Q(596,b|0,27164)|0;f=v[23048];v[23048]=0;if((f|0)==1){break C}if(c){v[23048]=0;f=U(376,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break C}v[23048]=0;e=a+901404|0;T(997,b|0,e|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break C}v[23048]=0;Ju(e);f=v[23048];v[23048]=0;if((f|0)==1){break C}h=h|16}v[23048]=0;f=Q(596,b|0,27169)|0;e=v[23048];v[23048]=0;if((e|0)==1){break C}if(f){v[23048]=0;f=U(376,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break Q}u[d+112>>1]=f>>>5;f=a+484344|0;e=Te(f);v[23048]=0;u[d+40>>1]=e;e=Vc(d+112|0,d+40|0);m=v[23048];v[23048]=0;if((m|0)==1){break P}m=x[e>>1];if(m){e=0;while(1){v[23048]=0;W(804,b|0,d+112|0,32)|0;j=v[23048];v[23048]=0;if((j|0)==1){break O}j=Yb(f,e);v[23048]=0;Q(805,j|0,d+112|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break O}e=e+1|0;if((m|0)!=(e|0)){continue}break}}h=h|16}v[23048]=0;f=Q(596,b|0,27174)|0;e=v[23048];v[23048]=0;if((e|0)==1){break C}if(f){v[23048]=0;f=U(376,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break N}u[d+112>>1]=(f>>>0)/20;f=x[a+480188>>1];v[23048]=0;u[d+40>>1]=f;f=Vc(d+112|0,d+40|0);e=v[23048];v[23048]=0;if((e|0)==1){break M}f=x[f>>1];if(f){e=0;while(1){v[23048]=0;W(612,b|0,((e<<5)+a|0)+480289|0,20)|0;m=v[23048];v[23048]=0;if((m|0)==1){break H}e=e+1|0;if((f|0)!=(e|0)){continue}break}}h=h|16}v[23048]=0;f=Q(250,b|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break C}if(f){f=v[b+8>>2];v[23048]=0;Q(613,a|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break G}h=(f|0)==v[b+8>>2]?h:h|16}if(!(h&16)){break J}if(!(h&4)){break K}v[a+1074304>>2]=17367040;v[23048]=0;f=Q(2,d+112|0,27179)|0;e=v[23048];v[23048]=0;if((e|0)==1){break L}Eb(l,f);vb(f);break J}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;vb(f);break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}if(!(h&2)){break J}v[a+1074304>>2]=18219008;v[23048]=0;f=Q(2,d+112|0,27200)|0;e=v[23048];v[23048]=0;if((e|0)==1){break F}Eb(l,f);vb(f)}V:{W:{X:{Y:{Z:{_:{$:{if((w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))==1852141647&(w[k+4|0]|w[k+5|0]<<8|(w[k+6|0]<<16|w[k+7|0]<<24))==542396493){v[23048]=0;f=Q(998,d+112|0,d+462|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break $}v[23048]=0;T(13,d+40|0,1,f|0);e=v[23048];v[23048]=0;if((e|0)==1){break _}v[23048]=0;e=U(999,d+40|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break Z}v[a+1074304>>2]=e;vb(d+40|0);t[a+1074364|0]=y[a+1074304>>2]<19007257?4:5;vb(f);h=24}if(!(!v[a+1074304>>2]|h&8)){t[a+1074364|0]=0;rv(a+1074308|0)}f=h&32;aa:{if(!f){break aa}t[a+1074364|0]=5;if(!c){v[23048]=0;Po(a+901404|0);c=v[23048];v[23048]=0;if((c|0)==1){break C}}if((w[d+474|0]|w[d+475|0]<<8)>>>0<260){break aa}v[23048]=0;W(458,a+1074308|0,4,1)|0;c=v[23048];v[23048]=0;if((c|0)==1){break C}}if(!hd(l)){break V}if(!(i&(h&256)>>>8)|g+1>>>0>1){break W}v[23048]=0;c=Q(2,d+112|0,27228)|0;g=v[23048];v[23048]=0;if((g|0)==1){break X}Eb(l,c);vb(c);break V}c=P()|0;O()|0;break j}c=P()|0;O()|0;break Y}c=P()|0;O()|0;vb(d+40|0)}vb(f);break j}c=P()|0;O()|0;break j}if(f){v[23048]=0;c=Q(2,d+112|0,27240)|0;g=v[23048];v[23048]=0;if((g|0)!=1){Eb(l,c);vb(c);break V}c=P()|0;O()|0;break j}v[23048]=0;c=Q(2,d+112|0,27268)|0;g=v[23048];v[23048]=0;if((g|0)==1){break E}Eb(l,c);vb(c)}t[d+8|0]=0;ba:{if(x[a+480192>>1]){v[23048]=0;c=Q(629,a|0,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break ba}t[d+8|0]=c}v[23048]=0;Y(630,a|0,b|0,1,d+8|0);b=v[23048];v[23048]=0;if((b|0)==1){break ba}c=a+1074304|0;e=v[c>>2];ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{if(w[d+8|0]){if(e>>>0>18284543){break pa}v[a+1074304>>2]=18284544;break pa}if(e>>>0<18284544){break oa}}v[23048]=0;b=Q(2,d+40|0,26938)|0;g=v[23048];v[23048]=0;if((g|0)==1){break na}v[23048]=0;S(1e3,d+96|0,c|0);g=v[23048];v[23048]=0;if((g|0)==1){break ma}v[23048]=0;T(3,d+112|0,b|0,d+96|0);g=v[23048];v[23048]=0;if((g|0)==1){break la}Eb(l,d+112|0);vb(d+112|0);vb(d+96|0);vb(b);e=v[c>>2]}qa:{if(e-1>>>0>19005952){break qa}v[23048]=0;b=a+484344|0;c=oe(b,254);g=v[23048];v[23048]=0;if((g|0)==1){break ba}if(!c){c=Qb(q);v[23048]=0;S(1001,c|0,254);c=v[23048];v[23048]=0;if((c|0)==1){break ba}}v[23048]=0;b=oe(b,255);c=v[23048];v[23048]=0;if((c|0)==1){break ba}if(b){break qa}b=Qb(q);v[23048]=0;c=v[23048];v[23048]=0;if((c|0)==1){break ba}v[23048]=0;fv(b,255,65535);b=v[23048];v[23048]=0;if((b|0)==1){break ba}}if(!w[d+383|0]){break ca}v[23048]=0;b=Q(2,d+112|0,27276)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ja}Eb(a+1300344|0,b);vb(b);v[23048]=0;b=Q(2,d+112|0,27297)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ia}Eb(a+1300356|0,b);vb(b);v[23048]=0;S(1003,d+40|0,27301);b=v[23048];v[23048]=0;if((b|0)==1){break ha}v[d+80>>2]=w[d+475|0];b=w[d+474|0];v[23048]=0;v[d+24>>2]=b;S(640,d+96|0,d+24|0);b=v[23048];v[23048]=0;if((b|0)==1){break ga}v[23048]=0;Y(623,d+112|0,d+40|0,d+80|0,d+96|0);b=v[23048];v[23048]=0;if((b|0)==1){break fa}Eb(a+1300380|0,d+112|0);vb(d+112|0);vb(d+96|0);Hb(d+40|0);v[23048]=0;b=Q(2,d+112|0,27322)|0;c=v[23048];v[23048]=0;if((c|0)==1){break da}Eb(a+1300392|0,b);break D}c=P()|0;O()|0;break j}c=P()|0;O()|0;break ka}c=P()|0;O()|0;vb(d+96|0)}vb(b);break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break ea}c=P()|0;O()|0;vb(d+96|0)}Hb(d+40|0);break j}c=P()|0;O()|0;break j}v[23048]=0;S(1003,d+40|0,27301);b=v[23048];v[23048]=0;ra:{sa:{ta:{ua:{if((b|0)!=1){v[d+80>>2]=w[d+475|0];b=w[d+474|0];v[23048]=0;v[d+24>>2]=b;S(640,d+96|0,d+24|0);b=v[23048];v[23048]=0;if((b|0)==1){break ua}v[23048]=0;Y(623,d+112|0,d+40|0,d+80|0,d+96|0);b=v[23048];v[23048]=0;if((b|0)==1){break ta}Eb(a+1300344|0,d+112|0);vb(d+112|0);vb(d+96|0);Hb(d+40|0);v[23048]=0;b=Q(2,d+112|0,27322)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ra}Eb(a+1300356|0,b);break D}c=P()|0;O()|0;break j}c=P()|0;O()|0;break sa}c=P()|0;O()|0;vb(d+96|0)}Hb(d+40|0);break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}vb(b);Eb(a+1300368|0,l);v[a+1300404>>2]=v[a+1074304>>2]?8:5;Yh(o);vb(l);break b}c=P()|0;O()|0}Yh(o);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0}vb(l);R(c|0);L()}e=1}gb=d+496|0;return e|0}function $ma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=gb-336|0;gb=d;yc(b);e=d+328|0;f=AD(b,e);if(!f){Sv(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!f){break x}if(!uW(d+328|0)){break x}if(!c){y=1;break x}C=Ni(d+304|0,b);v[23048]=0;S(709,d+288|0,C|0);b=v[23048];v[23048]=0;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{if((b|0)!=1){v[23048]=0;T(710,d+264|0,d+288|0,20041);b=v[23048];v[23048]=0;if((b|0)==1){break N}v[23048]=0;b=U(328,d+264|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}if(!b){break y}v[23048]=0;b=Q(711,d+264|0,d+168|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}if(!b){break y}v[23048]=0;S(428,a|0,16384);b=v[23048];v[23048]=0;if((b|0)==1){break E}v[a+480208>>2]=8;v[23048]=0;b=a+1074308|0;W(458,b|0,9,1)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}v[23048]=0;Q(459,b|0,21)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}v[23048]=0;Q(459,b|0,30)|0;b=v[23048];v[23048]=0;if((b|0)==1){break E}v[23048]=0;b=Q(2,d+112|0,19324)|0;e=v[23048];v[23048]=0;if((e|0)==1){break K}Eb(a+1300344|0,b);vb(b);v[23048]=0;b=Q(2,d+112|0,19336)|0;e=v[23048];v[23048]=0;if((e|0)==1){break J}Eb(a+1300356|0,b);vb(b);v[23048]=0;b=Q(2,d+152|0,19340)|0;e=v[23048];v[23048]=0;if((e|0)==1){break I}e=w[d+332|0];switch(e-16|0){case 1:break H;case 0:break M;default:break L}}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}v[23048]=0;Q(2,d+136|0,19355)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break F}break e}if(!e){break G}v[23048]=0;Q(2,d+136|0,19370)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}break F}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}v[23048]=0;Q(2,d+136|0,19353)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break F}break e}v[23048]=0;Q(2,d+136|0,19359)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}}v[23048]=0;T(3,d+112|0,b|0,d+136|0);e=v[23048];v[23048]=0;if((e|0)==1){break f}Eb(a+1300368|0,d+112|0);vb(d+112|0);vb(d+136|0);vb(b);v[a+1300404>>2]=5;v[23048]=0;df(d+152|0,3,d+168|0);b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;S(398,d+112|0,d+152|0);b=v[23048];v[23048]=0;if((b|0)==1){break g}Eb(a+1300308|0,d+112|0);vb(d+112|0);v[23048]=0;Mj(d+136|0,3,d+200|0);b=v[23048];v[23048]=0;if((b|0)==1){break h}v[23048]=0;S(398,d+152|0,d+136|0);b=v[23048];v[23048]=0;if((b|0)==1){break h}v[23048]=0;T(13,d+112|0,5,d+152|0);b=v[23048];v[23048]=0;if((b|0)==1){break i}Eb(a+1300320|0,d+112|0);vb(d+112|0);vb(d+152|0);v[a+480200>>2]=w[d+224|0]+1;G=a,H=Gd(w[d+225|0],1,255),v[G+480196>>2]=H;G=a,H=B(Gd(w[d+226|0],4,255),1e4),v[G+480204>>2]=H;b=a+484360|0;e=Qb(b);f=w[d+220|0]|w[d+221|0]<<8;v[23048]=0;ga(560,e|0,d+264|0,f|0,65535,65535)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}ff(Qb(b),w[d+222|0]|w[d+223|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[23048]=0;e=(b<<5)+a|0;f=e+480280|0;We(f);g=v[23048];v[23048]=0;if((g|0)==1){break j}g=b+d|0;h=w[g+227|0]<<1&254;u[e+480284>>1]=(h|0)==254?256:h;O:{if(t[g+227|0]<=-1){v[f>>2]=v[f>>2]|1024;break O}u[a+480188>>1]=b+1}v[23048]=0;S(713,d+264|0,e+480289|0);e=v[23048];v[23048]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[23048]=0;T(710,d+112|0,d+288|0,17741);b=v[23048];v[23048]=0;if((b|0)==1){break k}id(d+264|0,d+112|0);yb(d+112|0);v[23048]=0;b=U(247,d+264|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}v[23048]=0;ba(551,a+1300332|0,d+264|0,b|0,0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break E}v[23048]=0;T(710,d+112|0,d+288|0,21321);b=v[23048];v[23048]=0;if((b|0)==1){break l}id(d+264|0,d+112|0);yb(d+112|0);v[23048]=0;b=U(328,d+264|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}P:{if(b){v[23048]=0;T(710,d+112|0,d+288|0,16723);b=v[23048];v[23048]=0;if((b|0)==1){break m}v[23048]=0;i=U(373,d+264|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break n}Q:{if(!i){break Q}m=c&2;f=0;while(1){v[23048]=0;e=U(373,d+264|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break n}if(!e){break Q}v[23048]=0;b=Q(250,d+264|0,56)|0;g=v[23048];v[23048]=0;if((g|0)==1){break n}if(!b){break Q}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[23048]=0;b=B(e,104)+a|0;g=b+484380|0;S(372,g|0,0);h=v[23048];v[23048]=0;if((h|0)==1){break n}v[23048]=0;W(518,d+264|0,((e<<5)+a|0)+946300|0,32)|0;e=v[23048];v[23048]=0;if((e|0)==1){break n}v[23048]=0;W(521,d+264|0,b+484423|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break n}R:{if(w[d+332|0]<=15){v[23048]=0;e=U(340,d+264|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){break R}break n}v[23048]=0;e=U(376,d+264|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break n}}v[b+484404>>2]=e<<1;v[23048]=0;e=U(376,d+264|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break n}v[g>>2]=e;v[23048]=0;h=U(376,d+264|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=h;v[23048]=0;h=U(376,d+264|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break n}k=b+484388|0;v[k>>2]=h;if(h){j=b+484414|0;u[j>>1]=x[j>>1]|2;v[k>>2]=h+v[e>>2]}v[23048]=0;h=U(373,d+264|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break P}if(w[d+332|0]<=15){u[b+484410>>1]=h}v[23048]=0;h=U(373,d+264|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break n}j=8;if(h&1){j=b+484414|0;u[j>>1]=x[j>>1]|1;v[g>>2]=v[g>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[k>>2]=v[k>>2]>>>1;j=16}b=b+484414|0;u[b>>1]=x[b>>1]&65531|h<<1&4;b=Sc(d+152|0,j,1,0,((h&12)!=0)<<3);S:{if(!m){break S}v[23048]=0;W(384,b|0,g|0,d+112|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break S}break n}f=f+1|0;if(i>>>0>(f&255)>>>0){continue}break}}yb(d+112|0)}v[23048]=0;T(710,d+112|0,d+288|0,18761);b=v[23048];v[23048]=0;if((b|0)==1){break q}id(d+264|0,d+112|0);yb(d+112|0);v[23048]=0;b=U(328,d+264|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}T:{U:{V:{W:{if(b){j=dd(d+152|0);k=dd(d+136|0);m=dd(d+96|0);v[23048]=0;T(710,d+72|0,d+288|0,17750);b=v[23048];v[23048]=0;if((b|0)==1){break r}v[23048]=0;S(714,d+72|0,j|0);b=v[23048];v[23048]=0;if((b|0)==1){break s}yb(d+72|0);v[23048]=0;T(710,d+48|0,d+288|0,17744);b=v[23048];v[23048]=0;if((b|0)==1){break r}v[23048]=0;S(714,d+48|0,k|0);b=v[23048];v[23048]=0;if((b|0)==1){break t}yb(d+48|0);v[23048]=0;T(710,d+24|0,d+288|0,17734);b=v[23048];v[23048]=0;if((b|0)==1){break r}v[23048]=0;S(714,d+24|0,m|0);b=v[23048];v[23048]=0;if((b|0)==1){break u}yb(d+24|0);i=0;v[23048]=0;n=U(373,d+264|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break v}if(n){r=d+112|4;y=d+112|2;o=d+112|6;p=d+112|5;q=d+112|3;e=d+112|1;while(1){v[23048]=0;S(452,d+8|0,d+264|0);b=v[23048];v[23048]=0;if((b|0)==1){break A}l=rd(d+8|0);X:{Y:{b=d+8|0;Z:{if(!w[b|0]){break Z}f=w[l|0];v[23048]=0;f=Q(250,d+264|0,B(f,14)+32|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break p}if(!f){break Z}b=w[b|0];v[23048]=0;h=W(436,a|0,b|0,0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break p}if(h){break Y}}b=w[l|0];v[23048]=0;Q(370,d+264|0,B(b,14)+32|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break X}break p}v[23048]=0;W(518,d+264|0,h+492|0,32)|0;b=v[23048];v[23048]=0;if((b|0)==1){break p}if(!w[l|0]){break X}z=h+88|0;A=h+68|0;D=h+48|0;E=h+236|0;g=0;b=0;while(1){v[23048]=0;S(715,d+264|0,d+112|0);f=v[23048];v[23048]=0;if((f|0)==1){break w}_:{if(!w[d+112|0]|x[a+480190>>1]<w[d+112|0]){break _}f=e;if(w[e|0]>128){t[f|0]=128}if(w[e|0]>=(b&255)>>>0){while(1){f=w[d+112|0];G=ud(E,b&255),H=f,u[G>>1]=H;b=b+1|0;if(w[e|0]>=(b&255)>>>0){continue}break}}b=w[e|0];f=w[q|0];v[23048]=0;T(716,D|0,f|0,j|0);f=v[23048];v[23048]=0;if((f|0)==1){break w}f=w[p|0];v[23048]=0;T(716,A|0,f|0,k|0);f=v[23048];v[23048]=0;if((f|0)==1){break w}f=w[d+125|0];v[23048]=0;T(716,z|0,f|0,m|0);f=v[23048];v[23048]=0;if((f|0)==1){break w}v[h>>2]=(w[o|0]|w[o+1|0]<<8)+1>>>1;f=w[d+112|0];$:{if(w[q|0]&64){u[(B(f,104)+a|0)+484410>>1]=w[y|0];break $}s=(B(f,104)+a|0)+484414|0;u[s>>1]=x[s>>1]|32768}u[d+22>>1]=w[r|0]<<1;v[23048]=0;u[d+20>>1]=254;s=Vc(d+22|0,d+20|0);F=v[23048];v[23048]=0;if((F|0)==1){break W}b=b+1|0;f=B(f,104)+a|0;u[f+484408>>1]=x[s>>1];t[f+484418|0]=w[(w[d+123|0]&3)+19371|0];t[f+484419|0]=w[d+122|0];t[f+484420|0]=w[d+121|0];t[f+484421|0]=w[d+120|0];if(!(w[p|0]&64)){break _}f=f+484414|0;u[f>>1]=x[f>>1]|32}g=g+1|0;if(w[l|0]>(g&255)>>>0){continue}break}}i=i+1|0;if(n>>>0>(i&255)>>>0){continue}break}}ap(m);ap(k);ap(j)}y=1;k=nc(d+152|0);if(!(c&1)){break z}v[23048]=0;T(710,d+112|0,d+288|0,21076);b=v[23048];v[23048]=0;if((b|0)!=1){b=id(d+264|0,d+112|0);v[23048]=0;b=U(328,b|0)|0;c=v[23048];v[23048]=0;aa:{ba:{ca:{da:{ea:{fa:{if((c|0)!=1){yb(d+112|0);ga:{if(!b){break ga}v[23048]=0;c=U(340,d+264|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break fa}v[23048]=0;S(717,k|0,c+1|0);b=v[23048];v[23048]=0;if((b|0)==1){break fa}if(!c){break ga}b=1;while(1){v[23048]=0;e=U(340,d+264|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break ea}v[23048]=0;T(341,d+112|0,d+264|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break ea}id(Dg(k,b),d+112|0);e=(b|0)==(c|0);yb(d+112|0);b=b+1|0;if(!e){continue}break}}v[23048]=0;T(710,d+112|0,d+288|0,16720);b=v[23048];v[23048]=0;if((b|0)==1){break da}b=id(d+264|0,d+112|0);v[23048]=0;b=U(328,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ca}yb(d+112|0);if(!b){break aa}g=0;v[23048]=0;m=U(373,d+264|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break C}if(m){while(1){l=32;ha:{if(w[d+332|0]>=16){v[23048]=0;S(718,d+264|0,d+112|0);b=v[23048];v[23048]=0;if((b|0)==1){break V}if(!(w[d+112|0]>32|x[a+480188>>1]>=w[d+112|0])){u[a+480188>>1]=w[d+112|0]}l=w[d+112|0];if(!l){break ha}}b=0;while(1){v[23048]=0;c=U(340,d+264|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break U}if(!(!c|x[a+480188>>1]>(b&65535)>>>0)){u[a+480188>>1]=b+1}b=b+1|0;if((b&65535)>>>0<l>>>0){continue}break}}g=g+1|0;if(m>>>0>(g&65535)>>>0){continue}break}}v[23048]=0;Q(248,d+264|0,1)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break ba}break C}e=P()|0;O()|0;yb(d+112|0);break B}e=P()|0;O()|0;break B}e=P()|0;O()|0;break B}e=P()|0;O()|0;break B}e=P()|0;O()|0;yb(d+112|0);break B}v[23048]=0;n=a+484344|0;S(385,n|0,m|0);b=v[23048];v[23048]=0;if((b|0)==1){break C}if(!m){break aa}D=d+112|2;E=d+112|1;f=0;while(1){o=Jb(d+136|0);j=64;p=32;if(w[d+332|0]>=16){v[23048]=0;S(718,d+264|0,d+112|0);b=v[23048];v[23048]=0;if((b|0)==1){break D}p=w[d+112|0];b=w[E|0];v[23048]=0;sW(d+8|0,3,D);c=v[23048];v[23048]=0;if((c|0)==1){break D}v[23048]=0;S(398,d+96|0,d+8|0);c=v[23048];v[23048]=0;if((c|0)==1){break D}Eb(o,d+96|0);vb(d+96|0);j=b+1|0}v[23048]=0;b=W(386,n|0,f&65535,j|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break D}ia:{if(!b){v[23048]=0;Q(370,d+264|0,p<<1)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break ia}break D}b=Yb(n,f);v[23048]=0;Q(476,b|0,o|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break D}q=0;if(!p){break ia}while(1){v[23048]=0;b=U(340,d+264|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break D}ja:{if(!b){break ja}if(cf(k)>>>0<=b>>>0){break ja}r=q&65535;if(r>>>0>=x[a+480188>>1]){break ja}h=Dg(k,b);yc(h);c=0;while(1){v[23048]=0;b=Q(250,h|0,1)|0;e=v[23048];v[23048]=0;ka:{la:{ma:{na:{oa:{pa:{if((e|0)!=1){if(!b){break ja}b=Yb(n,f);v[23048]=0;b=Wc(b,c,r);e=v[23048];v[23048]=0;if((e|0)==1){break D}v[23048]=0;g=U(373,h|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break D}e=g>>>2|0;switch((g&3)-1|0){case 2:break ma;case 1:break na;case 0:break oa;default:break pa}}break D}c=(c+e|0)+1|0;break ka}if(!c){c=0;break ka}g=Yb(n,f);v[23048]=0;g=Wc(g,c-1|0,r);i=v[23048];v[23048]=0;if((i|0)!=1){while(1){i=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=i;t[b+1|0]=i>>>8;t[b+2|0]=i>>>16;t[b+3|0]=i>>>24;i=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=i;t[b+5|0]=i>>>8;c=c+1|0;if(j>>>0<=c>>>0){break ka}b=B(x[a+480188>>1],6)+b|0;i=e&255;e=e-1|0;if(i){continue}break ka}}break D}if(c>>>0<=e>>>0){break la}g=Yb(n,f);v[23048]=0;e=Wc(g,e,r);g=v[23048];v[23048]=0;if((g|0)==1){break T}g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;e=w[e+4|0]|w[e+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;break la}if(e&1){v[23048]=0;g=U(373,h|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break T}t[b|0]=g>>>0>120?-1:g}if(e&2){v[23048]=0;g=U(373,h|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break T}t[b+1|0]=g}l=0;g=0;if(e&4){v[23048]=0;g=U(373,h|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break D}}z=0;if(e&8){v[23048]=0;i=U(373,h|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break D}z=i>>>4|0;l=i&15}i=0;A=0;if(e&16){v[23048]=0;A=U(373,h|0)|0;s=v[23048];v[23048]=0;if((s|0)==1){break D}}if(e&32){v[23048]=0;i=U(373,h|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break D}}v[23048]=0;rW(b,g,l,z,A,i);b=v[23048];v[23048]=0;if((b|0)==1){break D}}c=c+1|0}if(c>>>0<j>>>0){continue}break}}q=q+1|0;if((q&65535)>>>0<p>>>0){continue}break}}vb(o);f=f+1|0;if((m|0)!=(f|0)){continue}break}}v[23048]=0;T(710,d+112|0,d+288|0,20048);b=v[23048];v[23048]=0;qa:{ra:{sa:{if((b|0)!=1){b=id(d+264|0,d+112|0);v[23048]=0;b=U(328,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break sa}yb(d+112|0);if(!b){break z}a=a+484344|0;if(!Te(a)){break z}while(1){v[23048]=0;b=Q(250,d+264|0,16)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ra}if(!b){break z}v[23048]=0;S(721,d+264|0,d+112|0);b=v[23048];v[23048]=0;if((b|0)==1){break qa}b=Yb(a,0);v[23048]=0;S(722,b|0,d+112|0);b=v[23048];v[23048]=0;if((b|0)==1){break qa}if(Te(a)){continue}break}break z}e=P()|0;O()|0;break B}e=P()|0;O()|0;yb(d+112|0);break B}e=P()|0;O()|0;break B}e=P()|0;O()|0;break B}e=P()|0;O()|0;break B}e=P()|0;O()|0;break o}e=P()|0;O()|0;break B}e=P()|0;O()|0;break B}break D}break n}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(o);break B}e=P()|0;O()|0}kd(k);break c}e=P()|0;O()|0;break o}kd(k)}yb(d+264|0);Cd(d+288|0);yb(C)}gb=d+336|0;return y|0}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;yb(d+24|0);break o}e=P()|0;O()|0;yb(d+48|0);break o}e=P()|0;O()|0;yb(d+72|0);break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break c}e=P()|0;O()|0}ap(m);ap(k);ap(j);break c}e=P()|0;O()|0;yb(d+112|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+152|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+136|0);break d}e=P()|0;O()|0}vb(b)}yb(d+264|0)}Cd(d+288|0)}yb(C);R(e|0);L()}function FJ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0;K=gb-144|0;gb=K;a:{b:{c:{if(d>>>0<=e>>>0){j=v[f>>2];N=g&4;M=N?-1:j+((d^-1)+e|0)|0;E=M+1|0;if(!(E&M)){break c}}v[f>>2]=0;v[c>>2]=0;k=-3;break b}F=e+j|0;D=v[c>>2];z=D+b|0;G=v[a+60>>2];r=v[a+40>>2];j=v[a+36>>2];A=v[a+32>>2];m=v[a+56>>2];i=v[a+4>>2];l=b;p=e;s=-1;k=-1;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{q=v[a>>2];switch(q|0){case 35:break i;case 17:break j;case 21:break k;case 37:break l;case 34:break m;case 42:break q;case 41:break r;case 53:break s;case 52:break t;case 51:break u;case 38:break v;case 27:break w;case 26:break x;case 25:break y;case 24:break z;case 23:break A;case 18:break B;case 16:break C;case 14:break D;case 11:break E;case 9:break F;case 7:break G;case 6:break H;case 3:break I;case 32:break J;case 5:break K;case 2:break M;case 1:break N;case 0:break O;case 36:break f;case 39:break g;case 10:break h;default:break d}}v[a+28>>2]=1;m=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;r=0;j=0;A=0;i=0;if(g&1){break N}break L}if((D|0)<=0){v[a>>2]=1;break e}v[a+8>>2]=w[b|0];l=b+1|0}if(l>>>0>=z>>>0){v[a>>2]=2;k=g&2?1:-4;break d}j=w[l|0];v[a+12>>2]=j;h=v[a+8>>2];k=(h&15)!=8|(((j|h<<8)>>>0)%31|j&32)!=0;j=1;l=l+1|0;if(!N){q=36;h=256<<(h>>>4);if(!(k|(h>>>0>32768|h>>>0>E>>>0))){break L}break f}q=36;if(k){break f}}h=0;break p}if((D|0)<=0){v[a>>2]=5;break e}l=b+1|0;m=w[b|0]<<i|m;i=i+8|0;h=2;break p}if((D|0)<=0){v[a>>2]=32;break e}l=b+1|0;m=w[b|0]<<i|m;C=j;i=i+8|0;break o}h=1;break p}h=4;break p}h=3;break p}h=7;break p}h=9;break p}h=10;break p}h=11;break p}h=12;break p}h=13;break p}h=14;break p}h=15;break p}h=16;break p}h=17;break p}h=8;break p}h=5;break p}h=6;break p}h=18;break p}n=2;break n}n=1;break n}P:while(1){Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{switch(h|0){case 0:j=C;if(i>>>0>2){break Fa}h=1;continue;case 17:break na;case 16:break oa;case 15:break pa;case 14:break qa;case 13:break ra;case 12:break sa;case 11:break ta;case 10:break ua;case 9:break va;case 8:break xa;case 7:break ya;case 6:break za;case 5:break Aa;case 4:break Ca;case 3:break Da;case 2:break Ea;case 1:break Ga;default:break ma}}while(1){if(l>>>0>=z>>>0){v[a>>2]=3;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<3){continue}break}l=h;C=j}j=m&7;v[a+20>>2]=j;H=1;h=j>>>1|0;v[a+24>>2]=h;i=i-3|0;m=m>>>3|0;k=0;j=C;switch(h|0){case 0:break la;case 1:break wa;case 3:break h;default:break ia}}h=i&-8;m=m>>>(i&7)|0;j=0;i=0;break ja}if(l>>>0<z>>>0){break Ba}v[a>>2]=7;k=g&2?1:-4;break d}while(1){if(l>>>0>=z>>>0){v[a>>2]=6;k=g&2?1:-4;break d}m=w[l|0]<<i|m;o=i>>>0>4294967287;k=l+1|0;l=k;h=i+8|0;i=h;if(o){continue}break}l=k;i=1;break ja}t[(a+j|0)+10528|0]=w[l|0];l=l+1|0;h=i;i=2;break ja}while(1){if(l>>>0>=z>>>0){v[a>>2]=51;k=g&2?1:-4;break d}m=w[l|0]<<i|m;o=i>>>0>4294967287;k=l+1|0;l=k;h=i+8|0;i=h;if(o){continue}break}l=k;break S}if(p>>>0<F>>>0){t[p|0]=A;j=j-1|0;p=p+1|0;h=i;break W}s=2;q=52;break f}if(p>>>0<F>>>0){break ka}s=2;q=9;break f}if(l>>>0>=z>>>0){v[a>>2]=38;k=g&2?1:-4;break d}h=F-p|0;k=z-l|0;h=h>>>0<k>>>0?h:k;h=h>>>0<j>>>0?h:j;j=j-h|0;p=hc(p,l,h)+h|0;l=h+l|0;break V}v[a+44>>2]=288;v[a+48>>2]=32;h=a+3552|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3560|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3568|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3576|0;v[h>>2]=84215045;v[h+4>>2]=84215045;Pb(a- -64|0,8,144);Pb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;break _}o=j+61616|0;while(1){if(l>>>0>=z>>>0){v[a>>2]=11;k=g&2?1:-4;break d}m=w[l|0]<<i|m;k=l+1|0;l=k;h=i+8|0;i=h;I=t[o|0];if(h>>>0<I>>>0){continue}break}l=k;k=j;i=h;j=1;break aa}while(1){if(l>>>0>=z>>>0){v[a>>2]=14;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<3){continue}break}l=h;h=1;break $}if(l>>>0>=z>>>0){v[a>>2]=16;k=g&2?1:-4;break d}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ha}break ga}while(1){if(l>>>0>=z>>>0){v[a>>2]=18;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(r>>>0>i>>>0){continue}break}O=A-16|0;l=h;h=3;break Z}if(l>>>0>=z>>>0){v[a>>2]=23;k=g&2?1:-4;break d}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break fa}break ea}if(p>>>0>=F>>>0){s=2;q=24;break f}t[p|0]=j;p=p+1|0;n=m;break Y}while(1){if(l>>>0>=z>>>0){v[a>>2]=25;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(r>>>0>i>>>0){continue}break}l=h;h=3;break X}if(l>>>0>=z>>>0){v[a>>2]=26;k=g&2?1:-4;break d}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break da}break ca}while(1){if(l>>>0>=z>>>0){v[a>>2]=27;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(r>>>0>i>>>0){continue}break}l=h;h=6;break X}if(p>>>0>=F>>>0){s=2;q=53;break f}t[p|0]=w[(G-A&M)+d|0];p=p+1|0;G=G+1|0;break ba}h=2;continue}h=8;continue}while(1){Ha:{Ia:{Ja:{Ka:{La:{switch(i|0){case 0:if(j>>>0>3){break Ka}if(!h){i=0;h=3;continue P}i=h;if(h>>>0>7){break Ia}h=4;continue P;case 1:t[(a+j|0)+10528|0]=m;h=h-8|0;m=m>>>8|0;break Ha;default:break La}}j=j+1|0;break Ja}i=h;j=x[a+10528>>1];if((j|0)==(x[a+10530>>1]^65535)){break W}break g}i=0;continue}i=1;continue}i=2;continue}}j=0;break aa}h=1;break Z}h=2;break Z}h=0;break X}h=1;break X}h=4;break X}h=5;break X}h=7;break X}while(1){Ma:{Na:{Oa:{if(!j){if(k>>>0>2){break Oa}j=k;I=t[j+61616|0];if(I>>>0<=i>>>0){break Ma}h=9;continue P}j=k<<2;v[(j+a|0)+44>>2]=v[j+61604>>2]+((-1<<I^-1)&m);k=k+1|0;i=i-I|0;m=m>>>I|0;break Na}j=0;Pb(a+7040|0,0,288);h=0;break $}j=0;continue}j=1;continue}}while(1){Pa:{Qa:{Ra:{if(!h){if(y[a+52>>2]<=j>>>0){break Ra}if(i>>>0>2){break Pa}h=10;continue P}t[(w[j+61584|0]+a|0)+7040|0]=m&7;j=j+1|0;i=i-3|0;m=m>>>3|0;break Qa}v[a+52>>2]=19;H=v[a+24>>2];C=j;break _}h=0;continue}h=1;continue}}h=0}while(1){Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{switch(h|0){case 0:j=0;if((H|0)<0){n=m;j=C;break Y}D=Pb(K,0,64);k=B(H,3488)+a|0;Pb(k+352|0,0,3200);q=v[a+24>>2];h=v[((q<<2)+a|0)+44>>2];if(h){while(1){o=D+(w[(j+k|0)- -64|0]<<2)|0;v[o>>2]=v[o>>2]+1;j=j+1|0;if((h|0)!=(j|0)){continue}break}}v[D+64>>2]=0;v[D+68>>2]=0;o=0;k=0;j=1;while(1){s=j<<2;j=j+1|0;s=v[s+D>>2];o=s+o<<1;v[(D- -64|0)+(j<<2)>>2]=o;k=k+s|0;if((j|0)!=16){continue}break};if(!((o|0)==65536|k>>>0<2)){j=C;break i}if(h){h=-1;E=0;J=B(H,3488)+a|0;while(1){q=w[(E+J|0)- -64|0];bb:{if(!q){break bb}k=(D- -64|0)+(q<<2)|0;j=v[k>>2];v[k>>2]=j+1;k=0;o=q;while(1){s=k;k=j&1|k<<1;j=j>>>1|0;o=o-1|0;if(o){continue}break}if(q>>>0<=10){if(k>>>0>1023){break bb}j=1<<q;o=q<<9|E;while(1){u[((k<<1)+J|0)+352>>1]=o;k=j+k|0;if(k>>>0<1024){continue}break}break bb}k=((k&1023)<<1)+J|0;j=u[k+352>>1];cb:{if(j){k=h;h=j;break cb}u[k+352>>1]=h;k=h-2|0}j=s>>>8&8388607;if(q>>>0>=12){while(1){j=j>>>1|0;o=(((j&1)+(h^-1)<<1)+J|0)+2400|0;h=u[o>>1];if(!h){u[o>>1]=k;h=k;k=h-2|0}q=q-1|0;if(q>>>0>11){continue}break}}u[(((j>>>1&1)+(h^-1)<<1)+J|0)+2400>>1]=E;h=k}E=E+1|0;q=v[a+24>>2];if(E>>>0<y[((q<<2)+a|0)+44>>2]){continue}break}}j=0;if((q|0)!=2){break Va}break Za;case 1:h=u[(((m&1023)<<1)+a|0)+7328>>1];db:{if((h|0)>=0){if((h>>9)-1>>>0>=i>>>0){break db}break Ya}if(i>>>0<11){break db}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<=-1){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>-1){break Ya}}h=11;continue P;case 2:k=u[(((m&1023)<<1)+a|0)+7328>>1];if((k|0)>=0){break $a}h=10;while(1){o=m>>>h|0;h=h+1|0;k=u[(((o&1)+(k^-1)<<1)+a|0)+9376>>1];if((k|0)<0){continue}break};break _a;default:break ab}}h=t[O+61624|0]+((-1<<r^-1)&m)|0;i=i-r|0;m=m>>>r|0;k=a+j|0;Pb(k+10532|0,(A|0)==16?w[k+10531|0]:0,h);j=h+j|0;break Za}h=k>>9;k=k&511}i=i-h|0;m=m>>>h|0;A=k;if(k>>>0>15){break Xa}t[(a+j|0)+10532|0]=A;j=j+1|0}k=v[a+48>>2];h=v[a+44>>2];o=k+h|0;if(o>>>0<=j>>>0){break Wa}if(i>>>0>14){break Ya}if((z-l|0)<=1){h=1;continue}m=w[l|0]<<i|m|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=2;continue}if(!((A|0)!=16|j)){A=16;j=0;break j}r=t[A+61604|0];if(r>>>0>i>>>0){break Ua}O=A-16|0;break Sa}if((j|0)!=(o|0)){break k}C=a+10532|0;hc(a- -64|0,C,h);hc(a+3552|0,h+C|0,k);q=v[a+24>>2];C=j}H=q-1|0;v[a+24>>2]=H;break Ta}h=12;continue P}h=0;continue}h=3;continue}}h=2}eb:while(1){fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{switch(h|0){case 0:h=u[(((m&1023)<<1)+a|0)+352>>1];ub:{if((h|0)>=0){if((h>>9)-1>>>0>=i>>>0){break ub}break fb}if(i>>>0<11){break ub}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<=-1){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>-1){break fb}}h=13;continue P;case 1:k=u[(((m&1023)<<1)+a|0)+352>>1];if((k|0)>=0){break sb}h=10;while(1){j=m>>>h|0;h=h+1|0;k=u[(((j&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break};j=k;break rb;case 3:break ib;case 4:break jb;case 5:break nb;case 6:break ob;case 2:break tb;default:break pb}}while(1){h=z-l|0;if(!((F-p|0)>1?(h|0)>=4:0)){if(i>>>0>14){m=n;break fb}if((h|0)<=1){m=n;h=0;continue eb}m=w[l|0]<<i|n|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0;break fb}vb:{if(i>>>0>14){m=i;h=l;break vb}m=i+16|0;n=(w[l|0]|w[l+1|0]<<8)<<i|n;h=l+2|0}j=u[(((n&1023)<<1)+a|0)+352>>1];wb:{if((j|0)<0){l=10;while(1){i=n>>>l|0;l=l+1|0;j=u[(((i&1)+(j^-1)<<1)+a|0)+2400>>1];if((j|0)<0){continue}break}break wb}l=j>>9}i=m-l|0;m=n>>>l|0;if(j&256){l=h;break qb}if(i>>>0>14){k=i}else{m=(w[h|0]|w[h+1|0]<<8)<<i|m;h=h+2|0;k=i+16|0}l=h;h=u[(((m&1023)<<1)+a|0)+352>>1];xb:{if((h|0)<0){n=10;while(1){i=m>>>n|0;n=n+1|0;h=u[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break xb}n=h>>9}t[p|0]=j;i=k-n|0;n=m>>>n|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=n;j=h;break qb}h=k>>9;j=k&511}i=i-h|0;m=m>>>h|0;if(j>>>0>255){break qb}h=14;continue P}C=256;k=j&511;h=256;if((k|0)==256){break U}r=0;h=m;o=k<<2;j=v[o+60044>>2];s=j;if(k-265>>>0>19){break hb}r=v[o+60172>>2];if(r>>>0>i>>>0){h=15;continue P}h=3;continue}if(!j){n=m;j=-1;break lb}j=j-1|0;h=18;continue P}i=i-r|0;n=m>>>r|0;A=((-1<<r^-1)&m)+A|0;break mb}r=u[(((m&1023)<<1)+a|0)+3840>>1];yb:{if((r|0)<0){h=10;while(1){k=m>>>h|0;h=h+1|0;r=u[(((k&1)+(r^-1)<<1)+a|0)+5888>>1];if((r|0)<0){continue}break}k=r;break yb}h=r>>9;k=r&511}i=i-h|0;m=m>>>h|0;h=k<<2;A=v[h+61328>>2];r=0;if(k-4>>>0>25){n=m;break mb}r=v[h+61456>>2];if(r>>>0<=i>>>0){break kb}h=17;continue P}G=p-d|0;if(!(!N|G>>>0>=A>>>0)){m=n;break l}h=(G-A&M)+d|0;if((h>>>0<p>>>0?p:h)+j>>>0>F>>>0){m=n;h=7;continue}if(j>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;j=j-3|0;if(j>>>0>2){continue}break}}if(!j){break lb}t[p|0]=w[h|0];if((j|0)!=1){t[p+1|0]=w[h+1|0]}p=j+p|0}h=2;continue}h=6;continue}h=u[(((m&1023)<<1)+a|0)+3840>>1];zb:{if((h|0)>=0){if((h>>9)-1>>>0>=i>>>0){break zb}break gb}if(i>>>0<11){break zb}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<=-1){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>-1){break gb}}h=16;continue P}i=i-r|0;h=m>>>r|0;s=((-1<<r^-1)&m)+j|0}j=s;m=h;if(i>>>0>14){break gb}if((z-l|0)<=1){h=4;continue}m=m|w[l|0]<<i|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=5;continue}h=1;continue}}if(h?j:0){break T}i=h}if(j){break Q}h=0}C=h;if(!(t[a+20|0]&1)){break R}break o}i=h;if(h>>>0>7){break S}h=5;continue}i=h-8|0;A=m&255;m=m>>>8|0;h=6;continue}h=0;continue}h=7;continue}}n=i&-8;if(!(!n|b>>>0>=l>>>0)){j=n-8|0;d=j>>>3|0;h=(b^-1)+l|0;d=d>>>0<h>>>0?d:h;n=j-(d<<3)|0;l=(d^-1)+l|0}if(!n){m=(((n&63)>>>0>=32?0:-1<<n)^-1)&m>>>(i&7);o=0;h=0;j=C;i=0;if(!(g&1)){break m}n=0;break n}ha(61628,61040,2787,61638);L()}while(1){Ab:{Bb:{Cb:{Db:{Eb:{Fb:{switch(n|0){case 0:if(o>>>0>3){j=o;i=h;break m}if(h){break Eb}i=0;j=o;n=1;continue;case 1:break Fb;default:break Db}}if(l>>>0<z>>>0){break Bb}v[a>>2]=42;k=g&2?1:-4;break d}j=o;i=h;if(h>>>0>7){break Cb}n=2;continue}while(1){if(l>>>0>=z>>>0){v[a>>2]=41;k=g&2?1:-4;break d}m=w[l|0]<<i|m;n=i>>>0>4294967287;d=l+1|0;l=d;h=i+8|0;i=h;if(n){continue}break}l=d;o=j}n=m&255;m=m>>>8|0;h=h-8|0;break Ab}n=w[l|0];l=l+1|0;o=j;h=i}v[a+16>>2]=v[a+16>>2]<<8|n;o=o+1|0;n=0;continue}}s=0;q=34;break f}q=37;s=-1;break f}q=21;s=-1;break f}q=17;s=-1;break f}q=35;s=-1;break f}q=10;s=-1;break f}q=39;s=-1}v[a>>2]=q;if(!(i>>>0<8|b>>>0>=l>>>0)){h=i-8|0;d=h>>>3|0;i=(b^-1)+l|0;d=d>>>0<i>>>0?d:i;l=(d^-1)+l|0;i=h-(d<<3)|0}k=s;break d}k=g&2?1:-4}v[a+4>>2]=i;v[a+60>>2]=G;v[a+40>>2]=r;v[a+36>>2]=j;v[a+32>>2]=A;v[a+56>>2]=(((i&63)>>>0>=32?0:-1<<i)^-1)&m;v[c>>2]=l-b;b=p-e|0;v[f>>2]=b;if(!(g&9)|(k|0)<0){break b}c=v[a+28>>2];l=c>>>16|0;i=c&65535;if(b){n=(b>>>0)%5552|0;while(1){h=0;if(n>>>0>=8){m=8;while(1){c=w[e|0]+i|0;d=c+w[e+1|0]|0;f=d+w[e+2|0]|0;j=f+w[e+3|0]|0;h=j+w[e+4|0]|0;C=h+w[e+5|0]|0;o=C+w[e+6|0]|0;i=o+w[e+7|0]|0;l=i+(o+(C+(h+(j+(f+(d+(c+l|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;if(n>>>0>(m|7)>>>0){m=m+8|0;continue}break}h=n&8184}j=h;m=e;if(h>>>0<n>>>0){while(1){i=w[m|0]+i|0;l=l+i|0;m=m+1|0;j=j+1|0;if((n|0)!=(j|0)){continue}break}e=(n-h|0)+e|0}b=b-n|0;l=(l>>>0)%65521|0;i=(i>>>0)%65521|0;n=5552;if(b){continue}break}}b=l<<16|i;v[a+28>>2]=b;if(k){break b}k=0;if(g&1){break a}}gb=K+144|0;return k}gb=K+144|0;return v[a+16>>2]==(b|0)?0:-2}function V5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=0,L=C(0),M=0,N=0,O=0,P=0,Q=0,R=0,S=C(0),T=0,U=0,V=C(0),W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=C(0);E=gb-17168|0;gb=E;v[E+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!hq(a+6152|0,b)){break c}h=jy(b,v[a+6148>>2])+gq(b)|0;v[E+17164>>2]=h;if((c|0)==(h|0)){h=c;break b}d:{if((h+4|0)<=(c|0)){if(hq(b,b+h|0)){break d}}v[E+17164>>2]=0;break c}if(h){break b}}j=b;r=Pb(a,0,6668)+6148|0;q=E+17164|0;i=c;e:{if((c|0)>=5){y=i-4|0;while(1){if(AJ(j)){s=jy(j,v[r>>2]);h=s+gq(j)|0;f=0;f:{g:{if(s){break g}l=4;H=k+4|0;while(1){if((y|0)<=((l<<1)+k|0)){break f}s=0;f=j+l|0;h:{if(!hq(j,f)){break h}g=l-gq(j)|0;A=gq(f)+g|0;if((i|0)<(A+(l+H|0)|0)){break h}if(!hq(j,f+A|0)){break h}v[r>>2]=g;s=g;h=l}f=!s;if(l>>>0>2302){break g}l=l+1|0;if(!s){continue}break}}if((i|0)<(h+k|0)|f){break f}A=j;H=i-k|0;g=0;f=0;i:{while(1){o=g;g=g+A|0;g=(o+jy(g,s)|0)+gq(g)|0;o=(f|0)!=0;if((H|0)<(g+4|0)){break i}o=0;if(!hq(A,g+A|0)){break i}f=f+1|0;if((f|0)!=10){continue}break}o=1}if(o){break e}}if(!((h|0)!=(i|0)|k)){k=0;h=i;break e}v[r>>2]=0}j=j+1|0;k=k+1|0;if((y|0)!=(k|0)){continue}break}}h=0;k=i}v[q>>2]=h;p=k;h=v[E+17164>>2];if((h+k|0)<=(c|0)?h:0){break b}v[e>>2]=p;p=0;break a}H=b+p|0;v[a+6152>>2]=w[H|0]|w[H+1|0]<<8|(w[H+2|0]<<16|w[H+3|0]<<24);v[e+4>>2]=p;v[e>>2]=h+p;v[e+8>>2]=w[H+3|0]>191?1:2;ba=e,ca=DJ(H),v[ba+12>>2]=ca;v[e+16>>2]=4-(w[H+1|0]>>>1&3);ba=e,ca=iy(H),v[ba+20>>2]=ca;if(!d){p=hy(H);break a}CJ(E+17152|0,H+4|0,h-4|0);if(!(t[H+1|0]&1)){de(E+17152|0,16)}j:{if(v[e+16>>2]==3){p=0;y=E+17152|0;h=E+3740|0;k=0;c=H;g=w[c+1|0];b=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[c+2|0]>>>2&3)|0;i=b-((b|0)!=0)|0;l=w[c+3|0]>191?1:2;k:{if(g&8){f=de(y,9);l=l<<1;k=de(y,l+7|0);break k}f=de(y,l|8)>>>l|0}b=B(i,40);q=b+61968|0;A=b+62288|0;j=B(i,23)+61776|0;l:{m:{while(1){g=w[c+3|0];i=de(y,12);u[h+4>>1]=i;b=de(y,9);u[h+6>>1]=b;if((b&65535)>>>0>288){break m}s=g>>>0>191?k<<4:k;ba=h,ca=de(y,8),t[ba+10|0]=ca;b=de(y,w[c+1|0]&8?4:9);t[h+13|0]=22;t[h+14|0]=0;v[h>>2]=j;u[h+8>>1]=b;n:{if(de(y,1)){b=de(y,2);t[h+11|0]=b;if(!(b&255)){break m}g=de(y,1);u[h+18>>1]=65287;t[h+12|0]=g;if(w[h+11|0]==2){b=h;o:{if(!(g&255)){v[h>>2]=q;t[h+18|0]=8;k=0;g=39;break o}v[h>>2]=A;k=w[c+1|0]&8?8:6;g=30}t[b+14|0]=g;t[h+13|0]=k;s=s&3855}b=de(y,10);ba=h,ca=de(y,3),t[ba+21|0]=ca;ba=h,ca=de(y,3),t[ba+22|0]=ca;ba=h,ca=de(y,3),t[ba+23|0]=ca;k=b<<5;break n}t[h+11|0]=0;t[h+12|0]=0;k=de(y,15);ba=h,ca=de(y,4),t[ba+18|0]=ca;b=de(y,3);t[h+20|0]=255;t[h+19|0]=b}t[h+17|0]=k&31;t[h+15|0]=k>>>10;t[h+16|0]=k>>>5&31;D=(i&65535)+D|0;b=h;p:{if(w[c+1|0]&8){i=de(y,1);break p}i=x[h+8>>1]>499}t[b+24|0]=i;ba=h,ca=de(y,1),t[ba+25|0]=ca;b=de(y,1);t[h+27|0]=s>>>12&15;t[h+26|0]=b;h=h+28|0;k=s<<4;l=l-1|0;if(l){continue}break}b=(v[y+4>>2]+D|0)>(v[y+8>>2]+(f<<3)|0)?-1:f;break l}b=-1}if(!((b|0)<0|v[E+17156>>2]>v[E+17160>>2])){s=E+17152|0;g=v[s+4>>2];i=v[s+8>>2];h=E+912|0;j=v[a+6144>>2];c=j-b|0;A=(b|0)<(j|0)?b:j;j=hc(h+12|0,(((c|0)>0?c:0)+a|0)+6156|0,A);c=(i-g|0)/8|0;hc(j+A|0,v[s>>2]+(v[s+4>>2]/8|0)|0,c);CJ(h,j,c+A|0);h=(b|0)<=v[a+6144>>2];if(h){Y=a+2304|0;p=v[e+8>>2];Z=E+8620|0;_=E+3852|0;b=0;while(1){$=Pb(_,0,4608);A=E+912|0;s=(B(B(b,p),28)+E|0)+3740|0;l=0;y=a;T=y+6152|0;if((p|0)>=1){j=A+7548|0;while(1){r=B(l,28)+s|0;D=x[r+4>>1];M=v[A+4>>2];P=(A+B(l,39)|0)+16156|0;k=A;i=j;c=l;o=gb-48|0;gb=o;m=r;R=!w[m+13|0]+(w[m+14|0]!=0)|0;U=w[m+25|0];f=o;N=f+44|0;q=T;q:{if(w[q+1|0]&8){F=w[m+27|0];g=w[x[m+8>>1]+62704|0];c=g&3;t[o+47|0]=c;t[o+46|0]=c;c=g>>>2|0;t[o+45|0]=c;t[o+44|0]=c;c=B(R,28)+62608|0;break q}c=(w[q+3|0]&16)>>>4&(c|0)!=0;O=c?12:0;K=x[m+8>>1]>>>c|0;while(1){G=1;g=3;while(1){c=g;I=w[(c+O|0)+62720|0];t[c+(o+44|0)|0]=((K|0)/(G|0)|0)%(I|0);g=c-1|0;G=B(G,I);if(c){continue}break}O=O+4|0;K=K-G|0;if((K|0)>-1){continue}break}F=-16;c=(B(R,28)+O|0)+62608|0}G=0;while(1){Q=w[c+G|0];if(Q){r:{if(F&8){hc(f,P,Q);break r}R=w[G+N|0];if(!R){Pb(f,0,Q);Pb(P,0,Q);break r}g=(F|0)>-1?-1:-1<<R^-1;O=0;while(1){I=de(k,R);t[O+P|0]=(g|0)==(I|0)?-1:I;t[f+O|0]=I;O=O+1|0;if((Q|0)!=(O|0)){continue}break}}F=F<<1;f=f+Q|0;P=P+Q|0;G=G+1|0;if((G|0)!=4){continue}}break}t[f+2|0]=0;t[f|0]=0;t[f+1|0]=0;I=w[m+14|0];s:{if(I){c=2-U|0;f=w[m+23|0]<<c;k=w[m+22|0]<<c;g=w[m+21|0]<<c;c=w[m+13|0];G=0;while(1){N=o+(c+G|0)|0;t[N|0]=g+w[N|0];t[N+1|0]=k+w[N+1|0];t[N+2|0]=f+w[N+2|0];G=G+3|0;if(I>>>0>G>>>0){continue}break}break s}if(!w[m+24|0]){break s}F=0;while(1){c=o+F|0;t[c+11|0]=w[c+11|0]+w[F+62744|0];F=F+1|0;if((F|0)!=10){continue}break}}L=gy(C(2048),((((w[q+3|0]&224)==96)<<1)-w[m+10|0]|0)+258|0);F=0;if((I|0)!=(0-w[m+13|0]|0)){c=U+1|0;while(1){ba=i+(F<<2)|0,da=gy(L,w[o+F|0]<<c),z[ba>>2]=da;F=F+1|0;if(F>>>0<w[m+14|0]+w[m+13|0]>>>0){continue}break}}gb=o+48|0;o=(A+B(l,2304)|0)+2940|0;c=j;D=D+M|0;J=C(0);X=0;k=A;i=v[k+4>>2];q=v[k>>2]+((i|0)/8|0)|0;g=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);f=(g<<24|g<<8&16711680|(g>>>8&65280|g>>>24))<<(i&7);n=i|-8;K=q+4|0;F=v[r>>2];G=x[r+6>>1];g=1;t:{if(!G){break t}while(1){i=r+X|0;g=w[i+15|0];W=(u[(g<<1)+67168>>1]<<1)+62784|0;O=w[i+18|0];u:{if(g>>>0>=16){M=w[g+67232|0];I=32-M|0;while(1){N=w[F|0]>>>1|0;q=(G|0)>(N|0)?N:G;J=z[c>>2];while(1){m=u[W+(f>>>26&62)>>1];if((m|0)<=-1){g=5;while(1){n=g+n|0;f=f<<g;g=m&7;m=u[W+((f>>>32-g|0)-(m<<16>>19)<<1)>>1];if((m|0)<0){continue}break}}Q=m&65535;i=Q>>>8|0;n=i+n|0;f=f<<i;P=1;while(1){aa=o;g=Q&15;v:{if((g|0)==15){m=f<<M;g=(f>>>I|0)+15|0;n=n+M|0;if((n|0)>=0){while(1){m=w[K|0]<<n|m;f=(n|0)>7;n=n-8|0;K=K+1|0;if(f){continue}break}}f=g;w:{if((f|0)<=128){S=z[(f<<2)+67328>>2];break w}U=f<<3;i=f;f=(f|0)<1024;U=f?U:i;R=U<<1&64;L=C(C((U&63)-R|0)/C((U&-64)+R|0));S=C(C(C(C(C(C(L*C(.2222222238779068))+C(1.3333333730697632))*L)+C(1))*(f?C(16):C(256)))*z[(R+U>>6<<2)+67328>>2])}S=C(C(S*J)*C(((m|0)>-1?1:-1)|0));break v}m=f;S=C(z[(((f>>>27&16|g)^16)<<2)+67264>>2]*J)}z[aa>>2]=S;Q=Q>>>4|0;o=o+4|0;i=(g|0)!=0;n=i+n|0;f=m<<i;i=P&1;P=0;if(i){continue}break}if((n|0)>-1){while(1){f=w[K|0]<<n|f;i=(n|0)>7;n=n-8|0;K=K+1|0;if(i){continue}break}}q=q-1|0;if(q){continue}break}G=G-N|0;c=c+4|0;F=F+1|0;if((O|0)<1){break u}O=O-1|0;if((G|0)>0){continue}break}break u}while(1){q=w[F|0]>>>1|0;P=(q|0)<(G|0)?q:G;J=z[c>>2];while(1){m=u[W+(f>>>26&62)>>1];if((m|0)<=-1){g=5;while(1){n=g+n|0;f=f<<g;g=m&7;m=u[W+((f>>>32-g|0)-(m<<16>>19)<<1)>>1];if((m|0)<0){continue}break}}m=m&65535;i=m>>>8|0;n=i+n|0;f=f<<i;g=1;while(1){i=m&15;z[o>>2]=z[(((i|f>>>27&16)^16)<<2)+67264>>2]*J;m=m>>>4|0;o=o+4|0;i=(i|0)!=0;n=i+n|0;f=f<<i;i=g&1;g=0;if(i){continue}break}if((n|0)>-1){while(1){f=w[K|0]<<n|f;i=(n|0)>7;n=n-8|0;K=K+1|0;if(i){continue}break}}P=P-1|0;if(P){continue}break}G=G-q|0;c=c+4|0;F=F+1|0;if((O|0)<1){break u}O=O-1|0;if((G|0)>0){continue}break}}X=X+1|0;if((G|0)>0){continue}break}g=1-G|0}while(1){x:{i=w[r+26|0]?67152:67120;m=w[i+(f>>>28|0)|0];if(!(m&8)){m=w[i+((f<<4>>>32-(m&3))+(m>>>3)|0)|0]}q=m&7;n=q+n|0;if((D|0)<((n+(K-v[k>>2]<<3)|0)-24|0)){break x}g=g-1|0;i=c;y:{if(g){break y}g=w[F|0]>>>1|0;if(!g){break x}F=F+1|0;J=z[c>>2];i=c+4|0}f=f<<q;if(m&128){z[o>>2]=(f|0)<0?C(-J):J;n=n+1|0;f=f<<1}if(m&64){z[o+4>>2]=(f|0)<0?C(-J):J;n=n+1|0;f=f<<1}g=g-1|0;c=i;z:{if(g){break z}g=w[F|0]>>>1|0;if(!g){break x}F=F+1|0;J=z[i>>2];c=i+4|0}if(m&32){z[o+8>>2]=(f|0)<0?C(-J):J;n=n+1|0;f=f<<1}if(m&16){z[o+12>>2]=(f|0)<0?C(-J):J;n=n+1|0;f=f<<1}if((n|0)>=0){while(1){f=w[K|0]<<n|f;i=(n|0)>7;n=n-8|0;K=K+1|0;if(i){continue}break}}o=o+16|0;continue}break}v[k+4>>2]=D;l=l+1|0;if((p|0)!=(l|0)){continue}break}}c=w[y+6155|0];A:{if(c&16){l=0;M=gb-16|0;gb=M;q=A+2940|0;f=q+2304|0;j=s;m=v[j>>2];o=w[j+14|0];r=o+w[j+13|0]|0;I=r;N=M+4|0;v[N+8>>2]=-1;v[N>>2]=-1;v[N+4>>2]=-1;if(r>>>0>=1){while(1){D=0;k=l+m|0;i=w[k|0];c=0;B:{if(!i){break B}C:{while(1){g=D<<2;if(z[g+f>>2]!=C(0)|z[(g|4)+f>>2]!=C(0)){break C}D=D+2|0;if(i>>>0>D>>>0){continue}break}c=i;break B}v[N+((l>>>0)%3<<2)>>2]=l;c=w[k|0]}f=((c&255)<<2)+f|0;l=l+1|0;if((I|0)!=(l|0)){continue}break}}if(w[j+13|0]){g=v[M+12>>2];i=v[M+8>>2];c=v[M+4>>2];c=(c|0)<(i|0)?i:c;c=(c|0)<(g|0)?g:c;v[M+12>>2]=c;v[M+8>>2]=c;v[M+4>>2]=c}m=A+16195|0;k=o?3:1;g=r-k|0;l=0;while(1){i=g+l|0;c=i-k|0;f=w[T+1|0]<<28>>31&3;D:{if((c|0)<=v[(M+4|0)+(l<<2)>>2]){break D}f=w[c+m|0]}c=f;t[i+m|0]=c;l=l+1|0;if((k|0)!=(l|0)){continue}break}l=M+4|0;k=u[j+36>>1]&1;f=0;g=v[j>>2];D=w[g|0];if(D){j=w[T+1|0]&8?7:64;c=g;while(1){i=w[T+3|0]&32;E:{F:{if(v[l+((f>>>0)%3<<2)>>2]>=(f|0)){break F}r=w[f+m|0];if(r>>>0>=j>>>0){break F}V=i?C(1.4142135381698608):C(1);G:{if(w[T+1|0]&8){i=r<<3;L=z[i+67856>>2];J=z[(i|4)+67856>>2];break G}L=gy(C(1),r+1>>>1<<k);i=r&1;J=i?C(1):L;L=i?L:C(1)}i=q;S=C(L*V);L=C(J*V);o=0;while(1){r=i+(o<<2)|0;V=z[r>>2];z[r+2304>>2]=V*L;z[r>>2]=V*S;o=o+1|0;if((o|0)!=(D|0)){continue}break}break E}if(!i){break E}zJ(q,D)}q=(w[c|0]<<2)+q|0;f=f+1|0;c=g+f|0;D=w[c|0];if(D){continue}break}}gb=M+16|0;break A}if((c&224)!=96){break A}zJ(A+2940|0,576)}if((p|0)>=1){i=A+7708|0;l=0;while(1){c=w[y+6153|0];I=(w[s+12|0]!=0)<<1<<((B((c>>>3&1)+(c>>>4&1)|0,3)+(w[y+6154|0]>>>2&3)|0)==2);k=(A+B(l,2304)|0)+2940|0;D=k;if(w[s+14|0]){j=((A+B(l,2304)|0)+B(I,72)|0)+2940|0;g=i;f=g;q=v[s>>2]+w[s+13|0]|0;n=w[q|0];if(n){c=j;while(1){m=n&255;o=m>>>0>1?m:1;T=m<<1;n=1;while(1){z[f>>2]=z[c>>2];z[f+4>>2]=z[(m<<2)+c>>2];r=T<<2;z[f+8>>2]=z[r+c>>2];c=c+4|0;f=f+12|0;if((n|0)!=(o|0)){n=n+1|0;continue}break}c=c+r|0;n=w[q+3|0];q=q+3|0;if(n){continue}break}}hc(j,g,f-g|0);c=I-1|0}else{c=31}if((c|0)>=1){while(1){g=0;while(1){f=g<<2;j=f+D|0;r=j;J=z[f+67920>>2];V=z[j+72>>2];S=z[f+67952>>2];j=(17-g<<2)+D|0;L=z[j>>2];z[r+72>>2]=C(J*V)-C(S*L);z[j>>2]=C(S*V)+C(J*L);g=g+1|0;if((g|0)!=8){continue}break}D=D+72|0;g=(c|0)>1;c=c-1|0;if(g){continue}break}}c=k;f=y+B(l,1152)|0;g=w[s+11|0];if(I){yJ(c,f,67984,I);f=B(I,36)+f|0;c=B(I,72)+c|0}H:{if((g|0)==2){o=gb-80|0;gb=o;g=32-I|0;if((g|0)>=1){T=o|8;r=o|4;while(1){q=hc(o,c,72);j=v[f+20>>2];v[c+16>>2]=v[f+16>>2];v[c+20>>2]=j;j=v[f+12>>2];v[c+8>>2]=v[f+8>>2];v[c+12>>2]=j;j=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=j;j=f+24|0;fy(q,c+24|0,j);fy(r,c+48|0,j);fy(T,f,j);c=c+72|0;f=f+36|0;j=(g|0)>1;g=g-1|0;if(j){continue}break}}gb=o+80|0;break H}yJ(c,f,B((g|0)==3,72)+67984|0,32-I|0)}f=0;k=k+72|0;while(1){g=1;while(1){c=(g<<2)+k|0;z[c>>2]=-z[c>>2];c=g>>>0<16;g=g+2|0;if(c){continue}break}k=k+144|0;c=f>>>0<30;f=f+2|0;if(c){continue}break}s=s+28|0;l=l+1|0;if((p|0)!=(l|0)){continue}break}}BJ(Y,$,18,v[e+8>>2],d,Z);p=v[e+8>>2];d=B(p,1152)+d|0;b=b+1|0;if(b>>>0<(w[H+1|0]&8?2:1)>>>0){continue}break}}b=a;j=E+912|0;d=v[j+8>>2]>>>3|0;c=v[j+4>>2]+7>>>3|0;g=d-c|0;i=(g|0)>511;e=i?511:g;if((g|0)>=1){kh(b+6156|0,(j+(i?d-511|0:c)|0)+12|0,e)}v[b+6144>>2]=e;break j}qt(a);break a}i=E+17152|0;p=0;k=0;s=0;b=E;A=b;g=0;I:{J:{K:{c=H;h=w[c+3|0];j=h>>>6|0;switch(j-1|0){case 2:break I;case 0:break K;default:break J}}g=(h>>>2&12)+4|0;break I}g=32}h=w[c+1|0];L:{if((h&6)==6){h=32;c=69388;break L}if(!(h&8)){h=30;c=69391;break L}h=w[c+2|0]>>>2&3;c=iy(c)>>>((j|0)!=3)|0;c=c?c:192;if(c>>>0<=55){h=(h|0)==2?12:8;c=69412;break L}h=(h|0)!=1?c>>>0>95?30:27:27;c=69400}t[A+768|0]=h;t[A+769|0]=(g|0)>(h|0)?h:g;h=c;M:{if(!w[b+768|0]){break M}f=69296;while(1){if((s|0)==(p|0)){f=w[h|0]+69296|0;s=w[h+2|0]+s|0;k=w[h+1|0];h=h+3|0}c=p<<1;j=w[de(i,k)+f|0];t[(c+b|0)+770|0]=j;D=w[b+769|0];if(p>>>0<D>>>0){j=w[de(i,k)+f|0];D=w[b+769|0]}t[(b+(c|1)|0)+770|0]=D?j:0;j=w[b+768|0];p=p+1|0;if(j>>>0>p>>>0){continue}break}if(!j){k=j<<1;break M}p=0;while(1){c=b+p|0;N:{if(!w[c+770|0]){h=6;break N}if((w[H+1|0]&6)==6){h=2;break N}h=de(i,2);j=w[b+768|0]}t[c+834|0]=h;k=j<<1&510;p=p+1|0;if(k>>>0>p>>>0){continue}break}}f=b+770|0;H=b+834|0;c=b;g=0;if((k|0)>=1){while(1){j=w[f|0];h=0;O:{if(!j){break O}h=19>>>w[g+H|0]&3|4}f=f+1|0;A=B(j,3)-6|0;l=4;L=C(0);while(1){if(h&l){j=de(i,6);s=(j|0)/3|0;L=C(z[(A+(j-B(s,3)|0)<<2)+69424>>2]*C(2097152>>>s|0))}z[c>>2]=L;c=c+4|0;l=l>>>1|0;if(l){continue}break}g=g+1|0;if((k|0)!=(g|0)){continue}break}}p=w[b+769|0];c=w[b+768|0];if(p>>>0<c>>>0){while(1){t[(b+(p<<1|1)|0)+770|0]=0;p=p+1|0;if((c|0)!=(p|0)){continue}break}}p=0;A=Pb(E+3852|0,0,4608);q=a+2304|0;s=E+8620|0;c=0;P:{while(1){H=((c<<2)+E|0)+3852|0;y=E+17152|0;r=v[e+16>>2]|1;D=0;i=E;l=w[i+768|0];b=576;while(1){Q:{if(!(l&255)){l=0;break Q}f=H+(B(r,D)<<2)|0;g=0;while(1){h=b;k=w[(g+i|0)+770|0];R:{if(!k){break R}if(k>>>0<=16){if((r|0)<1){break R}j=(-1<<k-1)+1|0;b=0;while(1){ba=(b<<2)+f|0,da=C(de(y,k)+j|0),z[ba>>2]=da;b=b+1|0;if((r|0)!=(b|0)){continue}break}break R}j=2<<k-17;k=j|1;b=de(y,(k-(j>>>3|0)|0)+2|0);if((r|0)<1){break R}j=j>>>1|0;l=0;while(1){o=b;b=(b>>>0)/(k>>>0)|0;z[(l<<2)+f>>2]=(o-B(k,b)|0)-j|0;l=l+1|0;if((r|0)!=(l|0)){continue}break}}b=18-h|0;f=(h<<2)+f|0;g=g+1|0;l=w[i+768|0];if(g>>>0<l<<1>>>0){continue}break}}D=D+1|0;if((D|0)!=4){continue}break}c=(r<<2)+c|0;if((c|0)==12){j=(p<<2)+E|0;b=A;c=E;i=w[c+769|0];h=b+B(i,72)|0;hc(h+2304|0,h,B(w[c+768|0]-i|0,72));if(w[c+768|0]){l=0;while(1){k=0;while(1){h=(k<<2)+b|0;z[h>>2]=z[h>>2]*z[j>>2];h=h+2304|0;z[h>>2]=z[h>>2]*z[j+12>>2];k=k+1|0;if((k|0)!=12){continue}break}j=j+24|0;b=b+72|0;l=l+1|0;if(l>>>0<w[c+768|0]){continue}break}}BJ(q,A,12,v[e+8>>2],d,s);Pb(A,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[E+17156>>2]<=v[E+17160>>2]){p=p+1|0;if((p|0)==3){break P}continue}break}qt(a);p=0;break a}h=1}p=B(hy(a+6152|0),h)}gb=E+17168|0;return p|0}function oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Y=0;f=gb-400|0;gb=f;yc(b);e=gb-32|0;gb=e;j=f+192|0;YT(e+24|0,j);g=xb(e+24|0);i=v[e+28>>2];k=v[e+24>>2];v[e+8>>2]=k;v[e+12>>2]=i;v[e>>2]=k;v[e+4>>2]=i;i=b;fc(e+16|0,i,e);k=xb(e+16|0);if((k|0)==(g|0)){Vb(i,xb(e+24|0))}gb=e+32|0;i=(g|0)==(k|0);if(!i){XT(j)}a:{if(!i){break a}if(!dU(f+192|0)){break a}if(!c){d=1;break a}Ed(a,134217728);of(f+136|0,26288);v[23048]=0;o=f+192|4;T(921,f+8|0,f+136|0,o|0);d=v[23048];v[23048]=0;b:{c:{d:{e:{f:{g:{h:{if((d|0)!=1){Eb(a+1300344|0,f+8|0);vb(f+8|0);Hb(f+136|0);d=Tb(f+8|0,26312);Eb(a+1300356|0,d);vb(d);v[a+480188>>2]=4;v[a+1300404>>2]=2;X=a,Y=Ib(w[f+328|0]|w[f+329|0]<<8),v[X+480196>>2]=Y;d=Ib(w[f+332|0]|w[f+333|0]<<8);v[a+480260>>2]=56;v[a+480264>>2]=13696;X=a,Y=cU(d),v[X+480204>>2]=Y;Hr(Qb(a+484360|0),f+200|0,w[f+192|6]);r=a+480190|0;p=dd(f+176|0);q=nc(f+160|0);i:{j:{k:{l:{m:{n:{if(Ib(w[f+392|0]|w[f+393|0]<<8)){while(1){v[23048]=0;d=U(465,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break h}u[f+112>>1]=d;if((d-1&65535)>>>0>=3999){break c}d=Ib(w[f+394|0]|w[f+395|0]<<8);if((Ib(w[o|0]|w[o+1|0]<<8)|0)==2){v[23048]=0;d=U(474,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break i}d=d-2|0}v[23048]=0;T(341,f+8|0,b|0,d|0);d=v[23048];v[23048]=0;o:{p:{q:{if((d|0)!=1){v[23048]=0;d=Le(r,f+112|0);i=v[23048];v[23048]=0;if((i|0)==1){break q}C=x[d>>1];u[a+480190>>1]=C;v[23048]=0;i=B(x[f+112>>1],104)+a|0;e=i+484380|0;S(372,e|0,1);d=v[23048];v[23048]=0;r:{if((d|0)==1){break r}if(Ib(w[o|0]|w[o+1|0]<<8)>>>0>1){break p}v[23048]=0;S(922,f+8|0,i+484423|0);d=v[23048];v[23048]=0;if((d|0)==1){break r}v[23048]=0;Q(370,f+8|0,1)|0;d=v[23048];v[23048]=0;if((d|0)==1){break r}v[23048]=0;W(374,f+8|0,((x[f+112>>1]<<5)+a|0)+946300|0,30)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break o}}e=P()|0;O()|0;break f}e=P()|0;O()|0;break e}e=P()|0;O()|0;break f}d=Jb(f+136|0);v[23048]=0;W(573,f+8|0,d|0,257)|0;g=v[23048];v[23048]=0;s:{t:{if((g|0)==1){break t}v[23048]=0;Q(355,i+484423|0,d|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break t}v[23048]=0;Q(370,f+8|0,1)|0;g=v[23048];v[23048]=0;if((g|0)==1){break t}v[23048]=0;W(573,f+8|0,d|0,31)|0;g=v[23048];v[23048]=0;if((g|0)==1){break t}v[23048]=0;Q(354,((x[f+112>>1]<<5)+a|0)+946300|0,d|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break t}if(!(v[f+16>>2]&1)){break s}v[23048]=0;Q(370,f+8|0,1)|0;g=v[23048];v[23048]=0;if((g|0)!=1){break s}}e=P()|0;O()|0;vb(d);break f}vb(d)}v[23048]=0;S(923,f+8|0,f+136|0);d=v[23048];v[23048]=0;if((d|0)==1){break n}v[23048]=0;bU(f+136|0,e);d=v[23048];v[23048]=0;if((d|0)==1){break n}if((Ib(w[o|0]|w[o+1|0]<<8)|0)==2){t[i+484417|0]=w[f+154|0]<<3}u:{if(!Ib(w[o|0]|w[o+1|0]<<8)){break u}v[23048]=0;S(369,q|0,C|0);d=v[23048];v[23048]=0;if((d|0)==1){break n}v[23048]=0;S(925,p|0,C|0);d=v[23048];v[23048]=0;if((d|0)==1){break n}g=Id(p,x[f+112>>1]-1|0);Rd(g);v[23048]=0;e=U(465,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break j}v[23048]=0;d=Q(250,b|0,e<<3)|0;j=v[23048];v[23048]=0;if((j|0)==1){break j}if(!d){break l}v[23048]=0;S(926,g|0,e|0);d=v[23048];v[23048]=0;if((d|0)==1){break j}d=0;v[f+128>>2]=0;if(!e){if(!(w[i+484414|0]&2)){break u}d=v[i+484384>>2];v[f+120>>2]=d;i=v[i+484388>>2];v[23048]=0;v[f+124>>2]=i-d;S(927,g|0,f+120|0);d=v[23048];v[23048]=0;if((d|0)!=1){break u}e=P()|0;O()|0;break f}while(1){v[23048]=0;i=U(474,b|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break k}v[23048]=0;v[f+120>>2]=i;i=U(474,b|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break k}v[23048]=0;v[f+124>>2]=i;S(927,g|0,f+120|0);i=v[23048];v[23048]=0;if((i|0)==1){break k}d=d+1|0;if(e>>>0>(d&65535)>>>0){continue}break}}yb(f+8|0);m=m+1|0;if(Ib(w[f+392|0]|w[f+393|0]<<8)>>>0>(m&65535)>>>0){continue}break}}D=128;if(Ib(w[o|0]|w[o+1|0]<<8)){break m}v[23048]=0;D=U(465,b|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break m}e=P()|0;O()|0;break e}e=P()|0;O()|0;break f}m=a+480188|0;F=w[f+192|7];u[f+118>>1]=4;v:{w:{x:{if(!Ib(w[o|0]|w[o+1|0]<<8)){e=x[m>>1];break x}i=v[b+8>>2];y:{if(!D){break y}while(1){v[23048]=0;d=U(465,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break w}if((d|0)==65535){break y}v[23048]=0;F=U(465,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break w}v[23048]=0;d=U(465,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break w}v[23048]=0;u[f+118>>1]=d;d=Le(m,f+118|0);e=v[23048];v[23048]=0;if((e|0)==1){break w}u[m>>1]=x[d>>1];v[23048]=0;Q(370,b|0,B(x[f+118>>1],F)<<2)|0;d=v[23048];v[23048]=0;if((d|0)==1){break w}h=h+1|0;if((h&65535)>>>0<D>>>0){continue}break}}d=0;v[23048]=0;Q(248,b|0,i|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break v}e=x[m>>1];if(e>>>0>127){break b}}v[23048]=0;H=Q(928,f+136|0,e&65535)|0;d=v[23048];v[23048]=0;if((d|0)!=1){I=Ib(w[f+330|0]|w[f+331|0]<<8);z:{if(!D){break z}M=a+484344|0;V=c&1;i=0;m=0;while(1){d=m;if(Ib(w[o|0]|w[o+1|0]<<8)){v[23048]=0;d=U(465,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}if((d|0)==65535){break z}v[23048]=0;F=U(465,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}v[23048]=0;e=U(465,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break g}u[f+118>>1]=e}G=F&65535;A:{B:{C:{if(!V){break C}v[23048]=0;N=d&65535;d=W(386,M|0,N|0,G|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}if(!d){break C}s=0;if(G){break B}break A}v[23048]=0;Q(370,b|0,B(x[f+118>>1],G)<<2)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break A}break g}while(1){d=Yb(M,N);v[23048]=0;j=Of(d,s);d=v[23048];v[23048]=0;D:{if((d|0)!=1){e=0;z=0;E:{F:{switch((I&3)-1|0){case 0:z=!(s&3);break E;case 1:z=!(s&1);break E;case 2:break F;default:break E}}z=(s&3)!=3}J=0;if(!x[f+118>>1]){break D}while(1){d=v[H>>2];v[23048]=0;S(571,f+120|0,b|0);g=v[23048];v[23048]=0;if((g|0)==1){break g}g=B(e,9)+d|0;d=rd(f+120|0);A=Df(f+120|0);k=Ri(f+120|0);l=j+B(e,6)|0;t[l+1|0]=w[f+120|0];d=w[d|0];t[l|0]=d;h=w[k|0];t[l+5|0]=h;k=l+5|0;if(d){t[l|0]=d+25;t[g+8|0]=0;t[g|0]=0;t[g+1|0]=0;t[g+2|0]=0;t[g+3|0]=0;t[g+4|0]=0;t[g+5|0]=0;t[g+6|0]=0;t[g+7|0]=0;h=w[k|0]}n=h&255;K=w[A|0];G:{if(K>>>0>=240){d=n|(K&15)<<8;if(d){v[23048]=0;d=Xm(+(cU(d)>>>0)*1e-4);h=v[23048];v[23048]=0;if((h|0)!=1){t[k|0]=d;t[l+3|0]=17;break G}break g}t[l+3|0]=0;break G}E=n<<4;A=n>>>4|0;d=E|A;H:{switch(K|0){case 0:d=j+B(e,6)|0;if(h&255){t[d+3|0]=1;break G}t[d+3|0]=0;break G;case 1:t[(j+B(e,6)|0)+3|0]=2;break G;case 2:t[(j+B(e,6)|0)+3|0]=3;break G;case 3:v[23048]=0;t[f+8|0]=15;d=$b(k,f+8|0);h=v[23048];v[23048]=0;if((h|0)!=1){t[g|0]=w[d|0]|16;t[g+7|0]=0;t[g+1|0]=0;t[g+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G}break g;case 4:v[23048]=0;t[f+8|0]=15;d=$b(k,f+8|0);h=v[23048];v[23048]=0;if((h|0)!=1){t[g|0]=w[d|0]|32;t[g+7|0]=0;t[g+1|0]=0;t[g+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G}break g;case 5:t[g+7|0]=0;t[g+2|0]=0;t[g+1|0]=h;t[g|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G;case 6:t[g+7|0]=0;t[g+2|0]=h;t[g|0]=0;t[g+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G;case 7:t[(j+B(e,6)|0)+3|0]=23;i=0;break G;case 8:t[(j+B(e,6)|0)+3|0]=0;i=d;break G;case 9:t[(j+B(e,6)|0)+3|0]=19;v[23048]=0;t[f+8|0]=15;d=$b(k,f+8|0);h=v[23048];v[23048]=0;if((h|0)!=1){t[k|0]=w[d|0]|16;break G}break g;case 10:t[(j+B(e,6)|0)+3|0]=19;v[23048]=0;t[f+8|0]=15;d=$b(k,f+8|0);h=v[23048];v[23048]=0;if((h|0)!=1){t[k|0]=w[d|0]|32;break G}break g;case 11:t[g+3|0]=d;t[(j+B(e,6)|0)+3|0]=0;break G;case 12:d=j+B(e,6)|0;t[d+4|0]=h;t[d+2|0]=1;t[g+3|0]=0;t[d+3|0]=0;break G;case 13:d=j+B(e,6)|0;I:{J:{if(n&240){t[(j+B(e,6)|0)+2|0]=4;E=(h&240)>>>4|0;break J}if(!(n&15)){break I}t[(j+B(e,6)|0)+2|0]=3;E=h&15}t[d+4|0]=E}t[g+3|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G;case 14:t[(j+B(e,6)|0)+3|0]=19;t[k|0]=!(h&255);break G;case 15:t[(j+B(e,6)|0)+3|0]=16;t[k|0]=(h&240)>>>4;I=h&15;break G;case 16:t[g+5|0]=0;t[g+4|0]=h;t[(j+B(e,6)|0)+3|0]=0;break G;case 17:t[g+6|0]=n&15?h:0;t[(j+B(e,6)|0)+3|0]=0;break G;case 18:t[(j+B(e,6)|0)+3|0]=14;break G;case 19:t[g+8|0]=0;t[g+7|0]=h;t[g+2|0]=0;t[g|0]=0;t[g+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G;case 20:t[(j+B(e,6)|0)+3|0]=12;break G;case 22:K:{d=w[l+1|0];L:{if(!d){break L}if(Gc(p)>>>0<d>>>0){break L}d=Id(p,d-1|0);h=h-1|0;t[k|0]=h;v[23048]=0;Q(930,f+8|0,0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break g}v[f+112>>2]=9;d=Gc(d);v[23048]=0;v[f+4>>2]=d;d=Gb(f+112|0,f+4|0);n=v[23048];v[23048]=0;if((n|0)==1){break K}if(y[d>>2]<=(h&255)>>>0){break L}d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}t[(j+B(e,6)|0)+3|0]=0;break G}break g;case 23:d=w[l+1|0];M:{if(!d){break M}if(Gc(p)>>>0<d>>>0){break M}d=Id(p,d-1|0);h=h-1|0;t[k|0]=h;h=h&255;if(Gc(d)>>>0<=h>>>0){break M}N:{if(x[Id(d,h)+8>>1]){break N}if(!Zh(a)){h=w[k|0];break N}n=x[r>>1]+1|0;u[r>>1]=n;h=w[k|0];X=Id(d,h),Y=n,u[X+8>>1]=Y}X=l,Y=w[Id(d,h)+8|0],t[X+1|0]=Y}t[(j+B(e,6)|0)+3|0]=0;break G;case 24:O:{d=w[l+1|0];P:{if(!d){break P}if(Gc(p)>>>0<d>>>0){break P}d=Id(p,d-1|0);h=h-1|0;t[k|0]=h;v[23048]=0;Q(930,f+8|0,0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break g}v[f+112>>2]=9;d=Gc(d);v[23048]=0;v[f+4>>2]=d;d=Gb(f+112|0,f+4|0);n=v[23048];v[23048]=0;if((n|0)==1){break O}if(y[d>>2]>(h&255)>>>0){d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}Q:{if(x[sc(q,w[l+1|0]-1|0)>>1]){break Q}if(!Zh(a)){break Q}d=x[r>>1]+1|0;u[r>>1]=d;X=sc(q,w[l+1|0]-1|0),Y=d,u[X>>1]=Y}X=l,Y=w[sc(q,w[l+1|0]-1|0)|0],t[X+1|0]=Y}t[(j+B(e,6)|0)+3|0]=0;break G}break g;case 25:d=w[l+1|0];R:{if(!d){break R}if(Gc(p)>>>0<d>>>0){break R}d=Id(p,d-1|0);h=h-1|0;t[k|0]=h;h=h&255;if(Gc(d)>>>0<=h>>>0){break R}S:{if(x[Id(d,h)+10>>1]){break S}if(!Zh(a)){h=w[k|0];break S}n=x[r>>1]+1|0;u[r>>1]=n;h=w[k|0];X=Id(d,h),Y=n,u[X+10>>1]=Y}X=l,Y=w[Id(d,h)+10|0],t[X+1|0]=Y}t[(j+B(e,6)|0)+3|0]=0;break G;case 29:t[(j+B(e,6)|0)+3|0]=11;t[k|0]=d;if(n&15){t[k|0]=E|15;break G}if(!A){break G}t[k|0]=A|240;break G;case 32:if(n&240){t[g+3|0]=A;t[(j+B(e,6)|0)+3|0]=0;break G}t[(j+B(e,6)|0)+3|0]=19;t[k|0]=h&15|192;break G;case 33:t[(j+B(e,6)|0)+3|0]=19;v[23048]=0;t[f+8|0]=15;d=$b(k,f+8|0);h=v[23048];v[23048]=0;if((h|0)!=1){t[k|0]=w[d|0]|208;break G}break g;case 34:t[(j+B(e,6)|0)+3|0]=19;v[23048]=0;t[f+8|0]=15;d=$b(k,f+8|0);h=v[23048];v[23048]=0;if((h|0)!=1){t[k|0]=w[d|0]|144;break G}break g;case 73:t[(j+B(e,6)|0)+3|0]=10;break G;case 78:if((h&112|128)==224){t[(j+B(e,6)|0)+3|0]=19;break G}t[(j+B(e,6)|0)+3|0]=0;break G;case 79:d=j+B(e,6)|0;if((h&255)>>>0<=31){t[d+3|0]=16;I=0;break G}t[d+3|0]=17;break G;default:break H}}t[(j+B(e,6)|0)+3|0]=0}h=0;d=w[g+3|0];if(!(w[l+2|0]|!d)){T:{if(d>>>0>=16){t[l+2|0]=5;t[l+4|0]=d>>>4;break T}t[l+2|0]=6;t[l+4|0]=d}h=1}U:{if(w[l+3|0]){break U}d=w[g+1|0];if(d){t[l+3|0]=2;t[k|0]=d;break U}d=w[g+2|0];if(d){t[l+3|0]=3;t[k|0]=d;break U}d=w[g|0];if(d){t[l+3|0]=19;t[k|0]=d;break U}d=w[g+7|0];if(d){t[l+3|0]=4;t[g+8|0]=d;t[k|0]=d;break U}d=w[g+4|0];if(d){t[l+3|0]=5;t[g+5|0]=d;t[k|0]=d;break U}d=w[g+3|0];if(!(!d|h)){t[l+3|0]=11;t[k|0]=d;if(d&15){t[k|0]=d|240;break U}if(!(d&240)){break U}t[k|0]=d|15;break U}d=w[g+6|0];if(d){t[l+3|0]=8;t[k|0]=d;break U}if(z){t[l+3|0]=20;t[k|0]=97;z=0;break U}z=0;d=i&255;if(!d|J){break U}t[l+3|0]=24;t[k|0]=i;if(i&15){t[k|0]=i|240;J=1;break U}J=1;if(!(d&240)){break U}t[k|0]=i|15}e=e+1|0;if(e>>>0<x[f+118>>1]){continue}break}break D}break g}s=s+1|0;if((G|0)!=(s|0)){continue}break}}m=m+1|0;if((m&65535)>>>0<D>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[23048]=0;jh(a,1);d=v[23048];v[23048]=0;if((d|0)==1){break g}if(Ib(w[o|0]|w[o+1|0]<<8)){V:{while(1){v[23048]=0;d=Q(250,b|0,2)|0;m=v[23048];v[23048]=0;if((m|0)==1){break g}if(!d){break V}v[23048]=0;d=U(465,b|0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break g}if((d|0)==65535){break V}v[23048]=0;Q(370,b|0,2)|0;d=v[23048];v[23048]=0;if((d|0)==1){break g}v[23048]=0;d=U(474,b|0)|0;m=v[23048];v[23048]=0;if((m|0)!=1){v[23048]=0;Q(370,b|0,d|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}}break}break g}v[23048]=0;Q(370,b|0,34)|0;d=v[23048];v[23048]=0;if((d|0)==1){break g}}W:{if(!(!(c&2)|!C)){d=1;m=1;while(1){c=(B(d,104)+a|0)+484380|0;X:{if(!v[c>>2]){break X}i=Sc(f+8|0,8,1,0,0);v[23048]=0;W(384,i|0,c|0,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break W}if(Gc(p)>>>0<d>>>0){break X}d=d-1|0;i=Id(p,d);v[23048]=0;S(931,c|0,i|0);i=v[23048];v[23048]=0;Y:{if((i|0)!=1){if(!x[sc(q,d)>>1]){break Y}i=x[sc(q,d)>>1];e=v[c>>2];v[23048]=0;ea(932,c|0,(B(i,104)+a|0)+484380|0,0,e|0,0);i=v[23048];v[23048]=0;if((i|0)!=1){break Y}}break g}d=Id(p,d);X=f,Y=Rb(d),v[X+8>>2]=Y;X=f,Y=Ub(d),v[X+120>>2]=Y;if(!Fb(f+8|0,f+120|0)){break X}while(1){d=v[f+8>>2];i=x[d+8>>1];if(i){e=v[d+4>>2];g=v[d>>2];v[23048]=0;ea(932,c|0,(B(i,104)+a|0)+484380|0,g|0,e|0,1);i=v[23048];v[23048]=0;if((i|0)==1){break g}}i=x[d+10>>1];if(i){e=v[d+4>>2];d=v[d>>2];v[23048]=0;ea(932,c|0,(B(i,104)+a|0)+484380|0,d|0,e|0,0);d=v[23048];v[23048]=0;if((d|0)==1){break g}}wr(f+8|0);if(Fb(f+8|0,f+120|0)){continue}break}}m=m+1|0;d=m&65535;if(C>>>0>=d>>>0){continue}break}}BB(H);d=1;break b}break g}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}yb(f+8|0);break c}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break e}e=P()|0;O()|0;Hb(f+136|0);break d}e=P()|0;O()|0;break e}e=P()|0;O()|0;BB(H);break e}yb(f+8|0)}Ze(q);ZT(p)}R(e|0);L()}d=0}Ze(q);ZT(p)}gb=f+400|0;return d|0}function yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-272|0;gb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!_u(b,d+176|0)){break h}if(!mU(d+176|0)){break h}if(!Nb(b,Xc(kU(d+176|0),jb))){break h}if(!c){s=1;break h}Ed(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;k=Jb(d+160|0);i:{j:{k:{l:{m:{n:{o:{p:{switch(((w[d+216|0]|w[d+217|0]<<8)&61440)-4096>>>12|0){case 0:q:{if(w[d+238|0]|w[d+239|0]<<8|(w[d+216|0]|w[d+217|0]<<8)!=4896|(w[d+228|0]|w[d+208|0]&15)){break q}if((w[d+214|0]|w[d+215|0]<<8)&65455){break q}v[a+1074304>>2]=18219008;v[23048]=0;f=Q(2,d+32|0,25962)|0;i=v[23048];v[23048]=0;e=1;if((i|0)==1){break o}Eb(k,f);vb(f);v[23048]=0;W(458,a+1074308|0,81,1)|0;g=v[23048];v[23048]=0;f=1;i=0;if((g|0)!=1){break i}break b}r:{if(w[d+238|0]|w[d+239|0]<<8|(w[d+216|0]|w[d+217|0]<<8)!=4896|(w[d+228|0]|(w[d+214|0]|w[d+215|0]<<8))){break r}if(w[d+229|0]){break r}v[23048]=0;f=Q(2,d+32|0,25988)|0;j=v[23048];v[23048]=0;if((j|0)!=1){break j}f=P()|0;O()|0;break a}v[23048]=0;e=Q(2,d+32|0,26002)|0;i=v[23048];v[23048]=0;j=1;if((i|0)!=1){Eb(k,e);vb(e);break k}f=P()|0;O()|0;break a;case 1:v[23048]=0;e=Q(2,d+32|0,26017)|0;i=v[23048];v[23048]=0;f=1;if((i|0)!=1){Eb(k,e);vb(e);break k}f=P()|0;O()|0;break a;case 2:s:{t:{u:{g=w[d+216|0]|w[d+217|0]<<8;v:{if(g>>>0<=12820){v[23048]=0;e=Q(2,d+32|0,26031)|0;f=v[23048];v[23048]=0;if((f|0)!=1){Eb(k,e);vb(e);break v}f=P()|0;O()|0;break a}v[23048]=0;S(638,d+144|0,26047);e=v[23048];v[23048]=0;if((e|0)==1){break u}e=w[d+216|0]|w[d+217|0]<<8;v[23048]=0;v[d+128>>2]=e-12820;T(639,d+32|0,d+144|0,d+128|0);e=v[23048];v[23048]=0;if((e|0)==1){break t}Eb(k,d+32|0);vb(d+32|0);Hb(d+144|0)}if((w[d+216|0]|w[d+217|0]<<8)>>>0<12807){break l}if(w[d+232|0]|w[d+233|0]<<8|(w[d+234|0]<<16|w[d+235|0]<<24)){break s}break l}f=P()|0;O()|0;break a}f=P()|0;O()|0;Hb(d+144|0);break a}e=w[d+216|0]|w[d+217|0]<<8;f=w[d+232|0]|w[d+233|0]<<8|(w[d+234|0]<<16|w[d+235|0]<<24);v[23048]=0;e=jw(e,f);f=v[23048];v[23048]=0;if((f|0)==1){break n}f=Gr(d+32|0);v[f+44>>2]=e;v[23048]=0;S(642,a+1300408|0,f|0);e=v[23048];v[23048]=0;if((e|0)!=1){break l}f=P()|0;O()|0;break a;case 3:f=w[d+216|0]|w[d+217|0]<<8;w:{if((f|0)==16640){v[23048]=0;e=Q(2,d+32|0,26071)|0;i=v[23048];v[23048]=0;if((i|0)!=1){Eb(k,e);vb(e);v[23048]=0;W(458,a+1074308|0,81,1)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}break w}f=P()|0;O()|0;break a}e=w[d+216|0]|w[d+217|0]<<8;i=w[d+230|0]|w[d+231|0]<<8;v[23048]=0;T(643,d+32|0,e|0,i|0);e=v[23048];v[23048]=0;if((e|0)==1){break m}Eb(k,d+32|0);vb(d+32|0);v[a+480260>>2]=1}i=(f|0)!=16640;f=1;e=0;break i;case 4:v[23048]=0;e=Q(2,d+32|0,26083)|0;i=v[23048];v[23048]=0;if((i|0)!=1){Eb(k,e);vb(e);v[a+1074304>>2]=((w[d+216|0]|w[d+217|0]<<8)&4095)<<16;break k}f=P()|0;O()|0;break a;case 5:v[23048]=0;f=Q(2,d+32|0,26071)|0;j=v[23048];v[23048]=0;if((j|0)!=1){Eb(k,f);vb(f);v[23048]=0;W(458,a+1074308|0,81,1)|0;g=v[23048];v[23048]=0;f=0;j=0;if((g|0)==1){break b}break i}f=P()|0;O()|0;break a;case 6:v[23048]=0;f=Q(2,d+32|0,26091)|0;j=v[23048];v[23048]=0;if((j|0)!=1){break j}f=P()|0;O()|0;break a;default:break p}}if((w[d+216|0]|w[d+217|0]<<8)!=51712){break i}v[23048]=0;f=Q(2,d+32|0,26104)|0;j=v[23048];v[23048]=0;if((j|0)!=1){break j}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}v[23048]=0;f=1;W(458,a+1074308|0,107,1)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}v[a+480260>>2]=1;e=0;if(g>>>0>12820){break i}}v[23048]=0;_(912,d+144|0);e=v[23048];v[23048]=0;x:{y:{z:{if((e|0)!=1){v[d+16>>2]=w[d+217|0]&15;e=w[d+216|0];v[23048]=0;v[d>>2]=e;S(640,d+128|0,d|0);e=v[23048];v[23048]=0;if((e|0)==1){break z}e=0;v[23048]=0;ea(913,d+32|0,d+144|0,k|0,d+16|0,d+128|0);i=v[23048];v[23048]=0;if((i|0)==1){break y}Eb(k,d+32|0);vb(d+32|0);vb(d+128|0);Hb(d+144|0);i=0;break i}f=P()|0;O()|0;break a}f=P()|0;O()|0;break x}f=P()|0;O()|0;vb(d+128|0)}Hb(d+144|0);break a}Eb(k,f);vb(f);f=0;j=0}v[23048]=0;g=Q(2,d+32|0,26120)|0;h=v[23048];v[23048]=0;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{if((h|0)!=1){Eb(a+1300344|0,g);vb(g);v[23048]=0;g=Q(2,d+32|0,26136)|0;h=v[23048];v[23048]=0;if((h|0)==1){break O}Eb(a+1300356|0,g);vb(g);Eb(a+1300368|0,k);v[a+1300404>>2]=v[a+1074304>>2]?8:5;if(f){v[23048]=0;f=a+1074308|0;Q(459,f|0,77)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}v[23048]=0;Q(459,f|0,78)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}v[23048]=0;Q(459,f|0,79)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}v[23048]=0;Q(459,f|0,80)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}v[23048]=0;Q(459,f|0,82)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}v[23048]=0;Q(459,f|0,96)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}}e=((w[d+216|0]|w[d+217|0]<<8)&61440)>>>0<4097|((w[d+216|0]|w[d+217|0]<<8)>>>0<12820?((w[d+216|0]|w[d+217|0]<<8)&61440)==12288:0)?e:1;v[23048]=0;f=a+901404|0;_(914,f|0);g=v[23048];v[23048]=0;if((g|0)==1){break b}if(!e){v[23048]=0;Po(f);e=v[23048];v[23048]=0;if((e|0)==1){break b}}v[23048]=0;Ak(d+144|0,1,d+176|0);e=v[23048];v[23048]=0;if((e|0)==1){break N}v[23048]=0;S(398,d+32|0,d+144|0);e=v[23048];v[23048]=0;if((e|0)==1){break N}Eb(a+1300308|0,d+32|0);vb(d+32|0);if(w[d+214|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[d+214|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[d+214|0]&64?0:(w[d+216|0]|w[d+217|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}e=w[d+225|0];v[a+480196>>2]=e;if(!(!j|(e|0)!=255?e:0)){v[a+480196>>2]=6}v[a+480204>>2]=B(w[d+226|0],1e4);if(w[d+226|0]<=32){v[a+480204>>2]=j?125e4:32e4}t[d+32|0]=w[d+224|0];v[23048]=0;t[d+144|0]=64;e=$b(d+32|0,d+144|0);f=v[23048];v[23048]=0;if((f|0)==1){break J}e=w[e|0];v[a+480200>>2]=e<<2;if(!((w[d+216|0]|w[d+217|0]<<8)>>>0>4895|e)){v[a+480200>>2]=256}if((w[d+218|0]|w[d+219|0]<<8)!=1|w[d+227|0]>7){break L}v[d+32>>2]=(w[d+227|0]<<4)+16;v[23048]=0;v[d+144>>2]=127;e=sd(d+32|0,d+144|0);f=v[23048];v[23048]=0;if((f|0)==1){break M}v[a+480228>>2]=v[e>>2];break K}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}if(!(w[d+227|0]!=18?w[d+227|0]!=2:0)){v[a+480228>>2]=32;break K}v[d+32>>2]=w[d+227|0]&127;v[23048]=0;v[d+144>>2]=16;e=Wf(d+32|0,d+144|0);f=v[23048];v[23048]=0;if((f|0)==1){break I}v[a+480228>>2]=v[e>>2]}v[a+480232>>2]=36;if(!(!i|(w[d+216|0]|w[d+217|0]<<8)>>>0>19762)){v[a+480232>>2]=64}u[a+480188>>1]=4;i=Ar(d+120|0);f=0;while(1){v[23048]=0;e=(f<<5)+a|0;o=e+480280|0;We(o);g=v[23048];v[23048]=0;if((g|0)==1){break H}g=d+f|0;h=w[g+240|0];if(w[g+240|0]!=255){u[a+480188>>1]=f+1;u[e+480284>>1]=h&8?204:51}if(t[g+240|0]<=-1){v[o>>2]=1024}if(((h&127)-16&255)>>>0<=13){u[e+480284>>1]=128;Wk(d+32|0,i,f);Ef(d+32|0,1)}f=f+1|0;if((f|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}e=Qb(a+484360|0);f=w[d+208|0]|w[d+209|0]<<8;v[23048]=0;ga(560,e|0,b|0,f|0,255,254)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}q=nc(d+144|0);e=w[d+210|0]|w[d+211|0]<<8;v[23048]=0;W(379,b|0,q|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}o=nc(d+128|0);e=w[d+212|0]|w[d+213|0]<<8;v[23048]=0;W(379,b|0,o|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){if(w[d+229|0]==252){f=0;v[23048]=0;S(915,b|0,d+32|0);e=v[23048];v[23048]=0;if((e|0)==1){break g}while(1){g=(d+32|0)+f|0;e=w[g|0];P:{if(!(e&32)){break P}h=((f<<5)+a|0)+480284|0;if(j){Wk(d+16|0,i,f);if(Cb(d+16|0)){break P}e=w[g|0]}u[h>>1]=(((e&15)<<8|8)>>>0)/15}f=f+1|0;if((f|0)!=32){continue}break}}u[d+32>>1]=w[d+210|0]|w[d+211|0]<<8;f=0;v[23048]=0;u[d+16>>1]=3999;e=Vc(d+32|0,d+16|0);i=v[23048];v[23048]=0;if((i|0)==1){break G}e=x[e>>1];u[a+480190>>1]=e;if(e){e=c&2;i=d+80|0;while(1){g=sc(q,f);g=w[g|0]|w[g+1|0]<<8;v[23048]=0;g=Q(248,b|0,g<<4)|0;h=v[23048];v[23048]=0;if((h|0)==1){break F}Q:{if(!g){break Q}v[23048]=0;g=Q(916,b|0,d+32|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break F}if(!g){break Q}v[23048]=0;g=f+1|0;h=(B(g,104)+a|0)+484380|0;T(917,d+32|0,h|0,j|0);l=v[23048];v[23048]=0;if((l|0)==1){break F}v[23048]=0;Ak(d,1,i);l=v[23048];v[23048]=0;R:{S:{T:{if((l|0)==1){break T}v[23048]=0;S(398,d+16|0,d|0);l=v[23048];v[23048]=0;if((l|0)==1){break T}v[23048]=0;Q(354,((g<<5)+a|0)+946300|0,d+16|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break S}vb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))|(!e|w[d+32|0]>1)){break Q}g=w[d+46|0];l=w[d+47|0];p=w[d+45|0];v[23048]=0;g=Q(248,b|0,l<<12|g<<4|p<<20)|0;l=v[23048];v[23048]=0;if((l|0)==1){break R}if(!g){break Q}g=w[d+218|0]|w[d+219|0]<<8;v[23048]=0;fR(d+16|0,d+32|0,(g|0)==1);g=v[23048];v[23048]=0;if((g|0)!=1){v[23048]=0;W(384,d+16|0,h|0,b|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){break Q}}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d+16|0);break f}f=P()|0;O()|0;break f}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}s=1;if(!(c&1)){break A}c=w[d+216|0]|w[d+217|0]<<8;u[d+32>>1]=w[d+212|0]|w[d+213|0]<<8;v[23048]=0;u[d+16>>1]=255;e=Vc(d+32|0,d+16|0);f=v[23048];v[23048]=0;U:{V:{if((f|0)!=1){r=x[e>>1];v[23048]=0;j=a+484344|0;S(385,j|0,r|0);e=v[23048];v[23048]=0;if((e|0)==1){break V}y=c>>>0<4896;if(r){break U}l=0;p=0;break B}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}A=d+32|5;C=d+32|3;z=d+32|4;D=d+32|2;E=d+32|1;i=0;p=0;l=0;while(1){v[23048]=0;c=W(386,j|0,i&65535,64)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}W:{if(!c){break W}c=sc(o,i);if(!(w[c|0]|w[c+1|0]<<8)){break W}c=sc(o,i);c=w[c|0]|w[c+1|0]<<8;v[23048]=0;c=Q(248,b|0,c<<4)|0;e=v[23048];v[23048]=0;if((e|0)==1){break E}if(!c){break W}v[23048]=0;Q(370,b|0,2)|0;c=v[23048];v[23048]=0;if((c|0)==1){break E}f=0;c=Yb(j,i);v[23048]=0;c=Of(c,0);e=v[23048];v[23048]=0;if((e|0)==1){break D}while(1){v[23048]=0;n=U(373,b|0)|0;e=v[23048];v[23048]=0;X:{Y:{if((e|0)!=1){if(n){break Y}if(f>>>0>62){break W}c=Yb(j,i);v[23048]=0;f=f+1|0;c=Of(c,f);e=v[23048];v[23048]=0;if((e|0)!=1){break X}}f=P()|0;O()|0;break f}F=Pi(d+32|0);g=n&31;e=g>>>0<x[a+480188>>1];g=B(g,6)+c|0;if(n&32){v[23048]=0;S(452,d+16|0,b|0);h=v[23048];v[23048]=0;Z:{_:{$:{if((h|0)!=1){m=rd(d+16|0);h=w[d+16|0];if(h>>>0>239){break $}h=(B(h>>>4|0,12)+(h&15)|0)+13|0;break _}f=P()|0;O()|0;break f}aa:{switch(h-254|0){case 0:break _;case 1:break aa;default:break Z}}h=0}t[(e?g:d+32|0)|0]=h}t[(e?g+1|0:E)|0]=w[m|0]}ba:{if(!(n&64)){break ba}v[23048]=0;h=U(373,b|0)|0;m=v[23048];v[23048]=0;ca:{if((m|0)!=1){m=e?g+2|0:D;t[d+16|0]=h;if(h<<24>>24>-1|h>>>0>192){break ca}t[m|0]=2;t[(e?g+4|0:z)|0]=w[d+16|0]^128;break ba}f=P()|0;O()|0;break f}t[m|0]=1;v[23048]=0;t[d|0]=64;h=$b(d+16|0,d);m=v[23048];v[23048]=0;if((m|0)==1){break C}t[(e?g+4|0:z)|0]=w[h|0]}if(!(n&128)){break X}v[23048]=0;S(452,d+16|0,b|0);h=v[23048];v[23048]=0;da:{if((h|0)!=1){m=rd(d+16|0);n=e?g+3|0:C;t[n|0]=w[d+16|0];h=e?g+5|0:A;t[h|0]=w[m|0];Wu(e?g:F,0);ea:{e=w[n|0];if((e|0)==20){if((w[h|0]&240)!=160){break X}if((w[d+216|0]|w[d+217|0]<<8)>>>0<4896){break ea}e=w[n|0]}if((e|0)!=31){break X}e=w[h|0];if(e>>>0<=15){break da}y=0;break X}t[h|0]=w[h|0]&15^136;break X}f=P()|0;O()|0;break f}if(e>>>0<=7){p=p+1|0;break X}l=((e|0)!=8)+l|0}if(f>>>0<64){continue}break}}i=i+1|0;if((r|0)!=(i|0)){continue}break}break B}f=P()|0;O()|0;break f}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}if(!y){break A}a=x[a+480188>>1];if((a|0)>(l+p|0)|(a|0)<=(l-p|0)){break A}e=Te(j)-1&65535;a=0;c=0;if(Te(j)>>>0>e>>>0){while(1){if(ai(ef(j,a))){b=Rb(ef(j,a));f=Ub(ef(j,a));a=gb-16|0;gb=a;v[a>>2]=f;v[a+8>>2]=b;if(Fb(a+8|0,a)){while(1){b=v[a+8>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}Oj(a+8|0);if(Fb(a+8|0,a)){continue}break}}gb=a+16|0}c=c+1|0;a=c&65535;if(e>>>0>=a>>>0){continue}break}}}Ek(o);Ek(q);vb(k)}gb=d+272|0;return s|0}f=P()|0;O()|0}Ek(o);break d}f=P()|0;O()|0}Ek(q);break a}f=P()|0;O()|0;break a}f=P()|0;O()|0}vb(k);R(f|0);L()}function y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;a:{b:{c:{d:{e:{f:{if(te(b,56371)){Jb(a);break f}if(te(b,56372)){b=gb-96|0;gb=b;d=Jb(a);v[23048]=0;_(223,b- -64|0);a=v[23048];v[23048]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23048]=0;v[b+32>>2]=0;S(2044,b+48|0,b+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break p}v[23048]=0;Q(1201,d|0,b+48|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break o}vb(b+48|0);v[23048]=0;Q(1926,d|0,57060)|0;a=v[23048];v[23048]=0;q:{if((a|0)==1){break q}v[23048]=0;v[b+32>>2]=6;S(2044,b+48|0,b+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break n}v[23048]=0;Q(1201,d|0,b+48|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break m}vb(b+48|0);v[23048]=0;Q(1926,d|0,57060)|0;a=v[23048];v[23048]=0;if((a|0)==1){break q}v[23048]=0;v[b+32>>2]=0;S(2044,b+48|0,b+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break l}v[23048]=0;Q(1201,d|0,b+48|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break k}vb(b+48|0);v[23048]=0;a=Q(91,b+48|0,56477)|0;e=v[23048];v[23048]=0;if((e|0)==1){break j}e=Bb(a);vb(a);if(!e){break i}v[23048]=0;Q(1926,d|0,56477)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}e=nc(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[23048]=0;v[b+12>>2]=a;S(2044,b+16|0,b+12|0);a=v[23048];v[23048]=0;if((a|0)==1){break D}v[23048]=0;T(2045,b+32|0,57804,b+16|0);a=v[23048];v[23048]=0;if((a|0)==1){break C}v[23048]=0;S(1438,e|0,b+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break B}vb(b+32|0);vb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[23048]=0;c=Q(91,b+32|0,57806)|0;a=v[23048];v[23048]=0;if((a|0)==1){break z}v[23048]=0;S(1438,e|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break y}vb(c);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(c);break r}if(!w[(b- -64|0)+17|0]){break w}v[23048]=0;c=Q(91,b+32|0,57815)|0;a=v[23048];v[23048]=0;if((a|0)==1){break v}v[23048]=0;S(1438,e|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break u}vb(c)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(c);break r}v[23048]=0;c=Q(91,b+32|0,57821)|0;a=v[23048];v[23048]=0;E:{if((a|0)!=1){v[23048]=0;S(1438,e|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break E}vb(c);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(c);break r}if(cd(e)){break g}v[23048]=0;Q(1926,d|0,57825)|0;a=v[23048];v[23048]=0;if((a|0)!=1){v[23048]=0;c=Q(91,b+16|0,57060)|0;a=v[23048];v[23048]=0;F:{G:{H:{if((a|0)!=1){v[23048]=0;T(2046,b+32|0,e|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break H}v[23048]=0;Q(1201,d|0,b+32|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break G}vb(b+32|0);vb(c);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;vb(b+32|0)}vb(c);break r}a=P()|0;O()|0}yd(e)}Hf(b- -64|0);break c}yd(e);Hf(b- -64|0);gb=b+96|0;break f}if(te(b,56388)){v[f>>2]=0;It(a,f);break f}if(te(b,56410)){v[f>>2]=6;It(a,f);break f}if(te(b,56432)){v[f>>2]=0;It(a,f);break f}if(te(b,56454)){b=gb-16|0;gb=b;v[b+12>>2]=56477;Tb(a,v[b+12>>2]);gb=b+16|0;break f}if(te(b,56485)){b=Tb(f,56477);e=Bb(b);v[23048]=0;Q(91,a|0,(e?56514:56512)|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break e}vb(b);break f}if(te(b,56516)){b=gb-48|0;gb=b;bG(b+16|0);v[23048]=0;e=Q(2,b|0,57895)|0;c=v[23048];v[23048]=0;I:{J:{K:{L:{if((c|0)!=1){v[23048]=0;T(243,b+32|0,b+16|0,e|0);c=v[23048];v[23048]=0;if((c|0)==1){break L}v[23048]=0;T(9,a|0,0,b+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break K}vb(b+32|0);vb(e);vb(b+16|0);gb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b+32|0)}vb(e)}vb(b+16|0);break a}if(te(b,56533)){b=gb-16|0;gb=b;i=gb-16|0;gb=i;v[i+8>>2]=101;e=b;c=gb-112|0;gb=c;g=nc(c+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[i+8>>2];if(d&1){v[23048]=0;v[c+80>>2]=19922997;S(230,c+48|0,c+80|0);d=v[23048];v[23048]=0;if((d|0)==1){break $}v[23048]=0;S(192,g|0,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break _}vb(c+48|0);d=v[i+8>>2]}if(!(d&4)){break Y}v[23048]=0;d=fa(231)|0;h=v[23048];v[23048]=0;if((h|0)==1){break X}if(!d){break Z}break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;vb(c+48|0);break N}v[23048]=0;_(232,c+48|0);d=v[23048];v[23048]=0;aa:{if((d|0)!=1){v[23048]=0;S(192,g|0,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break aa}vb(c+48|0);break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;vb(c+48|0);break N}ba:{d=v[i+8>>2];if(!(d&16)){break ba}v[23048]=0;S(233,c+80|0,11295);d=v[23048];v[23048]=0;ca:{da:{ea:{if((d|0)!=1){v[23048]=0;S(234,c+48|0,c+80|0);d=v[23048];v[23048]=0;if((d|0)==1){break ea}v[23048]=0;S(192,g|0,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break da}vb(c+48|0);Hb(c+80|0);d=v[i+8>>2];break ba}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ca}a=P()|0;O()|0;vb(c+48|0)}Hb(c+80|0);break N}fa:{if(!(d&32)){break fa}v[23048]=0;_(223,c+48|0);d=v[23048];v[23048]=0;ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{if((d|0)!=1){v[23048]=0;S(235,c+80|0,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break ha}d=hd(c+80|0);vb(c+80|0);if(!d){v[23048]=0;_(236,c+32|0);d=v[23048];v[23048]=0;if((d|0)==1){break ya}v[23048]=0;S(235,c+16|0,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break xa}v[23048]=0;T(237,c+80|0,c+32|0,c+16|0);d=v[23048];v[23048]=0;if((d|0)==1){break wa}v[23048]=0;S(192,g|0,c+80|0);d=v[23048];v[23048]=0;if((d|0)==1){break va}vb(c+80|0);vb(c+16|0);Hb(c+32|0)}if(!hd(ss(c+48|0))){v[23048]=0;_(238,c+32|0);d=v[23048];v[23048]=0;if((d|0)==1){break sa}d=ss(c+48|0);v[23048]=0;T(239,c+80|0,c+32|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break ra}v[23048]=0;S(192,g|0,c+80|0);d=v[23048];v[23048]=0;if((d|0)==1){break qa}vb(c+80|0);Hb(c+32|0)}v[23048]=0;S(240,c+80|0,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break oa}d=hd(c+80|0);vb(c+80|0);if(!d){v[23048]=0;_(236,c+32|0);d=v[23048];v[23048]=0;if((d|0)==1){break na}v[23048]=0;S(240,c+16|0,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break ma}v[23048]=0;T(237,c+80|0,c+32|0,c+16|0);d=v[23048];v[23048]=0;if((d|0)==1){break la}v[23048]=0;S(192,g|0,c+80|0);d=v[23048];v[23048]=0;if((d|0)==1){break ka}vb(c+80|0);vb(c+16|0);Hb(c+32|0)}Hf(c+48|0);d=v[i+8>>2];break fa}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ga}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ua}a=P()|0;O()|0;vb(c+80|0)}vb(c+16|0)}Hb(c+32|0);break ga}a=P()|0;O()|0;break ga}a=P()|0;O()|0;break pa}a=P()|0;O()|0;vb(c+80|0)}Hb(c+32|0);break ga}a=P()|0;O()|0;break ga}a=P()|0;O()|0;break ga}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ja}a=P()|0;O()|0;vb(c+80|0)}vb(c+16|0)}Hb(c+32|0);break ga}a=P()|0;O()|0}Hf(c+48|0);break N}za:{if(!(d&64)){break za}v[23048]=0;d=fa(231)|0;h=v[23048];v[23048]=0;if((h|0)==1){break X}if(d){break za}Jb(c+48|0);v[23048]=0;S(192,g|0,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break O}vb(c+48|0)}if(w[i+8|0]&128){v[23048]=0;_(241,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break W}v[23048]=0;S(192,g|0,c+48|0);d=v[23048];v[23048]=0;if((d|0)==1){break V}vb(c+48|0)}v[23048]=0;d=Q(2,c+48|0,11318)|0;h=v[23048];v[23048]=0;if((h|0)==1){break U}v[23048]=0;T(242,c|0,g|0,d|0);h=v[23048];v[23048]=0;if((h|0)==1){break T}v[23048]=0;h=Q(2,c+80|0,15226)|0;j=v[23048];v[23048]=0;if((j|0)==1){break S}v[23048]=0;T(243,e|0,c|0,h|0);e=v[23048];v[23048]=0;if((e|0)==1){break R}vb(h);vb(c);vb(d);em(g);gb=c+112|0;break M}a=P()|0;O()|0;break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;vb(c+48|0);break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;break P}a=P()|0;O()|0;break Q}a=P()|0;O()|0;vb(h)}vb(c)}vb(d);break N}a=P()|0;O()|0;vb(c+48|0)}em(g);R(a|0);L()}gb=i+16|0;v[23048]=0;T(9,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(te(b,56546)){b=gb-48|0;gb=b;us(b);v[23048]=0;S(235,b+32|0,b|0);e=v[23048];v[23048]=0;Aa:{Ba:{if((e|0)!=1){v[23048]=0;T(9,a|0,0,b+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break Ba}vb(b+32|0);Hf(b);gb=b+48|0;break f}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;vb(b+32|0)}Hf(b);break a}if(te(b,56557)){b=gb-32|0;gb=b;us(b);e=ss(b);v[23048]=0;T(9,a|0,0,e|0);a=v[23048];v[23048]=0;if((a|0)!=1){Hf(b);gb=b+32|0;break f}a=P()|0;O()|0;Hf(b);break a}if(te(b,56569)){b=gb-48|0;gb=b;us(b+16|0);Ca:{if(v[b+28>>2]){e=v[b+28>>2];v[23048]=0;v[b+12>>2]=e;S(2044,a|0,b+12|0);a=v[23048];v[23048]=0;if((a|0)!=1){break Ca}a=P()|0;O()|0;Hf(b+16|0);break a}Jb(a)}Hf(b+16|0);gb=b+48|0;break f}if(te(b,56585)){us(f);b=w[f+16|0];v[23048]=0;Q(91,a|0,(b?56512:56514)|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){Hf(f);break f}a=P()|0;O()|0;Hf(f);break a}if(te(b,56604)){us(f);b=w[f+17|0];v[23048]=0;Q(91,a|0,(b?56512:56514)|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){Hf(f);break f}a=P()|0;O()|0;Hf(f);break a}if(te(b,56630)){us(f);b=w[f+18|0];v[23048]=0;Q(91,a|0,(b?56512:56514)|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){Hf(f);break f}a=P()|0;O()|0;Hf(f);break a}if(te(b,56648)){b=gb-16|0;gb=b;e=gb-32|0;gb=e;c=Jb(b);v[23048]=0;_(223,e|0);d=v[23048];v[23048]=0;Da:{Ea:{Fa:{if((d|0)!=1){d=ss(e);v[23048]=0;Q(224,c|0,d|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break Fa}Hf(e);gb=e+32|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;Hf(e)}vb(c);break a}v[23048]=0;T(9,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(te(b,56654)){b=gb-16|0;gb=b;e=gb-48|0;gb=e;c=Jb(b);v[23048]=0;S(226,e+16|0,11280);d=v[23048];v[23048]=0;Ga:{Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){v[e+12>>2]=13;v[e+8>>2]=0;v[23048]=0;v[e+4>>2]=0;ea(227,e+32|0,e+16|0,e+12|0,e+8|0,e+4|0);d=v[23048];v[23048]=0;if((d|0)==1){break Ka}v[23048]=0;Q(183,c|0,e+32|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break Ja}vb(e+32|0);Hb(e+16|0);gb=e+48|0;break Ga}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;vb(e+32|0)}Hb(e+16|0)}vb(c);R(a|0);L()}v[23048]=0;T(9,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(te(b,56669)){b=gb-16|0;gb=b;co(b,0,11501);v[23048]=0;T(9,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(te(b,56677)){b=gb-48|0;gb=b;d=Tb(b+16|0,57900);v[23048]=0;S(2047,b|0,2);e=v[23048];v[23048]=0;La:{Ma:{Na:{Oa:{if((e|0)!=1){v[23048]=0;T(3,b+32|0,d|0,b|0);e=v[23048];v[23048]=0;if((e|0)==1){break Oa}v[23048]=0;T(9,a|0,0,b+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break Na}vb(b+32|0);vb(b);vb(d);gb=b+48|0;break f}a=P()|0;O()|0;break La}a=P()|0;O()|0;break Ma}a=P()|0;O()|0;vb(b+32|0)}vb(b)}break c}if(te(b,56685)){b=gb-16|0;gb=b;co(b,0,13527);v[23048]=0;T(9,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(te(b,56693)){b=gb-16|0;gb=b;rs(b,0);v[23048]=0;T(9,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(te(b,56697)){b=gb-16|0;gb=b;rs(b,2);v[23048]=0;T(9,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(te(b,56715)){b=gb-16|0;gb=b;rs(b,3);v[23048]=0;T(9,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}Jb(a)}gb=f+32|0;break d}a=P()|0;O()|0;vb(b);break a}return}vb(d);break a}a=P()|0;O()|0;vb(b)}R(a|0);L()}function Loa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=gb-352|0;gb=e;yc(b);f=e+328|0;g=xD(b,f);if(!g){Pv(f)}a:{if(!g){break a}if(!LX(e+328|0)){break a}if(!Nb(b,Xc(72,0))){break a}if(!c){d=1;break a}Ed(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;d=w[e+337|0];u[a+480190>>1]=63;u[a+480188>>1]=d;b:{if(d){d=0;while(1){cu(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}if(!x[a+480190>>1]){break b}}d=1;f=1;while(1){g=(B(d,104)+a|0)+484380|0;wd(g,1);h=(e+256|0)+d|0;d=Hd(b);t[h|0]=d;if(d<<24>>24>=0){A=g,C=KX(b),v[A>>2]=C}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}ID(b,a+1300308|0,-1);g=e+248|0;f=gb-32|0;gb=f;d=b;c:{if(Nb(d,8)){Hp(f+24|0,g);g=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=g;gd(f+16|0,d,f+8|0);break c}t[f+16|0]=0;bi(g,8,f+16|0)}gb=f+32|0;m=nc(e+232|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!(w[e+338|0]|w[e+339|0]<<8)){break n}g=w[e+338|0]|w[e+339|0]<<8;i=w[e+337|0];d=0;v[23048]=0;f=U(373,b|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break m}if(f>>>0>1){break d}d=B(g,i)<<1;if(f){v[23048]=0;T(542,e+160|0,b|0,d|0);d=v[23048];v[23048]=0;if((d|0)!=1){ip(m,e+160|0);gc(e+160|0);break n}f=P()|0;O()|0;break f}v[23048]=0;W(543,b|0,m|0,d|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break m}}cn(e+224|0,v[m>>2],qc(m)>>>1|0);f=hp(v[e+224>>2],v[e+228>>2]);d=0;if(f>>>0<B(x[a+480188>>1],w[e+338|0]|w[e+339|0]<<8)>>>0){break d}k=nc(e+208|0);o:{p:{if(!(w[e+340|0]|w[e+341|0]<<8)){break p}d=w[e+340|0]|w[e+341|0]<<8;f=0;v[23048]=0;S(544,k|0,d<<8);d=v[23048];v[23048]=0;if((d|0)==1){break o}if(!(w[e+340|0]|w[e+341|0]<<8)){break p}while(1){v[e+160>>2]=(w[e+340|0]|w[e+341|0]<<8)-f;v[23048]=0;v[e+72>>2]=2e3;d=sd(e+160|0,e+72|0);g=v[23048];v[23048]=0;q:{if((g|0)!=1){i=v[d>>2];d=nc(e+160|0);v[23048]=0;g=U(373,b|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break h}if(g>>>0<=1){break q}gc(d);d=0;break e}f=P()|0;O()|0;break g}i=i<<8;r:{if(g){v[23048]=0;T(542,e+72|0,b|0,i|0);g=v[23048];v[23048]=0;if((g|0)!=1){ip(d,e+72|0);gc(e+72|0);break r}break h}v[23048]=0;W(543,b|0,d|0,i|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break h}}A=e,C=Ub(k),v[A+72>>2]=C;Sd(e+200|0,e+72|0);g=Rb(d);i=Ub(d);v[23048]=0;Y(545,k|0,v[e+200>>2],g|0,i|0);g=v[23048];v[23048]=0;if((g|0)==1){break h}gc(d);f=f+2e3&65535;if(f>>>0<(w[e+340|0]|w[e+341|0]<<8)>>>0){continue}break}}d=0;v[23048]=0;me(e+184|0,k);f=v[23048];v[23048]=0;if((f|0)==1){break i}f=v[e+188>>2];v[e+32>>2]=v[e+184>>2];v[e+36>>2]=f;Ch(e+192|0,e+32|0);if(xb(e+192|0)>>>0<(w[e+340|0]|w[e+341|0]<<8)<<8>>>0){break e}p=a+484360|0;d=Qb(p);f=w[e+338|0]|w[e+339|0]<<8;i=0;v[23048]=0;S(547,d|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break i}if(!(w[e+338|0]|w[e+339|0]<<8)){break j}q=a+484344|0;s=c&1;while(1){A=sc(Qb(p),i),C=i,u[A>>1]=C;s:{if(!s){break s}v[23048]=0;r=i&65535;d=W(386,q|0,r|0,64)|0;f=v[23048];v[23048]=0;if((f|0)==1){break l}if(!d){break s}h=0;f=x[a+480188>>1];if(!f){break s}while(1){d=sc(e+224|0,B(f&65535,i)+h|0);f=w[d|0]|w[d+1|0]<<8;t:{if(f>>>0>=(w[e+340|0]|w[e+341|0]<<8)>>>0){f=x[a+480188>>1];break t}d=Yb(q,i);v[23048]=0;d=Wc(d,0,h&65535);g=v[23048];v[23048]=0;if((g|0)==1){break k}l=0;y=0-h|0;z=f<<8;while(1){_d(e+160|0,v[e+192>>2]+((l<<2)+z|0)|0,4);n=w[bn(e+160|0,0)|0]&63;t[d|0]=n?n+48|0:0;f=bn(e+160|0,0);A=d,C=w[bn(e+160|0,1)|0]<<2&60|w[f|0]>>>6,t[A+1|0]=C;g=w[bn(e+160|0,1)|0];o=w[bn(e+160|0,2)|0];f=bn(e+160|0,2);j=w[bn(e+160|0,3)|0];f=j<<4|w[f|0]>>>4;u[e+48>>1]=f;g=o<<2&60|g>>>6;u:{if(!(w[lc(e+248|0,g>>>3|0)|0]>>>(g&7)&1)|(f?0:!g)){break u}t[d+5|0]=f;t[d+3|0]=g;o=j>>>4|0;t[d+4|0]=o;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{switch(g|0){case 0:case 1:case 2:case 32:case 33:case 34:t[d+3|0]=g&15;v[23048]=0;Mf(d);f=v[23048];v[23048]=0;if((f|0)==1){break G}if(!w[d+4|0]){break u}t[d+2|0]=g>>>0<32?3:4;break u;case 3:case 4:case 5:case 6:case 7:case 12:v[23048]=0;Mf(d);f=v[23048];v[23048]=0;if((f|0)==1){break G}break u;case 9:t[d+3|0]=10;A=d,C=Ki(f>>>1|0),t[A+5|0]=C;break u;case 50:break w;case 48:break x;case 43:break y;case 47:break z;case 17:case 18:case 26:case 27:break A;case 22:case 25:case 28:case 29:case 30:break B;case 16:case 19:case 20:case 21:case 23:case 31:break C;case 13:break D;case 11:case 15:break E;case 10:case 42:break H;default:break v}}if(f>>>0>254){break F}t[d+3|0]=g&15;v[23048]=0;Mf(d);f=v[23048];v[23048]=0;if((f|0)!=1){break u}}f=P()|0;O()|0;break g}t[d+3|0]=19;t[d+5|0]=o|(g>>>0<32?16:32);g=j&15;if(g){t[d+2|0]=3;t[d+4|0]=g;break u}t[d+2|0]=4;t[d+4|0]=f&15;break u}t[d+3|0]=(g|0)==11?12:16;A=d,C=yv(f),t[A+5|0]=C;break u}t[d+3|0]=14;if((f&255)>>>0<64){break u}t[d+5|0]=0;break u}t[d+3|0]=19;t[d+5|0]=f&15|g<<4;break u}t[d+3|0]=19;v[23048]=0;u[e+72>>1]=15;f=Vc(e+48|0,e+72|0);j=v[23048];v[23048]=0;if((j|0)!=1){t[d+5|0]=w[f|0]|g<<4;break u}f=P()|0;O()|0;break g}t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((g|0)==17?16:(g|0)==26?16:32);if(!(j&240)){break u}t[d+2|0]=g>>>0>25?6:5;break u}t[d+5|0]=o|(g>>>0>25?-80:-96);break u}if(!f){break v}t[d+3|0]=17;v[e+72>>2]=8;v[23048]=0;v[e+96>>2]=f+4;f=Wf(e+72|0,e+96|0);g=v[23048];v[23048]=0;if((g|0)!=1){A=d,C=Ki(v[f>>2]/8|0),t[A+5|0]=C;break u}f=P()|0;O()|0;break g}t[d+3|0]=14;g=x[a+480188>>1];if(!g){break u}n=B(y,6)+d|0;f=0;while(1){j=n+B(f,6)|0;if(!w[j+3|0]){t[j+3|0]=12;A=j,C=yv(r),t[A+5|0]=C;g=x[a+480188>>1]}f=f+1|0;if(g>>>0>f>>>0){continue}break}break u}t[d+3|0]=9;g=f&7;if(g){t[d+5|0]=w[g+17334|0];break u}g=f>>>4|0;if((g|0)==128){break v}t[d+5|0]=g;if(!(f&2048)){t[d+5|0]=g^128;break u}t[d+5|0]=g^-1;break u}t[d+5|0]=0;t[d+3|0]=0;if(!n){t[d|0]=255;break u}t[d+3|0]=25;break u}t[d+3|0]=0}f=x[a+480188>>1];d=B(f,6)+d|0;l=l+1|0;if((l|0)!=64){continue}break}}h=h+1|0;if(h>>>0<(f&65535)>>>0){continue}break}}i=i+1|0;if(i>>>0<(w[e+338|0]|w[e+339|0]<<8)>>>0){continue}break}break j}f=P()|0;O()|0;break g}f=P()|0;O()|0;break f}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}I:{if(x[a+480190>>1]){i=c&2;d=1;f=1;while(1){v[23048]=0;c=w[(e+256|0)+d|0];W(374,b|0,((d<<5)+a|0)+946300|0,c&63)|0;g=v[23048];v[23048]=0;J:{K:{L:{M:{N:{O:{if((g|0)!=1){if(c<<24>>24<=-1){break J}v[23048]=0;g=U(548,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break I}c=B(d,104)+a|0;h=c+484392|0;v[h>>2]=g;v[23048]=0;d=U(548,b|0)|0;g=v[23048];v[23048]=0;P:{if((g|0)!=1){if(d>>>0>=3){v[c+484396>>2]=d+v[h>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[23048]=0;d=U(373,b|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){break P}break I}f=P()|0;O()|0;break g}u[c+484410>>1]=d<<2;v[23048]=0;d=U(373,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break I}t[c+484417|0]=d<<4;c=c+484380|0;if(!v[c>>2]){break J}v[23048]=0;g=U(373,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break M}d=0;Q:{R:{switch(g|0){case 0:if(!i){break Q}d=nc(e+72|0);g=v[c>>2];v[23048]=0;W(543,b|0,d|0,g|0)|0;g=v[23048];v[23048]=0;S:{if((g|0)!=1){A=e,C=Rb(d),v[A+160>>2]=C;A=e,C=Ub(d),v[A+96>>2]=C;if(Fb(e+160|0,e+96|0)){break S}break L}f=P()|0;O()|0;break K}while(1){h=v[e+160>>2];g=zb(w[h|0]);A=h,C=zb(((g<<7|g>>>1)^127)&255),t[A|0]=C;Se(e+160|0);if(Fb(e+160|0,e+96|0)){continue}break};break L;case 1:d=v[c>>2];v[23048]=0;T(542,e+72|0,b|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break O}T:{U:{V:{W:{if(i){v[23048]=0;me(e+136|0,e+72|0);d=v[23048];v[23048]=0;if((d|0)==1){break W}d=Xd(e+128|0);v[23048]=0;g=v[e+140>>2];v[e+16>>2]=v[e+136>>2];v[e+20>>2]=g;g=W(549,e+160|0,e+16|0,d|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break V}Bc(d);d=Sc(e+96|0,8,1,0,2);v[23048]=0;W(384,d|0,c|0,g|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break U}yb(g)}gc(e+72|0);break J}f=P()|0;O()|0;break T}f=P()|0;O()|0;Bc(d);break T}f=P()|0;O()|0;yb(g)}gc(e+72|0);break g;case 2:case 3:if(i){d=Sc(e+160|0,(g|0)==2?8:16,1,0,0);v[23048]=0;W(384,d|0,c|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break J}f=P()|0;O()|0;break g}c=v[c>>2];v[23048]=0;Q(370,b|0,B(c,g-1|0)|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break J}break M;case 4:case 5:break R;default:break e}}d=v[c>>2];v[23048]=0;T(550,e+72|0,b|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break N}X:{Y:{Z:{_:{if(i){$:{if((g|0)!=5){break $}A=e,C=Rb(e+72|0),v[A+160>>2]=C;A=e,C=Ub(e+72|0),v[A+96>>2]=C;if(!Fb(e+160|0,e+96|0)){break $}while(1){h=v[e+160>>2];d=zb(w[h|0]);A=h,C=zb((d^w[(d>>>7|0)+17342|0])&255),t[A|0]=C;Se(e+160|0);if(Fb(e+160|0,e+96|0)){continue}break}}v[23048]=0;me(e+120|0,e+72|0);d=v[23048];v[23048]=0;if((d|0)==1){break _}d=Xd(e+112|0);v[23048]=0;h=v[e+124>>2];v[e+24>>2]=v[e+120>>2];v[e+28>>2]=h;h=W(549,e+160|0,e+24|0,d|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break Z}Bc(d);d=(g|0)==5;d=Sc(e+96|0,d?16:8,1,0,d?17:1);v[23048]=0;W(384,d|0,c|0,h|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break Y}yb(h)}gc(e+72|0);break J}f=P()|0;O()|0;break X}f=P()|0;O()|0;Bc(d);break X}f=P()|0;O()|0;yb(h)}gc(e+72|0);break g}c=v[c>>2];v[23048]=0;Q(370,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break M}break J}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}v[23048]=0;me(e+152|0,d);g=v[23048];v[23048]=0;if((g|0)==1){f=P()|0;O()|0;break K}g=Xd(e+144|0);v[23048]=0;h=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=h;h=W(549,e+160|0,e+8|0,g|0)|0;l=v[23048];v[23048]=0;aa:{if((l|0)!=1){Bc(g);g=Sc(e+96|0,16,1,0,17);v[23048]=0;W(384,g|0,c|0,h|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break aa}yb(h);gc(d);break J}f=P()|0;O()|0;Bc(g);break K}f=P()|0;O()|0;yb(h)}gc(d);break g}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{d=w[e+342|0]|w[e+343|0]<<8|w[e+344|0]<<16;if(d){g=nc(e+96|0);v[23048]=0;c=U(270,e+160|0)|0;f=v[23048];v[23048]=0;ja:{ka:{la:{ma:{na:{oa:{if((f|0)!=1){v[23048]=0;f=U(373,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break ia}if(!f){break ka}v[23048]=0;T(542,e+48|0,b|0,d|0);b=v[23048];v[23048]=0;if((b|0)==1){break oa}b=ip(g,e+48|0);v[23048]=0;me(e- -64|0,b);b=v[23048];v[23048]=0;if((b|0)==1){break na}b=Xd(e+40|0);v[23048]=0;f=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=f;f=W(549,e+72|0,e|0,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break ma}id(c,f);yb(f);Bc(b);gc(e+48|0);break ja}f=P()|0;O()|0;break ba}f=P()|0;O()|0;break ca}f=P()|0;O()|0;break la}f=P()|0;O()|0;Bc(b)}gc(e+48|0);break ca}v[23048]=0;T(341,e+72|0,b|0,d|0);b=v[23048];v[23048]=0;if((b|0)==1){break da}id(c,e+72|0);yb(e+72|0)}v[23048]=0;ba(551,a+1300332|0,c|0,d|0,1)|0;b=v[23048];v[23048]=0;if((b|0)==1){break ia}yb(c);gc(g)}v[23048]=0;_(552,e+72|0);b=v[23048];v[23048]=0;if((b|0)==1){break ha}v[23048]=0;T(368,e+160|0,e+72|0,e+336|0);b=v[23048];v[23048]=0;if((b|0)==1){break ga}Eb(a+1300344|0,e+160|0);vb(e+160|0);Hb(e+72|0);v[23048]=0;b=Q(2,e+160|0,17365)|0;c=v[23048];v[23048]=0;if((c|0)==1){break fa}Eb(a+1300356|0,b);vb(b);v[23048]=0;b=Q(2,e+160|0,17370)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ea}Eb(a+1300368|0,b);vb(b);v[a+1300404>>2]=2;d=1;break e}f=P()|0;O()|0;break ca}f=P()|0;O()|0;break g}f=P()|0;O()|0;Hb(e+72|0);break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0}yb(c)}gc(g);break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;gc(d)}gc(k)}gc(m);R(f|0);L()}gc(k)}gc(m)}gb=e+352|0;return d|0}function Ad(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;m=gb-16|0;gb=m;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(a>>>0<=244){f=v[116855];i=a>>>0<11?16:a+11&-8;c=i>>>3|0;b=f>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;e=v[b+467468>>2];a=e+8|0;c=v[e+8>>2];b=b+467460|0;m:{if((c|0)==(b|0)){n=467420,o=Jpa(-2,d)&f,v[n>>2]=o;break m}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[e+4>>2]=b|3;b=b+e|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[116857];if(k>>>0>=i>>>0){break l}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+467468>>2];b=v[g+8>>2];a=a+467460|0;n:{if((b|0)==(a|0)){f=Jpa(-2,c)&f;v[116855]=f;break n}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=i|3;d=g+i|0;b=c<<3;e=b-i|0;v[d+4>>2]=e|1;v[b+g>>2]=e;if(k){b=k>>>3|0;c=(b<<3)+467460|0;g=v[116860];b=1<<b;o:{if(!(b&f)){v[116855]=b|f;b=c;break o}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[116860]=d;v[116857]=e;break a}h=v[116856];if(!h){break l}b=(h&0-h)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+467724>>2];d=(v[b+4>>2]&-8)-i|0;c=b;while(1){p:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break p}}c=(v[a+4>>2]&-8)-i|0;e=c>>>0<d>>>0;d=e?c:d;b=e?a:b;c=a;continue}break}j=b+i|0;if(j>>>0<=b>>>0){break k}l=v[b+24>>2];e=v[b+12>>2];if((e|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=e;v[e+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;e=a;c=a+20|0;a=v[c>>2];if(a){continue}c=e+16|0;a=v[e+16>>2];if(a){continue}break}v[g>>2]=0;break b}i=-1;if(a>>>0>4294967231){break l}a=a+11|0;i=a&-8;j=v[116856];if(!j){break l}f=31;d=0-i|0;if(i>>>0<=16777215){a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|i>>>a+21&1)+28|0}c=v[(f<<2)+467724>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=i<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-i|0;if(g>>>0>=d>>>0){break t}e=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|e)){a=2<<f;a=(0-a|a)&j;if(!a){break l}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+467724>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-i|0;c=b>>>0<d>>>0;d=c?b:d;e=c?a:e;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!e|v[116857]-i>>>0<=d>>>0){break l}h=e+i|0;if(h>>>0<=e>>>0){break k}f=v[e+24>>2];b=v[e+12>>2];if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=e+20|0;a=v[c>>2];if(!a){a=v[e+16>>2];if(!a){break i}c=e+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[116857];if(c>>>0>=i>>>0){d=v[116860];b=c-i|0;u:{if(b>>>0>=16){v[116857]=b;a=d+i|0;v[116860]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=i|3;break u}v[116860]=0;v[116857]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}h=v[116858];if(h>>>0>i>>>0){b=h-i|0;v[116858]=b;c=v[116861];a=c+i|0;v[116861]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}a=0;j=i+47|0;b=j;if(v[116973]){c=v[116975]}else{v[116976]=-1;v[116977]=-1;v[116974]=4096;v[116975]=4096;v[116973]=m+12&-16^1431655768;v[116978]=0;v[116966]=0;c=4096}g=b+c|0;e=0-c|0;c=g&e;if(c>>>0<=i>>>0){break a}d=v[116965];if(d){b=v[116963];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[467864]&4){break f}v:{w:{d=v[116861];if(d){a=467868;while(1){b=v[a>>2];if(d>>>0<b+v[a+4>>2]>>>0?b>>>0<=d>>>0:0){break w}a=v[a+8>>2];if(a){continue}break}}b=Xp(0);if((b|0)==-1){break g}f=c;d=v[116974];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=i>>>0|f>>>0>2147483646){break g}d=v[116965];if(d){a=v[116963];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=Xp(f);if((b|0)!=(a|0)){break v}break e}f=e&g-h;if(f>>>0>2147483646){break g}b=Xp(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|i+48>>>0<=f>>>0)){b=v[116975];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Xp(b)|0)!=-1){f=b+f|0;b=a;break e}Xp(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}L()}e=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[116966]=v[116966]|4}if(c>>>0>2147483646){break d}b=v[23044];c=c+3&-4;a=b+c|0;x:{y:{if(a>>>0<=b>>>0?c:0){break y}if(Rw()>>>0<a>>>0){if(!(va(a|0)|0)){break y}}v[23044]=a;break x}v[115529]=48;a=v[23044];b=-1}z:{if(Rw()>>>0>=a>>>0){break z}if(va(a|0)|0){break z}v[115529]=48;break d}v[23044]=a;if((b|0)==-1|a>>>0<=b>>>0|(a|0)==-1){break d}f=a-b|0;if(f>>>0<=i+40>>>0){break d}}a=v[116963]+f|0;v[116963]=a;if(a>>>0>y[116964]){v[116964]=a}A:{B:{C:{g=v[116861];if(g){a=467868;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break C}a=v[a+8>>2];if(a){continue}break}break B}a=v[116859];if(!(a>>>0<=b>>>0?a:0)){v[116859]=b}a=0;v[116968]=f;v[116967]=b;v[116863]=-1;v[116864]=v[116973];v[116970]=0;while(1){d=a<<3;c=d+467460|0;v[d+467468>>2]=c;v[d+467472>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116858]=c;a=a+b|0;v[116861]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116862]=v[116977];break A}if(v[a+12>>2]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break B}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[116861]=c;b=v[116858]+f|0;a=b-a|0;v[116858]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[116862]=v[116977];break A}if(y[116859]>b>>>0){v[116859]=b}c=b+f|0;a=467868;D:{E:{F:{G:{H:{I:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break I}break}if(!(w[a+12|0]&8)){break H}}a=467868;while(1){c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break G}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=i|3;f=c+(c+8&7?-8-c&7:0)|0;h=i+j|0;c=f-h|0;if((f|0)==(g|0)){v[116861]=h;a=v[116858]+c|0;v[116858]=a;v[h+4>>2]=a|1;break E}if(v[116860]==(f|0)){v[116860]=h;a=v[116857]+c|0;v[116857]=a;v[h+4>>2]=a|1;v[a+h>>2]=a;break E}a=v[f+4>>2];if((a&3)==1){g=a&-8;J:{if(a>>>0<=255){d=v[f+8>>2];a=a>>>3|0;b=v[f+12>>2];if((b|0)==(d|0)){n=467420,o=v[116855]&Jpa(-2,a),v[n>>2]=o;break J}v[d+12>>2]=b;v[b+8>>2]=d;break J}i=v[f+24>>2];b=v[f+12>>2];K:{if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break K}L:{a=f+20|0;d=v[a>>2];if(d){break L}a=f+16|0;d=v[a>>2];if(d){break L}b=0;break K}while(1){e=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[e>>2]=0}if(!i){break J}d=v[f+28>>2];a=(d<<2)+467724|0;M:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break M}n=467424,o=v[116856]&Jpa(-2,d),v[n>>2]=o;break J}v[i+(v[i+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break J}}v[b+24>>2]=i;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break J}v[b+20>>2]=a;v[a+24>>2]=b}f=f+g|0;c=c+g|0}v[f+4>>2]=v[f+4>>2]&-2;v[h+4>>2]=c|1;v[c+h>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+467460|0;c=v[116855];a=1<<a;N:{if(!(c&a)){v[116855]=a|c;a=b;break N}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break E}a=31;if(c>>>0<=16777215){a=c>>>8|0;e=a+1048320>>>16&8;a=a<<e;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|e))|0;a=(a<<1|c>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;e=(a<<2)+467724|0;d=v[116856];b=1<<a;O:{if(!(d&b)){v[116856]=b|d;v[e>>2]=h;v[h+24>>2]=e;break O}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[e>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break F}b=a>>>29|0;a=a<<1;e=d+(b&4)|0;b=v[e+16>>2];if(b){continue}break}v[e+16>>2]=h;v[h+24>>2]=d}v[h+12>>2]=h;v[h+8>>2]=h;break E}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116858]=c;a=a+b|0;v[116861]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116862]=v[116977];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116970];v[c+16>>2]=v[116969];v[c+20>>2]=a;a=v[116968];v[c+8>>2]=v[116967];v[c+12>>2]=a;v[116969]=c+8;v[116968]=f;v[116967]=b;v[116970]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break A}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){a=e>>>3|0;b=(a<<3)+467460|0;c=v[116855];a=1<<a;P:{if(!(c&a)){v[116855]=a|c;a=b;break P}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break A}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+467724|0;c=v[116856];b=1<<a;Q:{if(!(c&b)){v[116856]=b|c;v[d>>2]=g;v[g+24>>2]=d;break Q}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((e|0)==(v[b+4>>2]&-8)){break D}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break A}a=v[d+8>>2];v[a+12>>2]=h;v[d+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=d;v[h+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[116858];if(a>>>0<=i>>>0){break d}b=a-i|0;v[116858]=b;c=v[116861];a=c+i|0;v[116861]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}v[115529]=48;a=0;break a}R:{if(!f){break R}c=v[e+28>>2];a=(c<<2)+467724|0;S:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break S}j=Jpa(-2,c)&j;v[116856]=j;break R}v[f+(v[f+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break R}}v[b+24>>2]=f;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break R}v[b+20>>2]=a;v[a+24>>2]=b}T:{if(d>>>0<=15){a=d+i|0;v[e+4>>2]=a|3;a=a+e|0;v[a+4>>2]=v[a+4>>2]|1;break T}v[e+4>>2]=i|3;v[h+4>>2]=d|1;v[d+h>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+467460|0;c=v[116855];a=1<<a;U:{if(!(c&a)){v[116855]=a|c;a=b;break U}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break T}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;c=(a<<2)+467724|0;V:{b=1<<a;W:{if(!(b&j)){v[116856]=b|j;v[c>>2]=h;v[h+24>>2]=c;break W}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);i=v[c>>2];while(1){b=i;if((v[b+4>>2]&-8)==(d|0)){break V}c=a>>>29|0;a=a<<1;c=b+(c&4)|0;i=v[c+16>>2];if(i){continue}break}v[c+16>>2]=h;v[h+24>>2]=b}v[h+12>>2]=h;v[h+8>>2]=h;break T}a=v[b+8>>2];v[a+12>>2]=h;v[b+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=b;v[h+8>>2]=a}a=e+8|0;break a}X:{if(!l){break X}c=v[b+28>>2];a=(c<<2)+467724|0;Y:{if(v[a>>2]==(b|0)){v[a>>2]=e;if(e){break Y}n=467424,o=Jpa(-2,c)&h,v[n>>2]=o;break X}v[(v[l+16>>2]==(b|0)?16:20)+l>>2]=e;if(!e){break X}}v[e+24>>2]=l;a=v[b+16>>2];if(a){v[e+16>>2]=a;v[a+24>>2]=e}a=v[b+20>>2];if(!a){break X}v[e+20>>2]=a;v[a+24>>2]=e}Z:{if(d>>>0<=15){a=d+i|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break Z}v[b+4>>2]=i|3;v[j+4>>2]=d|1;v[d+j>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+467460|0;e=v[116860];a=1<<a;_:{if(!(a&f)){v[116855]=a|f;a=c;break _}a=v[c+8>>2]}v[c+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=c;v[e+8>>2]=a}v[116860]=j;v[116857]=d}a=b+8|0}gb=m+16|0;return a|0}function x7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;d=Tb(e+32|0,56885);f=Vf(c,d);vb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){dk(a,0,v[b+24>>2]+1300356|0);break k}d=Tb(e+32|0,56890);f=Vf(c,d);vb(d);if(f){dk(a,0,v[b+24>>2]+1300344|0);break k}d=Tb(e+32|0,56900);f=Vf(c,d);vb(d);if(f){dk(a,0,v[b+24>>2]+1300392|0);break k}d=Tb(e+32|0,56913);f=Vf(c,d);vb(d);if(f){dk(a,0,v[b+24>>2]+1300380|0);break k}d=Tb(e+32|0,56931);f=Vf(c,d);vb(d);if(f){c=e+32|0;d=v[v[b+24>>2]+480184>>2];b=33760;l:{while(1){if((d|0)==v[b>>2]){co(c,0,v[b+8>>2]);break l}b=b+12|0;if((b|0)!=33808){continue}break}Jb(c)}v[23048]=0;T(9,a|0,0,e+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break j}vb(e+32|0);break k}d=Tb(e+32|0,56941);f=Vf(c,d);vb(d);if(f){m=v[v[b+24>>2]+480184>>2];c=gb-48|0;gb=c;b=33760;i=vk(c+32|0);d=Jb(e+32|0);while(1){if((m|0)==v[b>>2]){f=v[b+4>>2];v[23048]=0;f=Q(2,c+16|0,f|0)|0;g=v[23048];v[23048]=0;m:{n:{o:{p:{q:{r:{if((g|0)!=1){v[23048]=0;T(1429,c|0,i|0,f|0);g=v[23048];v[23048]=0;if((g|0)==1){break p}if(!w[c+4|0]){break m}if(!hd(d)){v[23048]=0;g=Q(2,c|0,33808)|0;h=v[23048];v[23048]=0;if((h|0)==1){break r}v[23048]=0;Q(183,d|0,g|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break q}vb(g)}v[23048]=0;Q(183,d|0,f|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){break m}b=P()|0;O()|0;break o}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;vb(g);break o}b=P()|0;O()|0}vb(f)}vb(d);oO(i);R(b|0);L()}vb(f)}b=b+12|0;if((b|0)!=33808){continue}break}oO(i);gb=c+48|0;v[23048]=0;T(9,a|0,0,e+32|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,56956);f=Vf(c,d);vb(d);if(f){dk(a,0,v[b+24>>2]+1300368|0);break k}d=Tb(e+32|0,56964);f=Vf(c,d);vb(d);if(f){dk(a,0,v[b+24>>2]+1300320|0);break k}d=Tb(e+32|0,56971);f=Vf(c,d);vb(d);if(f){cg(e+32|0,v[b+24>>2]+1300308|0);v[23048]=0;T(2095,a|0,b|0,e+32|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,56977);f=Vf(c,d);vb(d);if(f){s:{if(!cd(xy(v[b+24>>2]))){if(v[UK(xy(v[b+24>>2]))+12>>2]){break s}}Jb(a);break k}b=UK(xy(v[b+24>>2]));h=gb-192|0;gb=h;hc(h+144|0,b,44);i=v[b+44>>2];if(i){hc(h+44|0,b,44);c=gb-16|0;gb=c;b=ox(v[h+64>>2]+1900|0,v[h+60>>2]+1|0,v[h+56>>2])-ox(1970,1,1)|0;b=Fpa(b,b>>31,86400,0);d=B(v[h+52>>2],3600);f=d;b=b+d|0;d=jb+(d>>31)|0;d=b>>>0<f>>>0?d+1|0:d;f=b;b=B(v[h+48>>2],60);g=b;f=f+b|0;b=(b>>31)+d|0;b=f>>>0<g>>>0?b+1|0:b;d=v[h+44>>2];g=d;f=d+f|0;d=(d>>31)+b|0;b=AH(c+8|0,f,f>>>0<g>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];gb=c+16|0;v[h+96>>2]=b;v[h+100>>2]=d;n=h+96|0;d=h+88|0;f=v[h+96>>2];g=v[h+100>>2];c=2147483647;l=fe(+(i>>>0)*.054945054945054944);b=-1;t:{if(!(l<0x8000000000000000)){break t}c=-2147483648;b=0;if(!(l>-0x8000000000000000)){break t}if(D(l)<0x8000000000000000){c=D(l)>=1?l>0?~~F(H(l*2.3283064365386963e-10),4294967295)>>>0:~~I((l-+(~~l>>>0>>>0))*2.3283064365386963e-10)>>>0:0;b=~~l>>>0;break t}b=0}j=d;d=c+g|0;f=b+f|0;d=f>>>0<b>>>0?d+1|0:d;b=AH(j,f,d);k=gb-16|0;gb=k;i=v[b>>2];o=v[b+4>>2];v[k+12>>2]=0;v[k+8>>2]=0;v[k+4>>2]=0;b=ox(1970,1,1)+Gpa(i,o,86400,0)|0;m=b>>31;c=b;d=Fpa(b,m,1e4,0)+14780|0;b=jb;g=d;b=d>>>0<14780?b+1|0:b;f=b;d=Gpa(d,b,-14609700,-1);b=c;j=d+b|0;d=m+jb|0;d=b>>>0>j>>>0?d+1|0:d;b=j;j=Gpa(g,f,365242500,0);b=b+j|0;d=jb+d|0;d=b>>>0<j>>>0?d+1|0:d;j=Gpa(g,f,-146097e4,-1);b=j+b|0;d=jb+d|0;d=b>>>0<j>>>0?d+1|0:d;j=b;b=Gpa(g,f,3652425,0);f=jb;p=f;g=j;j=Fpa(b,f,-365,-1);g=g+j|0;f=jb+d|0;f=g>>>0<j>>>0?f+1|0:f;d=f;if(!((d|0)>0?1:(d|0)>=0)){d=p-(b>>>0<1)|0;b=b-1|0;f=Fpa(b,d,-365,-1)+c|0;d=m+jb|0;d=c>>>0>f>>>0?d+1|0:d;c=f;f=(b|0)/-4|0;g=f;c=c+f|0;f=(f>>31)+d|0;f=c>>>0<g>>>0?f+1|0:f;d=c;c=(b|0)/100|0;g=c;d=d+c|0;c=(c>>31)+f|0;c=d>>>0<g>>>0?c+1|0:c;f=d;d=(b|0)/-400|0;g=d;f=f+d|0;d=(d>>31)+c|0;d=f>>>0<g>>>0?d+1|0:d;g=f}f=b;c=Fpa(g,d,100,0)+52|0;b=jb;b=Gpa(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[k+12>>2]=f+d;v[k+8>>2]=(c-B(d,12)|0)+1;b=Fpa(b,jb,306,0)+5|0;d=jb;b=Gpa(b,b>>>0<5?d+1|0:d,-10,-1)+g|0;v[k+4>>2]=b+1;xH(n);v[n+20>>2]=v[k+12>>2]-1900;v[n+16>>2]=v[k+8>>2]-1;b=v[k+4>>2];q=n,r=Hpa(Gpa(i,o,3600,0),jb,24),v[q+8>>2]=r;v[n+12>>2]=b;b=Gpa(i,o,60,0);c=jb;q=n,r=Hpa(b,c,60),v[q+4>>2]=r;q=n,r=i-Fpa(b,c,60,0)|0,v[q>>2]=r;gb=k+16|0;hc(h+144|0,h+96|0,44)}f=e+32|0;m=hc(h,h+144|0,44);d=m;b=gb-112|0;gb=b;c=Jb(b+96|0);v[23048]=0;i=Q(2,b+80|0,11032)|0;g=v[23048];v[23048]=0;u:{v:{w:{x:{y:{z:{A:{if((g|0)!=1){g=v[d+20>>2];if(g){break A}Dc(f,c);break z}a=P()|0;O()|0;break v}v[23048]=0;v[b+48>>2]=g+1900;S(182,b- -64|0,b+48|0);g=v[23048];v[23048]=0;if((g|0)==1){break y}v[23048]=0;Q(183,c|0,b- -64|0)|0;g=v[23048];v[23048]=0;B:{if((g|0)!=1){vb(b- -64|0);if(y[d+16>>2]<12){break B}Dc(f,c);break z}a=P()|0;O()|0;vb(b- -64|0);break w}v[23048]=0;g=Q(2,b+48|0,11034)|0;h=v[23048];v[23048]=0;C:{D:{E:{F:{G:{H:{if((h|0)!=1){h=v[d+16>>2];v[23048]=0;v[b+16>>2]=h+1;S(184,b+32|0,b+16|0);h=v[23048];v[23048]=0;if((h|0)==1){break H}v[23048]=0;T(3,b- -64|0,g|0,b+32|0);h=v[23048];v[23048]=0;if((h|0)==1){break G}v[23048]=0;Q(183,c|0,b- -64|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break F}vb(b- -64|0);vb(b+32|0);vb(g);if(v[d+12>>2]-1>>>0<31){break C}Dc(f,c);break z}a=P()|0;O()|0;break w}a=P()|0;O()|0;break D}a=P()|0;O()|0;break E}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break w}v[23048]=0;g=Q(2,b+48|0,11034)|0;h=v[23048];v[23048]=0;I:{J:{K:{L:{M:{N:{O:{P:{Q:{if((h|0)!=1){v[23048]=0;S(184,b+32|0,d+12|0);h=v[23048];v[23048]=0;if((h|0)==1){break Q}v[23048]=0;T(3,b- -64|0,g|0,b+32|0);h=v[23048];v[23048]=0;if((h|0)==1){break P}v[23048]=0;Q(183,c|0,b- -64|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break O}vb(b- -64|0);vb(b+32|0);vb(g);g=v[d+8>>2];if(g){break L}g=v[d+4>>2];if(g){break K}if(v[d>>2]){break J}Dc(f,c);break z}a=P()|0;O()|0;break w}a=P()|0;O()|0;break M}a=P()|0;O()|0;break N}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break w}if(g>>>0>23){break I}g=v[d+4>>2]}if(g>>>0<60){break J}Dc(f,c);break z}v[23048]=0;g=Q(2,b- -64|0,11036)|0;h=v[23048];v[23048]=0;R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if((h|0)!=1){v[23048]=0;Q(183,c|0,g|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break ba}vb(g);if(v[d+32>>2]>=1){v[23048]=0;g=Q(2,b- -64|0,11038)|0;h=v[23048];v[23048]=0;if((h|0)==1){break aa}Eb(i,g);vb(g)}v[23048]=0;S(184,b+32|0,d+8|0);g=v[23048];v[23048]=0;if((g|0)==1){break $}v[23048]=0;g=Q(2,b+16|0,11045)|0;h=v[23048];v[23048]=0;if((h|0)==1){break _}v[23048]=0;T(3,b+48|0,b+32|0,g|0);h=v[23048];v[23048]=0;if((h|0)==1){break Z}v[23048]=0;S(184,b|0,d+4|0);h=v[23048];v[23048]=0;if((h|0)==1){break Y}v[23048]=0;T(3,b- -64|0,b+48|0,b|0);h=v[23048];v[23048]=0;if((h|0)==1){break X}v[23048]=0;Q(183,c|0,b- -64|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break W}vb(b- -64|0);vb(b);vb(b+48|0);vb(g);vb(b+32|0);if(y[d>>2]<62){break R}v[23048]=0;T(185,f|0,c|0,i|0);d=v[23048];v[23048]=0;if((d|0)!=1){break z}break x}a=P()|0;O()|0;break w}a=P()|0;O()|0;vb(g);break w}a=P()|0;O()|0;break w}a=P()|0;O()|0;break w}a=P()|0;O()|0;break S}a=P()|0;O()|0;break T}a=P()|0;O()|0;break U}a=P()|0;O()|0;break V}a=P()|0;O()|0;vb(b- -64|0)}vb(b)}vb(b+48|0)}vb(g)}vb(b+32|0);break w}v[23048]=0;g=Q(2,b+48|0,11045)|0;h=v[23048];v[23048]=0;ca:{da:{ea:{fa:{ga:{if((h|0)!=1){v[23048]=0;S(184,b+32|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break ga}v[23048]=0;T(3,b- -64|0,g|0,b+32|0);d=v[23048];v[23048]=0;if((d|0)==1){break fa}v[23048]=0;Q(183,c|0,b- -64|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break ea}vb(b- -64|0);vb(b+32|0);vb(g);v[23048]=0;Q(183,c|0,i|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break x}Dc(f,c);break z}a=P()|0;O()|0;break w}a=P()|0;O()|0;break ca}a=P()|0;O()|0;break da}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break w}Dc(f,c)}vb(i);vb(c);gb=b+112|0;break u}a=P()|0;O()|0;break w}a=P()|0;O()|0}vb(i)}vb(c);R(a|0);L()}gb=m+192|0;v[23048]=0;T(9,a|0,0,e+32|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,56982);f=Vf(c,d);vb(d);if(f){c=b;TS(e+32|0,v[b+24>>2]+1300332|0);ha:{ia:{ja:{if(!hd(e+32|0)){break ja}c=v[c+24>>2];v[23048]=0;c=QO(c);d=v[23048];v[23048]=0;if((d|0)==1){break ha}ka:{switch(c|0){case 0:v[23048]=0;S(2097,e+16|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ja}c=P()|0;O()|0;break b;case 1:v[23048]=0;S(2098,e+16|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ja}c=P()|0;O()|0;break b;case 2:if(hd(e+32|0)){v[23048]=0;S(2097,e+16|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}Eb(e+32|0,e+16|0);vb(e+16|0)}if(!hd(e+32|0)){break ja}v[23048]=0;S(2098,e+16|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ja}c=P()|0;O()|0;break b;case 3:if(hd(e+32|0)){v[23048]=0;S(2098,e+16|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break h}Eb(e+32|0,e+16|0);vb(e+16|0)}if(!hd(e+32|0)){break ja}v[23048]=0;S(2097,e+16|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ja}c=P()|0;O()|0;break b;case 4:v[23048]=0;S(2097,e+16|0,b|0);c=v[23048];v[23048]=0;la:{ma:{if((c|0)!=1){v[23048]=0;S(2098,e|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break la}if(hd(e+16|0)){break ma}v[23048]=0;Q(1201,e+32|0,e+16|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break ma}break d}c=P()|0;O()|0;break b}if(!hd(e)){v[23048]=0;Q(1201,e+32|0,e|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break d}}vb(e);vb(e+16|0);break ja}c=P()|0;O()|0;break c;case 5:break ka;default:break ja}}v[23048]=0;S(2097,e+16|0,b|0);c=v[23048];v[23048]=0;na:{if((c|0)!=1){v[23048]=0;S(2098,e|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break ia}if(hd(e)){break na}v[23048]=0;Q(1201,e+32|0,e|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break na}break f}c=P()|0;O()|0;break b}if(!hd(e+16|0)){v[23048]=0;Q(1201,e+32|0,e+16|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}}vb(e);vb(e+16|0)}v[23048]=0;T(2095,a|0,b|0,e+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break ha}vb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Tb(e+32|0,56990);f=Vf(c,d);vb(d);if(f){TS(e+32|0,v[b+24>>2]+1300332|0);v[23048]=0;T(2095,a|0,b|0,e+32|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=c;c=Tb(e+32|0,57002);d=Vf(d,c);vb(c);if(d){a=Jb(a);b=b+68|0;q=e,r=Rb(b),v[q+32>>2]=r;q=e,r=Ub(b),v[q+16>>2]=r;if(!Fb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[23048]=0;Q(1926,a|0,57011)|0;c=v[23048];v[23048]=0;if((c|0)==1){break g}}v[23048]=0;Q(1201,a|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[e+32>>2]=v[e+32>>2]+12;c=0;if(Fb(e+32|0,e+16|0)){continue}break}break k}Tb(a,56371)}gb=e+48|0;return}c=P()|0;O()|0;vb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;vb(a);break a}c=P()|0;O()|0;vb(e)}vb(e+16|0);break b}c=P()|0;O()|0;vb(e)}vb(e+16|0)}vb(e+32|0)}R(c|0);L()}function XY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-288|0;gb=e;yc(b);if(Pr(b,16766)){o=Jb(e+272|0);v[23048]=0;f=W(413,b|0,o|0,-1)|0;h=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((h|0)!=1){if(!f){break a}v[23048]=0;f=Q(427,b|0,e+264|0)|0;h=v[23048];v[23048]=0;s:{if((h|0)==1){break s}if(!f){break a}if(!HD(e+264|0)){break a}f=Xc(GD(e+264|0),jb);v[23048]=0;f=Q(250,b|0,f|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break s}if(!f){break a}if(!c){break b}v[23048]=0;S(428,a|0,4096);d=v[23048];v[23048]=0;if((d|0)==1){break s}v[23048]=0;Q(429,a+1300308|0,o|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break s}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[23048]=0;jh(a,1);d=v[23048];v[23048]=0;if((d|0)==1){break s}v[23048]=0;d=Q(2,e+112|0,16774)|0;f=v[23048];v[23048]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{if((f|0)!=1){Eb(a+1300344|0,d);vb(d);v[23048]=0;d=Q(2,e+112|0,16738)|0;f=v[23048];v[23048]=0;if((f|0)==1){break B}Eb(a+1300356|0,d);vb(d);v[23048]=0;S(431,e+56|0,16788);d=v[23048];v[23048]=0;if((d|0)==1){break A}t[e+232|0]=w[e+264|1];d=w[e+264|0];v[23048]=0;t[e+16|0]=d;S(432,e+248|0,e+16|0);d=v[23048];v[23048]=0;if((d|0)==1){break z}v[23048]=0;Y(433,e+112|0,e+56|0,e+232|0,e+248|0);d=v[23048];v[23048]=0;if((d|0)==1){break y}Eb(a+1300368|0,e+112|0);vb(e+112|0);vb(e+248|0);Hb(e+56|0);v[a+1300404>>2]=5;if(w[e+264|0]<2){break u}u[e+112>>1]=8192;v[23048]=0;d=U(340,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break w}v[23048]=0;u[e+56>>1]=d;d=Le(e+112|0,e+56|0);f=v[23048];v[23048]=0;if((f|0)==1){break w}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[23048]=0;t[e+112|0]=1;d=U(373,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break v}v[23048]=0;t[e+56|0]=d;d=Ff(e+112|0,e+56|0);f=v[23048];v[23048]=0;if((f|0)==1){break v}v[a+480196>>2]=w[d|0];v[23048]=0;Q(370,b|0,3)|0;d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;d=U(340,b|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break t}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break x}b=P()|0;O()|0;vb(e+248|0)}Hb(e+56|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+112|0]=32;v[23048]=0;d=U(373,b|0)|0;f=v[23048];v[23048]=0;C:{D:{if((f|0)==1){break D}v[23048]=0;t[e+56|0]=d;d=Ff(e+112|0,e+56|0);f=v[23048];v[23048]=0;if((f|0)==1){break D}v[a+480204>>2]=B(w[d|0],1e4);v[23048]=0;t[e+112|0]=1;d=U(373,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break C}v[23048]=0;t[e+56|0]=d;d=Ff(e+112|0,e+56|0);f=v[23048];v[23048]=0;if((f|0)==1){break C}v[a+480196>>2]=w[d|0];v[23048]=0;d=U(373,b|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break t}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;n=nc(e+248|0);m=nc(e+232|0);E:{F:{G:{H:{I:{J:{if(!x[a+480192>>1]){break J}j=1;h=e+88|1;p=e+112|12;while(1){v[23048]=0;f=W(436,a|0,j&65535,0)|0;d=v[23048];v[23048]=0;K:{L:{M:{if((d|0)==1){break M}if(!f){break J}v[23048]=0;d=W(414,b|0,f+492|0,-1)|0;i=v[23048];v[23048]=0;if((i|0)==1){break M}if(!d){break J}v[23048]=0;i=U(373,b|0)|0;d=v[23048];v[23048]=0;N:{O:{P:{Q:{R:{if((d|0)!=1){Pb(e+112|0,0,120);if(!i){break K}if(w[e+264|0]){v[23048]=0;d=Q(437,b|0,e+112|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break R}if(!d){break K}}if(!w[e+264|0]){d=_d(e+104|0,p,96);v[23048]=0;g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;T(253,e+56|0,b|0,e+8|0);d=v[23048];v[23048]=0;if((d|0)==1){break Q}if(!xb(e+56|0)){break K}}g=f+236|0;d=0;while(1){l=w[(e+112|0)+d|0];k=x[a+480190>>1];r=ud(g,d),s=(k+l|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[23048]=0;d=f+48|0;T(438,e+16|0,d|0,b|0);g=v[23048];v[23048]=0;if((g|0)==1){break P}v[23048]=0;g=f+68|0;T(438,e+40|0,g|0,b|0);l=v[23048];v[23048]=0;if((l|0)==1){break P}v[23048]=0;l=f+88|0;T(438,e+96|0,l|0,b|0);k=v[23048];v[23048]=0;if((k|0)==1){break P}v[23048]=0;S(439,b|0,e+88|0);k=v[23048];v[23048]=0;if((k|0)==1){break O}v[f>>2]=(w[h|0]|w[h+1|0]<<8)&4095;f=w[h|0]|w[h+1|0]<<8;Uv(e+88|0,d,0);Uv(e+88|0,g,1);Uv(e+88|0,l,2);r=e,s=Rb(d),v[r+56>>2]=s;r=e,s=Ub(d),v[r+80>>2]=s;if(Fb(e+56|0,e+80|0)){break N}break L}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){S:{d=v[e+56>>2];t[e+76|0]=64;k=w[d+2|0];v[23048]=0;t[e+79|0]=((k<<6)- -64>>>0)/127;k=$b(e+76|0,e+79|0);q=v[23048];v[23048]=0;if((q|0)==1){break S}t[d+2|0]=w[k|0];Qg(e+56|0);if(Fb(e+56|0,e+80|0)){continue}break L}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}r=e,s=Rb(g),v[r+56>>2]=s;r=e,s=Ub(g),v[r+80>>2]=s;T:{if(!Fb(e+56|0,e+80|0)){break T}while(1){U:{d=v[e+56>>2];t[e+76|0]=64;g=w[d+2|0];v[23048]=0;t[e+79|0]=((g<<6)+128>>>0)/255;g=$b(e+76|0,e+79|0);k=v[23048];v[23048]=0;if((k|0)==1){break U}t[d+2|0]=w[g|0];Qg(e+56|0);if(Fb(e+56|0,e+80|0)){continue}break T}break}b=P()|0;O()|0;break d}r=e,s=Rb(l),v[r+56>>2]=s;r=e,s=Ub(l),v[r+80>>2]=s;if(Fb(e+56|0,e+80|0)){l=1<<(f>>>12&3);while(1){k=v[e+56>>2];d=t[k+2|0];f=Fpa(d^-128,d>>31^-1,l,0);g=jb;d=g;V:{if((d|0)>-1?1:(d|0)>=-1?f>>>0>=4294967292:0){f=f+4|0;d=f>>>0<4?d+1|0:d;d=((d&7)<<29|f>>>3)&536870911;f=0;break V}f=(f-3|0)/8|0;d=f;f=d>>31}r=k,s=vc(d,f)^128,t[r+2|0]=s;Qg(e+56|0);if(Fb(e+56|0,e+80|0)){continue}break}}d=x[a+480190>>1]+1|0;u[e+76>>1]=d;W:{X:{Y:{Z:{g=d&65535;if(g>>>0<=3999){d=0;f=0;while(1){v[23048]=0;W(414,b|0,((g<<5)+a|0)+946300|0,-1)|0;g=v[23048];v[23048]=0;if((g|0)==1){break Z}v[23048]=0;S(440,b|0,e+56|0);g=v[23048];v[23048]=0;if((g|0)==1){break Y}v[23048]=0;S(441,e+56|0,(B(x[e+76>>1]+f|0,104)+a|0)+484380|0);f=v[23048];v[23048]=0;if((f|0)==1){break Y}f=w[e+88|0];g=w[e+75|0];v[23048]=0;u[e+80>>1]=f|d<<8&32512|((g&3)!=0)<<15;S(442,m|0,e+80|0);f=v[23048];v[23048]=0;if((f|0)==1){break X}d=d+1|0;f=d&65535;if(i>>>0<=f>>>0){break W}g=x[e+76>>1]+f|0;if(g>>>0<=3999){continue}break}}v[23048]=0;Q(370,b|0,20)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break W}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23048]=0;S(442,n|0,e+76|0);d=v[23048];v[23048]=0;if((d|0)==1){break I}v[e+56>>2]=3999;d=x[a+480190>>1];v[23048]=0;v[e+80>>2]=d+i;d=sd(e+56|0,e+80|0);f=v[23048];v[23048]=0;if((f|0)==1){break H}u[a+480190>>1]=v[d>>2]}j=j+1|0;if(x[a+480192>>1]>=(j&65535)>>>0){continue}break}}d=Jb(e+112|0);v[23048]=0;f=W(413,b|0,d|0,-1)|0;h=v[23048];v[23048]=0;if((h|0)==1){break n}if(f){v[23048]=0;T(13,e+56|0,7,d|0);f=v[23048];v[23048]=0;if((f|0)==1){break E}Eb(a+1300320|0,e+56|0);vb(e+56|0)}vb(d);d=0;while(1){v[23048]=0;f=(d<<5)+a|0;We(f+480280|0);h=v[23048];v[23048]=0;if((h|0)==1){break G}v[23048]=0;T(416,b|0,f+480289|0,-1);f=v[23048];v[23048]=0;if((f|0)==1){break G}d=d+1|0;if((d|0)!=32){continue}break}v[23048]=0;d=Q(444,b|0,e+40|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break l}if(!d){break i}if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))>>>0<12){break m}d=w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24);v[23048]=0;d=Q(250,b|0,d-11|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break l}if(d){break F}break m}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[e+96>>2]=(w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))-11;j=nc(e+112|0);v[23048]=0;W(419,b|0,j|0,v[e+96>>2])|0;d=v[23048];v[23048]=0;if((d|0)==1){break p}v[23048]=0;v[e+56>>2]=50529027;d=Gb(e+96|0,e+56|0);f=v[23048];v[23048]=0;if((f|0)==1){break q}v[e+88>>2]=B(v[d>>2],85);h=Jb(e+56|0);d=e+40|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[23048]=0;v[e+16>>2]=d;d=Gb(e+88|0,e+16|0);f=v[23048];v[23048]=0;if((f|0)==1){break r}d=v[d>>2];v[23048]=0;S(111,h|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break r}if(v[e+96>>2]){f=0;while(1){_:{i=w[oc(j,f)|0];d=f+1|0;if(!((i|0)!=255|v[e+96>>2]-d>>>0<2)){d=t[oc(j,d)|0];i=w[oc(j,f+2|0)|0];r=e,s=hf(h),v[r+16>>2]=s;Sd(e+32|0,e+16|0);v[23048]=0;ba(420,h|0,v[e+32>>2],i|0,d|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){d=f+3|0;break _}break r}v[23048]=0;S(110,h|0,i<<24>>24);f=v[23048];v[23048]=0;if((f|0)!=1){break _}break r}f=d;if(y[e+96>>2]>d>>>0){continue}break}}v[23048]=0;Y(421,e+16|0,5,7,h|0);d=v[23048];v[23048]=0;$:{if((d|0)!=1){Eb(h,e+16|0);vb(e+16|0);d=zb(Ob(h));f=Bb(h);v[23048]=0;ga(422,a+1300332|0,d|0,f|0,74,0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break $}vb(h);gc(j);break m}break r}break r}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;vb(h);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}gc(j);break d}b=P()|0;O()|0;vb(d);break d}d=Qb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[23048]=0;ga(423,d|0,b|0,f|0,65535,65535)|0;d=v[23048];v[23048]=0;if((d|0)==1){break l}j=c&1;if(j){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[23048]=0;S(385,a+484344|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break l}}f=e+264|3;aa:{if(!(w[f|0]|w[f+1|0]<<8)){break aa}h=a+484344|0;d=0;while(1){v[23048]=0;i=Q(250,b|0,4)|0;g=v[23048];v[23048]=0;ba:{if((g|0)!=1){if(i){break ba}break aa}b=P()|0;O()|0;break d}v[23048]=0;i=U(376,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break f}v[23048]=0;T(341,e+112|0,b|0,i|0);i=v[23048];v[23048]=0;if((i|0)==1){break g}ca:{if(!j){break ca}v[23048]=0;i=U(373,e+112|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}v[23048]=0;Q(370,e+112|0,1)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}v[23048]=0;i=W(386,h|0,d&65535,i+1|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}if(!i){break ca}v[23048]=0;T(417,e+112|0,e+56|0,-1);i=v[23048];v[23048]=0;if((i|0)==1){break e}i=Yb(h,d);v[23048]=0;S(418,i|0,e+56|0);i=v[23048];v[23048]=0;if((i|0)==1){break e}i=Yb(h,d);v[23048]=0;T(425,i|0,1,e+112|0);i=v[23048];v[23048]=0;if((i|0)==1){break e}}yb(e+112|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break i}if(!x[a+480190>>1]){break j}d=0;while(1){c=d+1|0;if(!w[sc(m,d)|0]){c=d+1|0;f=B(c,104)+a|0;d=Sc(e+112|0,u[f+484414>>1]&1?16:8,1,0,u[sc(m,d)>>1]>-1?0:6);v[23048]=0;W(384,d|0,f+484380|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break k}}d=c;if(d>>>0<x[a+480190>>1]){continue}break}break j}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(!x[a+480190>>1]){break i}b=0;while(1){c=w[sc(m,b)|0];da:{if(!c){break da}c=c-1&65535;if(uc(n)>>>0<=c>>>0){break da}c=(w[sc(m,b)+1|0]&127)+x[sc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break da}f=B(c,104);d=(f+a|0)+484380|0;if(!Od(d)){break da}h=a+484380|0;c=h+B(b+1|0,104)|0;f=f+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[f+34>>1]&1;v[c>>2]=v[d>>2];v[23048]=0;h=U(446,c|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break h}if(!h){break da}hc(zb(v[c+20>>2]),zb(v[f+20>>2]),Oi(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}Ze(m);Ze(n);break b}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(e+112|0)}Ze(m);Ze(n)}vb(o);R(b|0);L()}d=1}vb(o)}gb=e+288|0;return d|0}function HZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;o=xh(b,16426);a:{if(!o){break a}if(!Nb(b,6)){break a}while(1){b:{k=_f(b);c:{if((k|0)==(qn(16431)|0)){break c}i=w[16436]|w[16437]<<8|(w[16438]<<16|w[16439]<<24);if(!(k&1616928864)|k&-2139062144){break c}if((i|0)!=(k|0)){break b}}kg(b,4);break a}l=1;q=Fg(b);if(x[a+480192>>1]){while(1){j=v[(((l&65535)<<2)+a|0)+900380>>2];if(j){d:{i=q;m=b;p=k;if((qn(16416)|0)==(k|0)){Vb(m,i);break d}e=p;c=i;d=m;g=0;h=gb-48|0;gb=h;e:{f:{g:{h:{i:{j:{k:{l:{m:{f=j;n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+23|0]=s;g=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+18|0]=s;g=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Nb(d,c)){break n}r=f,s=Xl(d,c),v[r>>2]=s;g=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+21|0]=s;g=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}e=f+236|0;td(h+24|0,d,c);d=0;while(1){v[23048]=0;c=U(358,h+24|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break F}r=ud(e,d),s=c,u[r>>1]=s;d=d+1|0;if(d>>>0<128){continue}break}yb(h+24|0);g=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+31|0]=s;g=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+34|0]=s;g=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+16|0]=s;g=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[h+24>>2]=240;r=h,s=Xl(d,c),v[r+8>>2]=s;Eg(f+68|0,v[Gb(h+24|0,h+8|0)>>2]);g=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}td(h+24|0,d,c);d=0;v[23048]=0;c=ci(f,1);e=v[23048];v[23048]=0;if((e|0)==1){break k}if(Lb(c)){while(1){v[23048]=0;e=U(360,h+24|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break k}r=Mb(c,d),s=e,t[r+2|0]=s;d=d+1|0;if(Lb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+82|0]=s;g=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+27|0]=s;g=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}td(h+24|0,d,c);d=0;v[23048]=0;c=ci(f,1);e=v[23048];v[23048]=0;if((e|0)==1){break h}if(Lb(c)){while(1){v[23048]=0;e=U(358,h+24|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break h}r=Mb(c,d),s=e,u[r>>1]=s;d=d+1|0;if(Lb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+83|0]=s;g=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}r=f,s=B(Tr(d,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[r+40>>2]=s;g=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+36|0]=s;g=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}td(h+24|0,d,c);d=0;v[23048]=0;c=ci(f,2);e=v[23048];v[23048]=0;if((e|0)==1){break l}if(Lb(c)){while(1){v[23048]=0;e=U(360,h+24|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break l}r=Mb(c,d),s=e,t[r+2|0]=s;d=d+1|0;if(Lb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}td(h+24|0,d,c);d=0;v[23048]=0;c=ci(f,2);e=v[23048];v[23048]=0;if((e|0)==1){break i}if(Lb(c)){while(1){v[23048]=0;e=U(358,h+24|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break i}r=Mb(c,d),s=e,u[r>>1]=s;d=d+1|0;if(Lb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+24|0]=s;g=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}td(h+24|0,d,c);d=0;v[23048]=0;c=ci(f,0);e=v[23048];v[23048]=0;if((e|0)==1){break j}if(Lb(c)){while(1){v[23048]=0;e=U(360,h+24|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break j}r=Mb(c,d),s=e,t[r+2|0]=s;d=d+1|0;if(Lb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+62|0]=s;g=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}td(h+24|0,d,c);d=0;v[23048]=0;c=ci(f,0);e=v[23048];v[23048]=0;if((e|0)==1){break g}if(Lb(c)){while(1){v[23048]=0;e=U(358,h+24|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break g}r=Mb(c,d),s=e,u[r>>1]=s;d=d+1|0;if(Lb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+63|0]=s;g=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+15|0]=s;g=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}td(h+24|0,d,c);e=Jb(h+8|0);if(c){d=0;while(1){v[23048]=0;g=U(361,h+24|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break E}v[23048]=0;S(362,e|0,g|0);g=v[23048];v[23048]=0;if((g|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[23048]=0;Q(354,f+492|0,e|0)|0;c=v[23048];v[23048]=0;g=1;if((c|0)==1){break E}vb(e);yb(h+24|0);break n}if(c>>>0>4){break n}if(!Nb(d,c)){break n}r=f,s=Xl(d,c),v[r+4>>2]=s;g=1;break n}if(c>>>0>4){break n}if(!Nb(d,c)){break n}r=f,s=Xl(d,c),v[r+8>>2]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+61|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f- -64|0,s=xd(d,c),t[r|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+81|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+84|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+101|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+102|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+103|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+104|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+17|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+19|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+20|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+22|0]=s;g=1;break n}if(c>>>0>2){break n}if(!Nb(d,c)){break n}r=f,s=Tr(d,c),u[r+28>>1]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+30|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=GE(d,c),t[r+26|0]=s;g=1;break n}if(c>>>0>128){break n}e=f+108|0;td(h+24|0,d,c);d=0;while(1){v[23048]=0;c=U(360,h+24|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break p}r=lc(e,d),s=c,t[r|0]=s;d=d+1|0;if(d>>>0<128){continue}break}yb(h+24|0);g=1;break n}d=P()|0;O()|0;break f}d=P()|0;O()|0;vb(e);break f}if(c>>>0>32){break n}td(h+24|0,d,c);e=Jb(h+8|0);if(c){d=0;while(1){v[23048]=0;g=U(361,h+24|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break m}v[23048]=0;S(362,e|0,g|0);g=v[23048];v[23048]=0;if((g|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[23048]=0;Q(354,f+524|0,e|0)|0;c=v[23048];v[23048]=0;g=1;if((c|0)!=1){vb(e);yb(h+24|0);break n}break m}if(c>>>0>2){break n}if(!Nb(d,c)){break n}r=f,s=Tr(d,c),u[r+12>>1]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+25|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+35|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+105|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+85|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+65|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+100|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+80|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=xd(d,c),t[r+60|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Nb(d,c)){break n}r=f,s=GE(d,c),t[r+33|0]=s;g=1;break n}g=1;c=Xl(d,c);if(!xp(c)){break n}t[f+14|0]=c;break n}v[h+24>>2]=240;r=h,s=Xl(d,c),v[r+8>>2]=s;Eg(f+48|0,v[Gb(h+24|0,h+8|0)>>2]);g=1;break n}v[h+24>>2]=240;r=h,s=Xl(d,c),v[r+8>>2]=s;Eg(f+88|0,v[Gb(h+24|0,h+8|0)>>2]);g=1;break n}d=P()|0;O()|0;break f}c=Tr(d,c);d=v[f+40>>2];v[f+40>>2]=d-((d>>>0)%1e4|0)+(c>>>0)%1e4;g=1}gb=h+48|0;break e}d=P()|0;O()|0;vb(e);break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0}yb(h+24|0);R(d|0);L()}if(!g){Vb(m,i);break d}if((qn(16421)|0)==(p|0)){i=w[j+15|0];t[j+15|0]=0;t[j+60|0]=i>>>1&2|i<<1&4|(w[j+60|0]&240|i&1);t[j+80|0]=i>>>4&2|i>>>2&4|(w[j+80|0]&240|i>>>3&1);t[j+100|0]=i>>>5&4|(w[j+100|0]&224|i>>>6&1)}}}l=l+1|0;if(x[a+480192>>1]>=(l&65535)>>>0){continue}break}}if(Nb(b,6)){continue}break}}return o|0}function _oa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=gb+-64|0;gb=f;yc(a);a:{b:{if(b>>>0<=2){C=f,D=Hd(a),t[C+56|0]=D;Vb(a,2);b=f+56|2;e=Fg(a);t[b|0]=e;t[b+1|0]=e>>>8;b=f+56|4;e=_f(a);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;break b}Fr(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{m=d+484344|0;b=f+56|2;r=Gd(w[b|0]|w[b+1|0]<<8,1,1024);l=Zy(m,r,0);if((l|0)!=65535){i=Of(Yb(m,l),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];s=x[Vc(f,f+40|0)>>1];e=s+1|0;if(x[d+480188>>1]>(e&65535)>>>0){b=e&65535;while(1){t[i+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Ev(f+40|0,e,f);if(r){b=(b|0)!=0;while(1){d:{e:{if(!w[oc(o,0)|0]){v[23048]=0;e=U(373,a|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}e=e<<24>>24;if((e|0)<=-1){v[23048]=0;i=U(373,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}C=oc(o,0),D=i,t[C|0]=D}y=0;t[f|0]=0;g=e&63;f:{g:{if(!g){break g}v[23048]=0;e=U(373,a|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}t[f|0]=e;i=0;h:{switch(g-1|0){case 0:t[c+12|0]=0;v[23048]=0;t[f+36|0]=1;b=Ff(f+36|0,f);e=v[23048];v[23048]=0;if((e|0)!=1){t[c+14|0]=w[b|0];t[c+15|0]=0;b=1;break f}break c;case 1:if(!e){break f}t[c+15|0]=e;b=1;t[c+12|0]=1;i=w[c+13|0];if(!i){break g}t[c+14|0]=B(B(e,i),15);break g;case 2:e=e>>>4|0;t[c+13|0]=e;if(e){b=w[c+12|0]!=0;break f}t[c+12|0]=0;break f;case 3:i=e;break f;case 5:if(!e){break f}i=(w[c+12|0]?15:14)+c|0;b=w[i|0];t[i|0]=b>>>0<256-e>>>0?b+e|0:-1;b=1;break g;case 6:break h;default:break f}}if(!e){break f}b=1;g=(w[c+12|0]?15:14)+c|0;i=w[g|0];t[g|0]=i>>>0>e+1>>>0?i-e|0:1}i=0}v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d}i=0;e=oc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;y=0;if(!(b&1)){break d}}b=w[c+12|0];e=w[c+13|0];if(e?0:b){break d}i:{if(b){v[f>>2]=1;b=w[c+15|0];v[23048]=0;v[f+28>>2]=B(b,e)<<1;b=Wf(f,f+28|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}e=v[b>>2];break i}e=B(w[c+14|0],30)+30|0}b=255;j:{while(1){g=B(b,e);if(g-1536>>>0<10752){e=g;break j}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(e|0)/48;Vd(f+32|0,32,255);v[23048]=0;v[f>>2]=1;b=Wf(f,f+36|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}t[c+16|0]=v[b>>2];y=1}b=Yb(m,l);v[23048]=0;b=Wc(b,k,1);e=v[23048];v[23048]=0;if((e|0)==1){break c}if(s){z=k-1|0;h=1;p=1;while(1){k:{l:{m:{n:{if(!w[oc(o,h)|0]){v[23048]=0;j=U(373,a|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}if(j&128){v[23048]=0;e=U(373,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}C=oc(o,h),D=e,t[C|0]=D}A=1;if(j&64){v[23048]=0;e=U(373,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}t[b+1|0]=e;A=!e}if(!(j&32)){e=w[b|0];break n}v[23048]=0;e=U(373,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}t[b|0]=e;if((e-1&255)>>>0<=107){e=lp(e+24|0);t[b|0]=e;C=ad(c,h),D=e,t[C+1|0]=D;break n}if((e+127&255)>>>0<=107){e=lp((e&127)+24|0);t[b|0]=e;C=ad(c,h),D=e,t[C|0]=D;t[b|0]=0;break m}if((e|0)!=255){break n}t[b|0]=254;break l}e=oc(o,h);t[e|0]=w[e|0]-1;break k}if(e&255){break l}}if(!w[b+1|0]){break l}e=w[ad(c,h)+1|0];t[b+1|0]=0;t[b|0]=e}v[23048]=0;e=ne(b);g=v[23048];v[23048]=0;if((g|0)==1){break c}if(e){C=ad(c,h),D=0,t[C+5|0]=D}t[f+28|0]=0;t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;if(j&16){t[b+2|0]=1;v[23048]=0;e=U(373,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}t[b+4|0]=e+2>>>2}o:{if(!(j&8)){break o}v[23048]=0;e=U(373,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}v[23048]=0;t[f+28|0]=e;e=U(373,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}t[f+25|0]=e;p:{q:{r:{s:{t:{u:{v:{w:{g=w[f+28|0];switch(g-1|0){case 0:break q;case 9:break r;case 5:case 6:case 7:case 8:break s;case 4:break t;case 3:break u;case 2:break v;case 1:break w;default:break p}}t[b|0]=255;break p}C=b,D=w[ad(c,h)+1|0],t[C|0]=D;C=ad(c,h),D=0,t[C+5|0]=D;break p}e=Dv(e,w[c+16|0]);t[f+25|0]=e;x:{if(e){t[f+28|0]=20;t[f+25|0]=e|208;break x}t[f+28|0]=0}if(w[b|0]){break o}C=b,D=w[ad(c,h)+1|0],t[C|0]=D;C=ad(c,h),D=0,t[C+5|0]=D;break o}t[f|0]=1;e=Dv(e,w[c+16|0]);v[23048]=0;t[f+22|0]=e;e=Ff(f,f+22|0);g=v[23048];v[23048]=0;if((g|0)!=1){t[f+25|0]=w[e|0];t[f+28|0]=15;C=ad(c,h),D=0,t[C+5|0]=D;break o}break c}y:{if(!k){break y}if((g|0)==w[ad(c,h)+4|0]){break y}e=Yb(m,l);v[23048]=0;g=De(f,20,(w[f+28|0]+122|160)&255);n=v[23048];v[23048]=0;if((n|0)==1){break c}g=mp(kp(Ve(g,z),p&65535));v[23048]=0;e=Q(479,e|0,g|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}if(!e){break y}C=ad(c,h),D=w[f+28|0],t[C+4|0]=D}t[f+28|0]=10;if(!w[b|0]){C=b,D=w[ad(c,h)+1|0],t[C|0]=D}C=ad(c,h),D=0,t[C+5|0]=D;break o}t[f+28|0]=20;C=f,D=w[ad(c,h)+5|0]?-98:-97,t[C+25|0]=D;e=ad(c,h);t[e+5|0]=w[e+5|0]^1;break o}t[b|0]=254}t[f+28|0]=0}n=0;e=0;z:{if(!(j&4)){break z}v[23048]=0;e=U(373,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}v[23048]=0;t[f+27|0]=e;e=U(373,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}t[f+24|0]=e;g=f;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{q=w[f+27|0];switch(q-1|0){case 11:break C;case 10:break D;case 7:case 8:case 9:break E;case 6:break F;case 5:break G;case 3:case 4:break H;case 2:break I;case 1:break J;case 0:break K;default:break B}}v[23048]=0;it(f,e<<24>>24<<3,128);e=v[23048];v[23048]=0;if((e|0)==1){break c}v[23048]=0;e=ne(b);g=v[23048];v[23048]=0;if((g|0)==1){break c}if(e){C=b,D=lp(v[f>>2]+w[b|0]|0),t[C|0]=D}t[f+27|0]=35;t[f+24|0]=w[f+4|0]^128;e=0;break z}e=Dv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|208;e=1;break z}t[f+27|0]=0;e=1;break z}e=1;break A}g=w[c+16|0];v[23048]=0;e=bD(e,g,1);g=v[23048];v[23048]=0;if((g|0)==1){break c}t[f+24|0]=e;t[f+27|0]=w[f+27|0]==4?2:3;e=1;break z}if(!w[b|0]){C=b,D=w[ad(c,h)|0],t[C|0]=D;e=w[f+24|0]}g=w[c+16|0];v[23048]=0;e=bD(e&255,g,0);g=v[23048];v[23048]=0;if((g|0)==1){break c}t[f+27|0]=4;t[f+24|0]=e;e=1;break z}C=b,D=lp(e+25|0),t[C|0]=D;t[f+24|0]=255;t[f+27|0]=4;e=1;break z}L:{if(!k){break L}if((q|0)==w[ad(c,h)+2|0]){break L}e=Yb(m,l);v[23048]=0;g=De(f,20,(w[f+27|0]-8|48)&255);q=v[23048];v[23048]=0;if((q|0)==1){break c}g=mp(kp(Ve(g,z),p&65535));v[23048]=0;e=Q(479,e|0,g|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}if(!e){break L}C=ad(c,h),D=w[f+27|0],t[C+2|0]=D}t[f+27|0]=5;e=w[c+16|0];v[23048]=0;e=Cv(w[f+24|0],e);g=v[23048];v[23048]=0;if((g|0)==1){break c}t[f+24|0]=e;e=1;break z}e=dY(e,w[c+16|0]);t[f+27|0]=18;t[f+24|0]=e;e=1;break z}e=Dv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|192;e=1;break z}t[f+27|0]=0;t[b|0]=254;e=1;break z}e=0}t[g+27|0]=e}M:{if(!(j&2)){break M}v[23048]=0;g=U(373,a|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break c}v[23048]=0;t[f+26|0]=g;g=U(373,a|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break c}t[f+23|0]=g;N:{O:{P:{Q:{R:{S:{T:{j=w[f+26|0];switch(j-1|0){case 9:break O;case 7:case 8:break P;case 6:break Q;case 3:case 4:case 5:break R;case 2:break S;case 0:case 1:break T;default:break N}}h=w[c+16|0];v[23048]=0;g=aD(g,h,(j|0)==1);h=v[23048];v[23048]=0;if((h|0)==1){break c}t[f+26|0]=11;t[f+23|0]=g;n=1;break M}g=dY(g,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=g;n=1;break M}U:{if(!k){break U}if((j|0)==w[ad(c,h)+3|0]){break U}g=Yb(m,l);v[23048]=0;j=De(f,20,(w[f+26|0]-4|64)&255);n=v[23048];v[23048]=0;if((n|0)==1){break c}j=mp(kp(Ve(j,z),p&65535));v[23048]=0;g=Q(479,g|0,j|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break c}if(!g){break U}C=ad(c,h),D=w[f+26|0],t[C+3|0]=D}t[f+26|0]=8;g=w[c+16|0];v[23048]=0;g=Cv(w[f+23|0],g);h=v[23048];v[23048]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break M}t[f+26|0]=9;break M}h=w[c+16|0];v[23048]=0;g=aD(g,h,(j|0)==8);h=v[23048];v[23048]=0;if((h|0)==1){break c}t[f+26|0]=29;t[f+23|0]=g;n=1;break M}t[f+26|0]=27;h=w[c+16|0];v[23048]=0;g=Cv(g,h);h=v[23048];v[23048]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break M}t[f+26|0]=0}if(e){cY(b,k,x[d+480188>>1],w[f+27|0],f+24|0)}if(n){cY(b,k,x[d+480188>>1],w[f+26|0],f+23|0)}V:{if(!A){break V}v[23048]=0;e=ne(b);g=v[23048];v[23048]=0;if((g|0)==1){break c}if(!e){break V}e=w[f+27|0];if(!e){t[f+24|0]=255;t[f+27|0]=4;break V}if(w[f+26|0]|(e|0)==4){break V}t[f+23|0]=255;t[f+26|0]=4}W:{if(w[b+2|0]!=1){break W}X:{if(!w[f+27|0]){t[f+27|0]=13;t[f+24|0]=w[b+4|0];break X}if(w[f+26|0]){break W}t[f+26|0]=13;t[f+23|0]=w[b+4|0]}t[b+2|0]=0}v[23048]=0;oo(f,f+27|0,f+24|0,f+26|0,f+23|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}Y:{if(w[b+2|0]){break Y}e=w[f+27|0];if(!e){break Y}t[b+2|0]=e;t[b+4|0]=w[f+24|0]}e=b;Z:{if(w[f+28|0]){v[23048]=0;oo(f,f+26|0,f+23|0,f+28|0,f+25|0);g=v[23048];v[23048]=0;if((g|0)==1){break c}_:{if(w[b+2|0]){break _}g=w[f+26|0];if(!g){break _}t[b+2|0]=g;t[b+4|0]=w[f+23|0]}t[b+3|0]=w[f+28|0];g=f+25|0;break Z}g=w[f+26|0];if(!g){break k}t[b+3|0]=g;g=f+23|0}t[e+5|0]=w[g|0]}b=b+6|0;p=p+1|0;h=p&65535;if(s>>>0>=h>>>0){continue}break}}$:{if(!y){break $}b=Yb(m,l);v[23048]=0;e=De(f,17,w[f+32|0]);g=v[23048];v[23048]=0;if((g|0)==1){break c}e=wh(kp(Ve(e,k),0));v[23048]=0;Q(479,b|0,e|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}b=Yb(m,l);v[23048]=0;e=De(f,16,w[f+36|0]);g=v[23048];v[23048]=0;if((g|0)!=1){e=wh(Ve(e,k));v[23048]=0;Q(479,b|0,e|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break $}}break c}aa:{if(!(i&240)){break aa}b=Yb(m,l);v[23048]=0;e=De(f,20,i>>>4|224);g=v[23048];v[23048]=0;if((g|0)!=1){e=bY(Ve(e,k));v[23048]=0;Q(479,b|0,e|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break aa}}break c}ba:{b=i&15;if(!b){break ba}e=w[c+16|0];i=Yb(m,l);b=Gd((B(b,e)>>>0)/15&255,1,15);v[23048]=0;b=De(f,20,b|96);e=v[23048];v[23048]=0;if((e|0)!=1){b=bY(Ve(b,k));v[23048]=0;Q(479,i|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break ba}}break c}b=0;k=k+1|0;if((r|0)!=(k|0)){continue}break}}gc(o)}gb=f- -64|0;return l|0}a=P()|0;O()|0;gc(o);R(a|0);L()}function Dea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;f=gb-48|0;gb=f;b=v[a+1074304>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Cg(a+1074308|0,0)}h=a+1074308|0;Db(f+32|0,h,0);if(Cb(f+32|0)){q=(v[a+480180>>2]&16777248)!=0}Db(f+32|0,h,0);if(Cb(f+32|0)){E=v[a+480180>>2]==4}i=a+1074304|0;b=v[i>>2];if(b>>>0<=18874367){a:{if(!x[a+480192>>1]){break a}c=1;while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[f+32>>2]=B(w[b+20|0],100)>>>6;v[f+16>>2]=100;F=b,G=v[Gb(f+32|0,f+16|0)>>2],t[F+20|0]=G;c:{d:{e:{if(q){e=v[i>>2];if(e>>>0>18350079){break b}k=t[b+26|0];t[b+26|0]=(((k|0)>-1?1:-1)+k|0)/2;if(e>>>0<18285314){break e}break d}e=t[b+26|0];t[b+26|0]=(((e|0)>-1?1:-1)+e|0)/2}JS(ci(b,2),4,v[a+480180>>2]);e=v[a+1074304>>2];if(e>>>0<18284544){break c}if(e>>>0>18285135){break b}if(!w[b+34|0]){break d}if(!uj(b)){break d}Kb(h,2,1)}if(y[i>>2]>18285135){break b}}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))){break b}Kb(h,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!x[a+480190>>1]|(!(v[a+480180>>2]&16777248)|y[i>>2]>18285313&q))){b=1;while(1){c=B(b&65535,104)+a|0;e=c+484419|0;if(!(w[e|0]|!(w[c+484421|0]|w[c+484420|0]))){t[e|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;g=WS(b);if((g|0)!=(b|0)){while(1){b=c;d=b+32|0;while(1){e=w[b|0];f:{g:{if((e-97&255)>>>0<=5){k=e-32|0;break g}k=99;h:{if(e>>>0<=106){if(e-88>>>0<2){break h}if((e|0)==75){break g}break f}if(e-120>>>0<2){break h}if((e|0)==107){break g}break f}k=122}t[b|0]=k}b=b+1|0;if((d|0)!=(b|0)){continue}break}c=c+32|0;if((g|0)!=(c|0)){continue}break}}b=v[a+1074304>>2]}i:{if(!x[a+480192>>1]|(!(v[a+480180>>2]&16777252)|((b|0)==18874368|b>>>0>18874895))){break i}b=1;c=0;while(1){j:{e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[e+31|0]?e:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break j}break i}t[e+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Kb(h,3,1)}b=v[i>>2];k:{if(!(v[a+480180>>2]&16777248)|(b>>>0>19006225|(b|0)==19005440)){break k}Db(f+32|0,h,0);if(!Cb(f+32|0)){Db(f+16|0,h,1);if(!Cb(f+16|0)){break k}}if(!x[a+480192>>1]){break k}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}l:{m:{n:{if(y[i>>2]<=19007232){c=a+946300|0;b=a+906300|0;while(1){e=b+80|0;XO(f+16|0,e);v[23048]=0;Y(421,f+32|0,0,8,f+16|0);k=v[23048];v[23048]=0;if((k|0)==1){break m}vb(f+16|0);v[23048]=0;Iv(e,f+32|0);e=v[23048];v[23048]=0;if((e|0)==1){break n}vb(f+32|0);b=b+160|0;if((c|0)!=(b|0)){continue}break}}o:{p:{q:{r:{if(v[a+480180>>2]!=4){break r}b=v[i>>2];if(b>>>0<19007257){break p}if(b>>>0>19071235){break q}if(w[a+1074364|0]!=4){break r}Uz(a,5)}b=v[i>>2]}if((b|0)==19202048|b>>>0>19202054){break o}}if(!x[a+480192>>1]){break o}c=1;while(1){k=(((c&65535)<<2)+a|0)+900380|0;b=v[k>>2];s:{if(!b|!w[b+20|0]|!w[b+31|0]){break s}b=b+236|0;e=Ku(b);if((b|0)!=(e|0)){while(1){if(x[b>>1]){break s}b=b+2|0;if((e|0)!=(b|0)){continue}break}}t[v[k>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}b=v[i>>2];if(b>>>0<=19267583){if(x[a+480192>>1]){c=1;while(1){b=v[(((c&65535)<<2)+a|0)+900380>>2];t:{if(!b){break t}e=t[b+26|0];t[b+26|0]=(((e|0)>-1?1:-1)+e|0)/2;if(y[i>>2]>18350079?q:0){break t}t[b+19|0]=w[b+19|0]+3>>>2}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}b=v[i>>2]}u:{if(!x[a+480192>>1]|b>>>0>19398673){break u}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Kb(h,94,1);break u}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}v:{if(!x[a+480192>>1]|y[i>>2]>19399427){break v}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Kb(h,101,1);break v}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=gb-16|0;gb=b;u[f+12>>1]=0;v[f+8>>2]=a;Db(b+8|0,a+1074308|0,0);F=f,G=Cb(b+8|0),t[F+14|0]=G;gb=b+16|0;b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;c=gb-16|0;gb=c;o=a+484344|0;k=Te(o);b=v[f+4>>2];e=v[f>>2];v[c>>2]=e;v[c+4>>2]=b;v[c+8>>2]=e;v[c+12>>2]=b;b=c;e=gb-32|0;gb=e;C=k-1&65535;w:{if(Te(o)>>>0>C>>>0){s=v[b>>2];z=v[b+4>>2];while(1){b=A&65535;if(ai(ef(o,b))){g=Rb(ef(o,b));d=Ub(ef(o,b));b=e;v[b+24>>2]=s;v[b+28>>2]=z;v[b+8>>2]=s;v[b+12>>2]=z;k=b+8|0;m=gb-16|0;gb=m;v[m>>2]=d;v[m+8>>2]=g;if(Fb(m+8|0,m)){while(1){d=v[m+8>>2];b=k;n=x[b+4>>1];g=n+1|0;u[b+4>>1]=g;if(x[v[b>>2]+480188>>1]<=(g&65535)>>>0){u[b+4>>1]=0}x:{if(tg(d)){break x}g=v[b>>2];l=v[g+1074304>>2];y:{z:{A:{B:{C:{D:{E:{p=v[g+480180>>2];F:{G:{if((p|0)==2){if(l>>>0>18415615){break G}if(w[d+3|0]!=23){break F}Af(d+5|0,64);break F}H:{I:{if(p&16777248){J:{if(l>>>0>=18285314){if(w[b+6|0]){break J}if(l>>>0>=18874368){break I}}K:{switch(w[d+3|0]-20|0){case 3:Af(d+5|0,128);break J;case 0:break K;default:break J}}g=w[d+5|0];if((g|0)!=208){if((g|0)!=192){break J}t[d|0]=254;t[d+3|0]=0;break J}t[d+3|0]=0}L:{M:{N:{if(l>>>0>=18350080){if(w[b+6|0]){break N}if(l>>>0>=18874368){break I}}j=w[d+3|0];if(j>>>0>29){break M}g=1;if(!(1<<j&536873152)){break M}break L}if(l>>>0>=18874368){break I}j=w[d+3|0]}g=0}r=g;g=j&255;g=r|((g|0)==24|(g|0)==22);break H}if((p|0)!=4){break G}O:{P:{Q:{R:{S:{if(l>>>0<18285314){break S}g=!w[b+6|0]&l>>>0<18874368;if(g){break S}if(l>>>0>19137025){break A}if(!(w[d+3|0]!=23|w[d+5|0]<65)){t[d+3|0]=0}if(!g&l>>>0>18415615){break R}}if(w[d+3|0]!=10|w[d+2|0]!=11){break Q}t[d+3|0]=0;break Q}if(l>>>0>18874639){break P}}if(w[d+2|0]!=11|w[d+3|0]!=4){break O}g=w[d+4|0];if(w[b+6|0]?0:!g){break O}j=w[d+5|0];if(!j){break O}t[d+2|0]=0;F=d,G=yv(j+(g<<4)|0),t[F+5|0]=G;break O}if(l>>>0>19007240){break A}}if(w[d+5|0]|w[d+3|0]!=16){break G}t[d+3|0]=0;break G}g=0}T:{if(!g){break T}j=w[d+5|0];g=j&15;if(!g|(g|0)==15){break T}j=j&240;if(!j|(j|0)==240){break T}if(w[d+3|0]==24){t[d+5|0]=j;break T}t[d+5|0]=g}if(l>>>0>19005699){break A}if((l|0)==19005440){break E}if(w[b+6|0]|(!x[v[b>>2]+480192>>1]|x[v[b>>2]+480192>>1]>=w[d+1|0])){break G}t[d+4|0]=0;t[d+2|0]=1}if(l>>>0>18874367){break A}}r=w[d+5|0]&240;D=(r|0)==96;j=w[d+3|0];g=D&(j|0)==20;if(!(!D|(j|0)!=28)){if(!w[b+6|0]|(p|0)!=4){break D}g=g|l>>>0<18350080}if(!g|!n){break B}break C}j=d+2|0;b=w[d+2|0];if((b|0)==8){break z}break y}if(!n){break A}}b=d+B(0-n|0,6)|0;while(1){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}j=w[d+3|0]}if(!n|((j&255)!=20|(r|0)!=224)){break A}b=d+B(0-n|0,6)|0;while(1){if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}j=d+2|0;b=w[d+2|0];if((b|0)!=8){break y}if((l|0)==19333120|l>>>0>19333174){break x}}U:{V:{W:{X:{b=w[d+3|0];switch(b-5|0){case 0:break V;case 2:break X;case 1:break x;default:break W}}if(!w[d+4|0]){break U}t[d+3|0]=11;break x}if((b|0)!=26){break x}}g=w[d+5|0];if(!(g&15)){t[d+3|0]=5;t[d+5|0]=g|w[d+4|0]&15;break U}Y:{switch(b-5|0){case 0:case 2:break U;case 1:break x;default:break Y}}if((b|0)!=26){break x}}t[j|0]=0;break x}if(!(w[d+3|0]|((p|0)==16777216|(b|0)!=15))){t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3;break x}if(w[d+3|0]!=10|l>>>0>19922963|(b|0)!=15){break x}if(!(w[d+4|0]?!w[d+5|0]:0)){t[j|0]=0;break x}t[d+3|0]=0}Oj(m+8|0);if(Fb(m+8|0,m)){continue}break}}b=v[k+4>>2];v[e+16>>2]=v[k>>2];v[e+20>>2]=b;gb=m+16|0}A=A+1|0;if((A&65535)>>>0<=C>>>0){continue}break}v[f+32>>2]=s;v[f+36>>2]=z;break w}k=v[b+4>>2];v[f+32>>2]=v[b>>2];v[f+36>>2]=k}gb=e+32|0;gb=c+16|0;Z:{_:{if(!q){break _}b=v[i>>2];if(b>>>0>19267583){break _}Kb(h,8,(b|0)==18284544|b>>>0>18285313);b=44024;while(1){c=v[i>>2];e=v[b+4>>2];Kb(h,v[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=44360){continue}break}break Z}if(!E){break Z}b=v[i>>2];if(b>>>0>19267583){break Z}Kb(h,8,b>>>0>18285313);b=44376;while(1){Kb(h,v[b>>2],y[i>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=44608){continue}break}}$:{if(v[a+480180>>2]&16777248){b=44608;while(1){c=v[i>>2];e=v[b+4>>2];k=e&-65536;if(!(c>>>0<=k>>>0|c>>>0>=e>>>0?c>>>0>=k>>>0:0)){Cg(h,v[b>>2])}b=b+8|0;if((b|0)!=44656){continue}break}break $}if(v[a+480180>>2]==4){b=44656;while(1){if(y[i>>2]<y[b+4>>2]){Cg(h,v[b>>2])}b=b+8|0;if((b|0)!=44712){continue}break}break $}if(v[a+480180>>2]!=2){break $}b=44720;while(1){if(y[i>>2]<y[b+4>>2]){Cg(h,v[b>>2])}b=b+8|0;if((b|0)!=44800){continue}break}}aa:{if(v[a+480180>>2]==4){b=v[i>>2];if(b>>>0>18415615){break aa}Kb(h,98,1)}b=v[i>>2]}if(b-19333159>>>0<=33){b=0;while(1){c=b+77|0;Db(f+32|0,h,c);Kb(h,b+86|0,Cb(f+32|0));Cg(h,c);b=b+1|0;if((b|0)!=5){continue}break}b=v[i>>2]}c=8;ba:{ca:{if(b>>>0>=18284544){if(b>>>0>18874627){break ba}c=6;if((b|0)==18874368){break ca}}Kb(h,c,1)}b=v[i>>2]}da:{if(b>>>0<=19136511){Cg(h,7);break da}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break da}Kb(h,7,1)}Db(f+32|0,h,31);ea:{if(!Cb(f+32|0)){break ea}b=v[i>>2];if(!x[a+480192>>1]|(b>>>0<19071234|b>>>0>19398722)){break ea}b=1;while(1){fa:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break fa}e=w[c+65|0];if(!(w[c+60|0]&4)|(e|0)==255|e>>>0<=w[c- -64|0]){break fa}Kb(h,97,1);break ea}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}ga:{if(!(v[a+480180>>2]&16777218)|!x[a+480190>>1]){break ga}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break ga}break}ha:{ia:{if(!(!x[a+480192>>1]|v[a+480180>>2]!=16777216)){a=v[i>>2];if(a>>>0<19398688){break ha}if(a>>>0>19464277){break ia}Kb(h,109,1)}a=v[i>>2]}if((a|0)==19922944|a>>>0>19922996){break ga}}Cg(h,111)}gb=f+48|0;return}a=P()|0;O()|0;vb(f+32|0);break l}a=P()|0;O()|0;vb(f+16|0)}R(a|0);L()}function rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-768|0;gb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if(!dh(b,d+760|0)){break J}if(!XN(d+760|0)){break J}if(!mC(b,d+752|0)){break J}if(!WN(d+752|0)){break J}h=1313423693;e=w[d+752|0]|w[d+753|0]<<8|(w[d+754|0]<<16|w[d+755|0]<<24);if((e|0)!=1179012417){h=1414090313;if((e|0)!=538987841){break J}}l=Ni(d+728|0,b);j=_g(d+712|0);K:{if(!c){v[23048]=0;Y(1465,d+128|0,l|0,((e|0)==1179012417?1:2)|0,h|0);b=v[23048];v[23048]=0;if((b|0)!=1){break K}a=P()|0;O()|0;break a}v[23048]=0;T(1466,d+128|0,l|0,((e|0)==1179012417?1:2)|0);b=v[23048];v[23048]=0;if((b|0)==1){break u}}GU(j,d+128|0);Cd(d+128|0);v[23048]=0;T(1467,d+688|0,j|0,h|0);b=v[23048];v[23048]=0;if((b|0)==1){break v}v[23048]=0;b=U(328,d+688|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break t}g=0;L:{if(!b){break L}v[23048]=0;b=Q(1468,d+688|0,d+608|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break t}if(!b|!w[d+673|0]){break L}b=w[d+673|0];v[23048]=0;g=Q(250,d+688|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break t}if(!c|g^1){break L}v[23048]=0;S(428,a|0,8388608);b=v[23048];v[23048]=0;if((b|0)==1){break t}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+672|0]<<4^-1)&16;u[d+128>>1]=w[d+673|0];v[23048]=0;u[d+496>>1]=127;b=Vc(d+128|0,d+496|0);g=v[23048];v[23048]=0;if((g|0)==1){break c}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+674|0];v[a+480204>>2]=B(w[d+675|0],1e4);v[a+480200>>2]=w[d+680|0]<<1;v[23048]=0;Q(225,a+1300344|0,((e|0)==1179012417?44869:44835)|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break t}v[23048]=0;b=Q(2,d+128|0,44903)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}Eb(a+1300356|0,b);vb(b);v[a+1300404>>2]=5;v[23048]=0;Jr(d+496|0,2,d+608|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;S(398,d+128|0,d+496|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}Eb(a+1300308|0,d+128|0);vb(d+128|0);if(x[a+480188>>1]){b=0;i=(e|0)==1179012417;while(1){v[23048]=0;h=(b<<5)+a|0;f=h+480280|0;We(f);g=v[23048];v[23048]=0;M:{N:{O:{P:{Q:{if((g|0)!=1){v[23048]=0;g=U(373,d+688|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break Q}if(i){break P}if(g>>>0<129){break O}break N}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}if(g<<24>>24<=-1){break N}v[d+128>>2]=g<<2;v[23048]=0;v[d+496>>2]=256;g=sd(d+128|0,d+496|0);f=v[23048];v[23048]=0;if((f|0)!=1){u[h+480284>>1]=v[g>>2];break M}a=P()|0;O()|0;break b}u[h+480284>>1]=g<<1;break M}v[f>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=gb-16|0;gb=b;v[b+12>>2]=1380209231;m=b,n=eY(Rb(j),Ub(j),b+12|0),v[m+8>>2]=n;m=b,n=Ub(j),v[m>>2]=n;g=Fb(b+8|0,b);gb=b+16|0;if(g){v[23048]=0;T(1467,d+128|0,j|0,1380209231);b=v[23048];v[23048]=0;if((b|0)==1){break f}v[23048]=0;b=U(373,d+128|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break g}g=Qb(a+484360|0);v[23048]=0;ga(560,g|0,d+128|0,b+1&255,255,254)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}yb(d+128|0)}if(c&1){u[d+40>>1]=0;v[23048]=0;T(1470,d+496|0,j|0,1414807888);b=v[23048];v[23048]=0;if((b|0)==1){break h}b=cf(d+496|0);v[23048]=0;g=a+484344|0;S(385,g|0,b&65535);b=v[23048];v[23048]=0;if((b|0)==1){break n}m=d,n=Rb(d+496|0),v[m+560>>2]=n;m=d,n=Ub(d+496|0),v[m+72>>2]=n;if(Fb(d+560|0,d+72|0)){h=(e|0)!=1179012417;while(1){b=Me(d+128|0,v[d+560>>2]);v[23048]=0;i=U(373,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break k}v[23048]=0;u[d+480>>1]=i;i=U(376,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break l}v[23048]=0;T(341,d+584|0,b|0,i|0);i=v[23048];v[23048]=0;if((i|0)==1){break l}v[23048]=0;Y(1471,d+584|0,x[d+480>>1],h|0,a|0);i=v[23048];v[23048]=0;if((i|0)==1){break m}yb(d+584|0);v[23048]=0;i=Le(d+40|0,d+480|0);f=v[23048];v[23048]=0;if((f|0)==1){break l}u[d+40>>1]=x[i>>1];yb(b);sh(d+560|0);if(Fb(d+560|0,d+72|0)){continue}break}}if(x[d+40>>1]){b=0;while(1){v[23048]=0;h=b&65535;i=oe(g,h);f=v[23048];v[23048]=0;R:{if((f|0)!=1){if(i){break R}v[23048]=0;W(386,g|0,h|0,64)|0;h=v[23048];v[23048]=0;if((h|0)!=1){break R}}a=P()|0;O()|0;break i}b=b+1|0;if(x[d+40>>1]>(b&65535)>>>0){continue}break}}kd(d+496|0)}S:{if((e|0)==1179012417){v[23048]=0;T(1470,d+72|0,j|0,1414745673);b=v[23048];v[23048]=0;if((b|0)==1){break H}m=d,n=Rb(d+72|0),v[m+112>>2]=n;m=d,n=Ub(d+72|0),v[m+24>>2]=n;T:{if(Fb(d+112|0,d+24|0)){g=c&2;h=d+504|0;i=d+128|1;while(1){c=Me(d+560|0,v[d+112>>2]);v[23048]=0;b=Q(1472,c|0,d+128|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break T}U:{if(!b){break U}b=w[i|0];if((b|0)==255){break U}v[23048]=0;b=W(436,a|0,b+1|0,0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break G}if(!b){break U}e=x[a+480190>>1];v[23048]=0;T(1473,d+128|0,b|0,e|0);b=v[23048];v[23048]=0;if((b|0)==1){break G}b=0;if(!w[d+158|0]){break U}while(1){V:{if(!Zh(a)){break V}v[23048]=0;e=Q(1474,c|0,d+496|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break F}if(!e){break V}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;if((w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24))!=1347240275){break V}v[23048]=0;Ak(d+480|0,2,h);f=v[23048];v[23048]=0;W:{X:{Y:{if((f|0)==1){break Y}v[23048]=0;S(398,d+40|0,d+480|0);f=v[23048];v[23048]=0;if((f|0)==1){break Y}v[23048]=0;e=e&65535;Q(354,((e<<5)+a|0)+946300|0,d+40|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break X}vb(d+40|0);v[23048]=0;e=(B(e,104)+a|0)+484380|0;T(1475,d+496|0,d+128|0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break p}if(!g){break W}f=d+534|0;Sc(d+40|0,(w[f|0]|w[f+1|0]<<8)&4?16:8,1,0,0);v[23048]=0;W(384,d+40|0,e|0,c|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break V}a=P()|0;O()|0;break o}a=P()|0;O()|0;break o}a=P()|0;O()|0;vb(d+40|0);break o}e=Oi(e);v[23048]=0;Q(370,c|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break p}}b=b+1|0;if(b>>>0<w[d+158|0]){continue}break}}yb(c);sh(d+112|0);if(Fb(d+112|0,d+24|0)){continue}break}}kd(d+72|0);break S}a=P()|0;O()|0;break o}v[23048]=0;T(1470,d+480|0,j|0,1179011410);b=v[23048];v[23048]=0;if((b|0)==1){break E}m=d,n=Rb(d+480|0),v[m+472>>2]=n;m=d,n=Ub(d+480|0),v[m+464>>2]=n;if(Fb(d+472|0,d+464|0)){g=c&2;h=d+496|4;c=d- -64|4;i=d+128|5;while(1){e=Ni(d+560|0,v[d+472>>2]);v[23048]=0;b=U(376,d+560|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break D}Z:{if((b|0)!=538986817){break Z}v[23048]=0;b=Q(1476,d+560|0,d+456|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break C}if(!b|(w[d+456|0]|w[d+457|0]<<8|(w[d+458|0]<<16|w[d+459|0]<<24))!=1414745673){break Z}v[23048]=0;b=Q(1477,d+560|0,d+128|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break B}if(!b){break Z}b=w[i|0];if((b|0)==255){break Z}v[23048]=0;b=W(436,a|0,b+1|0,0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break A}if(!b){break Z}f=x[a+480190>>1];v[23048]=0;T(1478,d+128|0,b|0,f|0);b=v[23048];v[23048]=0;if((b|0)==1){break A}v[23048]=0;T(1466,d+496|0,e|0,2);b=v[23048];v[23048]=0;if((b|0)==1){break I}v[23048]=0;T(1470,d+112|0,d+496|0,1179011410);b=v[23048];v[23048]=0;if((b|0)==1){break z}Cd(d+496|0);m=d,n=Rb(d+112|0),v[m+104>>2]=n;m=d,n=Ub(d+112|0),v[m+96>>2]=n;_:{if(!Fb(d+104|0,d+96|0)){break _}$:{while(1){b=Me(d+72|0,v[d+104>>2]);v[23048]=0;e=U(376,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break y}aa:{ba:{if((e|0)!=538989377){break ba}if(!Zh(a)){break ba}e=w[d+452|0]|w[d+453|0]<<8;f=e-1|0;t[d+452|0]=f;t[d+453|0]=f>>>8;if(!e){yb(b);break _}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;v[23048]=0;e=Q(1476,b|0,d- -64|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break x}ca:{da:{if(!e){break da}e=d- -64|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=1347240275){break da}e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23048]=0;T(341,d+40|0,b|0,e|0);e=v[23048];v[23048]=0;ea:{if((e|0)!=1){v[23048]=0;e=Q(1479,d+40|0,d+496|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break aa}if(!e){break $}v[23048]=0;df(d+8|0,2,h);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)!=1){break ea}}a=P()|0;O()|0;break s}a=P()|0;O()|0;break r}v[23048]=0;e=f&65535;Q(354,((e<<5)+a|0)+946300|0,d+24|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break w}vb(d+24|0);v[23048]=0;e=(B(e,104)+a|0)+484380|0;T(1480,d+496|0,d+128|0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break aa}if(!g){break ca}f=w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24);v[23048]=0;Q(248,d+40|0,f+4|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break aa}f=d+536|0;Sc(d+24|0,(w[f|0]|w[f+1|0]<<8)&4?16:8,1,0,0);v[23048]=0;W(384,d+24|0,e|0,d+40|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break ca}a=P()|0;O()|0;break s}yb(b);break _}yb(d+40|0)}yb(b);sh(d+104|0);if(Fb(d+104|0,d+96|0)){continue}break _}break}a=P()|0;O()|0;break s}yb(d+40|0);yb(b)}kd(d+112|0)}yb(d+560|0);sh(d+472|0);if(Fb(d+472|0,d+464|0)){continue}break}}kd(d+480|0)}g=1}yb(d+688|0);Cd(j);yb(l)}gb=d+768|0;return g|0}a=P()|0;O()|0;break q}a=P()|0;O()|0;break b}a=P()|0;O()|0;break o}a=P()|0;O()|0;break o}a=P()|0;O()|0;break b}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;Cd(d+496|0);break q}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d+24|0);break s}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}yb(d+40|0)}yb(b);kd(d+112|0)}yb(d+560|0);kd(d+480|0);break b}a=P()|0;O()|0}yb(c);kd(d+72|0);break b}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(d+584|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0}yb(b)}kd(d+496|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+128|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}yb(d+688|0)}Cd(j);yb(l);R(a|0);L()}function Qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;j=gb-240|0;gb=j;a:{if(!Qu(a)){hc(j+80|0,a,128);uf(j+208|0,j+80|0,128,2);Fc(j+224|0,j+208|0);v[23048]=0;Q(354,b+492|0,j+224|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break a}vb(j+224|0)}u[c+34>>1]=x[c+34>>1]&65489;g=c;h=gb-48|0;gb=h;e=a;b:{if(!(w[e+128|0]==4|w[e+128|0]==8)){v[h+44>>2]=0;v[h+40>>2]=0;break b}t[h+40|0]=w[e+129|0];t[h+36|0]=100;f=w[$b(h+40|0,h+36|0)|0];v[h+44>>2]=f;t[h+36|0]=w[e+130|0];t[h+32|0]=100;z=h,A=w[$b(h+36|0,h+32|0)|0],v[z+40>>2]=A;c:{if(w[e+140|0]&16){z=h,A=Ib(w[e+150|0]|w[e+151|0]<<8)|f<<16,v[z+44>>2]=A;z=h,A=v[h+40>>2]<<16|Ib(w[e+152|0]|w[e+153|0]<<8),v[z+40>>2]=A;r=+y[g>>2]*1.52587890625e-7;e=lr(r*+y[h+44>>2]);v[h+44>>2]=e;v[h+36>>2]=v[g>>2]-e;z=h,A=lr(r*+y[h+40>>2]),v[z+32>>2]=A;z=h,A=v[Gb(h+36|0,h+32|0)>>2],v[z+40>>2]=A;break c}if(!Od(g)){break c}i=v[g>>2];f=i>>>7|0;e=B(f,(v[h+44>>2]<<7>>>0)/100|0);v[h+44>>2]=e;v[h+36>>2]=i-e;v[h+32>>2]=B(f,(v[h+40>>2]<<7>>>0)/100|0);z=h,A=v[Gb(h+36|0,h+32|0)>>2],v[z+40>>2]=A;q=h;d:{if(t[g+34|0]&1){cn(h+24|0,v[g+20>>2],B(v[g>>2],ld(g)));k=ld(g);e=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=e;f=v[h+44>>2];e=v[h+8>>2];g=v[h+40>>2];e:{if(g){p=u[e+(B(f,k)<<1)>>1];m=e+(B(k,f+g|0)<<1)|0;k=0-k<<1;while(1){f=u[m>>1]-p|0;o=f>>31;e=g;if((o^f+o)>>>0<1536){break e}m=k+m|0;g=g-1|0;if(g){continue}break}}e=0}break d}cc(h+16|0,v[g+20>>2],B(v[g>>2],ld(g)));k=ld(g);e=v[h+20>>2];v[h>>2]=v[h+16>>2];v[h+4>>2]=e;f=v[h+44>>2];e=v[h>>2];g=v[h+40>>2];f:{if(g){o=0-k|0;p=t[e+B(f,k)|0];f=e+B(k,f+g|0)|0;while(1){k=t[f|0]-p|0;m=k>>31;e=g;if((m^k+m)>>>0<6){break f}f=f+o|0;g=g-1|0;if(g){continue}break}}e=0}}v[q+40>>2]=e}}v[j+224>>2]=v[h+44>>2];v[j+228>>2]=v[h+40>>2];gb=h+48|0;f=128;o=j+224|0;m=dc(j+224|0);if(!(!v[m>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;v[c+4>>2]=v[o>>2];v[c+8>>2]=v[m>>2]+v[o>>2]}e=j;if(!(!w[a+134|0]|w[a+134|0]>199)){t[j+80|0]=w[a+134|0];t[j+208|0]=100;f=(w[$b(j+80|0,j+208|0)|0]<<7>>>0)/100|0}t[e+79|0]=f;t[j+80|0]=64;z=c,A=w[Ff(j+79|0,j+80|0)|0]>>>1|0,u[z+32>>1]=A;t[j+80|0]=64;z=b,A=w[$b(j+79|0,j+80|0)|0],v[z+4>>2]=A;v[c+24>>2]=40460;Jo(c,+t[a+139|0]*.08333333333333333+ +(0-w[a+143|0]|0)+ +t[a+138|0]*.0006510416666666666);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){Zl(b,127,1);Yl(b,0,1)}g:{if(!Od(c)){break g}if(t[a+140|0]&1){b=d;e=c;h:{if(!Od(e)){break h}f=v[e>>2];if(f>>>0<2){break h}i:{if((Wi(e)|0)==4){i=v[e+20>>2];k=0;g=f>>>1|0;while(1){mc(i+(k<<2)|0,i+((k^-1)+f<<2)|0);k=k+1|0;if((g|0)!=(k|0)){continue}break}break i}if((Wi(e)|0)==2){i=v[e+20>>2];k=0;g=f>>>1|0;while(1){zz(i+(k<<1)|0,i+((k^-1)+f<<1)|0);k=k+1|0;if((g|0)!=(k|0)){continue}break}break i}if((Wi(e)|0)!=1){break h}i=v[e+20>>2];k=0;g=f>>>1|0;while(1){th(i+k|0,i+((k^-1)+f|0)|0);k=k+1|0;if((g|0)!=(k|0)){continue}break}}Sh(e,b,0)}}if(w[a+140|0]&4){b=d;e=c;j:{if(!Od(e)){break j}f=v[e>>2];ld(e);i=0;g=B(ld(e),f);k:{if((Vi(e)|0)==2){h=v[e+20>>2]+(i<<1)|0;f=0;i=g-i|0;if(i){while(1){g=h+(f<<1)|0;u[g>>1]=x[g>>1]^-1;f=f+1|0;if((i|0)!=(f|0)){continue}break}}break k}if((Vi(e)|0)!=1){break j}h=i+v[e+20>>2]|0;f=0;i=g-i|0;if(i){while(1){g=f+h|0;t[g|0]=w[g|0]^-1;f=f+1|0;if((i|0)!=(f|0)){continue}break}}}Sh(e,b,0)}}if(!(t[c+34|0]&1|(w[a+141|0]?0:!(w[a+160|0]|w[a+170|0]==2)))){e=$q(v[c>>2],ld(c)<<1);if(!e){break g}b=e;i=B(v[c>>2],ld(c));g=v[c+20>>2];f=Oi(c);h=gb-16|0;gb=h;v[h+12>>2]=i;tc(h+12|0,f);k=v[h+12>>2];if(k){while(1){u[b>>1]=t[g|0]<<8;g=g+1|0;b=b+2|0;k=k-1|0;if(k){continue}break}v[h+12>>2]=-1}gb=h+16|0;u[c+34>>1]=x[c+34>>1]|1;QN(c,e,v[c>>2],d)}l:{if(t[a+141|0]>-1){break l}cn(j+80|0,v[c+20>>2],B(v[c>>2],ld(c)));if(t[a+141|0]>=0){break l}while(1){b=v[j+80>>2];e=v[j+84>>2];if((b|0)!=(e|0)){f=u[v[j+80>>2]>>1];while(1){f=jd(u[b>>1]-jd(f,1)|0,1);u[b>>1]=f;b=b+2|0;if((e|0)!=(b|0)){continue}break}}l=l+1|0;if((l|0)<(0-t[a+141|0]|0)){continue}break}}m:{if(w[a+170|0]!=2){break m}cn(j+80|0,v[c+20>>2],B(v[c>>2],ld(c)));f=w[a+171|0];g=w[a+172|0];e=w[a+171|0];b=0-(g>>>0<e>>>0)|0;e=g-e|0;h=b<<24|e>>>8;g=e<<24;i=wB(j+80|0);e=(i|0)/2|0;b=e;g=g+e|0;e=(e>>31)+h|0;g=vc(Gpa(g,b>>>0>g>>>0?e+1|0:e,i,i>>31),jb);b=v[j+80>>2];h=v[j+84>>2];if((b|0)==(h|0)){break m}e=f<<24;k=e;f=e>>31;e=g;i=e>>31;while(1){g=u[b>>1];g=Fpa(k,f,g,g>>31)+838860800|0;p=jb;z=b,A=vc(Gpa(g,g>>>0<838860800?p+1|0:p,1677721600,0),jb),u[z>>1]=A;f=f+i|0;k=e+k|0;f=k>>>0<e>>>0?f+1|0:f;b=b+2|0;if((h|0)!=(b|0)){continue}break}}n:{if(!w[a+160|0]){break n}cn(j+208|0,v[c+20>>2],B(v[c>>2],ld(c)));k=w[a+162|0];i=w[a+163|0];if(w[a+161|0]>=2){g=w[a+164|0];e=w[a+162|0];b=0-(g>>>0<e>>>0)|0;e=g-e|0;p=b<<23|e>>>9;b=e<<23;f=wB(j+208|0);e=(f|0)/2|0;g=b+e|0;h=(e>>31)+p|0;s=vc(Gpa(g,e>>>0>g>>>0?h+1|0:h,f,f>>31),jb)}if(w[a+161|0]>=2){g=w[a+165|0];e=w[a+163|0];b=0-(g>>>0<e>>>0)|0;e=g-e|0;p=b<<23|e>>>9;b=e<<23;h=wB(j+208|0);e=(h|0)/2|0;g=b+e|0;f=(e>>31)+p|0;n=vc(Gpa(g,e>>>0>g>>>0?f+1|0:f,h,h>>31),jb)}b=v[j+208>>2];h=v[j+212>>2];if((b|0)==(h|0)){break n}f=k<<23;g=i<<23;i=(j+80|0)+((w[a+160|0]&2)<<2)|0;l=0;k=0;while(1){e=(u[b>>1]>>1)-k|0;v[j+88>>2]=e;q=e;e=(f|0)/8388608|0;l=jd(B(q,e),8)+l|0;v[j+84>>2]=l;e=jd(B(e,l),6)+k|0;k=jd(jd(B(e,(g|0)/8388608|0),6)+e|0,2);v[j+80>>2]=k;z=b,A=Uc(v[i>>2]),u[z>>1]=A;g=g+n|0;f=f+s|0;b=b+2|0;if((h|0)!=(b|0)){continue}break}}o:{if(t[a+141|0]<1){break o}cn(j+80|0,v[c+20>>2],B(v[c>>2],ld(c)));l=0;if(t[a+141|0]<=0){break o}while(1){b=v[j+80>>2];e=v[j+84>>2];if((b|0)!=(e|0)){f=u[v[j+80>>2]>>1];while(1){f=((u[b>>1]<<1)+f|0)/3|0;u[b>>1]=f;b=b+2|0;if((e|0)!=(b|0)){continue}break}}l=l+1|0;if((l|0)<t[a+141|0]){continue}break}}p:{if(t[c+34|0]&1){cn(j- -64|0,v[c+20>>2],B(v[c>>2],ld(c)));b=v[j+68>>2];v[j+32>>2]=v[j+64>>2];v[j+36>>2]=b;k=gb-16|0;gb=k;e=v[j+36>>2];i=gb-16|0;gb=i;v[i+4>>2]=v[j+32>>2];f=Ou(k+8|0,i+4|0,i+4|0);b=v[i+4>>2];q:{if((b|0)==(e|0)){break q}b=b+2|0;v[i+4>>2]=b;if((b|0)==(e|0)){break q}b=f+(Aj(b,v[f>>2])?0:4)|0;l=v[i+4>>2];v[b>>2]=l;g=l+2|0;if((e|0)==(g|0)){break q}while(1){b=l+4|0;v[i+4>>2]=b;if((b|0)==(e|0)){if(Aj(g,v[f>>2])){v[f>>2]=g;break q}if(Aj(g,v[f+4>>2])){break q}v[f+4>>2]=g;break q}r:{if(Aj(b,g)){if(Aj(v[i+4>>2],v[f>>2])){v[f>>2]=v[i+4>>2]}if(Aj(g,v[f+4>>2])){break r}v[f+4>>2]=g;break r}if(Aj(g,v[f>>2])){v[f>>2]=g}if(Aj(v[i+4>>2],v[f+4>>2])){break r}v[f+4>>2]=v[i+4>>2]}l=v[i+4>>2];g=l+2|0;v[i+4>>2]=g;if((e|0)!=(g|0)){continue}break}}gb=i+16|0;v[k+4>>2]=0-u[v[k+8>>2]>>1];z=k,A=u[v[dc(k+8|0)>>2]>>1],v[z>>2]=A;e=v[Wf(k+4|0,k)>>2];s:{if((e|0)>=32767|!e){break s}f=v[j+32>>2];b=v[j+36>>2];if((f|0)==(b|0)){break s}while(1){u[f>>1]=(B(u[f>>1],32767)|0)/(e|0);f=f+2|0;if((b|0)!=(f|0)){continue}break}}break p}cc(j+56|0,v[c+20>>2],B(v[c>>2],ld(c)));b=v[j+60>>2];v[j+24>>2]=v[j+56>>2];v[j+28>>2]=b;k=gb-16|0;gb=k;e=v[j+28>>2];i=gb-16|0;gb=i;v[i+4>>2]=v[j+24>>2];f=Ou(k+8|0,i+4|0,i+4|0);b=v[i+4>>2];t:{if((b|0)==(e|0)){break t}b=b+1|0;v[i+4>>2]=b;if((b|0)==(e|0)){break t}b=f+(zj(b,v[f>>2])?0:4)|0;l=v[i+4>>2];v[b>>2]=l;g=l+1|0;if((e|0)==(g|0)){break t}while(1){b=l+2|0;v[i+4>>2]=b;if((b|0)==(e|0)){if(zj(g,v[f>>2])){v[f>>2]=g;break t}if(zj(g,v[f+4>>2])){break t}v[f+4>>2]=g;break t}u:{if(zj(b,g)){if(zj(v[i+4>>2],v[f>>2])){v[f>>2]=v[i+4>>2]}if(zj(g,v[f+4>>2])){break u}v[f+4>>2]=g;break u}if(zj(g,v[f>>2])){v[f>>2]=g}if(zj(v[i+4>>2],v[f+4>>2])){break u}v[f+4>>2]=v[i+4>>2]}l=v[i+4>>2];g=l+1|0;v[i+4>>2]=g;if((e|0)!=(g|0)){continue}break}}gb=i+16|0;v[k+4>>2]=0-t[v[k+8>>2]];z=k,A=t[v[dc(k+8|0)>>2]],v[z>>2]=A;e=v[Wf(k+4|0,k)>>2];v:{if((e|0)>=127|!e){break v}f=v[j+24>>2];b=v[j+28>>2];if((f|0)==(b|0)){break v}while(1){t[f|0]=(B(t[f|0],127)|0)/(e|0);f=f+1|0;if((b|0)!=(f|0)){continue}break}}}gb=k+16|0;w:{if(w[a+134|0]<101|w[a+134|0]>199){break w}e=B(v[c>>2],ld(c));if(t[c+34|0]&1){b=v[c+20>>2];g=_c(j+48|0,b,b+(e<<1)|0);e=w[a+134|0];b=v[g+4>>2];v[j+16>>2]=v[g>>2];v[j+20>>2]=b;n=(3276800-(e<<14)|0)/100|0;b=v[j+16>>2];f=v[j+20>>2];if((b|0)!=(f|0)){g=0-n|0;h=32768-n|0;while(1){e=b;k=e;i=u[e>>1];x:{if((i|0)>(n|0)){e=h+((B(n,i-n|0)|0)/(h|0)|0)|0;break x}e=((B(n,i+n|0)|0)/(h|0)|0)-h|0;if((g|0)>(i|0)){break x}e=(B(h,i)|0)/(n|0)|0}z=k,A=Uc(e),u[z>>1]=A;b=b+2|0;if((f|0)!=(b|0)){continue}break}}break w}b=v[c+20>>2];g=_c(j+40|0,b,b+e|0);e=w[a+134|0];b=v[g+4>>2];v[j+8>>2]=v[g>>2];v[j+12>>2]=b;n=(3276800-(e<<14)|0)/100|0;b=v[j+8>>2];f=v[j+12>>2];if((b|0)!=(f|0)){g=0-n|0;h=32768-n|0;while(1){e=b;k=e;i=t[e|0]<<8;y:{if((i|0)>(n|0)){e=h+((B(n,i-n|0)|0)/(h|0)|0)|0;break y}e=((B(n,i+n|0)|0)/(h|0)|0)-h|0;if((g|0)>(i|0)){break y}e=(B(h,i)|0)/(n|0)|0}z=k,A=DV((e|0)/256|0),t[z|0]=A;b=b+1|0;if((f|0)!=(b|0)){continue}break}}}if(!v[m>>2]|(!w[a+131|0]|w[a+128|0]!=8)){break g}v[c+12>>2]=v[o>>2];v[c+16>>2]=v[m>>2]+v[o>>2];if(y[m>>2]>268435456/w[a+131|0]>>>0|y[c>>2]>268435456-B(v[m>>2],w[a+131|0])>>>0){break g}h=Wi(c);f=v[o>>2];g=v[m>>2];e=w[a+131|0];i=v[c>>2]+B(v[m>>2],w[a+131|0])|0;b=$q(i,h);if(!b){break g}e=f+B(g,e+1|0)|0;v[c>>2]=i;g=hc(b,zb(v[c+20>>2]),B(h,v[m>>2]+v[o>>2]|0));z:{if(!w[a+131|0]){break z}b=1;while(1){hc(g+B(h,v[o>>2]+B(v[m>>2],b)|0)|0,zb(v[c+20>>2])+B(h,v[o>>2])|0,B(h,v[m>>2]));if(w[a+131|0]<=b>>>0){break z}b=b+1|0;continue}}hc(g+B(e,h)|0,zb(v[c+20>>2])+B(h,v[m>>2]+v[o>>2]|0)|0,B(h,i-e|0));QN(c,g,v[c>>2],d)}gb=j+240|0;return}a=P()|0;O()|0;vb(j+224|0);R(a|0);L()}function JH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=0;f=gb-144|0;gb=f;E=Pb(f,0,144);v[E+76>>2]=-1;v[E+44>>2]=a;v[E+32>>2]=2342;v[E+84>>2]=a;F=c;i=gb-304|0;gb=i;e=E;d=b;a=w[b|0];a:{if(!a){break a}b:{c:{d:{e:{while(1){f:{g:{if(pm(a&255)){while(1){a=d;d=d+1|0;if(pm(w[a+1|0])){continue}break}oi(e,0,0);while(1){b=v[e+4>>2];h:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break h}b=pd(e)}if(pm(b)){continue}break}d=v[e+4>>2];if(v[e+104>>2]){d=d-1|0;v[e+4>>2]=d}b=d-v[e+8>>2]|0;f=b>>31;d=b;b=l+v[e+124>>2]|0;c=s+v[e+120>>2]|0;b=c>>>0<s>>>0?b+1|0:b;l=c;c=d+c|0;d=b+f|0;s=c;l=c>>>0<l>>>0?d+1|0:d;break g}i:{j:{k:{b=w[d|0];if((b|0)==37){a=w[d+1|0];if((a|0)==42){break k}if((a|0)!=37){break j}}oi(e,0,0);a=((b|0)==37)+d|0;b=v[e+4>>2];l:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break l}b=pd(e)}if((b|0)!=w[a|0]){if(v[e+104>>2]){v[e+4>>2]=v[e+4>>2]-1}if(G){break a}D=0;if((b|0)>-1){break a}break c}b=s+1|0;l=b>>>0<1?l+1|0:l;s=b;break g}m=0;a=d+2|0;break i}if(!(!Lh(a)|w[d+2|0]!=36)){a=w[d+1|0]-48|0;b=gb-16|0;v[b+12>>2]=F;a=a>>>0>1?((a<<2)+F|0)-4|0:F;v[b+8>>2]=a+4;m=v[a>>2];a=d+3|0;break i}m=v[F>>2];F=F+4|0;a=d+1|0}D=0;m:{if(!Lh(w[a|0])){d=0;break m}d=0;while(1){b=a+1|0;d=(w[a|0]+d|0)-48|0;if(Lh(w[a+1|0])){d=B(d,10);a=b;continue}else{a=b}break}}b=a;c=w[b|0];n:{if((c|0)!=109){break n}p=0;D=(m|0)!=0;c=w[a+1|0];q=0;b=a+1|0}a=b+1|0;k=3;o:{p:{switch(c-65|0){case 39:c=b+2|0;b=w[b+1|0]==104;a=b?c:a;k=b?-2:-1;break o;case 43:c=b+2|0;b=w[b+1|0]==108;a=b?c:a;k=b?3:1;break o;case 51:case 57:k=1;break o;case 11:k=2;break o;case 41:break o;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break p;default:break d}}k=0;a=b}b=w[a|0];c=(b&47)==3;H=c?1:k;x=c?b|32:b;q:{if((x|0)==91){break q}r:{if((x|0)!=110){if((x|0)!=99){break r}d=(d|0)>1?d:1;break q}KH(m,H,s,l);break g}oi(e,0,0);while(1){b=v[e+4>>2];s:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break s}b=pd(e)}if(pm(b)){continue}break}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}b=b-v[e+8>>2]|0;f=b>>31;h=b;l=l+v[e+124>>2]|0;b=s+v[e+120>>2]|0;l=b>>>0<s>>>0?l+1|0:l;c=b;b=h+b|0;f=f+l|0;s=b;l=b>>>0<c>>>0?f+1|0:f}j=d;h=d>>31;oi(e,d,h);b=v[e+104>>2];c=v[e+4>>2];t:{if(b>>>0>c>>>0){v[e+4>>2]=c+1;break t}if((pd(e)|0)<0){break d}b=v[e+104>>2]}if(b){v[e+4>>2]=v[e+4>>2]-1}b=16;u:{v:{w:{x:{y:{z:{A:{switch(x-88|0){default:b=x-65|0;if(b>>>0>6|!(1<<b&113)){break u}case 9:case 13:case 14:case 15:MI(i,e,H,0);b=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-b|0)&v[e+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break b}if(!m){break u}b=v[i+8>>2];c=v[i+12>>2];f=v[i>>2];d=v[i+4>>2];switch(H|0){case 2:break w;case 1:break x;case 0:break y;default:break u};case 3:case 11:case 27:if((x&239)==99){Pb(i+32|0,-1,257);t[i+32|0]=0;if((x|0)!=115){break v}t[i+65|0]=0;t[i+46|0]=0;u[i+42>>1]=0;u[i+44>>1]=0;break v}c=w[a+1|0];f=(c|0)==94;Pb(i+32|0,f,257);t[i+32|0]=0;b=f?a+2|0:a+1|0;B:{C:{D:{a=w[(f?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break D}k=(c|0)!=94;a=b;break B}k=(c|0)!=94;t[i+78|0]=k;break C}k=(c|0)!=94;t[i+126|0]=k}a=b+1|0}while(1){b=w[a|0];E:{if((b|0)!=45){if(!b){break d}if((b|0)!=93){break E}break v}b=45;c=w[a+1|0];if(!c|(c|0)==93){break E}f=a+1|0;a=w[a-1|0];F:{if(c>>>0<=a>>>0){b=c;break F}while(1){a=a+1|0;t[a+(i+32|0)|0]=k;b=w[f|0];if(b>>>0>a>>>0){continue}break}}a=f}t[(b+i|0)+33|0]=k;a=a+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break u;case 0:case 24:case 32:break z;case 17:break A}}b=0}g=e;j=0;d=0;k=0;I=gb-16|0;gb=I;G:{H:{I:{J:{K:{L:{if(b>>>0<=36){while(1){c=v[g+4>>2];M:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break M}c=pd(g)}if(pm(c)){continue}break}N:{O:{switch(c-43|0){case 0:case 2:break O;default:break N}}k=(c|0)==45?-1:0;c=v[g+4>>2];if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break N}c=pd(g)}P:{if(!(b&-17|(c|0)!=48)){c=v[g+4>>2];Q:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break Q}c=pd(g)}if((c&-33)==88){b=16;c=v[g+4>>2];R:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break R}c=pd(g)}if(w[c+75329|0]<16){break K}if(!v[g+104>>2]){break H}v[g+4>>2]=v[g+4>>2]-1;break H}if(b){break P}b=8;break K}b=b?b:10;if(b>>>0>w[c+75329|0]){break P}if(v[g+104>>2]){v[g+4>>2]=v[g+4>>2]-1}oi(g,0,0);v[115529]=28;b=0;c=0;break G}if((b|0)!=10){break K}h=c-48|0;if(h>>>0<=9){c=0;while(1){j=c+h|0;f=j>>>0>429496728;b=v[g+4>>2];S:{if(b>>>0<y[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break S}c=pd(g)}h=c-48|0;if(!(f|h>>>0>9)){c=B(j,10);continue}break}}if(h>>>0>9){break L}r=Fpa(j,0,10,0);n=jb;f=h;while(1){d=n;b=f+r|0;d=b>>>0<f>>>0?d+1|0:d;j=b;f=(d|0)==429496729&b>>>0>2576980377|d>>>0>429496729;b=v[g+4>>2];T:{if(b>>>0<y[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break T}c=pd(g)}h=c-48|0;if(f|h>>>0>=10){break L}r=Fpa(j,d,10,0);b=r;n=jb;o=n;f=h;if((o|0)==-1&(f^-1)>>>0>=b>>>0|(o|0)!=-1){continue}break}b=10;break J}v[115529]=28;b=0;c=0;break G}b=10;if(h>>>0<=9){break J}break I}if(b-1&b){h=w[c+75329|0];if(h>>>0<b>>>0){c=0;while(1){j=c+h|0;f=j>>>0>119304646;c=v[g+4>>2];U:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break U}c=pd(g)}h=w[c+75329|0];if(!(f|h>>>0>=b>>>0)){c=B(b,j);continue}break}}if(b>>>0<=h>>>0){break J}o=b;r=Fpa(j,0,b,0);n=jb;f=h;if((n|0)==-1&(f^-1)>>>0<r>>>0){break J}while(1){c=f;d=c+r|0;f=n;j=d;d=c>>>0>d>>>0?f+1|0:f;c=v[g+4>>2];V:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break V}c=pd(g)}f=w[c+75329|0];if(f>>>0>=b>>>0){break J}Bh(I,o,0,j,d);if(v[I+8>>2]|v[I+12>>2]){break J}r=Fpa(j,d,o,0);h=r;n=jb;if((n|0)==-1&(f^-1)>>>0>=h>>>0|(n|0)!=-1){continue}break}break J}n=t[(B(b,23)>>>5&7)+75585|0];h=w[c+75329|0];if(h>>>0<b>>>0){c=0;while(1){j=c|h;f=j>>>0>134217727;c=v[g+4>>2];W:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break W}c=pd(g)}h=w[c+75329|0];if(!(f|h>>>0>=b>>>0)){c=j<<n;continue}break}}if(b>>>0<=h>>>0){break J}f=n;o=f&31;if((f&63)>>>0>=32){f=0;r=-1>>>o|0}else{f=-1>>>o|0;r=(1<<o)-1<<32-o|-1>>>o}if(!f&j>>>0>r>>>0){break J}while(1){o=h&255;h=j;c=n;j=c&31;if((c&63)>>>0>=32){d=h<<j;c=0}else{d=(1<<j)-1&h>>>32-j|d<<j;c=h<<j}j=o|c;o=b;c=v[g+4>>2];X:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break X}c=pd(g)}h=w[c+75329|0];if(o>>>0<=h>>>0){break J}if((d|0)==(f|0)&j>>>0<=r>>>0|d>>>0<f>>>0){continue}break}}if(w[c+75329|0]>=b>>>0){break I}while(1){f=v[g+4>>2];Y:{if(f>>>0<y[g+104>>2]){v[g+4>>2]=f+1;c=w[f|0];break Y}c=pd(g)}if(w[c+75329|0]<b>>>0){continue}break}v[115529]=68;k=0;j=-1;d=-1}if(v[g+104>>2]){v[g+4>>2]=v[g+4>>2]-1}if((j|0)==-1&(d|0)==-1){if(!(k|1)){v[115529]=68;b=-2;c=-1;break G}}b=k;f=b^j;c=b;b=f-b|0;h=d;d=c>>31;c=(h^d)-((c>>>0>f>>>0)+d|0)|0;break G}oi(g,0,0);b=0;c=0}gb=I+16|0;f=v[e+4>>2]-v[e+8>>2]|0;d=f;if(v[e+120>>2]==(0-d|0)&v[e+124>>2]==(0-((d>>31)+((d|0)!=0)|0)|0)){break b}if(!(!m|(x|0)!=112)){v[m>>2]=b;break u}KH(m,H,b,c);break u}J=m,K=KI(f,d,b,c),z[J>>2]=K;break u}J=m,L=Xx(f,d,b,c),A[J>>3]=L;break u}v[m>>2]=f;v[m+4>>2]=d;v[m+8>>2]=b;v[m+12>>2]=c;break u}c=(x|0)==99;k=c?d+1|0:31;n=(H|0)!=1;Z:{if(!n){b=m;if(D){b=Ad(k<<2);if(!b){break e}}v[i+296>>2]=0;v[i+300>>2]=0;d=0;while(1){q=b;_:{while(1){b=v[e+4>>2];$:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break $}b=pd(e)}if(!w[(b+i|0)+33|0]){break _}t[i+27|0]=b;b=dq(i+28|0,i+27|0,1,i+296|0);if((b|0)==-2){continue}if((b|0)==-1){break f}if(q){v[(d<<2)+q>>2]=v[i+28>>2];d=d+1|0}if(!D|(d|0)!=(k|0)){continue}break}k=k<<1|1;b=Yp(q,k<<2);if(b){continue}break f}break}if(!((i|0)==-296?1:!v[i+296>>2])){break f}p=0;break Z}if(D){d=0;b=Ad(k);if(!b){break e}while(1){p=b;while(1){b=v[e+4>>2];aa:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break aa}b=pd(e)}if(!w[(b+i|0)+33|0]){q=0;break Z}t[d+p|0]=b;d=d+1|0;if((k|0)!=(d|0)){continue}break}q=0;k=k<<1|1;b=Yp(p,k);if(b){continue}break}break d}d=0;if(m){while(1){b=v[e+4>>2];ba:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break ba}b=pd(e)}if(w[(b+i|0)+33|0]){t[d+m|0]=b;d=d+1|0;continue}else{q=0;p=m;break Z}}}while(1){b=v[e+4>>2];ca:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break ca}b=pd(e)}if(w[(b+i|0)+33|0]){continue}break}p=0;q=0}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}f=b-v[e+8>>2]|0;g=f;b=g+v[e+120>>2]|0;f=v[e+124>>2]+(g>>31)|0;f=b>>>0<g>>>0?f+1|0:f;if(!(f|b)|((b|0)!=(j|0)|(f|0)!=(h|0)?(x|0)==99:0)){break b}da:{if(!D){break da}if(!n){v[m>>2]=q;break da}v[m>>2]=p}if(c){break u}if(q){v[(d<<2)+q>>2]=0}if(!p){p=0;break u}t[d+p|0]=0}b=v[e+4>>2]-v[e+8>>2]|0;f=b>>31;d=b;l=l+v[e+124>>2]|0;b=s+v[e+120>>2]|0;l=b>>>0<s>>>0?l+1|0:l;c=b;b=d+b|0;l=f+l|0;l=b>>>0<c>>>0?l+1|0:l;s=b;G=((m|0)!=0)+G|0}d=a+1|0;a=w[a+1|0];if(a){continue}break a}break}p=0;break d}p=0;q=0}if(G){break b}}G=-1}if(!D){break a}Zb(p);Zb(q)}gb=i+304|0;gb=E+144|0;return G}function $E(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;m=gb-192|0;gb=m;y=h;G=i&65535;r=d;n=e&65535;F=(e^i)&-2147483648;l=i>>>16&32767;a:{t=e>>>16&32767;b:{c:{if(l-1>>>0<32766?t-1>>>0<=32765:0){break c}I=e&2147483647;k=I;j=d;if(!(!j&(k|0)==2147418112?!(b|c):k>>>0<2147418112)){L=d;F=e|32768;break b}I=i&2147483647;e=I;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){L=h;F=i|32768;b=f;c=g;break b}if(!(b|j|(k^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;F=2147450880;break b}F=F|2147418112;b=0;c=0;break b}if(!(d|f|(e^2147418112|g))){b=0;c=0;break b}if(!(b|j|(c|k))){break a}if(!(d|f|(e|g))){F=F|2147418112;b=0;c=0;break b}if((k|0)==65535|k>>>0<65535){i=b;d=!(n|r);h=d<<6;j=E(d?b:r)+32|0;b=E(d?c:n);b=h+((b|0)==32?j:b)|0;Uf(m+176|0,i,c,r,n,b-15|0);K=16-b|0;r=v[m+184>>2];n=v[m+188>>2];c=v[m+180>>2];b=v[m+176>>2]}if(e>>>0>65535){break c}d=!(y|G);e=d<<6;h=E(d?f:y)+32|0;d=E(d?g:G);d=e+((d|0)==32?h:d)|0;Uf(m+160|0,f,g,y,G,d-15|0);K=(d+K|0)-16|0;y=v[m+168>>2];G=v[m+172>>2];f=v[m+160>>2];g=v[m+164>>2]}e=G|65536;I=e;M=y;d=y;j=e<<15|d>>>17;d=d<<15|g>>>17;h=-102865788-d|0;e=j;i=1963258675-(j+(d>>>0>4192101508)|0)|0;Bh(m+144|0,d,j,h,i);j=v[m+152>>2];Bh(m+128|0,0-j|0,0-(v[m+156>>2]+((j|0)!=0)|0)|0,h,i);h=v[m+136>>2];i=h<<1|v[m+132>>2]>>>31;h=v[m+140>>2]<<1|h>>>31;Bh(m+112|0,i,h,d,e);j=h;h=v[m+120>>2];Bh(m+96|0,i,j,0-h|0,0-(v[m+124>>2]+((h|0)!=0)|0)|0);h=v[m+104>>2];i=h<<1|v[m+100>>2]>>>31;h=v[m+108>>2]<<1|h>>>31;Bh(m+80|0,i,h,d,e);j=h;h=v[m+88>>2];Bh(m- -64|0,i,j,0-h|0,0-(v[m+92>>2]+((h|0)!=0)|0)|0);h=v[m+72>>2];i=h<<1|v[m+68>>2]>>>31;h=v[m+76>>2]<<1|h>>>31;Bh(m+48|0,i,h,d,e);j=h;h=v[m+56>>2];Bh(m+32|0,i,j,0-h|0,0-(v[m+60>>2]+((h|0)!=0)|0)|0);h=v[m+40>>2];i=h<<1|v[m+36>>2]>>>31;h=v[m+44>>2]<<1|h>>>31;Bh(m+16|0,i,h,d,e);j=h;h=v[m+24>>2];Bh(m,i,j,0-h|0,0-(v[m+28>>2]+((h|0)!=0)|0)|0);K=(t-l|0)+K|0;h=v[m+8>>2];j=v[m+12>>2]<<1|h>>>31;k=h<<1|v[m+4>>2]>>>31;h=k-1|0;k=j-(k>>>0<1)|0;j=0;D=j;i=h;p=e;t=0;q=Fpa(h,j,e,t);e=jb;w=e;x=k;l=0;h=d;j=Fpa(k,l,d,0);d=j+q|0;k=jb+e|0;e=d;k=d>>>0<j>>>0?k+1|0:k;d=k;k=0;j=(d|0)==(w|0)&e>>>0<q>>>0|d>>>0<w>>>0;q=Fpa(x,l,p,t);t=q+d|0;j=jb+(j|k)|0;z=t;w=q>>>0>t>>>0?j+1|0:j;h=Fpa(i,D,h,o);d=0+h|0;j=jb+e|0;j=d>>>0<h>>>0?j+1|0:j;A=(e|0)==(j|0)&d>>>0<k>>>0|e>>>0>j>>>0;p=d;h=j;d=g;B=(d&131071)<<15|f>>>17;o=Fpa(i,D,B,0);d=jb;u=d;j=f;s=j<<15&-32768;j=Fpa(x,l,s,0);e=j+o|0;k=jb+d|0;k=e>>>0<j>>>0?k+1|0:k;d=k;C=Fpa(i,D,s,C);s=0+C|0;j=e;k=j+jb|0;k=s>>>0<C>>>0?k+1|0:k;k=(j|0)==(k|0)&s>>>0<J>>>0|j>>>0>k>>>0;j=(d|0)==(u|0)&j>>>0<o>>>0|d>>>0<u>>>0;e=d;d=Fpa(x,l,B,H)+d|0;j=j+jb|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=k+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=d+p|0;j=j+h|0;j=d>>>0<e>>>0?j+1|0:j;t=d;q=j;e=(j|0)==(h|0)&d>>>0<p>>>0|h>>>0>j>>>0;d=e+A|0;k=0;k=d>>>0<e>>>0?1:k;e=d;d=d+z|0;j=k+w|0;j=d>>>0<e>>>0?j+1|0:j;e=(t|0)!=0|(q|0)!=0;d=e+d|0;j=d>>>0<e>>>0?j+1|0:j;h=d;o=0-d|0;s=0;w=Fpa(o,s,i,D);d=jb;u=d;e=w;p=d;s=Fpa(x,l,o,s);d=jb;z=d;A=0-(((h|0)!=0)+j|0)|0;o=0;k=Fpa(i,D,A,o);h=k+s|0;j=jb+d|0;j=h>>>0<k>>>0?j+1|0:j;d=j;j=h+p|0;B=0;e=B+e|0;p=e;k=e;j=k>>>0<B>>>0?j+1|0:j;e=j;j=(u|0)==(j|0)&k>>>0<w>>>0|j>>>0<u>>>0;k=(d|0)==(z|0)&h>>>0<s>>>0|d>>>0<z>>>0;h=d;d=Fpa(x,l,A,o)+d|0;k=k+jb|0;k=d>>>0<h>>>0?k+1|0:k;h=d;d=j+d|0;j=k;A=d;h=d>>>0<h>>>0?j+1|0:j;B=0-(((t|0)!=0)+q|0)|0;q=0;z=Fpa(B,q,i,D);s=jb;u=0-t|0;k=Fpa(u,0,x,l);d=k+z|0;j=jb+s|0;t=d;d=d>>>0<k>>>0?j+1|0:j;C=0;u=Fpa(i,D,u,H);i=C+u|0;k=t;j=k+jb|0;j=i>>>0<u>>>0?j+1|0:j;j=(j|0)==(k|0)&i>>>0<C>>>0|j>>>0<k>>>0;k=(d|0)==(s|0)&k>>>0<z>>>0|d>>>0<s>>>0;i=d;d=Fpa(x,l,B,q)+d|0;k=k+jb|0;k=d>>>0<i>>>0?k+1|0:k;i=d;d=j+d|0;j=k;j=d>>>0<i>>>0?j+1|0:j;i=d;d=d+p|0;k=j+e|0;k=d>>>0<i>>>0?k+1|0:k;i=d;j=d;d=k;k=(e|0)==(k|0)&j>>>0<p>>>0|e>>>0>k>>>0;e=k+A|0;j=h;j=e>>>0<k>>>0?j+1|0:j;k=e;e=i;w=e-2|0;h=w;q=d-(e>>>0<2)|0;e=q;e=(d|0)==(e|0)&h>>>0<i>>>0|d>>>0>e>>>0;d=k+e|0;k=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;h=k-(e>>>0<1)|0;e=0;x=e;l=d;i=r;z=i<<2|c>>>30;A=0;p=Fpa(d,e,z,A);e=jb;o=e;j=e;e=c;B=(e&1073741823)<<2|b>>>30;t=0;H=h;i=0;e=Fpa(B,t,h,i);d=e+p|0;j=jb+j|0;j=d>>>0<e>>>0?j+1|0:j;k=(j|0)==(o|0)&d>>>0<p>>>0|j>>>0<o>>>0;p=d;h=j;e=j;s=q;j=0;q=j;c=k;C=((n&1073741823)<<2|r>>>30)&-262145|262144;j=Fpa(s,j,C,0);d=j+d|0;k=jb+e|0;k=d>>>0<j>>>0?k+1|0:k;n=d;e=k;h=(k|0)==(h|0)&d>>>0<p>>>0|h>>>0>k>>>0;d=c+h|0;j=0;j=d>>>0<h>>>0?1:j;h=Fpa(H,i,C,J);d=h+d|0;j=jb+j|0;j=d>>>0<h>>>0?j+1|0:j;r=Fpa(l,x,C,J);h=jb;c=d;o=Fpa(z,A,H,i);d=o+r|0;k=jb+h|0;k=d>>>0<o>>>0?k+1|0:k;o=d;d=k;k=(h|0)==(d|0)&r>>>0>o>>>0|h>>>0>d>>>0;r=c+d|0;j=j+k|0;k=r;h=k>>>0<d>>>0?j+1|0:j;p=n;n=0;d=p+n|0;r=e;j=o+e|0;j=d>>>0<n>>>0?j+1|0:j;e=j;n=(j|0)==(r|0)&d>>>0<p>>>0|j>>>0<r>>>0;j=k+n|0;k=h;u=j;h=j>>>0<n>>>0?k+1|0:k;r=d;n=e;p=Fpa(B,t,s,q);e=jb;o=Fpa(w,0,z,A);d=o+p|0;j=jb+e|0;j=d>>>0<o>>>0?j+1|0:j;o=d;p=(e|0)==(j|0)&p>>>0>d>>>0|e>>>0>j>>>0;e=j;D=p;k=b;c=k<<2&-4;k=Fpa(l,x,c,0);d=k+d|0;j=jb+j|0;j=d>>>0<k>>>0?j+1|0:j;p=d;k=d;d=j;j=(j|0)==(e|0)&k>>>0<o>>>0|e>>>0>j>>>0;e=D+j|0;k=0;k=e>>>0<j>>>0?1:k;o=e;e=r+e|0;j=k+n|0;j=e>>>0<o>>>0?j+1|0:j;o=e;k=e;e=j;n=(j|0)==(n|0)&k>>>0<r>>>0|j>>>0<n>>>0;k=n+u|0;j=h;u=k;n=k>>>0<n>>>0?j+1|0:j;N=Fpa(H,i,c,O);H=jb;i=Fpa(C,J,w,P);h=i+N|0;k=jb+H|0;k=h>>>0<i>>>0?k+1|0:k;C=h;r=Fpa(z,A,s,q);h=h+r|0;i=k;j=k+jb|0;j=h>>>0<r>>>0?j+1|0:j;z=h;k=Fpa(l,x,B,t);h=h+k|0;l=j;j=j+jb|0;r=h;j=h>>>0<k>>>0?j+1|0:j;h=j;x=0;D=(j|0)==(l|0)&r>>>0<z>>>0|j>>>0<l>>>0;j=(i|0)==(l|0)&z>>>0<C>>>0|i>>>0>l>>>0;i=j+((i|0)==(H|0)&C>>>0<N>>>0|i>>>0<H>>>0)|0;k=0;i=D+i|0;j=i;k=h|0;i=k+o|0;j=(j|x)+e|0;j=i>>>0<k>>>0?j+1|0:j;k=i;l=j;j=(e|0)==(j|0)&k>>>0<o>>>0|e>>>0>j>>>0;e=j+u|0;k=n;z=e;e=e>>>0<j>>>0?k+1|0:k;o=i;s=Fpa(s,q,c,O);q=jb;k=Fpa(B,t,w,P);i=k+s|0;j=jb+q|0;j=i>>>0<k>>>0?j+1|0:j;n=j;j=0;k=(n|0)==(q|0)&i>>>0<s>>>0|n>>>0<q>>>0;i=n+p|0;j=(j|k)+d|0;j=i>>>0<n>>>0?j+1|0:j;k=i;i=j;c=(d|0)==(j|0)&k>>>0<p>>>0|d>>>0>j>>>0;j=j+r|0;n=0;h=n+k|0;d=h;j=d>>>0<n>>>0?j+1|0:j;h=(i|0)==(j|0)&d>>>0<k>>>0|i>>>0>j>>>0;d=c+h|0;j=0;j=d>>>0<h>>>0?1:j;h=d;d=d+o|0;k=j+l|0;k=d>>>0<h>>>0?k+1|0:k;h=d;i=k;k=(k|0)==(l|0)&d>>>0<o>>>0|k>>>0<l>>>0;d=k+z|0;j=e;j=d>>>0<k>>>0?j+1|0:j;e=j;d:{if((j|0)==131071|j>>>0<131071){q=0;w=b<<17;l=f;x=0;s=Fpa(i,0,l,x);b=jb;z=b;c=0;A=c;t=0;j=Fpa(h,c,g,t);c=j+s|0;k=jb+b|0;k=c>>>0<j>>>0?k+1|0:k;b=k;p=q;u=0;o=Fpa(l,x,h,A);q=u+o|0;j=c;k=j+jb|0;k=q>>>0<o>>>0?k+1|0:k;o=k;j=(j|0)==(k|0)&u>>>0>q>>>0|j>>>0>k>>>0;H=p-j|0;k=(q|0)!=0|(k|0)!=0;u=H-k|0;w=(w-(j>>>0>p>>>0)|0)-(k>>>0>H>>>0)|0;j=Fpa(d,0,l,x);k=jb;l=Fpa(h,A,y,0);j=l+j|0;k=jb+k|0;k=j>>>0<l>>>0?k+1|0:k;r=Fpa(i,n,g,t);l=r+j|0;j=jb+k|0;j=l>>>0<r>>>0?j+1|0:j;j=((b|0)==(z|0)&c>>>0<s>>>0|b>>>0<z>>>0)+j|0;c=b;b=b+l|0;k=b;b=k>>>0<c>>>0?j+1|0:j;c=Fpa(h,i,I,0);j=jb;p=k;l=Fpa(f,g,e,0);c=l+c|0;k=jb+j|0;k=c>>>0<l>>>0?k+1|0:k;l=Fpa(d,e,g,t);c=l+c|0;j=jb+k|0;k=Fpa(i,n,y,G);c=k+c|0;k=c;y=0;c=p+y|0;j=b+k|0;j=c>>>0<y>>>0?j+1|0:j;b=c;y=u-b|0;G=w-((b>>>0>u>>>0)+j|0)|0;K=K-1|0;n=0-q|0;b=0-(((q|0)!=0)+o|0)|0;break d}q=i>>>1|0;w=0;p=b<<16;h=(i&1)<<31|h>>>1;i=d<<31|i>>>1;b=0;s=b;r=0;t=Fpa(h,b,g,r);b=jb;A=b;j=n;k=e<<31|d>>>1;n=d<<31|q;H=j|k;o=n;C=0;B=0;k=Fpa(n,C,f,B);c=k+t|0;j=jb+b|0;j=c>>>0<k>>>0?j+1|0:j;b=j;u=w;x=0;D=Fpa(h,s,f,B);w=x+D|0;j=c;k=j+jb|0;k=w>>>0<D>>>0?k+1|0:k;D=k;j=(j|0)==(k|0)&x>>>0>w>>>0|j>>>0>k>>>0;J=u-j|0;k=(w|0)!=0|(k|0)!=0;x=J-k|0;u=(p-(j>>>0>u>>>0)|0)-(k>>>0>J>>>0)|0;j=Fpa(h,i,I,0);p=jb;J=Fpa(f,g,e>>>1|0,0);j=J+j|0;k=jb+p|0;k=j>>>0<J>>>0?k+1|0:k;d=(e&1)<<31|d>>>1;e=e>>>1|0;J=Fpa(d,e,g,r);p=J+j|0;n=Fpa(n,H,y,G);G=n+p|0;n=0;j=Fpa(g,r,o,C);r=jb;q=Fpa(d,0,f,B);k=q+j|0;j=jb+r|0;l=Fpa(h,s,y,0);y=l+k|0;k=jb+(k>>>0<q>>>0?j+1|0:j)|0;j=y;y=l>>>0>j>>>0?k+1|0:k;k=(b|0)==(A|0)&c>>>0<t>>>0|b>>>0<A>>>0;c=b;b=b+j|0;k=k+y|0;k=b>>>0<c>>>0?k+1|0:k;c=b;b=b+n|0;j=k+G|0;j=b>>>0<c>>>0?j+1|0:j;y=x-b|0;G=u-((b>>>0>x>>>0)+j|0)|0;n=0-w|0;b=0-(((w|0)!=0)+D|0)|0}if((K|0)>=16384){F=F|2147418112;b=0;c=0;break b}l=K+16383|0;if((K|0)<=-16383){e:{if(l){break e}l=n;k=b<<1|l>>>31;l=l<<1;c=(g|0)==(k|0)&f>>>0<l>>>0|g>>>0<k>>>0;f=y;k=G<<1|f>>>31;f=f<<1|b>>>31;f=(f|0)==(M|0)&(k|0)==(I|0)?c:(I|0)==(k|0)&f>>>0>M>>>0|k>>>0>I>>>0;b=f+h|0;j=i;j=b>>>0<f>>>0?j+1|0:j;c=j;f=d+((i|0)==(j|0)&b>>>0<h>>>0|i>>>0>j>>>0)|0;k=e&65535;e=f;k=d>>>0>e>>>0?k+1|0:k;d=k;if(!(d&65536)){break e}L=e|L;F=d|F;break b}b=0;c=0;break b}j=i;k=b<<1|n>>>31;r=n<<1;g=(g|0)==(k|0)&f>>>0<=r>>>0|g>>>0<k>>>0;f=y;k=G<<1|f>>>31;c=f<<1|b>>>31;c=(c|0)==(M|0)&(k|0)==(I|0)?g:(I|0)==(k|0)&c>>>0>=M>>>0|k>>>0>I>>>0;b=c+h|0;j=b>>>0<c>>>0?j+1|0:j;c=j;f=d+((i|0)==(j|0)&b>>>0<h>>>0|i>>>0>j>>>0)|0;j=e&65535;e=f;k=(l<<16)+(d>>>0>e>>>0?j+1|0:j)|0;f=0;e=f+e|0;L=L|e;F=F|(e>>>0<f>>>0?k+1|0:k)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=L;v[a+12>>2]=F;gb=m+192|0;return}v[a>>2]=0;v[a+4>>2]=0;b=!(d|f|(e|g));v[a+8>>2]=b?0:L;v[a+12>>2]=b?2147450880:F;gb=m+192|0}function kga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;j=gb-272|0;gb=j;f=gb-112|0;gb=f;g=j+88|0;h=Ni(g,c);v[23048]=0;i=U(270,g+20|0)|0;c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){v[23048]=0;n=U(270,g+40|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break B}v[23048]=0;o=U(270,g+60|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break A}v[23048]=0;p=U(270,g+80|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break z}v[23048]=0;m=U(270,g+100|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break y}v[23048]=0;q=U(270,g+120|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break x}r=Co(g+140|0);yc(g);v[g+172>>2]=1873739776;u[g+176>>1]=0;v[23048]=0;c=Q(1443,g|0,f+96|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break w}if(!c){break m}c=f+96|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1179011410){c=f+96|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1414744396){break m}}c=f+104|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1702257015?(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1163280727:0){break m}c=f+96|0;t[g+176|0]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==1414744396;v[23048]=0;T(1444,f+80|0,h|0,2);c=v[23048];v[23048]=0;if((c|0)==1){break v}C:{if(Je(f+80|0)>>>0<4){break C}c=Zt(f+80|0,1);if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1635017060){break C}if(!(Qm(Zt(f+80|0,1))&1)){break C}if(Qm(Zt(f+80|0,2))){break C}c=Zt(f+80|0,3);if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break C}v[23048]=0;Q(248,g|0,12)|0;c=v[23048];v[23048]=0;if((c|0)==1){break u}v[23048]=0;T(1444,f+32|0,h|0,1);c=v[23048];v[23048]=0;if((c|0)==1){break t}cO(f+80|0,f+32|0);Nm(f+32|0)}v[23048]=0;T(1445,f+56|0,f+80|0,544501094);c=v[23048];v[23048]=0;if((c|0)==1){break s}v[23048]=0;c=g+156|0;h=Q(1446,f+56|0,c|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break k}if(!h){break n}if((w[c|0]|w[c+1|0]<<8)==1){v[23048]=0;h=U(511,f+56|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break k}if((h|0)==4){break r}}if((w[c|0]|w[c+1|0]<<8)!=65534){break o}v[23048]=0;h=Q(1447,f+56|0,f+32|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break q}if(!h){break n}h=v[f+52>>2];v[f+8>>2]=v[f+48>>2];v[f+12>>2]=h;v[23048]=0;h=v[f+44>>2];v[f>>2]=v[f+40>>2];v[f+4>>2]=h;h=cH(f+16|0,f);k=v[23048];v[23048]=0;if((k|0)==1){break p}u[g+172>>1]=v[h>>2];break o}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}v[23048]=0;h=U(358,f+56|0)|0;k=v[23048];v[23048]=0;D:{if((k|0)!=1){v[23048]=0;k=U(358,f+56|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break D}if((h|0)!=2|(k|0)!=1){break o}t[g+177|0]=1;break o}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[23048]=0;T(1445,f+32|0,f+80|0,1635017060);h=v[23048];v[23048]=0;E:{F:{G:{H:{I:{if((h|0)!=1){id(i,f+32|0);yb(f+32|0);v[23048]=0;h=U(328,i|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break k}if(!h){v[23048]=0;T(1445,f+32|0,f+80|0,544039792);h=v[23048];v[23048]=0;if((h|0)==1){break I}id(i,f+32|0);yb(f+32|0)}v[23048]=0;T(1445,f+32|0,f+80|0,1952670054);h=v[23048];v[23048]=0;if((h|0)==1){break H}v[23048]=0;h=U(376,f+32|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break G}v[g+152>>2]=h;yb(f+32|0);if(v[g+152>>2]?(w[c|0]|w[c+1|0]<<8)==17:0){break E}if(!mz(g)){break E}if(Do(g)){c=Do(g);h=yj(g);if((c>>>0)/(h>>>0)>>>0<mz(g)<<1>>>0){break F}}v[23048]=0;c=U(247,i|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break k}s=g,y=(c>>>0)/(mz(g)>>>0)|0,v[s+152>>2]=y;break E}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;yb(f+32|0);break j}v[23048]=0;c=U(247,i|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break k}s=g,y=(c>>>0)/(Do(g)>>>0)|0,v[s+152>>2]=y}v[23048]=0;c=Q(1449,g|0,f+80|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break k}u[g+174>>1]=c;v[23048]=0;S(1450,g|0,f+80|0);c=v[23048];v[23048]=0;if((c|0)==1){break k}v[23048]=0;T(1445,f+32|0,f+80|0,1886221175);c=v[23048];v[23048]=0;if((c|0)==1){break l}id(m,f+32|0);yb(f+32|0)}yb(f+56|0);Nm(f+80|0)}gb=f+112|0;c=g;break a}a=P()|0;O()|0;break j}a=P()|0;O()|0}yb(f+56|0)}Nm(f+80|0)}Nm(r);yb(q)}yb(m)}yb(p)}yb(o)}yb(n)}yb(i)}yb(g);R(a|0);L()}v[23048]=0;g=U(1172,c|0)|0;f=v[23048];v[23048]=0;J:{K:{L:{M:{N:{O:{P:{if((f|0)==1){break P}Q:{R:{if(!g){break R}if(!yj(c)){break R}if(yj(c)>>>0>2){break R}if(!Bl(c)){v[23048]=0;g=Th(c);f=v[23048];v[23048]=0;if((f|0)==1){break P}if((g|0)!=85){break R}}if(Bl(c)>>>0<=31){v[23048]=0;g=Th(c);f=v[23048];v[23048]=0;if((f|0)==1){break P}if((g|0)==3){break R}}if(Bl(c)>>>0>64){break R}i=0;v[23048]=0;g=Th(c);f=v[23048];v[23048]=0;if((f|0)==1){break O}v[j+64>>2]=g;h=v[j- -64>>2];g=30892;S:{while(1){f=g;l=f;if((h|0)==v[f>>2]){break S}g=g+4|0;if((g|0)!=30916){continue}break}l=30916}if((l|0)==30916){break Q}v[23048]=0;Q(1167,a|0,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break P}v[23048]=0;g=Q(91,j- -64|0,30916)|0;f=v[23048];v[23048]=0;T:{U:{V:{W:{X:{Y:{if((f|0)!=1){v[23048]=0;i=((b<<5)+a|0)+946300|0;Q(354,i|0,g|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break Y}vb(g);v[23048]=0;g=B(b,104)+a|0;f=g+484380|0;S(372,f|0,0);h=v[23048];v[23048]=0;if((h|0)==1){break X}v[f>>2]=v[c+152>>2];v[g+484404>>2]=w[c+160|0]|w[c+161|0]<<8|(w[c+162|0]<<16|w[c+163|0]<<24);v[23048]=0;g=wk(a);h=v[23048];v[23048]=0;if((h|0)==1){break X}v[23048]=0;Y(1174,c|0,f|0,g|0,i|0);g=v[23048];v[23048]=0;if((g|0)==1){break X}Me(j- -64|0,c+20|0);g=Sc(j+56|0,8,yj(c)>>>0>1?2:1,0,0);v[23048]=0;i=Th(c);h=v[23048];v[23048]=0;if((h|0)==1){break L}if((i|0)!=17){break W}if(yj(c)>>>0>2){break W}tc(f,268435456);d=(B(b,104)+a|0)+484414|0;u[d>>1]=x[d>>1]|1;g=yj(c);u[d>>1]=x[d>>1]&65471|((g|0)==2)<<6;i=0;v[23048]=0;d=U(446,f|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break L}if(!d){break U}d=v[(B(b,104)+a|0)+484400>>2];g=v[f>>2];b=Me(j+32|0,j- -64|0);i=Do(c);h=yj(c);v[23048]=0;ea(1175,d|0,g|0,b|0,i|0,h|0);d=v[23048];v[23048]=0;if((d|0)==1){break T}yb(b);v[23048]=0;Sh(f,a,0);b=v[23048];v[23048]=0;if((b|0)==1){break L}break V}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(g);break J}a=P()|0;O()|0;break J}v[23048]=0;i=Th(c);h=v[23048];v[23048]=0;if((h|0)==1){break L}if((i|0)==85){v[23048]=0;b=ga(791,a|0,b|0,j- -64|0,0,1)|0;d=v[23048];v[23048]=0;Z:{if((d|0)==1){break Z}if(b){break V}i=0;v[23048]=0;a=v[23048];v[23048]=0;if((a|0)==1){break Z}break U}a=P()|0;O()|0;break K}_:{if(jB(c)|!w[c+177|0]){break _}v[23048]=0;b=Th(c);i=v[23048];v[23048]=0;if((i|0)==1){break L}if((b|0)!=1){break _}if((Bl(c)|0)!=32){break _}if((Do(c)|0)!=yj(c)<<2){break _}Li(g,32);tf(g,13);v[23048]=0;W(384,g|0,f|0,j- -64|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break V}break L}$:{if(jB(c)){break $}v[23048]=0;b=Th(c);i=v[23048];v[23048]=0;if((i|0)==1){break L}if((b|0)!=1){break $}if((Bl(c)|0)!=24){break $}if((Do(c)|0)!=yj(c)<<2){break $}Li(g,32);tf(g,14);v[23048]=0;W(384,g|0,f|0,j- -64|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break L}break V}v[23048]=0;b=Th(c);i=v[23048];v[23048]=0;if((i|0)==1){break L}aa:{if((b|0)!=6){v[23048]=0;b=Th(c);i=v[23048];v[23048]=0;if((i|0)==1){break L}if((b|0)!=7){break aa}}Li(g,16);v[23048]=0;b=Th(c);d=v[23048];v[23048]=0;if((d|0)==1){break L}tf(g,(b|0)==6?18:17);v[23048]=0;W(384,g|0,f|0,j- -64|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break L}break V}i=(Bl(c)-1>>>3|0)-1|0;h=i<<3;b=h&31;Li(g,(i>>>0<7?(h&63)>>>0>=32?4196360>>>b|0:((1<<b)-1&4196360)<<32-b|136321040>>>b:8)&255);if(Bl(c)>>>0<9){tf(g,1)}v[23048]=0;b=Th(c);i=v[23048];v[23048]=0;if((i|0)==1){break M}if((b|0)==3){tf(g,3)}if(d){dR(g)}v[23048]=0;W(384,g|0,f|0,j- -64|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break M}}if(e){Me(j+8|0,c+100|0);id(e,j+8|0);yb(j+8|0)}b=v[a+480180>>2];v[23048]=0;T(1169,f|0,32,b|0);b=v[23048];v[23048]=0;i=1;if((b|0)==1){break N}v[23048]=0;Sh(f,a,0);a=v[23048];v[23048]=0;if((a|0)==1){break L}}yb(j- -64|0);break Q}a=P()|0;O()|0;yb(b);break K}i=0}iT(c);gb=j+272|0;return i|0}a=P()|0;O()|0;break J}a=P()|0;O()|0;break J}a=P()|0;O()|0;break K}a=P()|0;O()|0;break K}a=P()|0;O()|0}yb(j- -64|0)}iT(c);R(a|0);L()}function xK(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-128|0;gb=h;a:{b:{if(g){$g(h+112|0,f,32);v[23048]=0;W(753,h+96|0,f|0,32)|0;i=v[23048];v[23048]=0;if((i|0)!=1){break b}f=P()|0;O()|0;break a}Jb(h+112|0);Jb(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(Bt(c)){i=b+24|0;b=v[i>>2];v[23048]=0;b=oe(b+484344|0,c&65535);j=v[23048];v[23048]=0;if((j|0)==1){break r}if(b){break q}}v[23048]=0;T(2104,a|0,h+112|0,h+96|0);a=v[23048];v[23048]=0;if((a|0)!=1){break p}}f=P()|0;O()|0;break c}b=Yb(v[i>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)?(d|0)>=0:0)){v[23048]=0;T(2104,a|0,h+112|0,h+96|0);a=v[23048];v[23048]=0;if((a|0)!=1){break p}break d}if(!(x[v[i>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){v[23048]=0;T(2104,a|0,h+112|0,h+96|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}break p}v[23048]=0;c=Wc(b,d,e&65535);b=v[23048];v[23048]=0;if((b|0)==1){break o}bf(h+112|0);bf(h+96|0);v[23048]=0;b=ne(c);d=v[23048];v[23048]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((d|0)!=1){F:{G:{if(!b){if(!Xt(c)){break G}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[23048]=0;Y(2106,h- -64|0,b|0,e|0,d|0);d=v[23048];v[23048]=0;b=1;if((d|0)==1){break E}v[23048]=0;T(9,h+80|0,0,h- -64|0);d=v[23048];v[23048]=0;if((d|0)!=1){break F}f=P()|0;O()|0;break B}b=0;v[23048]=0;Q(91,h+80|0,57035)|0;d=v[23048];v[23048]=0;if((d|0)==1){break D}}v[23048]=0;Q(1201,h+112|0,h+80|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break C}vb(h+80|0);if(b){vb(h- -64|0)}v[23048]=0;b=ne(c);d=v[23048];v[23048]=0;if((d|0)==1){break e}H:{if(b){v[23048]=0;Q(91,h+80|0,57039)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}break H}if(Xt(c)){v[23048]=0;Q(91,h+80|0,57043)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break H}break e}v[23048]=0;Q(91,h+80|0,57035)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}}v[23048]=0;Q(1201,h+96|0,h+80|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break A}vb(h+80|0);j=f-1|0;if(j>>>0<5){break t}v[23048]=0;b=Q(91,h+80|0,57053)|0;d=v[23048];v[23048]=0;if((d|0)==1){break z}v[23048]=0;Q(1201,h+112|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break y}vb(b);v[23048]=0;b=Q(91,h+80|0,57053)|0;d=v[23048];v[23048]=0;if((d|0)==1){break x}v[23048]=0;Q(1201,h+96|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break w}vb(b);b=c+1|0;I:{if(w[c+1|0]){v[23048]=0;S(775,h+80|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){break I}break f}v[23048]=0;Q(91,h+80|0,57047)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}}v[23048]=0;Q(1201,h+112|0,h+80|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break v}vb(h+80|0);J:{if(w[b|0]){v[23048]=0;Q(91,h+80|0,57050)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break J}break g}v[23048]=0;Q(91,h+80|0,57047)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}}v[23048]=0;Q(1201,h+96|0,h+80|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break u}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}}vb(h- -64|0);break c}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;vb(h+80|0);break c}vb(h+80|0);if(j>>>0<8){break t}v[23048]=0;b=tg(c);d=v[23048];v[23048]=0;K:{L:{M:{N:{O:{P:{Q:{if((d|0)!=1){R:{if(b){v[23048]=0;b=Q(91,h+48|0,57053)|0;d=v[23048];v[23048]=0;if((d|0)==1){break Q}v[23048]=0;e=Pq(c);d=v[23048];v[23048]=0;if((d|0)==1){break P}d=0;v[23048]=0;v[h+16>>2]=e&255;S(773,h+32|0,h+16|0);k=v[23048];v[23048]=0;e=1;if((k|0)==1){break P}v[23048]=0;T(2062,h+80|0,b|0,h+32|0);b=v[23048];v[23048]=0;if((b|0)!=1){break R}f=P()|0;O()|0;break i}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[23048]=0;b=gz(b,d);d=v[23048];v[23048]=0;if((d|0)==1){break L}v[23048]=0;b=W(753,h+48|0,1,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break L}e=0;v[23048]=0;S(775,h+32|0,c+4|0);k=v[23048];v[23048]=0;d=1;if((k|0)==1){break O}v[23048]=0;T(2062,h+80|0,b|0,h+32|0);b=v[23048];v[23048]=0;if((b|0)!=1){break R}f=P()|0;O()|0;vb(h+32|0);break k}e=0;v[23048]=0;Q(91,h+80|0,57067)|0;b=v[23048];v[23048]=0;d=0;if((b|0)==1){break M}}v[23048]=0;Q(1201,h+112|0,h+80|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break N}vb(h+80|0);if(d){vb(h+32|0);vb(h+48|0)}if(e){vb(h+32|0);vb(h+48|0)}v[23048]=0;b=tg(c);d=v[23048];v[23048]=0;if((d|0)==1){break l}S:{if(b){v[23048]=0;Q(91,h+80|0,57071)|0;b=v[23048];v[23048]=0;if((b|0)==1){break l}break S}if(w[c+2|0]){v[23048]=0;Q(91,h+80|0,57075)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break S}break l}v[23048]=0;Q(91,h+80|0,57067)|0;b=v[23048];v[23048]=0;if((b|0)==1){break l}}v[23048]=0;Q(1201,h+96|0,h+80|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break K}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break h}f=P()|0;O()|0;break k}f=P()|0;O()|0;vb(h+80|0);if(!d){break j}vb(h+32|0);break k}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}vb(h+80|0);if(j>>>0<12){break t}v[23048]=0;b=Q(91,h+80|0,57053)|0;d=v[23048];v[23048]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{if((d|0)!=1){v[23048]=0;Q(1201,h+112|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break $}vb(b);v[23048]=0;b=Q(91,h+80|0,57053)|0;d=v[23048];v[23048]=0;if((d|0)==1){break _}v[23048]=0;Q(1201,h+96|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break Z}vb(b);v[23048]=0;b=tg(c);d=v[23048];v[23048]=0;if((d|0)==1){break Y}aa:{if(b){b=0;v[23048]=0;d=zo(c);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;v[h+28>>2]=d&4095;S(2108,h+80|0,h+28|0);d=v[23048];v[23048]=0;if((d|0)!=1){break aa}}f=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[23048]=0;b=fz(b,d);d=v[23048];v[23048]=0;if((d|0)==1){break X}v[23048]=0;d=W(753,h+16|0,1,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break X}v[23048]=0;S(775,h|0,c+5|0);e=v[23048];v[23048]=0;b=1;if((e|0)==1){break W}v[23048]=0;T(2062,h+80|0,d|0,h|0);d=v[23048];v[23048]=0;if((d|0)!=1){break aa}f=P()|0;O()|0;vb(h);break m}b=0;v[23048]=0;Q(91,h+80|0,57035)|0;d=v[23048];v[23048]=0;if((d|0)==1){break U}}v[23048]=0;Q(1201,h+112|0,h+80|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break V}vb(h+80|0);if(b){vb(h);vb(h+16|0)}v[23048]=0;b=tg(c);d=v[23048];v[23048]=0;if((d|0)==1){break n}ba:{if(b){v[23048]=0;Q(91,h+80|0,57079)|0;b=v[23048];v[23048]=0;if((b|0)==1){break n}break ba}if(w[c+3|0]){v[23048]=0;Q(91,h+80|0,57079)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break ba}break n}v[23048]=0;Q(91,h+80|0,57035)|0;b=v[23048];v[23048]=0;if((b|0)==1){break n}}v[23048]=0;Q(1201,h+96|0,h+80|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break T}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break m}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}vb(h);break m}f=P()|0;O()|0;break c}vb(h+80|0);if(!f){break s}}ca:{da:{ea:{fa:{if(Bb(h+112|0)>>>0>f>>>0){v[23048]=0;Y(219,h+80|0,h+112|0,0,f|0);b=v[23048];v[23048]=0;if((b|0)!=1){break fa}f=P()|0;O()|0;break c}if(g){b=Bb(h+112|0);v[23048]=0;b=W(753,h+80|0,f-b|0,32)|0;c=v[23048];v[23048]=0;if((c|0)==1){break da}v[23048]=0;Q(1201,h+112|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){f=P()|0;O()|0;vb(b);break c}vb(b);if(Bb(h+96|0)>>>0>f>>>0){break ca}break ea}if(Bb(h+96|0)>>>0<=f>>>0){break s}break ca}Eb(h+112|0,h+80|0);vb(h+80|0);if(Bb(h+96|0)>>>0>f>>>0){break ca}if(!g){break s}}b=Bb(h+96|0);v[23048]=0;b=W(753,h+80|0,f-b|0,32)|0;c=v[23048];v[23048]=0;ga:{if((c|0)!=1){v[23048]=0;Q(1201,h+96|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break ga}vb(b);break s}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}v[23048]=0;Y(219,h+80|0,h+96|0,0,f|0);b=v[23048];v[23048]=0;if((b|0)!=1){Eb(h+96|0,h+80|0);vb(h+80|0);break s}f=P()|0;O()|0;break c}v[23048]=0;T(2104,a|0,h+112|0,h+96|0);a=v[23048];v[23048]=0;if((a|0)==1){break o}}vb(h+96|0);vb(h+112|0);gb=h+128|0;return}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}vb(h+16|0);break c}f=P()|0;O()|0;break c}vb(h+48|0)}if(!e){break c}}vb(h+32|0)}vb(h+48|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}vb(h+96|0)}vb(h+112|0);R(f|0);L()}function _ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-304|0;gb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!_u(b,d+208|0)){break j}if(!NU(d+208|0)){break j}if(!Nb(b,Xc(MU(d+208|0),jb))){break j}if(!c){n=1;break j}if(!Rc(b,w[d+208|4])){break j}Ed(a,268435456);sg(a);v[a+480208>>2]=4;e=Tb(d+88|0,25584);Eb(a+1300344|0,e);vb(e);e=Tb(d+88|0,25603);Eb(a+1300356|0,e);vb(e);v[a+1300404>>2]=5;uf(d+16|0,d+208|6,48,3);Fc(d+88|0,d+16|0);Eb(a+1300308|0,d+88|0);vb(d+88|0);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){e=0;while(1){u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;if(e>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];e=w[d+302|0]|w[d+303|0]<<8;l=d+192|0;i=Jg(l);k:{if(!e){break k}v[23048]=0;S(880,l|0,e|0);h=v[23048];v[23048]=0;if((h|0)!=1){v[23048]=0;Wm(l,e);e=v[23048];v[23048]=0;if((e|0)!=1){break k}}a=P()|0;O()|0;Vh(i);R(a|0);L()}e=w[d+302|0]|w[d+303|0]<<8;v[23048]=0;T(873,b|0,l|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break i}s=nc(d+176|0);o=nc(d+160|0);e=w[d+301|0];v[23048]=0;W(605,b|0,s|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break f}i=w[d+300|0];e=0;v[23048]=0;W(605,b|0,o|0,i|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break f}if(w[d+300|0]){p=c&2;q=d+88|4;m=d+126|0;r=d+88|6;while(1){v[23048]=0;i=e;e=e+1|0;h=B(e,104)+a|0;g=h+484380|0;S(372,g|0,0);f=v[23048];v[23048]=0;l:{m:{if((f|0)!=1){f=Mb(o,i);if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break l}f=Mb(o,i);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[23048]=0;f=Q(248,b|0,f|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break c}if(!f){break l}v[23048]=0;f=Q(874,b|0,d+88|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break c}if(!f){break l}v[23048]=0;df(d+72|0,2,r);f=v[23048];v[23048]=0;if((f|0)!=1){v[23048]=0;S(398,d+16|0,d+72|0);f=v[23048];v[23048]=0;if((f|0)!=1){break m}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[23048]=0;Q(354,((e<<5)+a|0)+946300|0,d+16|0)|0;f=v[23048];v[23048]=0;n:{o:{p:{q:{r:{if((f|0)!=1){vb(d+16|0);v[23048]=0;zk(d+72|0,2,m);f=v[23048];v[23048]=0;if((f|0)==1){break r}v[23048]=0;S(398,d+16|0,d+72|0);f=v[23048];v[23048]=0;if((f|0)==1){break r}v[23048]=0;Q(355,h+484423|0,d+16|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break q}vb(d+16|0);if(w[d+138|0]<=15){f=h+484414|0;u[f>>1]=x[f>>1]|32;u[h+484408>>1]=B(w[d+138|0],17)}t[d+16|0]=w[d+139|0];v[23048]=0;t[d+72|0]=64;f=$b(d+16|0,d+72|0);k=v[23048];v[23048]=0;if((k|0)==1){break p}u[h+484412>>1]=w[f|0];v[h+484404>>2]=w[d+141|0]|w[d+142|0]<<8;f=h+484384|0;v[f>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);k=h+484388|0;v[k>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[g>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break o}n=v[f>>2];f=v[k>>2];break n}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}n=v[f>>2]>>>1|0;v[f>>2]=n;f=v[k>>2]>>>1|0;v[k>>2]=f;v[g>>2]=v[g>>2]>>>1}s:{if(f>>>0<=n>>>0){break s}h=h+484414|0;u[h>>1]=x[h>>1]|2;if(!(w[d+140|0]&2)){break s}u[h>>1]=x[h>>1]|4}v[23048]=0;pk(g);h=v[23048];v[23048]=0;if((h|0)==1){break c}if(!p){break l}i=Mb(o,i);i=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);h=w[q|0];v[23048]=0;Q(248,b|0,h+i|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}i=Sc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[23048]=0;W(384,i|0,g|0,b|0)|0;i=v[23048];v[23048]=0;if((i|0)!=1){break l}e=P()|0;O()|0;break b}if(w[d+300|0]>e>>>0){continue}break}}n=1;t:{if(!(c&1)){break t}v[d+68>>2]=0;f=a+484360|0;fn(Qb(f));F=d,G=Rb(l),v[F+64>>2]=G;F=d,G=Ub(l),v[F+56>>2]=G;k=a+484344|0;if(Fb(d- -64|0,d+56|0)){r=d+88|5;p=d+88|4;while(1){i=v[d- -64>>2];c=i;u:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break u}c=Mb(s,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23048]=0;c=Q(248,b|0,c|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}if(!c){break u}v[23048]=0;S(877,b|0,d+88|0);c=v[23048];v[23048]=0;if((c|0)==1){break h}if(!w[p|0]){break u}c=w[i|0]|w[i+1|0]<<8;e=w[i|0]|w[i+1|0]<<8;t[d+16|0]=w[r|0];h=w[d+262|0];g=w[i+2|0];v[23048]=0;t[d+72|0]=h-g;h=$b(d+16|0,d+72|0);g=v[23048];v[23048]=0;if((g|0)==1){break d}q=w[h|0];h=w[i|0]|w[i+1|0]<<8;g=w[p|0];v[23048]=0;v[d+52>>2]=g+h;h=Jc(d+68|0,d+52|0);g=v[23048];v[23048]=0;if((g|0)==1){break e}v[d+68>>2]=v[h>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break u}y=c>>>6|0;e=e&63;A=0;while(1){v:{w:{x:{y:{z:{A:{B:{h=e>>>0>63;y=h+y|0;c=y&65535;if(uc(Qb(f))>>>0<=c>>>0){g=Qb(f);v[23048]=0;S(547,g|0,y+1&65535);g=v[23048];v[23048]=0;if((g|0)==1){break B}v[23048]=0;g=W(585,k|0,64,0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break B}F=sc(Qb(f),c),G=g,u[F>>1]=G}m=x[sc(Qb(f),c)>>1];v[23048]=0;c=oe(k,m);g=v[23048];v[23048]=0;if((g|0)==1){break z}if(!c){break u}c=Yb(k,m);g=w[i+2|0];v[23048]=0;z=h?0:e;e=Wc(c,z,g);c=v[23048];v[23048]=0;if((c|0)==1){break w}h=0;if(q){break A}break x}e=P()|0;O()|0;break b}while(1){v[23048]=0;S(878,d+72|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break y}g=rd(d+72|0);D=Df(d+72|0);C=Ri(d+72|0);E=dc(d+72|0);j=0;c=w[d+72|0];if((c-1&255)>>>0<=142){j=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+h|0]=j}t[e|0]=j;c=w[g|0];t[e+2|0]=1;t[e+1|0]=c;c=w[D|0];C:{if((c|0)!=255){t[e+4|0]=c;break C}t[e+2|0]=0}c=w[C|0];D:{if(c>>>0>22){break D}t[e+3|0]=w[c+25616|0];g=w[E|0];t[e+5|0]=g;c=e+5|0;E:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break D;case 4:t[c|0]=g&3|48;break D;case 7:if(Lb(l)>>>0<=g>>>0){break D}j=c;c=Mb(l,g);g=w[c|0]|w[c+1|0]<<8;t[j|0]=g>>>6;c=Yb(k,m);j=x[a+480188>>1];v[23048]=0;c=Wc(c,z,j-1&65535);j=v[23048];v[23048]=0;if((j|0)!=1){t[c+3|0]=14;t[c+5|0]=g&63;break D}e=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=Yb(k,m);g=x[a+480188>>1];v[23048]=0;c=Wc(c,z,g-1&65535);g=v[23048];v[23048]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break D}e=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break D;case 12:v[23048]=0;t[d+15|0]=15;g=$b(c,d+15|0);j=v[23048];v[23048]=0;if((j|0)!=1){t[c|0]=w[g|0]|208;break D}e=P()|0;O()|0;break b;case 13:v[23048]=0;t[d+15|0]=15;g=$b(c,d+15|0);j=v[23048];v[23048]=0;if((j|0)!=1){t[c|0]=w[g|0]|192;break D}e=P()|0;O()|0;break b;case 14:v[23048]=0;t[d+15|0]=15;g=$b(c,d+15|0);j=v[23048];v[23048]=0;if((j|0)!=1){t[c|0]=w[g|0]|224;break D}e=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break D}j=g&240;if(!j|(j|0)==240){break D}t[c|0]=g|15;break D;case 9:case 18:break E;default:break D}}if(j&255){break D}t[e|0]=w[(d+16|0)+h|0]}e=e+6|0;h=h+1|0;if((q|0)!=(h|0)){continue}break}break x}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(q>>>0>=w[r|0]){break v}c=w[r|0];v[23048]=0;Q(370,b|0,B(c-q|0,5)|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break v}}e=P()|0;O()|0;break b}e=z+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}Ag(d- -64|0);if(Fb(d- -64|0,d+56|0)){continue}break}}F:{a=v[d+68>>2];b=a&63;if(!b){break F}c=Qb(f);v[23048]=0;a=a>>>6|0;c=Q(516,c|0,a&65535)|0;e=v[23048];v[23048]=0;if((e|0)!=1){if(!c){break F}a=Yb(k,x[sc(Qb(f),a&65535)>>1]);v[23048]=0;ba(879,a|0,b|0,0,1)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break F}}e=P()|0;O()|0;break b}a=Qb(f);F=d,G=Rb(a),v[F+88>>2]=G;F=d,G=Ub(a),v[F+16>>2]=G;if(!Fb(d+88|0,d+16|0)){break t}h=65535;while(1){a=v[d+88>>2];if(x[a>>1]==65535){G:{if((h&65535)!=65535){break G}v[23048]=0;h=W(585,k|0,64,0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break G}e=P()|0;O()|0;break b}u[a>>1]=h}sf(d+88|0);if(Fb(d+88|0,d+16|0)){continue}break}}Yh(o);Yh(s);Vh(l)}gb=d+304|0;return n|0}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}Yh(o);Yh(s)}Vh(l);R(e|0);L()}function ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0;e=gb-1312|0;gb=e;yc(b);f=gb-32|0;gb=f;TU(f+24|0,e+200|0);m=xb(f+24|0);l=v[f+28>>2];d=v[f+24>>2];v[f+8>>2]=d;v[f+12>>2]=l;v[f>>2]=d;v[f+4>>2]=l;d=b;fc(f+16|0,b,f);l=xb(f+16|0);if((l|0)==(m|0)){Vb(d,xb(f+24|0))}gb=f+32|0;a:{if((l|0)!=(m|0)){break a}if(!WU(e+200|0)){break a}if(!Nb(b,Xc(VU(e+200|0),jb))){break a}if(!c){p=1;break a}yc(b);d=Ni(e+200|0,b);v[23048]=0;S(853,e+184|0,d|0);b=v[23048];v[23048]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){yb(d);v[23048]=0;T(854,e+168|0,e+184|0,1196314451);b=v[23048];v[23048]=0;if((b|0)!=1){v[23048]=0;T(854,e+152|0,e+184|0,1280331091);b=v[23048];v[23048]=0;if((b|0)!=1){if(cd(e+168|0)){break g}if(cd(e+152|0)){break g}v[23048]=0;S(428,a|0,1);b=v[23048];v[23048]=0;j:{if((b|0)==1){break j}v[23048]=0;sg(a);b=v[23048];v[23048]=0;if((b|0)==1){break j}v[a+480188>>2]=4;v[a+480208>>2]=16842752;D=e,E=Rb(e+152|0),v[D+16>>2]=E;D=e,E=Ub(e+152|0),v[D+112>>2]=E;if(!Fb(e+16|0,e+112|0)){break i}l=c&2;k:{l:{while(1){f=v[e+16>>2];if(!Zh(a)){break i}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;v[23048]=0;i=B(b&65535,104)+a|0;m=i+484380|0;S(372,m|0,1);b=v[23048];v[23048]=0;m:{n:{if((b|0)!=1){v[23048]=0;d=Q(855,f|0,e+200|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break n}if(!d){break h}if(bv(e+200|0)){break m}break h}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[23048]=0;d=Q(91,e+48|0,e+200|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){b=x[a+480190>>1];v[23048]=0;Q(354,((b<<5)+a|0)+946300|0,d|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break l}vb(d);b=w[e+236|0]|w[e+237|0]<<8|(w[e+238|0]<<16|w[e+239|0]<<24);v[m>>2]=b;v[i+484388>>2]=b;v[i+484384>>2]=w[e+232|0]|w[e+233|0]<<8|(w[e+234|0]<<16|w[e+235|0]<<24);u[i+484410>>1]=255;b=i+484414|0;u[b>>1]=x[b>>1]|2;if(l){b=Sc(e+48|0,8,1,0,0);v[23048]=0;W(384,b|0,m|0,f|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break k}}sh(e+16|0);if(Fb(e+16|0,e+112|0)){continue}break i}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break d}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d);break b}D=e,E=Rb(e+168|0),v[D+144>>2]=E;D=e,E=Ub(e+168|0),v[D+136>>2]=E;n=a+484360|0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!Fb(e+144|0,e+136|0)){break B}r=a+484344|0;p=1;C=c&1;m=e+1292|0;l=e+1296|0;k=e+1288|0;s=e+1286|0;y=a+484380|0;c=1;while(1){d=v[e+144>>2];if(!(c&1)){v[23048]=0;c=U(466,n|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break w}if(!c){break B}}fn(Qb(n));v[23048]=0;c=Q(856,d|0,e+200|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break v}if(!c|(w[s|0]|w[s+1|0]<<8)|(!(w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))|(w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))>>>0>4)){break h}c=Qb(n);v[23048]=0;T(6,e+48|0,5,e+200|0);b=v[23048];v[23048]=0;if((b|0)==1){break o}v[23048]=0;S(467,c|0,e+48|0);b=v[23048];v[23048]=0;if((b|0)==1){break p}vb(e+48|0);C:{if(C){b=l;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[23048]=0;T(341,e+112|0,d|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break C}break f}v[23048]=0;U(270,e+112|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}}Pb(e+48|0,0,64);j=1;z=1;D:{E:{while(1){v[23048]=0;f=(B(j,34)+e|0)+166|0;d=f+32|0;Ye(e,d);b=v[23048];v[23048]=0;if((b|0)==1){break u}F:{if(!w[v[e>>2]]){break F}c=w[f- -64|0];if(c>>>0>15){break E}b=w[f+65|0];if(b>>>0>64){break E}if(!bv(d)){break E}if(!x[a+480190>>1]){break F}o=b<<2;h=c<<4;c=1;i=0;b=1;while(1){v[23048]=0;S(858,e+16|0,e|0);d=v[23048];v[23048]=0;G:{H:{if((d|0)!=1){v[23048]=0;f=Q(859,e+16|0,((c<<5)+a|0)+946300|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break H}vb(e+16|0);if(f){break G}D=ud(e+48|0,j),E=b,u[D>>1]=E;f=B(c,104)+a|0;d=f+484410|0;c=x[d>>1];if((c|0)!=255){i=b;if(w[f+484417|0]!=(h&255)|(c|0)!=(o|0)){break G}}t[f+484417|0]=h;u[d>>1]=o;break F}a=P()|0;O()|0;break q}a=P()|0;O()|0;vb(e+16|0);break q}b=b+1|0;c=b&65535;if(c>>>0<=x[a+480190>>1]){continue}break}i=i&65535;if(!i){break F}if(!Zh(a)){break F}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;D=ud(e+48|0,j),E=b,u[D>>1]=E;b=x[a+480190>>1];v[23048]=0;d=B(b,104);f=d+y|0;Al(f);b=v[23048];v[23048]=0;if((b|0)==1){break t}c=B(i,104)+y|0;Uo(f,c);b=a+d|0;u[b+484410>>1]=o;t[b+484417|0]=h;v[23048]=0;Q(785,f|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break t}b=a+946300|0;d=b+(x[a+480190>>1]<<5)|0;c=b+(i<<5)|0;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;b=v[c+28>>2];v[d+24>>2]=v[c+24>>2];v[d+28>>2]=b;b=v[c+20>>2];v[d+16>>2]=v[c+16>>2];v[d+20>>2]=b;b=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=b}z=j>>>0<31;j=j+1|0;if((j|0)!=32){continue}break}f=0;v[e+40>>2]=0;v[e+32>>2]=0;v[e+36>>2]=0;v[e+24>>2]=0;v[e+28>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;A=w[k|0]|w[k+1|0]<<8;c=64;q=65535;j=0;while(1){I:{if(!j){v[23048]=0;d=Q(250,e+112|0,1)|0;b=v[23048];v[23048]=0;if((b|0)==1){break A}if(!d){break I}}c=c+1|0;if(c>>>0>=64){v[23048]=0;q=W(585,r|0,64,0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break A}if((q|0)==65535){break D}c=0;b=Qb(n);v[23048]=0;S(749,b|0,q|0);b=v[23048];v[23048]=0;if((b|0)==1){break A}}b=Yb(r,q&65535);v[23048]=0;b=Wc(b,c,0);d=v[23048];v[23048]=0;if((d|0)==1){break s}if(!A){continue}d=0;i=0;while(1){g=(e+16|0)+B(d,7)|0;d=w[g+6|0];J:{if(d){t[g+6|0]=d-1;d=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=d;t[b+5|0]=d>>>8;d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=d;t[b+1|0]=d>>>8;t[b+2|0]=d>>>16;t[b+3|0]=d>>>24;j=j-1|0;break J}v[23048]=0;h=Q(250,e+112|0,1)|0;d=v[23048];v[23048]=0;if((d|0)==1){break r}if(!h){break J}d=m;if(v[e+120>>2]==(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){h=Qb(n);d=Qb(n);v[23048]=0;f=U(512,d|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break r}ff(h,f);f=c}v[23048]=0;h=U(373,e+112|0)|0;d=v[23048];v[23048]=0;K:{if((d|0)!=1){d=h<<24>>24;if((d|0)>-1){break K}h=d&127;t[g+6|0]=h;d=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=d;t[b+5|0]=d>>>8;d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=d;t[b+1|0]=d>>>8;t[b+2|0]=d>>>16;t[b+3|0]=d>>>24;j=h+j|0;break J}a=P()|0;O()|0;break q}if((d-1&255)>>>0<=35){t[b|0]=d+48}v[23048]=0;h=U(373,e+112|0)|0;d=v[23048];v[23048]=0;L:{M:{if((d|0)!=1){D=b,E=w[ud(e+48|0,h&31)|0],t[D+1|0]=E;if(!(h&128)){break M}t[b+3|0]=w[g+3|0];t[b+5|0]=w[g+5|0];break L}a=P()|0;O()|0;break q}v[23048]=0;S(452,e|0,e+112|0);d=v[23048];v[23048]=0;N:{if((d|0)!=1){h=rd(e);d=e;o=w[e|0];if(o>>>0>19){break L}t[b+3|0]=w[(o<<1)+25424|0];h=w[h|0];t[b+5|0]=h;if((o|0)!=18|h>>>0<32){break N}t[b+3|0]=17;break L}a=P()|0;O()|0;break q}d=w[d|0];if(819137>>>d&1){break L}t[b+5|0]=w[(d<<1)+25425|0]|h&15}d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[g|0]=d;t[g+1|0]=d>>>8;t[g+2|0]=d>>>16;t[g+3|0]=d>>>24;d=w[b+4|0]|w[b+5|0]<<8;t[g+4|0]=d;t[g+5|0]=d>>>8}b=b+6|0;i=i+1|0;d=i&65535;if(A>>>0>d>>>0){continue}break}continue}break}b=q&65535;if(!f&c>>>0>62|(b|0)==65535){break D}i=Yb(r,b);v[23048]=0;d=De(e,14,f&255);b=v[23048];v[23048]=0;if((b|0)!=1){b=wh(Ve(d,c));v[23048]=0;Q(479,i|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break D}}a=P()|0;O()|0;break q}p=0}yb(e+112|0);if(z){break g}sh(e+144|0);c=0;if(Fb(e+144|0,e+136|0)){continue}break}}v[23048]=0;Fi(n,0);b=v[23048];v[23048]=0;if((b|0)==1){break z}v[23048]=0;c=Q(2,e+200|0,25464)|0;b=v[23048];v[23048]=0;if((b|0)==1){break y}Eb(a+1300344|0,c);vb(c);v[23048]=0;c=Q(2,e+200|0,25489)|0;b=v[23048];v[23048]=0;p=1;if((b|0)==1){break x}Eb(a+1300356|0,c);vb(c);v[a+1300404>>2]=5;break g}a=P()|0;O()|0;break q}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0}yb(e+112|0);break e}a=P()|0;O()|0;vb(e+48|0);break e}a=P()|0;O()|0;break e}p=0}kd(e+152|0);kd(e+168|0);Cd(e+184|0);break a}a=P()|0;O()|0}kd(e+152|0)}kd(e+168|0)}Cd(e+184|0)}R(a|0);L()}gb=e+1312|0;return p|0}function AZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;f=gb-176|0;gb=f;yc(b);a:{b:{c:{d:{e:{if(!nE(b,f+128|0)){break e}if(!oE(f+128|0)){break e}if(!c){m=1;break e}Ed(a,2048);sg(a);d=gb-16|0;gb=d;e=Tb(d,16570);Dc(f+112|0,e);vb(e);gb=d+16|0;v[23048]=0;k=f+128|3;T(368,f+32|0,f+112|0,k|0);d=v[23048];v[23048]=0;f:{g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){Eb(a+1300344|0,f+32|0);vb(f+32|0);Hb(f+112|0);d=Tb(f+32|0,16566);Eb(a+1300356|0,d);vb(d);v[a+1300404>>2]=5;u[a+480188>>1]=w[f+168|0];u[a+480190>>1]=w[f+164|0];df(f+112|0,2,f+128|4);Fc(f+32|0,f+112|0);Eb(a+1300308|0,f+32|0);vb(f+32|0);if(w[k|0]<=9){u[a+480188>>1]=4;kg(b,1);jh(a,1)}d=w[k|0];n:{if(w[k|0]>=11){e=d>>>0>11?32:16;d=0;while(1){h=((d<<5)+a|0)+480284|0;i=gE(b)<<1;i=(i|0)>-128?i:-128;o:{if((i|0)<129){d=i+128|0;break o}v[((d<<5)+a|0)+480280>>2]=256;d=128}u[h>>1]=d;g=g+1|0;d=g&65535;if(e>>>0>d>>>0){continue}break}break n}if((d|0)!=10){break n}d=f+32|0;e=gb-32|0;gb=e;g=b;p:{if(Nb(b,16)){aw(e+24|0,d);d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;gd(e+16|0,g,e+8|0);break p}g=gb-16|0;gb=g;j=d+16|0;while(1){Re(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}gb=g+16|0}gb=e+32|0;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=t[(f+32|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}q:{if(w[k|0]>=13){Rr(f+32|0,b);e=rd(f+32|0);g=a;d=w[f+32|0];if(d>>>0<32){t[f+32|0]=125;d=125}v[g+480204>>2]=B(d,1e4);v[a+480196>>2]=w[e|0];break q}v[a+480196>>2]=6;v[a+480204>>2]=125e4}g=a+484360|0;Cf(Qb(g),w[f+165|0]);n=nc(f+112|0);q=v[b+8>>2];r=w[k|0];r:{if(w[k|0]<14){break r}d=w[f+165|0];v[23048]=0;S(369,n|0,d|0);d=v[23048];v[23048]=0;if((d|0)!=1){break r}b=P()|0;O()|0;break b}s:{if(w[f+165|0]){d=0;while(1){z=sc(Qb(g),d),A=d,u[z>>1]=A;if(w[k|0]>=14){v[23048]=0;e=U(340,b|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break s}z=sc(n,d),A=e,u[z>>1]=A}e=x[a+480188>>1];v[23048]=0;Q(370,b|0,e<<1)|0;e=v[23048];v[23048]=0;if((e|0)==1){break s}d=d+1|0;if(d>>>0<w[f+165|0]){continue}break}}d=x[a+480190>>1];v[23048]=0;v[f+32>>2]=0;o=W(371,f+96|0,d|0,f+32|0)|0;d=v[23048];v[23048]=0;g=1;if((d|0)!=1){v[f+92>>2]=0;t:{if(x[a+480190>>1]){j=1;while(1){v[23048]=0;e=B(g,104)+a|0;i=e+484380|0;S(372,i|0,0);d=v[23048];v[23048]=0;if((d|0)==1){break t}v[23048]=0;l=U(373,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;W(374,b|0,((g<<5)+a|0)+946300|0,32)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;W(375,b|0,e+484423|0,13)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;d=U(376,b|0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break d}m=g-1|0;z=Mb(o,m),A=d,v[z>>2]=A;u:{if(w[k|0]<=9){v[23048]=0;g=U(340,b|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break u}break d}v[23048]=0;g=U(376,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}}v[i>>2]=g;v[23048]=0;d=U(340,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}v[e+484404>>2]=d;v[23048]=0;d=U(373,b|0)|0;g=v[23048];v[23048]=0;v:{w:{x:{if((g|0)!=1){t[f+32|0]=d;v[23048]=0;t[f+80|0]=64;d=$b(f+32|0,f+80|0);g=v[23048];v[23048]=0;if((g|0)==1){break x}u[e+484410>>1]=w[d|0]<<2;if(w[k|0]>9){break w}v[23048]=0;d=U(340,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}v[e+484384>>2]=d;v[23048]=0;d=U(340,b|0)|0;break v}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[23048]=0;d=U(376,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}v[e+484384>>2]=d;v[23048]=0;d=U(376,b|0)|0}g=v[23048];v[23048]=0;if((g|0)==1){break d}g=e+484388|0;v[g>>2]=d;if(l){l=e+484384|0;y:{if(!(d>>>0<=v[l>>2]+2>>>0|d>>>0>y[i>>2])){d=e+484414|0;u[d>>1]=x[d>>1]|2;break y}v[g>>2]=0;v[l>>2]=0}d=Mb(o,m);v[23048]=0;d=Jc(f+92|0,d);g=v[23048];v[23048]=0;if((g|0)==1){break d}v[f+92>>2]=v[d>>2]}j=j+1|0;g=j&65535;if(g>>>0<=x[a+480190>>1]){continue}break}}j=nc(f+80|0);d=w[f+166|0]|w[f+167|0]<<8;v[23048]=0;m=W(379,b|0,j|0,d|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break m}if(!m){break f}g=0;if(!cd(j)){g=Rb(j);e=Ub(j);d=gb-32|0;gb=d;v[d+16>>2]=e;v[d+24>>2]=g;z:{if(!Fb(d+24|0,d+16|0)){break z}v[d>>2]=g;e=sf(d);if(!Fb(e,d+16|0)){break z}while(1){if($D(v[d+24>>2],v[e>>2])){g=v[d>>2];v[d+24>>2]=g}if(Fb(sf(e),d+16|0)){continue}break}}gb=d+32|0;v[f+32>>2]=g;d=v[f+32>>2];g=w[d|0]|w[d+1|0]<<8}v[23048]=0;e=g;l=Q(380,f- -64|0,e|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){A:{if(e){d=0;while(1){v[23048]=0;Q(381,b|0,f+24|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break l}v[23048]=0;T(341,f+32|0,b|0,B(w[f+24|0]|w[f+25|0]<<8|w[f+26|0]<<16,3)|0);i=v[23048];v[23048]=0;if((i|0)==1){break A}id(Dg(l,d),f+32|0);yb(f+32|0);d=d+1|0;if((e|0)!=(d|0)){continue}break}}if(c&2){s=Sc(f+24|0,8,1,0,1);v[23048]=0;i=Q(382,f+32|0,o|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break j}d=Rb(i);e=Ub(i);v[23048]=0;iE(d,e);d=v[23048];v[23048]=0;if((d|0)==1){break k}h=Rb(i);p=Ub(i);d=gb-32|0;gb=d;v[d+16>>2]=p;v[d+24>>2]=h;e=gb-32|0;gb=e;v[e+16>>2]=p;v[e+24>>2]=h;B:{C:{if(!Fb(e+24|0,e+16|0)){break C}v[e+8>>2]=v[e+24>>2];if(!Fb(Qg(e+8|0),e+16|0)){break C}while(1){if(Ck(v[e+24>>2],v[e+8>>2])){h=v[e+24>>2];break B}v[e+24>>2]=v[e+8>>2];if(Fb(Qg(e+8|0),e+16|0)){continue}break}}h=v[e+16>>2]}gb=e+32|0;v[d+24>>2]=h;if(Fb(d+24|0,d+16|0)){v[d>>2]=v[d+24>>2];Qg(d);if(Fb(Qg(d),d+16|0)){while(1){if(!Ck(v[d+24>>2],v[d>>2])){e=v[v[d>>2]>>2];z=v[Qg(d+24|0)>>2],A=e,v[z>>2]=A}if(Fb(Qg(d),d+16|0)){continue}break}}Qg(d+24|0)}gb=d+32|0;v[f+16>>2]=v[d+24>>2];z=f,A=Rb(i),v[z+8>>2]=A;D:{if(!Fb(f+8|0,f+16|0)){break D}while(1){v[23048]=0;d=Q(250,b|0,1)|0;e=v[23048];v[23048]=0;E:{if((e|0)!=1){if(!d){break D}d=0;if(!x[a+480190>>1]){break E}while(1){v[23048]=0;e=Q(250,b|0,1)|0;h=v[23048];v[23048]=0;if((h|0)==1){break k}if(!e){break E}e=d+1|0;if(v[v[f+8>>2]>>2]!=v[Mb(o,d)>>2]){d=e;if(d>>>0>=x[a+480190>>1]){break E}continue}break}v[23048]=0;W(384,s|0,(B(e,104)+a|0)+484380|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break E}break k}break k}hE(f+8|0);if(Fb(f+8|0,f+16|0)){continue}break}}Qc(i)}if(!(c&1)){break g}d=w[f+165|0];c=0;v[23048]=0;i=a+484344|0;S(385,i|0,d|0);d=v[23048];v[23048]=0;F:{if((d|0)!=1){if(!w[f+165|0]){break g}p=q+((r>>>0>13)<<1)|0;while(1){G:{d=64;H:{if(uc(n)>>>0<=c>>>0){break H}d=x[sc(n,c)>>1]}v[23048]=0;d=W(386,i|0,c&65535,d|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break F}I:{if(d){d=x[a+480188>>1];e=w[k|0];v[23048]=0;Q(248,b|0,p+B(((e>>>0>13)<<1)+(d<<1)|0,c)|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break F}e=nc(f+32|0);d=x[a+480188>>1];v[23048]=0;d=W(379,b|0,e|0,d|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break I}J:{if(!d){break J}d=0;if(!x[a+480188>>1]){break J}while(1){K:{h=sc(e,d);if(!(w[h|0]|w[h+1|0]<<8)){break K}h=sc(e,d);if((w[h|0]|w[h+1|0]<<8)>>>0>(w[f+166|0]|w[f+167|0]<<8)>>>0){break K}h=sc(e,d);h=sc(j,(w[h|0]|w[h+1|0]<<8)-1|0);h=w[h|0]|w[h+1|0]<<8;if(!h|g>>>0<h>>>0){break K}q=Yb(i,c);h=Dg(l,h-1&65535);v[23048]=0;T(387,q|0,d&65535,h|0);h=v[23048];v[23048]=0;if((h|0)!=1){break K}break G}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}Ek(e)}c=c+1|0;if(c>>>0>=w[f+165|0]){break g}continue}}break}b=P()|0;O()|0;Ek(e);break i}b=P()|0;O()|0;break i}b=P()|0;O()|0;break i}b=P()|0;O()|0;break i}b=P()|0;O()|0;break h}b=P()|0;O()|0;break c}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;Hb(f+112|0);break a}b=P()|0;O()|0;break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;Qc(i);break i}b=P()|0;O()|0}kd(l)}Ek(j);break c}kd(l)}Ek(j);Qc(o);Ze(n)}gb=f+176|0;return m|0}b=P()|0;O()|0}Qc(o)}Ze(n)}R(b|0);L()}function ioa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=gb-256|0;gb=d;yc(b);f=gb-32|0;gb=f;k=d+96|0;kX(f+24|0,k);h=xb(f+24|0);e=v[f+28>>2];j=v[f+24>>2];v[f+8>>2]=j;v[f+12>>2]=e;v[f>>2]=j;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);j=xb(f+16|0);if((j|0)==(h|0)){Vb(e,xb(f+24|0))}gb=f+32|0;e=(h|0)==(j|0);if(!e){jX(k)}a:{b:{c:{d:{e:{f:{g:{if(!e){break g}if(!lX(d+96|0)){break g}if(!c){g=1;break g}Ed(a,v[((w[d+212|0]|w[d+213|0]<<8)<<2)+17600>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;e=Tb(d+16|0,17640);Eb(a+1300344|0,e);vb(e);e=Tb(d+16|0,17662);Eb(a+1300356|0,e);vb(e);e=gb-16|0;gb=e;f=Tb(e,17666);Dc(d+80|0,f);vb(f);gb=e+16|0;v[23048]=0;Y(410,d+16|0,d+80|0,d+175|0,d+172|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}Eb(a+1300368|0,d+16|0);vb(d+16|0);Hb(d+80|0);Zc(a+1300392|0,((w[d+212|0]|w[d+213|0]<<8)<<2)+17696|0);Zc(a+1300380|0,v[((w[d+212|0]|w[d+213|0]<<8)<<2)+17744>>2]);v[a+1300404>>2]=5;df(d+80|0,2,d+96|4);Fc(d+16|0,d+80|0);Eb(a+1300308|0,d+16|0);vb(d+16|0);df(d+80|0,2,d+132|0);Fc(d+16|0,d+80|0);if(Br(d+16|0,17784)){v[23048]=0;T(13,d+80|0,5,d+16|0);e=v[23048];v[23048]=0;if((e|0)==1){break f}Eb(a+1300320|0,d+80|0);vb(d+80|0)}vb(d+16|0);u[a+480188>>1]=32;e=0;h:{while(1){g=(e<<5)+a|0;h=g+480280|0;We(h);i:{f=d+e|0;if(w[f+177|0]<=15){v[d+16>>2]=w[f+177|0]<<4|8;v[d+80>>2]=256;r=g+480284|0,s=v[sd(d+16|0,d+80|0)>>2],u[r>>1]=s;break i}if(w[f+177|0]==16){u[g+480284>>1]=128;v[h>>2]=256;break i}if(w[f+177|0]!=255){break i}u[a+480188>>1]=e;break h}e=e+1|0;if((e|0)!=32){continue}break}e=x[a+480188>>1]}g=0;if(!(e&65535)){break g}v[d+16>>2]=w[d+209|0]<<2;v[d+80>>2]=256;r=a,s=v[Gb(d+16|0,d+80|0)>>2],v[r+480200>>2]=s;v[a+480196>>2]=w[d+210|0];v[a+480204>>2]=B(w[d+211|0],1e4);if(Rc(b,w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))){fp(Qb(a+484360|0),b,w[d+218|0]+1|0,255,254)}if(!Rc(b,w[d+224|0]|w[d+225|0]<<8|(w[d+226|0]<<16|w[d+227|0]<<24))){break g}u[a+480190>>1]=w[d+232|0]+1;j=d+48|0;e=1;k=1;while(1){g=gb-32|0;gb=g;l=d+16|0;cc(g+24|0,l,62);h=xb(g+24|0);f=v[g+28>>2];i=v[g+24>>2];v[g+8>>2]=i;v[g+12>>2]=f;v[g>>2]=i;v[g+4>>2]=f;f=b;fc(g+16|0,f,g);i=xb(g+16|0);if((i|0)==(h|0)){Vb(f,xb(g+24|0))}gb=g+32|0;f=(h|0)==(i|0);if(!f){Pb(l,0,62)}if(f){f=B(e,104)+a|0;g=f+484380|0;wd(g,0);df(d,2,d+16|0);Fc(d+80|0,d);v[23048]=0;Q(354,((e<<5)+a|0)+946300|0,d+80|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}vb(d+80|0);zk(d,2,j);Fc(d+80|0,d);v[23048]=0;Q(355,f+484423|0,d+80|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}vb(d+80|0);e=f+484404|0;v[e>>2]=w[d+74|0]|w[d+75|0]<<8;j:{if(!ep(a)){break j}h=v[e>>2];e=0;while(1){if((h|0)==x[(e<<1)+17792>>1]){t[f+484417|0]=e<<4;break j}e=e+1|0;if((e|0)!=16){continue}break}}u[f+484412>>1]=64;v[g>>2]=w[d+61|0]|w[d+62|0]<<8|(w[d+63|0]<<16|w[d+64|0]<<24);if(w[d+73|0]&2){e=f+484414|0;u[e>>1]=x[e>>1]|1;v[g>>2]=v[g>>2]>>>1}v[f+484384>>2]=w[d+65|0]|w[d+66|0]<<8|(w[d+67|0]<<16|w[d+68|0]<<24);v[f+484388>>2]=(w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24))-1;if(t[d+73|0]&1){e=f+484414|0;u[e>>1]=x[e>>1]|2}k:{if(!(!(w[d+73|0]&4)|w[d+76|0]==255)){t[d+80|0]=w[d+76|0];t[d|0]=64;r=f+484410|0,s=w[$b(d+80|0,d)|0]<<2,u[r>>1]=s;break k}e=f+484414|0;u[e>>1]=x[e>>1]|32768}l:{if(!(w[d+73|0]&8)){u[f+484408>>1]=128;break l}e=f+484414|0;u[e>>1]=x[e>>1]|32;m=f+484408|0;if(w[d+77|0]>=16){f=128}else{f=w[d+77|0];v[d>>2]=256;v[d+80>>2]=f<<4|8;f=v[sd(d+80|0,d)>>2]}u[m>>1]=f;u[e>>1]=x[e>>1]&65279|(w[d+77|0]==16)<<8}k=k+1|0;e=k&65535;if(e>>>0<=x[a+480190>>1]){continue}}break}m:{if(!(c&2)){break m}if(!Rc(b,w[d+228|0]|w[d+229|0]<<8|(w[d+230|0]<<16|w[d+231|0]<<24))|!x[a+480190>>1]){break m}e=1;while(1){f=B(e&65535,104)+a|0;ug(Sc(d+16|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}}n=a+484344|0;rg(n,w[d+223|0]+1|0);f=Hq(a);e=gb-16|0;gb=e;v[e+12>>2]=0;du(e+12|0,f);j=v[e+12>>2];gb=e+16|0;Rc(b,w[d+219|0]|w[d+220|0]<<8|(w[d+221|0]<<16|w[d+222|0]<<24));p=c&1;l=0;k=1;m=a;while(1){c=Fg(b);if(c>>>0>=3){td(d+16|0,b,c-2|0);n:{if(!p){break n}v[23048]=0;c=U(328,d+16|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}if(!c){break n}v[23048]=0;c=W(386,n|0,l&65535,64)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}f=0;if(!c){break n}while(1){c=Yb(n,l);v[23048]=0;q=Of(c,f);c=v[23048];v[23048]=0;if((c|0)==1){break d}o:while(1){v[23048]=0;c=U(373,d+16|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}p:{if(!c){break p}e=c&31;if(e>>>0>=x[a+480188>>1]){break p}g=B(e,6)+q|0;if(c&32){v[23048]=0;S(452,d+80|0,d+16|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}h=rd(d+80|0);e=w[d+80|0];if(e){e=(e&127)-1|0;t[d+80|0]=e;t[g|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+13;v[23048]=0;e=uv(g);i=v[23048];v[23048]=0;if((i|0)==1){break d}k=e&k}t[g+1|0]=w[h|0]}if(!(c&64)){continue}t[g+2|0]=0;t[g+3|0]=0;h=g+5|0;while(1){v[23048]=0;c=Q(250,d+16|0,2)|0;e=v[23048];v[23048]=0;q:{r:{s:{t:{u:{v:{w:{x:{y:{if((e|0)!=1){if(!c){continue o}o=w[h|0];c=w[g+3|0];v[23048]=0;S(452,d+80|0,d+16|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}i=w[rd(d+80|0)|0];t[h|0]=i;e=w[(w[d+80|0]&31)+17824|0];t[g+3|0]=e;switch(e-2|0){case 18:break t;case 13:break u;case 17:break v;case 11:break w;case 4:case 5:break x;case 0:case 1:break y;default:break r}}break d}if(v[a+480180>>2]==1|i>>>0<224){break s}t[h|0]=223;break s}e=i&240;if(!e){break s}t[h|0]=e;break s}v[23048]=0;t[d|0]=64;e=$b(h,d);i=v[23048];v[23048]=0;if((i|0)!=1){t[h|0]=w[e|0];v[23048]=0;e=hz(j,1);i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!e){break s}t[g+2|0]=1;t[g+4|0]=w[h|0];t[g+3|0]=c;t[h|0]=o;e=c;break r}break d}v[23048]=0;e=vq(j,19);i=v[23048];v[23048]=0;if((i|0)==1){break d}if(e){break s}v[23048]=0;Yt(g);e=v[23048];v[23048]=0;if((e|0)!=1){break s}break d}v[23048]=0;e=vq(j,15);i=v[23048];v[23048]=0;if((i|0)==1){break d}if(e){break s}v[23048]=0;e=vq(j,19);i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!e){break s}t[g+3|0]=19;t[h|0]=w[h|0]&15|144;break q}z:{A:{e=i>>>4|0;if((e|0)!=8){if(e){break A}B:{switch(i&15){case 4:t[g+3|0]=20;t[h|0]=158;break q;case 0:case 1:break z;case 5:break B;default:break A}}t[g+3|0]=20;t[h|0]=159;break q}v[23048]=0;e=vq(j,20);i=v[23048];v[23048]=0;if((i|0)==1){break d}if(e){break s}t[g+3|0]=19;break q}t[g+3|0]=0;break q}t[h|0]=i-112}e=w[g+3|0]}if((e&255)!=20){break q}e=w[h|0];if(w[g+2|0]|(e&240)!=128){break q}t[g+2|0]=2;t[g+4|0]=(((e&15)<<6|8)>>>0)/15;t[g+3|0]=c;t[h|0]=o}if(w[d+80|0]&32){continue}break}continue}break}f=f+1|0;if((f|0)!=64){continue}break}}yb(d+16|0)}c=w[d+223|0]>l>>>0;l=l+1|0;if(c){continue}break}c=v[a+480208>>2]|8454144;C:{if(!((k^-1|x[a+480188>>1]!=4)&1|v[a+480180>>2]!=1)){break C}c=v[a+480208>>2]&-8454145}v[m+480208>>2]=c;g=1;if(!(w[d+237|0]|w[d+238|0]<<8|(w[d+239|0]<<16|w[d+240|0]<<24))){break g}if(!Rc(b,w[d+233|0]|w[d+234|0]<<8|(w[d+235|0]<<16|w[d+236|0]<<24))){break g}cB(a+1300332|0,b,w[d+237|0]|w[d+238|0]<<8|(w[d+239|0]<<16|w[d+240|0]<<24),4)}gb=d+256|0;return g|0}e=P()|0;O()|0;vb(d+16|0);break a}e=P()|0;O()|0;Hb(d+80|0);break a}e=P()|0;O()|0;yb(d+16|0);break a}e=P()|0;O()|0;vb(d+80|0);break a}e=P()|0;O()|0;vb(d+80|0)}R(e|0);L()}function epa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-240|0;gb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!jY(b,d+168|0)){break j}if(!kY(d+168|0)){break j}if(!c){e=1;break j}Ed(a,131072);e=gb-16|0;gb=e;k=Tb(e,17232);Dc(d+80|0,k);vb(k);gb=e+16|0;v[23048]=0;T(507,d+120|0,d+80|0,d+168|4);e=v[23048];v[23048]=0;if((e|0)==1){break i}Eb(a+1300344|0,d+120|0);vb(d+120|0);Hb(d+80|0);e=Tb(d+120|0,17246);Eb(a+1300356|0,e);vb(e);v[a+1300404>>2]=5;Mv(d+80|0,3,d+181|0);Fc(d+120|0,d+80|0);Eb(a+1300308|0,d+120|0);vb(d+120|0);Mj(d+56|0,3,d+211|0);Fc(d+80|0,d+56|0);v[23048]=0;T(13,d+120|0,5,d+80|0);e=v[23048];v[23048]=0;k:{l:{m:{n:{o:{if((e|0)!=1){Eb(a+1300320|0,d+120|0);vb(d+120|0);vb(d+80|0);e=Gr(d+120|0);m=e,n=Gd(w[d+231|0],1,31),v[m+12>>2]=n;m=e,n=Gd(w[d+232|0],1,12)-1|0,v[m+16>>2]=n;v[e+20>>2]=w[d+233|0];k=a+1300408|0;dD(k);hY(k,e);i=d+56|4;k=_g(d+104|0);while(1){v[23048]=0;e=Q(250,b|0,8)|0;f=v[23048];v[23048]=0;if((f|0)==1){break o}if(!e){break k}v[23048]=0;S(508,b|0,d+56|0);e=v[23048];v[23048]=0;if((e|0)==1){break n}f=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);e=w[d+172|0];p:{if((e|0)==3){g=2;if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))==1431389523){break p}e=w[d+172|0]}if((e&255)==4){g=4;if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))==1431389523){break p}e=w[d+172|0]}g=0;if((e&255)>>>0>7){break p}f=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))==1146113363?-1:f}v[23048]=0;T(341,d+80|0,b|0,f|0);e=v[23048];v[23048]=0;if((e|0)==1){break m}v[23048]=0;T(509,k|0,d+56|0,d+80|0);e=v[23048];v[23048]=0;if((e|0)==1){break l}yb(d+80|0);v[23048]=0;Q(370,b|0,g|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+80|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+80|0);break b}v[23048]=0;b=U(270,d+80|0)|0;e=v[23048];v[23048]=0;q:{r:{s:{if((e|0)!=1){v[23048]=0;T(510,d+56|0,k|0,1431389523);e=v[23048];v[23048]=0;if((e|0)==1){break s}id(b,d+56|0);yb(d+56|0);u[d+54>>1]=0;u[d+52>>1]=65534;if(w[d+172|0]<3){break q}v[23048]=0;e=U(340,b|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break r}break d}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}u[d+54>>1]=e;if(w[d+172|0]<4){break q}v[23048]=0;e=U(340,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break d}u[d+52>>1]=e?e:w[d+172|0]==4?-2:e}e=a+484360|0;f=Qb(e);v[23048]=0;g=U(511,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}v[23048]=0;ga(423,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[23048];v[23048]=0;if((f|0)==1){break d}f=Qb(e);v[23048]=0;f=U(512,f|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}og(d+54|0,f);f=Qb(e);v[23048]=0;f=U(512,f|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}og(d+52|0,f);v[23048]=0;T(510,d+56|0,k|0,1414807888);f=v[23048];v[23048]=0;t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){id(b,d+56|0);yb(d+56|0);v[23048]=0;f=U(328,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}if(!(c&1)|f^1){break t}v[23048]=0;S(513,b|0,d+48|0);f=v[23048];v[23048]=0;if((f|0)==1){break A}m=a,n=Gd(w[d+48|2],1,32)+1|0,u[m+480188>>1]=n;f=w[d+48|0]|w[d+49|0]<<8;v[23048]=0;f=Q(380,d|0,f|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break z}m=d,n=Rb(f),v[m+16>>2]=n;m=d,n=Ub(f),v[m+40>>2]=n;if(Fb(d+16|0,d+40|0)){while(1){i=v[d+16>>2];v[23048]=0;g=w[d+172|0]<3?9:8;Q(370,b|0,g-4|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break y}v[23048]=0;h=U(376,b|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break x}kg(b,g);v[23048]=0;T(341,d+56|0,b|0,g+h|0);g=v[23048];v[23048]=0;if((g|0)==1){break w}id(i,d+56|0);yb(d+56|0);sh(d+16|0);if(Fb(d+16|0,d+40|0)){continue}break}}g=x[a+480188>>1];v[23048]=0;g=Q(514,d+56|0,g|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break v}h=Ol(Qb(e));v[23048]=0;i=a+484344|0;S(385,i|0,h|0);h=v[23048];v[23048]=0;if((h|0)==1){break f}h=Qb(e);m=d,n=Rb(h),v[m+16>>2]=n;m=d,n=Ub(h),v[m+40>>2]=n;if(Fb(d+16|0,d+40|0)){while(1){h=v[d+16>>2];j=x[h>>1];if(cf(f)>>>0>j>>>0){j=Dg(f,x[h>>1]);v[23048]=0;j=ba(515,j|0,w[d+172|0],g|0,a|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break f}u[h>>1]=j}sf(d+16|0);if(Fb(d+16|0,d+40|0)){continue}break}}h=Qb(e);v[23048]=0;h=Q(516,h|0,x[d+52>>1])|0;j=v[23048];v[23048]=0;if((j|0)==1){break f}if(!h){break u}if(!x[d+54>>1]){h=x[d+52>>1];j=Qb(e);v[23048]=0;j=U(512,j|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break f}if(h>>>0>=j>>>0){break u}}e=x[sc(Qb(e),x[d+52>>1])>>1];h=Yb(i,e);v[23048]=0;j=De(d+16|0,12,w[d+54|0]);l=v[23048];v[23048]=0;if((l|0)!=1){e=mp(Ve(j,v[Yb(i,e)+12>>2]-1|0));v[23048]=0;Q(479,h|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break u}}break f}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}$C(g);kd(f)}v[23048]=0;T(510,d+56|0,k|0,1196641603);e=v[23048];v[23048]=0;if((e|0)==1){break h}id(b,d+56|0);yb(d+56|0);v[23048]=0;e=U(328,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break d}if(e){v[23048]=0;Q(370,b|0,1)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;e=U(511,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break d}v[23048]=0;ga(517,a+1300332|0,b|0,e|0,40,0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}}v[23048]=0;T(510,d+56|0,k|0,1146113363);e=v[23048];v[23048]=0;if((e|0)==1){break g}v[23048]=0;T(510,d+16|0,k|0,1229999443);e=v[23048];v[23048]=0;B:{C:{if((e|0)!=1){id(b,d+16|0);yb(d+16|0);v[23048]=0;f=U(373,b|0)|0;g=v[23048];v[23048]=0;e=1;D:{if((g|0)!=1){u[a+480190>>1]=f;if(x[a+480190>>1]){i=!(c&2);g=1;while(1){f=30;E:{F:{G:{if(w[d+172|0]>=2){v[23048]=0;f=U(373,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break G}}v[23048]=0;W(518,b|0,((e<<5)+a|0)+946300|0,f|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break G}v[23048]=0;S(519,b|0,d|0);c=v[23048];v[23048]=0;if((c|0)==1){break F}v[23048]=0;c=B(e,104)+a|0;f=c+484380|0;S(520,d|0,f|0);e=v[23048];v[23048]=0;if((e|0)==1){break F}e=w[d+172|0];if(e>>>0>=8){v[23048]=0;W(521,b|0,c+484423|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break F}e=w[d+172|0]}v[23048]=0;Q(370,b|0,((e&255)>>>0>1?6:2)|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break F}v[23048]=0;e=U(376,d+56|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){v[23048]=0;T(341,d+16|0,d+56|0,e|0);e=v[23048];v[23048]=0;if((e|0)!=1){break E}}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}v[23048]=0;e=U(328,d+16|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break D}H:{if(i|e^1){break H}c=Sc(d+40|0,u[c+484414>>1]&1?16:8,1,0,(w[d+15|0]&12)==4?7:0);v[23048]=0;W(384,c|0,f|0,d+16|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break H}break D}yb(d+16|0);g=g+1|0;e=g&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}v[23048]=0;sg(a);c=v[23048];v[23048]=0;e=1;if((c|0)!=1){break B}}a=P()|0;O()|0;break C}a=P()|0;O()|0;yb(d+16|0);break C}a=P()|0;O()|0}yb(d+56|0);break c}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;yb(d+56|0);yb(b);Cd(k)}gb=d+240|0;return e|0}a=P()|0;O()|0;Hb(d+80|0);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;$C(g)}kd(f);break c}a=P()|0;O()|0}yb(b)}Cd(k)}R(a|0);L()}function p2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2402;r=ge(l+136|0,l+144|0,l+96|0);b=v[r>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;u=Jb(l+96|0);m=Jb(l+80|0);n=Jb(l- -64|0);o=Jb(l+48|0);s=Jb(l+32|0);v[23048]=0;na(2411,c|0,d|0,l+120|0,l+116|0,l+112|0,u|0,m|0,n|0,o|0,l+28|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;e=v[l+28>>2];k=0;f:{while(1){v[23048]=0;c=Q(2380,a|0,l+552|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}g:{if(!c){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+p|0]){case 1:if((p|0)==3){break g}v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}v[23048]=0;c=W(2412,h|0,8192,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if(c){v[23048]=0;S(2413,l+16|0,a|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=v[l+16>>2];v[23048]=0;S(112,s|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((p|0)==3){break g}}while(1){v[23048]=0;c=Q(2380,a|0,l+552|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(!c){break h}v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;c=W(2412,h|0,8192,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(!c){break h}v[23048]=0;S(2413,l+16|0,a|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=v[l+16>>2];v[23048]=0;S(112,s|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Bb(n)|0)==(0-Bb(o)|0)){break h}r:{if(Bb(n)){if(Bb(o)){break r}}if(Bb(n)){v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if((c|0)!=v[Ob(n)>>2]){break l}v[23048]=0;U(2384,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}k=Bb(n)>>>0>1?n:k;break h}v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if((c|0)!=v[Ob(o)>>2]){break h}v[23048]=0;U(2384,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}t[g|0]=1;k=Bb(o)>>>0>1?o:k;break h}v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if((c|0)==v[Ob(n)>>2]){v[23048]=0;U(2384,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}k=Bb(n)>>>0>1?n:k;break h}v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if((c|0)==v[Ob(o)>>2]){v[23048]=0;U(2384,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}t[g|0]=1;k=Bb(o)>>>0>1?o:k;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(p>>>0<2|k|((p|0)==2&w[l+123|0]!=0|z))){k=0;break h}B=l,C=Ld(m),v[B+8>>2]=C;c=Sd(l+16|0,l+8|0);s:{if(!p|w[(l+p|0)+119|0]>1){break s}B=l,C=mi(m),v[B+8>>2]=C;t:{if(!Fb(c,l+8|0)){break t}while(1){d=v[v[c>>2]>>2];v[23048]=0;d=W(2412,h|0,8192,d|0)|0;q=v[23048];v[23048]=0;if((q|0)==1){break k}if(!d){break t}Ag(c);B=l,C=mi(m),v[B+8>>2]=C;if(Fb(c,l+8|0)){continue}break}}B=l,C=Ld(m),v[B+8>>2]=C;d=lv(c,l+8|0);if(Bb(s)>>>0>=d>>>0){B=l,C=mi(s),v[B+8>>2]=C;c=gb-16|0;gb=c;v[c+8>>2]=v[l+8>>2];v[c+8>>2]=v[c+8>>2]+(0-d<<2);d=v[c+8>>2];gb=c+16|0;q=mi(s);x=Ld(m);c=gb-32|0;gb=c;v[c+16>>2]=q;v[c+24>>2]=d;v[c+8>>2]=x;d=1;u:{if(!Fb(c+24|0,c+16|0)){break u}while(1){d=Ck(v[c+24>>2],v[c+8>>2]);if(!d){break u}Ag(c+24|0);Ag(c+8|0);if(Fb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;if(d){break s}}B=l,C=Ld(m),v[B>>2]=C;Sd(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];B=l,C=mi(m),v[B>>2]=C;v:{w:{x:{if(!Fb(l+8|0,l)){break x}while(1){v[23048]=0;c=Q(2380,a|0,l+552|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break w}if(!c){break x}v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break w}if((c|0)!=v[v[l+8>>2]>>2]){break x}v[23048]=0;U(2384,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break v}Ag(l+8|0);B=l,C=mi(m),v[B>>2]=C;if(Fb(l+8|0,l)){continue}break}}if(!y){break h}B=l,C=mi(m),v[B>>2]=C;if(!Fb(l+8|0,l)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+28>>2]=e;break a}a=P()|0;O()|0;v[l+28>>2]=e;break a}c=0;x=v[l+112>>2];d=b;y:{while(1){z:{v[23048]=0;b=Q(2380,a|0,l+552|0)|0;q=v[23048];v[23048]=0;if((q|0)==1){break z}if(!b){break y}v[23048]=0;q=U(2382,a|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;b=W(2412,h|0,2048,q|0)|0;A=v[23048];v[23048]=0;if((A|0)==1){break e}A:{if(b){b=v[j>>2];if((b|0)==v[l+548>>2]){v[23048]=0;T(2414,i|0,j|0,l+548|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}b=v[j>>2]}v[j>>2]=b+4;v[b>>2]=q;c=c+1|0;break A}if(!c|!Bb(u)|(q|0)!=(x|0)){break y}if(v[l+128>>2]==(d|0)){v[23048]=0;T(2408,r|0,l+132|0,l+128|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;d=b;c=0}v[23048]=0;U(2384,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!c|v[r>>2]==(d|0)){break j}if(v[l+128>>2]==(d|0)){v[23048]=0;T(2408,r|0,l+132|0,l+128|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;break i}t[g|0]=1;break h}a=P()|0;O()|0;v[l+28>>2]=e;break a}b=d}B:{if((e|0)<1){break B}v[23048]=0;c=Q(2381,a|0,l+552|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}C:{if(!c){v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}if((c|0)==v[l+116>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break f}v[23048]=0;U(2384,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break d}while(1){if((e|0)<1){e=0;break B}v[23048]=0;c=Q(2381,a|0,l+552|0)|0;d=v[23048];v[23048]=0;D:{if((d|0)==1){break D}E:{if(!c){v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break D}v[23048]=0;c=W(2412,h|0,2048,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break D}if(c){break E}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[23048]=0;T(2414,i|0,j|0,l+548|0);c=v[23048];v[23048]=0;if((c|0)==1){break D}}v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break D}d=v[j>>2];v[j>>2]=d+4;v[d>>2]=c;v[23048]=0;U(2384,a|0)|0;c=v[23048];v[23048]=0;e=e-1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}p=p+1|0;if((p|0)!=4){continue}}break}v[l+28>>2]=e;F:{if(!k){break F}e=1;while(1){if(Bb(k)>>>0<=e>>>0){break F}v[23048]=0;c=Q(2381,a|0,l+552|0)|0;d=v[23048];v[23048]=0;G:{if((d|0)==1){break G}H:{if(!c){v[23048]=0;c=U(2382,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break G}if((c|0)==v[ck(k,e)>>2]){break H}}v[f>>2]=v[f>>2]|4;a=0;break f}v[23048]=0;U(2384,a|0)|0;c=v[23048];v[23048]=0;e=e+1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[r>>2]==(b|0)){break f}a=0;v[l+16>>2]=0;kf(u,v[r>>2],b,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}Pc(s);Pc(o);Pc(n);Pc(m);vb(u);Hc(r);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Pc(s);Pc(o);Pc(n);Pc(m);vb(u);Hc(r);R(a|0);L()}function I_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=gb-1488|0;gb=d;yc(b);ps(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!VF(b,d+1472|0)){break j}if(!XF(d+1472|0)){break j}q=d+1456|0;g=CF(b,q);if(!g){xw(q)}if(!g){break j}if(!WF(d+1456|0)){break j}if(!c){E=1;break j}q=d+1464|0;c=q;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>Pk(b)>>>0){break j}c=q;s=d+1456|2;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+((w[s|0]|w[s+1|0]<<8)<<2)>>>0>Pk(b)>>>0){break j}Hw(a);Gw(d+88|0);Fw(Yi(a)+32|0,d+88|0);os(d+88|0);n=v[Yi(a)+32>>2];c=d+1456|4;Rp(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));Pb(d+1200|0,0,256);k:{if(w[s|0]|w[s+1|0]<<8){k=d+1176|4;l=d+1192|0;A=d+1194|0;u=d+1190|0;h=d+1188|0;while(1){c=q;if(!Rc(b,(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+(D<<2)|0)){break j}if(!Nb(b,4)){break j}g=_f(b);if(!Rc(b,g)){break j}if(!Ew(b,d+1176|0)){break j}c=w[h|0]|w[h+1|0]<<8;r=d+1160|0;f=Jg(r);l:{if(!c){break l}v[23048]=0;S(255,r|0,c|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;Cw(r,c);c=v[23048];v[23048]=0;if((c|0)!=1){break l}}a=P()|0;O()|0;An(f);R(a|0);L()}c=0;m:{if(!(w[h|0]|w[h+1|0]<<8)){break m}n:{while(1){f=qe(r,c);v[23048]=0;f=Q(246,b|0,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break n}if(f){c=c+1|0;if(c>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break m}continue}break}break k}c=P()|0;O()|0;break b}if(w[h|0]|w[h+1|0]<<8){c=v[r>>2]}else{c=0}f=w[h|0]|w[h+1|0]<<8;v[23048]=0;e=U(247,b|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break h}g=g+20|0;if(e>>>0<=g+(f<<3)>>>0){break k}f=g+((w[h|0]|w[h+1|0]<<8)<<3)|0;o:{if(!(t[u|0]&1)){e=0;if(!(w[h|0]|w[h+1|0]<<8)){break o}while(1){if(!c){break k}if(!Mp(n,c)){break k}v[23048]=0;g=Q(248,b|0,f|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break g}if(!g){break k}g=c;i=_d(d+1152|0,oc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24));v[23048]=0;o=v[i+4>>2];v[d+16>>2]=v[i>>2];v[d+20>>2]=o;T(249,d+88|0,b|0,d+16|0);i=v[23048];v[23048]=0;if((i|0)==1){break f}if((xb(d+88|0)|0)!=(w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24))){break k}c=c+8|0;e=e+1|0;if(e>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}break o}p:{q:{r:{if(w[u|0]&4){if(!c){break k}if(!Mp(n,c)){break k}g=oc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));z=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);o=w[A|0]|w[A+1|0]<<8;e=w[l|0]|w[l+1|0]<<8;v[23048]=0;f=Q(248,b|0,e+f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}if(!f){break k}f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[23048]=0;f=Q(250,b|0,f-e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}if(!f){break k}f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[23048]=0;T(251,d- -64|0,b|0,f-e|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}f=Ok(d+88|0,d- -64|0);yb(d- -64|0);y=0;i=0;p=0;s:{t:{u:{if(!(w[h|0]|w[h+1|0]<<8)){break u}while(1){v:{v[23048]=0;e=Q(252,f|0,o+1|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break v}j=o&15;B=x[(j<<1)+15280>>1];w:{x:{if(B>>>0<=e>>>0){v[23048]=0;j=w[j+15376|0];m=Q(252,f|0,j|0)|0;C=v[23048];v[23048]=0;if((C|0)==1){break v}e=m+(e-B<<j)|0;if((e|0)!=(o|0)){o=e&15;break w}v[23048]=0;e=Q(252,f|0,4)|0;j=v[23048];v[23048]=0;if((j|0)==1){break v}if((e|0)==15){v[23048]=0;j=Q(252,f|0,1)|0;e=v[23048];v[23048]=0;if((e|0)==1){break v}e=65535;if(!j){break x}yb(d+88|0);break o}e=e+65520|0}if(e>>>0>65535){break w}}e=e&1?0-(e+1>>>1|0)|0:e>>>1|0;j=g+i|0;m=j;y:{if(w[u|0]&2){y=e+y|0;e=y;break y}e=w[u+1|0]&2?e:e^32768}t[m|0]=e;t[j+1|0]=e>>>8;i=i+2|0}if(i>>>0>=z>>>0){p=p+1|0;if(p>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break p}g=(p<<3)+c|0;if(!Mp(n,g)){break r}z=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);i=0;g=oc(n,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))}if((w[h|0]|w[h+1|0]<<8)>>>0>p>>>0){continue}break u}break}c=V(15256)|0;if((O()|0)!=(da(15256)|0)){break s}Z(c|0)|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)==1){break t}}yb(d+88|0);break o}c=P()|0;O()|0}yb(d+88|0);break b}if(!c){break k}if(!Mp(n,c)){break k}y=oc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));z=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);o=w[A|0]|w[A+1|0]<<8;z:{A:{if((w[l|0]|w[l+1|0]<<8)>>>0<=256){v[23048]=0;g=Q(248,b|0,f|0)|0;f=v[23048];v[23048]=0;B:{if((f|0)!=1){if(!g){break B}g=_d(d+56|0,d+1200|0,w[l|0]|w[l+1|0]<<8);v[23048]=0;f=v[g+4>>2];v[d+24>>2]=v[g>>2];v[d+28>>2]=f;T(253,d+88|0,b|0,d+24|0);g=v[23048];v[23048]=0;if((g|0)==1){break A}if(xb(d+88|0)>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break k}g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[23048]=0;g=Q(250,b|0,g-f|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break z}}c=P()|0;O()|0;break b}break k}break k}c=P()|0;O()|0;break b}if(!g){break k}g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[23048]=0;T(251,d- -64|0,b|0,g-f|0);g=v[23048];v[23048]=0;if((g|0)==1){break d}j=Ok(d+88|0,d- -64|0);yb(d- -64|0);g=0;i=0;p=0;C:{D:{E:{F:{G:{if(!(w[h|0]|w[h+1|0]<<8)){break G}while(1){H:{v[23048]=0;e=Q(252,j|0,o+1|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break H}F=i+y|0;m=o&7;C=w[m+15312|0];I:{J:{if(C>>>0<=e>>>0){v[23048]=0;m=w[m+15320|0];B=Q(252,j|0,m|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break H}e=B+(e-C<<m)|0;if((e|0)!=(o|0)){o=e&7;break I}v[23048]=0;e=Q(252,j|0,3)|0;m=v[23048];v[23048]=0;if((m|0)==1){break H}if((e|0)==7){v[23048]=0;e=Q(252,j|0,1)|0;m=v[23048];v[23048]=0;if((m|0)==1){break H}if(e){break D}e=d+1455|0;break J}e=e+248|0}if(e>>>0>255){break I}e=(d+1200|0)+e|0}f=w[e|0];e=f+g|0;m=f;f=(w[u|0]|w[u+1|0]<<8)&2;t[F|0]=f?e:m;g=f?e:g;i=i+1|0}if(i>>>0>=z>>>0){p=p+1|0;if(p>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break C}f=(p<<3)+c|0;if(!Mp(n,f)){break q}z=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);y=oc(n,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));i=0}if((w[h|0]|w[h+1|0]<<8)>>>0>p>>>0){continue}break G}break}c=V(15256)|0;if((O()|0)!=(da(15256)|0)){break E}Z(c|0)|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)==1){break F}}yb(d+88|0);break o}c=P()|0;O()|0}yb(d+88|0);break b}yb(d+88|0);break o}yb(d+88|0);break o}yb(d+88|0);break k}yb(d+88|0);break k}yb(d+88|0)}An(r);D=D+1|0;if(D>>>0<(w[s|0]|w[s+1|0]<<8)>>>0){continue}break}}me(d+40|0,n);b=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=b;Ch(d+48|0,d+8|0);b=Xd(d+32|0);v[23048]=0;c=v[d+52>>2];v[d>>2]=v[d+48>>2];v[d+4>>2]=c;c=W(254,d+88|0,d|0,b|0)|0;q=v[23048];v[23048]=0;E=1;if((q|0)==1){break i}id(Yi(a)+12|0,c);yb(c);Bc(b);break j}An(r)}gb=d+1488|0;return E|0}c=P()|0;O()|0;Bc(b);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0}An(r)}R(c|0);L()}function Hka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-272|0;gb=d;yc(b);f=gb-32|0;gb=f;h=d+120|0;sU(f+24|0,h);i=xb(f+24|0);e=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=e;v[f>>2]=g;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);g=xb(f+16|0);if((g|0)==(i|0)){Vb(e,xb(f+24|0))}gb=f+32|0;e=(g|0)==(i|0);if(!e){rU(h)}a:{b:{c:{d:{e:{if(!e){break e}if(!zU(d+120|0)){break e}if(!c){k=1;break e}Ed(a,4194304);e=Tb(d+32|0,25798);Eb(a+1300344|0,e);vb(e);e=Tb(d+32|0,25794);Eb(a+1300356|0,e);vb(e);v[a+1300404>>2]=5;m=a,n=Gd(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[m+480188>>1]=n;e=w[d+189|0];v[a+480228>>2]=(e|0)==255?48:e;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);uf(d+96|0,d+120|4,59,3);Fc(d+32|0,d+96|0);Eb(a+1300308|0,d+32|0);vb(d+32|0);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Rc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!xh(b,25832)){break f}fp(Qb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Rc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!xh(b,25837)){break g}while(1){e=(k<<5)+a|0;We(e+480280|0);m=e+480284|0,n=((((Hd(b)^-1)&15)<<8|8)>>>0)/15|0,u[m>>1]=n;k=k+1|0;if((k|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Rc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!xh(b,25842)){break h}td(d+96|0,b,(w[d+196|0]|w[d+197|0]<<8)<<6);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}k=c&2;i=a+480190|0;h=d+45|0;while(1){v[23048]=0;e=Q(905,d+96|0,d+32|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break d}if(!e){break i}e=w[d+77|0]|w[d+78|0]<<8;u[d+30>>1]=e;j:{if((e-1&65535)>>>0>3998){break j}if(Od((B(e,104)+a|0)+484380|0)){break j}v[23048]=0;e=Le(i,d+30|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}u[a+480190>>1]=x[e>>1];v[23048]=0;S(906,d+32|0,(B(x[d+30>>1],104)+a|0)+484380|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}uf(d,h,24,1);v[23048]=0;S(398,d+16|0,d|0);e=v[23048];v[23048]=0;k:{if((e|0)!=1){v[23048]=0;Q(354,((x[d+30>>1]<<5)+a|0)+946300|0,d+16|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break k}vb(d+16|0);if(!k){break j}e=w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24);v[23048]=0;Q(248,b|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}f=1;e=d+79|0;g=Sc(d+16|0,w[e|0]&4?16:8,1,0,0);l:{m:{if(w[e|0]&8){break m}f=2;if(w[e|0]&16){break m}if(w[e|0]&127){break l}}tf(g,f)}v[23048]=0;W(384,d+16|0,(B(x[d+30>>1],104)+a|0)+484380|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break j}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+16|0);break b}j=j+1|0;if((j&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}yb(d+96|0)}k=1;if(!(c&1)){break e}n:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break n}if(!Rc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break n}if(!xh(b,25847)){break n}h=a+484344|0;rg(h,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break n}i=d+16|2;f=0;while(1){if(!mC(b,d+16|0)){break n}if((w[d+16|0]|w[d+17|0]<<8)>>>0>3){td(d+32|0,b,((w[d+16|0]|w[d+17|0]<<8)+15&131056)-4|0);c=w[i|0];v[23048]=0;c=W(386,h|0,f&65535,c|0)|0;e=v[23048];v[23048]=0;o:{if((e|0)!=1){p:{j=0;if(!c){break o}while(1){v[23048]=0;c=Q(250,d+32|0,1)|0;e=v[23048];v[23048]=0;q:{r:{s:{if((e|0)!=1){if(!c|w[i|0]<=j>>>0){break r}v[23048]=0;e=U(373,d+32|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break p}if(e){break s}j=j+1|0;continue}break p}c=Yb(h,f);u[d+96>>1]=e&31;g=x[a+480188>>1];v[23048]=0;u[d>>1]=g-1;g=Vc(d+96|0,d);l=v[23048];v[23048]=0;if((l|0)==1){break p}g=x[g>>1];v[23048]=0;c=Wc(c,j,g);g=v[23048];v[23048]=0;if((g|0)==1){break p}if(e&128){v[23048]=0;S(452,d+96|0,d+32|0);g=v[23048];v[23048]=0;if((g|0)==1){break p}g=rd(d+96|0);t[c|0]=w[d+96|0]+36;t[c+1|0]=w[g|0]}if(!(e&64)){break q}t[c+2|0]=1;v[23048]=0;g=U(373,d+32|0)|0;l=v[23048];v[23048]=0;t:{if((l|0)!=1){t[d+96|0]=g;v[23048]=0;t[d|0]=64;g=$b(d+96|0,d);l=v[23048];v[23048]=0;if((l|0)==1){break t}t[c+4|0]=w[g|0];break q}break p}break p}if(w[i|0]==64){break o}c=Yb(h,f);v[23048]=0;e=De(d+96|0,14,0);j=v[23048];v[23048]=0;if((j|0)!=1){e=wh(Ve(e,w[i|0]-1|0));v[23048]=0;Q(479,c|0,e|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break o}}break p}if(!(e&32)){continue}v[23048]=0;S(452,d+96|0,d+32|0);e=v[23048];v[23048]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((e|0)!=1){e=w[rd(d+96|0)|0];t[c+5|0]=e;switch(w[d+96|0]-1|0){case 71:break v;case 70:break w;case 69:break x;case 60:break y;case 59:break z;case 52:break A;case 51:break B;case 50:break C;case 49:break D;case 42:break E;case 41:break F;case 40:break G;case 39:break H;case 30:break I;case 29:break J;case 22:break K;case 21:break L;case 20:break M;case 19:break N;case 16:break O;case 15:break P;case 14:break Q;case 13:break R;case 12:break S;case 11:break T;case 10:break U;case 9:break V;case 3:break W;case 2:break X;case 1:break Y;case 0:break Z;default:break u}}break p}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[23048]=0;e=U(373,d+32|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){t[c+5|0]=e;v[23048]=0;Q(370,d+32|0,1)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}}break p}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;yb(d+32|0);break a}yb(d+32|0)}f=f+1|0;if(f>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Rc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));cB(a+1300332|0,b,Fg(b),4)}gb=d+272|0;return k|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}yb(d+96|0)}R(b|0);L()}function Tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;d=gb-320|0;gb=d;a:{if(!Rc(b,1080)){break a}if(!dp(b,d+316|0)){break a}Ed(a,1);n=AV(d+296|0);if(!zV(d+316|0,n)){break a}e=x[n+8>>1];if((e-1&65535)>>>0>126){break a}if(!c){f=1;break a}u[a+480188>>1]=e;j=w[n+12|0];M=w[n+11|0];e=w[n+10|0];H=1;if(!ke(d+316|0,24387)){H=ke(d+316|0,24392)}if(w[n+13|0]){Kb(a+1074308|0,5,1)}C=a+480188|0;s=M?x[C>>1]==8:0;p=ke(d+316|0,24397);k=1;if(!ke(d+316|0,24402)){k=ke(d+316|0,24407)}Rc(b,0);HC(b,a+1300308|0,20);u[a+480190>>1]=31;o=(e|0)!=0;f=1;e=p;while(1){l=B(f,104)+a|0;h=l+484380|0;q=YB(b,d+160|0,h,((f<<5)+a|0)+946300|0,x[a+480188>>1]==4);h=v[h>>2];b:{if(k){t[l+484417|0]=0-(w[d+184|0]<<3);break b}o=h>>>0<65536&o}if(Ib(w[d+182|0]|w[d+183|0]<<8)){N=!Ib(w[d+188|0]|w[d+189|0]<<8)|N}l=e&1;e=0;c:{if(!l){break c}g=(Ib(w[d+182|0]|w[d+183|0]<<8)<<1)+g|0;if(w[d+184|0]){break c}if(!Ib(w[d+182|0]|w[d+183|0]<<8)){e=1;break c}e=w[d+185|0]==64}I=q+I|0;i=h+i|0;f=f+1|0;if((f|0)!=32){continue}break}d:{e:{f:{g:{h:{i:{Q=v[n+4>>2];if(Q>>>0>=I>>>0){xV(b,d+160|0);Vb(b,4);q=d+160|1;k=w[q|0];f=128;h=a+484360|0;Hr(Qb(h),d+160|2,128);J=g;g=!k&e;l=g?J:0;e=w[d+160|0];j:{if(e>>>0>128){break j}f=e;if(e){break j}e=128;while(1){k=e-1|0;if(!x[sc(Qb(h),k)>>1]){f=1;e=k;if(e>>>0>1){continue}break j}break}f=e}F=(j|0)!=0;l=wV(b,Qb(h),f&65535,i,C,l);if(!(!g|x[a+480188>>1]!=8)){v[n>>2]=24412;F=1}k:{if(!s){break k}e=Qb(h);ca=d,da=Rb(e),v[ca+144>>2]=da;ca=d,da=Ub(e),v[ca+128>>2]=da;if(!Fb(d+144|0,d+128|0)){break k}while(1){e=v[d+144>>2];u[e>>1]=x[e>>1]>>>1;sf(d+144|0);if(Fb(d+144|0,d+128|0)){continue}break}}ff(Qb(h),w[q|0]);U=f-1&65535;if(!(w[q|0]!=120|x[C>>1]!=4?U>>>0>=w[q|0]:0)){ff(Qb(h),0)}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;g=0;e=ac(256/x[a+480188>>1]|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=e;jh(a,0);t[d+159|0]=0;D=1;V=1;if(!o){l:{if(!l){i=p;break l}y=d+144|5;i=p;o=0;k=0;while(1){e=0;f=0;while(1){h=Pi(d+144|0);gv(b,h);r=uv(h);m:{n:{o:{h=w[d+147|0];if((h-7&255)>>>0<3){i=0;break o}i=r?i:0;p:{q:{r:{switch(h-13|0){case 2:if(w[d+149|0]>31){break q}break m;case 1:break p;case 0:break r;default:break o}}f=f+1|0;if((f&65535)>>>0<2){break m}}i=0;break m}j=w[d+149|0];i=j>>>0>1?0:i;break n}if((h|0)!=8){if((h|0)!=14){break m}j=w[d+149|0];break n}ca=d,da=w[Ff(d+159|0,y)|0],t[ca+159|0]=da;h=t[d+149|0];if((h|0)>-1){k=1;break m}o=(h|0)!=-92&(h&255)>>>0>143|o;break m}if((j&240)!=128){break m}t[d+128|0]=j<<4;ca=d,da=w[Ff(d+159|0,d+128|0)|0],t[ca+159|0]=da}D=r&D;e=e+1|0;if((e|0)!=256){continue}break}g=g+1|0;if(l>>>0>(g&65535)>>>0){continue}break}g=0;if((k^-1|o)&1){break l}g=w[d+159|0]>47}V=i&1}Rc(b,1084);i=4;i=s?i:x[C>>1];y=a+484344|0;E=l+s&65535;rg(y,E);l=a+1074308|0;s:{if(!E){E=0;break s}$=c&1;h=i;aa=g^1;t:{u:{while(1){f=!$;v:{if(s){e=(z&65534)>>>1|0;k=z&1;if(!k){if(!Sg(y,e,64)){break s}}k=Wc(Yb(y,e),0,k<<2);break v}if(!Sg(y,z&65535,64)){break s}k=Wc(Yb(y,z),0,0)}if(f|!k){break s}e=x[a+480188>>1];t[d+128|0]=0;r=Ev(d+144|0,e,d+128|0);e=x[a+480188>>1];v[23048]=0;t[d+64|0]=0;G=W(816,d+128|0,e|0,d- -64|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){o=0;while(1){J=m;w:{if(h){j=0;X=0;f=0;while(1){v[23048]=0;g=B(j,6)+k|0;S(817,b|0,g|0);e=v[23048];v[23048]=0;if((e|0)==1){break u}e=w[g+3|0];x:{y:{z:{if(!e){if(w[g+5|0]){break z}break y}if(!M){break z}A:{switch(e-14|0){case 0:t[g+3|0]=0;t[g+5|0]=0;break z;case 1:break A;default:break z}}if(w[g+5|0]<32){break z}t[g+5|0]=31}Mf(g);e=1;B:{C:{D:{m=w[g+3|0];switch(m-14|0){case 2:break x;case 0:break C;case 3:break D;default:break B}}Y=w[g+5|0]<100|Y;X=1;break y}if(!V){break y}t[g+5|0]=0;break y}if(!(aa|(m|0)!=9)){e=w[g+5|0];if((e|0)==164){t[g+3|0]=20;t[g+5|0]=145;break y}ca=g,da=Ki(e<<1),t[ca+5|0]=da;break y}if((m|0)!=19){break y}e=w[g+5|0];if(e>>>0>15){break y}m=e&1;e=!m;ba=!m;m=Z&1;Z=(m|0)==(e|0)?Z:ba;K=((e|0)!=(m|0))+K|0}e=f}E:{if(!w[g|0]){if(!w[g+1|0]|s){break E}if(!w[oc(r,j)|0]){break E}if(w[oc(r,j)|0]==w[g+1|0]){break E}m=oc(G,j);f=w[m|0]+1|0;t[m|0]=f;if((f&255)>>>0<4){break E}v[23048]=0;W(458,l|0,85,1)|0;f=v[23048];v[23048]=0;if((f|0)==1){break u}break E}ca=oc(G,j),da=0,t[ca|0]=da}f=w[g+1|0];if(f){ca=oc(r,j),da=f,t[ca|0]=da}f=e;j=j+1|0;if((h|0)!=(j|0)){continue}break}e=e&X;break w}e=0}m=J|e;k=B(x[C>>1],6)+k|0;o=o+1|0;if((o|0)!=64){continue}break}gc(G);gc(r);z=z+1|0;if((E|0)==(z|0)){break s}continue}break}j=P()|0;O()|0;break t}j=P()|0;O()|0;gc(G)}gc(r);break d}F:{G:{H:{if((D^-1|N)&1){break H}I:{if(ke(d+316|0,24397)){break I}if(ke(d+316|0,24424)){break I}if(!ke(d+316|0,24429)){break H}}v[a+480208>>2]=v[a+480208>>2]|2162688;Kb(l,85,1);Kb(l,91,1);Kb(l,92,1);J:{if(w[d+159|0]>47){break J}Kb(l,84,1);if(w[q|0]==127){break J}Kb(l,83,1)}if(!((K|0)>6|F)){break G}break F}if(!D){if(p^1|w[q|0]!=127|U>>>0>w[q|0]+1>>>0){break F}v[n>>2]=24434;break F}if((K|0)>6|F){break F}}v[a+480208>>2]=v[a+480208>>2]|8388608}if((p|F)==1){Kb(l,89,1)}if(H){Kb(l,84,1)}if(c&2){Rc(b,(B(i,E)<<8)+1084|0);i=p&D;f=1;while(1){k=B(f,104)+a|0;c=k+484380|0;if(v[c>>2]){g=d+144|0;if(H){e=2}else{e=vV(b,24448)?11:0}e=Sc(g,8,1,0,e);s=v[b+8>>2]+sv(e,v[c>>2])|0;if(i){ca=c,da=v[Jc(c,k+484388|0)>>2],v[ca>>2]=da}ug(e,c,b);Rc(b,s)}f=f+1|0;if((f|0)!=32){continue}break}}K:{if((p&Y^-1|m)&1){break K}b=uV(d+104|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;qu(d+144|0,a,0,d+24|0);_=A[v[d+144>>2]>>3];Rm(d+144|0);if(_<600){break K}Kb(l,5,1);b=tV(d+80|0,_);c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;qu(d+144|0,a,0,d);b=w[v[d+144>>2]+26|0];Rm(d+144|0);if(b){Cg(l,5);break K}v[n>>2]=24454}b=d+316|0;i=b;c=b;e=dc(d+316|0);f=e;if((b|0)!=(e|0)){while(1){p=w[i|0];t[c|0]=p>>>0>32?p:32;c=c+1|0;i=i+1|0;if((f|0)!=(i|0)){continue}break}}of(d+128|0,24474);v[23048]=0;b=W(818,d+48|0,b|0,e|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break i}v[23048]=0;T(13,d- -64|0,1,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break h}v[23048]=0;T(237,d+144|0,d+128|0,d- -64|0);c=v[23048];v[23048]=0;if((c|0)==1){break g}Eb(a+1300344|0,d+144|0);vb(d+144|0);vb(d- -64|0);vb(b);Hb(d+128|0);b=Tb(d+144|0,24494);Eb(a+1300356|0,b);vb(b);b=v[n>>2];if(b){Zc(a+1300368|0,b)}v[a+1300404>>2]=2}f=I>>>0<=Q>>>0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}j=P()|0;O()|0;vb(d- -64|0)}vb(b)}Hb(d+128|0)}R(j|0);L()}gb=d+320|0;return f|0}function ou(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-32|0;gb=h;v[h+28>>2]=c;a:{if((c|0)<1){break a}l=v[b+104>>2];i=v[b+656>>2];if(!(!i|v[a+480180>>2]!=16777216)){n=v[i+44>>2]!=0}b:{if(!(!i|(c|0)>128)){k=x[ud(i+236|0,c-1|0)>>1];c:{if((k-1&65535)>>>0<=3998){l=(B(k,104)+a|0)+484380|0;break c}Db(h+16|0,a+1074308|0,43);if(!Cb(h+16|0)){break c}if(!kk(b)){break a}}k=w[lc(i+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=k;break b}k=c}if((k|0)>=121){d:{if(!(v[a+480180>>2]&16777248?(k|0)!=255:0)){wo(a,b);if(d){break d}Db(h+16|0,a+1074308|0,100);if(!Cb(h+16|0)|!(w[a+480208|0]&4)|!w[b+791|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}Db(h+16|0,a+1074308|0,50);if(Cb(h+16|0)){break g}}v[b+688>>2]=0}Db(h+16|0,a+1074308|0,50);if(Cb(h+16|0)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}Db(h+16|0,a+1074308|0,20);if(!Cb(h+16|0)){break a}t[b+799|0]=0;t[b+804|0]=0;break a}h:{i:{j:{if(n){if(d){j=w[b+799|0];if(j){break j}}v[b+708>>2]=0}if(d){break i}if(!(!l|!(v[a+480180>>2]&1048588))){u[b+772>>1]=t[l+36|0];u[b+774>>1]=t[l+37|0]}if(l){Db(h+16|0,a+1074308|0,24);k=0;m=1;if(!Cb(h+16|0)){break h}v[b+704>>2]=v[l+24>>2];break h}k=0;break h}m=v[i+44>>2];u[h>>1]=j;u[h+14>>1]=k;v[h+16>>2]=0;k=(v[h+16>>2]+B(u[m+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+856>>2]|0;v[b+708>>2]=k;v[b+856>>2]=0-k}m=(l|0)!=0;k=1;if(zi(b)){break h}k=a+1074308|0;Db(h+16|0,k,54);if(Cb(h+16|0)){v[b+700>>2]=0;break a}Db(h+16|0,k,39);k=(Cb(h+16|0)^-1)&d}k:{if(ep(a)){v[h+28>>2]=v[h+28>>2]+u[b+772>>1];Vd(h+28|0,12,131);break k}eV(h+28|0)}j=a+1074308|0;Db(h+16|0,j,34);d=b;c=(c|0)<120?c:120;l:{if(Cb(h+16|0)){break l}c=v[h+28>>2]}t[d+799|0]=c;t[b+853|0]=w[b+853|0]|8;if(!(v[a+480180>>2]&16777250?0:k)){t[b+805|0]=0}d=Vg(a,v[h+28>>2],u[b+774>>1],v[b+704>>2]);t[b+833|0]=0;Db(h+16|0,j,48);if(Cb(h+16|0)){NP(a,b,i,l)}m:{if(e^1|k){break m}u[b+778>>1]=0;u[b+780>>1]=0;u[b+782>>1]=0;u[b+784>>1]=0;if(!i){break m}Db(h+16|0,j,29);if(Cb(h+16|0)){t[b+800|0]=w[i+16|0]}if(!(w[i+60|0]&8)){rj(b+724|0)}if(!(w[i+80|0]&8)){rj(b+732|0)}if(!(w[i+100|0]&8)){rj(b+740|0)}if(w[i+20|0]){c=mu(vo(a));o=w[i+20|0];Db(h+16|0,j,28);p=((B(c,o)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(Cb(h+16|0)){o=v[b+752>>2];break n}o=(v[b+688>>2]+1|0)/2|0}u[c+778>>1]=(B(o,p)|0)/199}o:{if(!w[i+19|0]){break o}q=b,r=(B(mu(vo(a)),w[i+19|0])<<16>>16)/32|0,u[q+780>>1]=r;Db(h+16|0,j,28);if(Cb(h+16|0)|x[b+786>>1]){break o}u[b+786>>1]=x[b+692>>1]+1}c=w[i+23|0];if(c){o=mu(vo(a));p=w[b+839|0];t[b+798|0]=p+1;u[b+782>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[i+24|0];if(!c){break m}o=mu(vo(a));p=w[b+840|0];t[b+797|0]=p+1;u[b+784>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!m){break a}m=0;p:{q:{if(!d){break q}r:{s:{t:{if(k){u:{if(!v[b+700>>2]){v[b+700>>2]=d;if(!n){break u}break t}if(n){break t}}v[b+708>>2]=d;break t}v[b+700>>2]=d;if(n){break s}Db(h+16|0,j,69);if(Cb(h+16|0)){break s}Db(h,j,46);if(Cb(h)|v[a+480180>>2]==1){break s}v[b+708>>2]=d;break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=l;c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v:{w:{if(!(v[a+480208>>2]&2097152)){Db(h+16|0,j,96);if(!Cb(h+16|0)){break w}}if(w[b+791|0]){break w}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Gb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break v}v[b+660>>2]=0}c=x[l+34>>1];d=c&1023;n=d|v[b+88>>2]&-525056;v[b+88>>2]=n;x:{if(c&8){v[b+80>>2]=v[l+12>>2];c=v[l+16>>2];v[b+88>>2]=(d&16?n|4:n&-524295)|2;v[b+84>>2]=c;if(c>>>0>=y[b+76>>2]){break x}v[b+76>>2]=c;break x}if(!(d&2)){break x}v[b+80>>2]=v[l+4>>2];c=v[l+8>>2];v[b+84>>2]=c;if(c>>>0>=y[b+76>>2]){break x}v[b+76>>2]=c}Db(h+16|0,j,83);if(!(!Cb(h+16|0)|v[b+80>>2])){c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c}c=v[b+88>>2];if(c&128){v[b+88>>2]=c|128;v[b+4>>2]=v[b+76>>2]-1}y:{if(w[b+824|0]>3){break y}Db(h+16|0,j,21);if(!(Cb(h+16|0)|!(v[a+480180>>2]&16777248)|v[a+480208>>2]&4)){t[b+821|0]=16;break y}if(v[a+480180>>2]==16){t[b+821|0]=32;break y}if(v[a+480180>>2]&67633152){break y}t[b+821|0]=0}Db(h+16|0,j,21);if(Cb(h+16|0)|w[b+827|0]>3){break r}t[b+822|0]=0}d=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){c=d;d=v[b+80>>2];v[b>>2]=c;v[b+4>>2]=d}if(!k){break q}m=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}if(!(w[a+480208|0]&8)|!w[b+791|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){zm(b);Db(h+16|0,j,21);if(!Cb(h+16|0)){t[b+820|0]=0;v[b+760>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(w[b+791|0]|(!m|!(w[a+480208|0]&8)))){m=1;break p}if(w[b+791|0]?0:v[a+480180>>2]&1048580){break p}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}Db(h+16|0,j,40);z:{A:{B:{C:{if(Cb(h+16|0)){if(m){if(w[b+791|0]?w[a+480208|0]&8:0){break B}v[b+88>>2]=v[b+88>>2]&-4194305;break A}c=v[b+88>>2]&-4196353;break C}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;l=1;if(m){break z}}u[b+844>>1]=65535;v[b+88>>2]=c&-6326273|2097152;Db(h+16|0,j,23);D:{if(Cb(h+16|0)){break D}Db(h,j,22);if(Cb(h)){break D}Db(h+16|0,j,52);if(Cb(h+16|0)){break D}Db(h,j,71);if(Cb(h)){break D}t[b+841|0]=0;t[b+810|0]=0}if(e){t[b+820|0]=0;v[b+760>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;E:{if(i){F:{G:{if(!OE(i)){if(lw(i)){break G}c=!(c>>>13|0);if(c){break F}break E}q=b,r=PE(i),t[q+840|0]=r;if(!lw(i)){break F}}q=b,r=QE(i),t[q+839|0]=r}c=1;d=w[i+25|0];if((d|0)==255){break E}t[b+847|0]=d;break E}u[b+778>>1]=0;u[b+780>>1]=0;u[b+782>>1]=0;u[b+784>>1]=0;c=!c}H:{if(w[b+839|0]>=127){Db(h+16|0,j,36);if(!Cb(h+16|0)){break H}}if(!c){break H}if((Rq(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break H}c=a+1300300|0;if(!Fd(c)|(g|0)==65535){break H}_q(v[c>>2],g,w[b+839|0]>>>1|0,1)}l=0;if(!(w[b+89|0]&2)){break z}c=a+1300300|0;if(!Fd(c)|(g|0)==65535){break z}Db(h+16|0,j,111);if(Cb(h+16|0)){nk(v[c>>2],g);break z}Db(h+16|0,j,110);if(!Cb(h+16|0)){break z}JA(v[c>>2],g,0,1,0);break z}v[b+88>>2]=v[b+88>>2]&-4196353}l=1}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}I:{J:{if(w[a+24618|0]&16?c&1024:0){break J}a=v[b+104>>2];if(f?0:!(!a|!(w[a+35|0]&4))){break J}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break I}}if(f){break I}v[b+700>>2]=0}if(l){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}gb=h+32|0}function x2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2402;p=ge(l+136|0,l+144|0,l+104|0);b=v[p>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;u=Jb(l+104|0);m=Jb(l+88|0);n=Jb(l+72|0);o=Jb(l+56|0);r=Jb(l+40|0);v[23048]=0;na(2405,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,m|0,n|0,o|0,l+36|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;q=v[l+36>>2];k=0;e=0;f:{while(1){v[23048]=0;c=Q(2352,a|0,l+552|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}g:{if(!c){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break g}v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if(fh(h,8192,c)){v[23048]=0;S(2406,l+24|0,a|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=t[l+24|0];v[23048]=0;S(110,r|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break h}}if((e|0)==3){break g}}while(1){v[23048]=0;c=Q(2352,a|0,l+552|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(!c){break h}v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(!fh(h,8192,c)){break h}v[23048]=0;S(2406,l+24|0,a|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=t[l+24|0];v[23048]=0;S(110,r|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Bb(n)|0)==(0-Bb(o)|0)){break h}q:{if(Bb(n)){if(Bb(o)){break q}}if(Bb(n)){v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if(w[pc(n,0)|0]!=(c&255)){break k}v[23048]=0;U(2356,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}k=Bb(n)>>>0>1?n:k;break h}v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if(w[pc(o,0)|0]!=(c&255)){break h}v[23048]=0;U(2356,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}t[g|0]=1;k=Bb(o)>>>0>1?o:k;break h}v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if(w[pc(n,0)|0]==(c&255)){v[23048]=0;U(2356,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}k=Bb(n)>>>0>1?n:k;break h}v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if(w[pc(o,0)|0]==(c&255)){v[23048]=0;U(2356,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}t[g|0]=1;k=Bb(o)>>>0>1?o:k;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(e>>>0<2|k|((e|0)==2&w[l+123|0]!=0|z))){k=0;break h}A=l,B=Ld(m),v[A+16>>2]=B;c=Sd(l+24|0,l+16|0);r:{if(!e|w[(e+l|0)+119|0]>1){break r}A=l,B=hf(m),v[A+16>>2]=B;s:{if(!Fb(c,l+16|0)){break s}while(1){if(!fh(h,8192,t[v[c>>2]])){break s}Se(c);A=l,B=hf(m),v[A+16>>2]=B;if(Fb(c,l+16|0)){continue}break}}A=l,B=Ld(m),v[A+16>>2]=B;c=Hk(c,l+16|0);if(Bb(r)>>>0>=c>>>0){A=l,B=hf(r),v[A+16>>2]=B;d=Ne(l+16|0,0-c|0);s=hf(r);x=Ld(m);c=gb-32|0;gb=c;v[c+16>>2]=s;v[c+24>>2]=d;v[c+8>>2]=x;d=1;t:{if(!Fb(c+24|0,c+16|0)){break t}while(1){d=w[v[c+24>>2]]==w[v[c+8>>2]];if(!d){break t}Se(c+24|0);Se(c+8|0);if(Fb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;if(d){break r}}A=l,B=Ld(m),v[A+8>>2]=B;Sd(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];A=l,B=hf(m),v[A+8>>2]=B;u:{v:{w:{if(!Fb(l+16|0,l+8|0)){break w}while(1){v[23048]=0;c=Q(2352,a|0,l+552|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break v}if(!c){break w}v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break v}if(w[v[l+16>>2]]!=(c&255)){break w}v[23048]=0;U(2356,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break u}Se(l+16|0);A=l,B=hf(m),v[A+8>>2]=B;if(Fb(l+16|0,l+8|0)){continue}break}}if(!y){break h}A=l,B=hf(m),v[A+8>>2]=B;if(!Fb(l+16|0,l+8|0)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+36>>2]=q;break a}a=P()|0;O()|0;v[l+36>>2]=q;break a}c=0;x=w[l+118|0];d=b;x:{while(1){y:{v[23048]=0;b=Q(2352,a|0,l+552|0)|0;s=v[23048];v[23048]=0;if((s|0)==1){break y}if(!b){break x}v[23048]=0;s=U(2354,a|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}z:{if(fh(h,2048,s)){b=v[j>>2];if((b|0)==v[l+548>>2]){v[23048]=0;T(2407,i|0,j|0,l+548|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}b=v[j>>2]}v[j>>2]=b+1;t[b|0]=s;c=c+1|0;break z}if(!c|!Bb(u)|(x|0)!=(s&255)){break x}if(v[l+128>>2]==(d|0)){v[23048]=0;T(2408,p|0,l+132|0,l+128|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;d=b;c=0}v[23048]=0;U(2356,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!c|v[p>>2]==(d|0)){break j}if(v[l+128>>2]==(d|0)){v[23048]=0;T(2408,p|0,l+132|0,l+128|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;break i}t[g|0]=1;break h}b=d}A:{if((q|0)<1){break A}v[23048]=0;c=Q(2353,a|0,l+552|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}B:{if(!c){v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}if(w[l+119|0]==(c&255)){break B}}v[f>>2]=v[f>>2]|4;a=0;break f}v[23048]=0;U(2356,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break d}while(1){if((q|0)<1){q=0;break A}v[23048]=0;c=Q(2353,a|0,l+552|0)|0;d=v[23048];v[23048]=0;C:{if((d|0)==1){break C}D:{if(!c){v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break C}if(fh(h,2048,c)){break D}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[23048]=0;T(2407,i|0,j|0,l+548|0);c=v[23048];v[23048]=0;if((c|0)==1){break C}}v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break C}d=v[j>>2];v[j>>2]=d+1;t[d|0]=c;v[23048]=0;U(2356,a|0)|0;c=v[23048];v[23048]=0;q=q-1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}e=e+1|0;if((e|0)!=4){continue}}break}v[l+36>>2]=q;E:{if(!k){break E}e=1;while(1){if(Bb(k)>>>0<=e>>>0){break E}v[23048]=0;c=Q(2353,a|0,l+552|0)|0;d=v[23048];v[23048]=0;F:{if((d|0)==1){break F}G:{if(!c){v[23048]=0;c=U(2354,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break F}if(w[pc(k,e)|0]==(c&255)){break G}}v[f>>2]=v[f>>2]|4;a=0;break f}v[23048]=0;U(2356,a|0)|0;c=v[23048];v[23048]=0;e=e+1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[p>>2]==(b|0)){break f}a=0;v[l+24>>2]=0;kf(u,v[p>>2],b,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}vb(r);vb(o);vb(n);vb(m);vb(u);Hc(p);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vb(r);vb(o);vb(n);vb(m);vb(u);Hc(p);R(a|0);L()}function goa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=gb-1328|0;gb=d;yc(b);f=gb-32|0;gb=f;j=d+752|0;fX(f+24|0,j);k=xb(f+24|0);i=v[f+28>>2];l=v[f+24>>2];v[f+8>>2]=l;v[f+12>>2]=i;v[f>>2]=l;v[f+4>>2]=i;i=b;fc(f+16|0,i,f);l=xb(f+16|0);if((l|0)==(k|0)){Vb(i,xb(f+24|0))}gb=f+32|0;i=(k|0)==(l|0);if(!i){eX(j)}a:{b:{c:{d:{if(!i){break d}if(!iX(d+752|0)){break d}if(!Nb(b,Xc(hX(d+752|0),jb))){break d}if(!c){e=1;break d}o=Ar(d+744|0);q=1;e:{while(1){i=(e<<5)+a|0;f=i+480280|0;We(f);k=(d+752|0)+(e<<4)|0;u[i+480284>>1]=((w[k+78|0]<<8&65280)>>>0)/255;zk(d+480|0,1,k- -64|0);Fc(d+96|0,d+480|0);v[23048]=0;Q(449,i+480289|0,d+96|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}vb(d+96|0);f:{g:{switch(w[k+79|0]){case 0:g=e+1|0;break f;case 1:v[f>>2]=1024;g=h+1|0;break f;case 2:break g;default:break e}}v[f>>2]=1024;Wk(d+96|0,o,e);Ef(d+96|0,1)}q=e>>>0<31;h=h+1|0;e=e+1|0;if((e|0)!=32){continue}break}Ed(a,33554432);u[a+480188>>1]=g&255;e=Tb(d+96|0,17998);Eb(a+1300344|0,e);vb(e);e=Tb(d+96|0,18012);Eb(a+1300356|0,e);vb(e);v[a+1300404>>2]=5;h:{if(w[d+831|0]){break h}h=1;while(1){if(w[((h<<4)+d|0)+831|0]!=1){break h}e=1;h=h+1|0;if((h|0)!=16){continue}break}while(1){h=((e<<5)+a|0)+480280|0;v[h>>2]=v[h>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}df(d+480|0,1,d+752|0);Fc(d+96|0,d+480|0);Eb(a+1300308|0,d+96|0);vb(d+96|0);v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+790|0]|w[d+791|0]<<8)<<4&16;v[a+480196>>2]=w[d+800|0];v[a+480204>>2]=B(w[d+801|0],1e4);A=a,C=Gd(w[d+802|0],0,64)<<2,v[A+480200>>2]=C;A=a,C=Gd(w[d+803|0],4,127),v[A+480228>>2]=C;e=w[d+788|0]|w[d+789|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=e;dw(b,d+480|0);Sr(Qb(a+484360|0),d+480|0,w[d+784|0]|w[d+785|0]<<8,65535,255);r=c&1;if(r){rg(a+484344|0,w[d+786|0]|w[d+787|0]<<8)}if(w[d+786|0]|w[d+787|0]<<8){s=a+484344|0;while(1){e=Fg(b);n=Fg(b);td(d+96|0,b,e-4|0);i:{if(!r){break i}v[23048]=0;e=W(386,s|0,m&65535,n|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){j:{if(!e){break i}l=0;k=Pi(d+8|0);if(!n){break i}while(1){k:{v[23048]=0;i=U(373,d+96|0)|0;e=v[23048];v[23048]=0;l:{m:{if((e|0)!=1){if(i){break m}l=l+1|0;break l}break j}e=k;p=i&31;if(p>>>0<x[a+480188>>1]){e=Yb(s,m);v[23048]=0;e=Wc(e,l,p);h=v[23048];v[23048]=0;if((h|0)==1){break j}}n:{if(!(i&32)){break n}v[23048]=0;S(452,d+32|0,d+96|0);g=v[23048];v[23048]=0;h=e;o:{p:{if((g|0)!=1){f=rd(d+32|0);g=w[d+32|0];t[e|0]=g;t[e+1|0]=w[f|0];if((g|0)!=160){break p}g=255;break o}break j}if((g|0)!=255){t[e|0]=(B(g>>>4|0,12)+(g&15)|0)+13;v[23048]=0;f=KC(e);g=v[23048];v[23048]=0;if((g|0)!=1){g=0;if(!f){break o}break n}break j}g=0}t[h|0]=g}h=i&192;q:{if(!h){break q}if((h|0)==192){v[23048]=0;S(571,d+32|0,d+96|0);h=v[23048];v[23048]=0;r:{s:{t:{if((h|0)!=1){f=rd(d+32|0);h=Df(d+32|0);g=Ri(d+32|0);j=d+32|0;z=w[j|0];if((z|0)!=12){break t}v[23048]=0;t[d|0]=64;i=$b(f,d);f=v[23048];v[23048]=0;if((f|0)==1){break j}t[e+4|0]=w[i|0];i=1;break s}break j}i=w[h|0];u:{if((i|0)==12){v[23048]=0;t[d|0]=64;h=$b(g,d);i=v[23048];v[23048]=0;if((i|0)!=1){t[e+4|0]=w[h|0];i=1;break u}break j}if((z|0)==10){t[e+4|0]=(w[f|0]<<6>>>0)/255;i=2;break s}if((i|0)!=10){break r}t[e+4|0]=(w[g|0]<<6>>>0)/255;i=2}h=j;g=f}t[e+2|0]=i;i=w[h|0]}t[e+3|0]=i;t[e+5|0]=w[g|0];break q}v[23048]=0;S(452,d+32|0,d+96|0);h=v[23048];v[23048]=0;if((h|0)==1){break j}h=rd(d+32|0);t[e+3|0]=w[d+32|0];t[e+5|0]=w[h|0]}if(w[e+3|0]){v[23048]=0;_(594,e|0);h=v[23048];v[23048]=0;if((h|0)==1){break j}}Wk(d+32|0,o,p);if(!Cb(d+32|0)){break l}v[23048]=0;h=gX(e);i=v[23048];v[23048]=0;if((i|0)==1){break k}if(!h){break l}t[e+3|0]=0}if(l>>>0<n>>>0){continue}break i}break}}}e=P()|0;O()|0;yb(d+96|0);break b}yb(d+96|0);m=m+1|0;if(m>>>0<(w[d+786|0]|w[d+787|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break e}n=c&2;i=1;h=1;while(1){m=i&65535;g=MO(a,m,0);e=gb-32|0;gb=e;k=d+96|0;cc(e+24|0,k,384);f=xb(e+24|0);c=v[e+28>>2];j=v[e+24>>2];v[e+8>>2]=j;v[e+12>>2]=c;v[e>>2]=j;v[e+4>>2]=c;c=b;fc(e+16|0,c,e);j=xb(e+16|0);if((j|0)==(f|0)){Vb(c,xb(e+24|0))}gb=e+32|0;c=(f|0)==(j|0);if(!c){Pb(k,0,384)}if(!(!c|!g)){k=h&65535;c=gb-32|0;gb=c;f=d+96|0;df(c,1,f);Fc(c+16|0,c);v[23048]=0;Q(354,g+492|0,c+16|0)|0;e=v[23048];v[23048]=0;v:{if((e|0)!=1){vb(c+16|0);w:{if(!(w[f+378|0]|w[f+379|0]<<8)){break w}v[c+16>>2]=120;v[c>>2]=116;if(!v[Gb(c+16|0,c)>>2]){break w}j=g+236|0;e=0;while(1){l=w[(e+f|0)+32|0];A=ud(j,e+12|0),C=k+l|0,u[A>>1]=C;v[c+16>>2]=120;v[c>>2]=116;e=e+1|0;if(e>>>0<y[Gb(c+16|0,c)>>2]){continue}break}}e=w[f+376|0]|w[f+377|0]<<8;t[g+33|0]=1;v[g>>2]=e;JC(f,g+48|0,0);JC(f,g+68|0,1);JC(f,g+88|0,2);e=w[g+100|0];if(e&1){t[g+100|0]=e|16}if(!(v[g>>2]|t[g+60|0]&1)){v[g>>2]=32767}gb=c+32|0;break v}break a}e=0;x:{if(!(w[d+474|0]|w[d+475|0]<<8)){break x}while(1){y:{PX(b,d+32|0);c=e+h|0;j=c&65535;z:{if((w[d+92|0]|w[d+93|0]<<8|(w[d+94|0]<<16|w[d+95|0]<<24))!=808538953|j>>>0>3999){break z}u[a+480190>>1]=c;c=gb-32|0;gb=c;l=B(j,104)+a|0;k=l+484380|0;f=k;wd(f,0);g=d+32|0;Pj(c,1,g);Fc(c+16|0,c);v[23048]=0;Q(355,f+43|0,c+16|0)|0;o=v[23048];v[23048]=0;A:{if((o|0)!=1){vb(c+16|0);v[f>>2]=w[g+16|0]|w[g+17|0]<<8|(w[g+18|0]<<16|w[g+19|0]<<24);v[f+4>>2]=w[g+20|0]|w[g+21|0]<<8|(w[g+22|0]<<16|w[g+23|0]<<24);v[f+8>>2]=w[g+24|0]|w[g+25|0]<<8|(w[g+26|0]<<16|w[g+27|0]<<24);v[f+24>>2]=w[g+28|0]|w[g+29|0]<<8|(w[g+30|0]<<16|w[g+31|0]<<24);u[f+30>>1]=w[g+32|0]<<2;u[f+28>>1]=w[g+33|0];if(t[g+48|0]&1){u[f+34>>1]=x[f+34>>1]|2}if(w[g+48|0]&2){u[f+34>>1]=x[f+34>>1]|4}if(w[g+48|0]&4){u[f+34>>1]=x[f+34>>1]|1;v[f>>2]=v[f>>2]>>>1;v[f+4>>2]=v[f+4>>2]>>>1;v[f+8>>2]=v[f+8>>2]>>>1}if(w[g+48|0]&8){u[f+34>>1]=x[f+34>>1]|32}gb=c+32|0;break A}break a}ME(d+8|0,l+484423|0);v[23048]=0;Q(354,((j<<5)+a|0)+946300|0,d+8|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break y}vb(d+8|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))){break z}td(d+8|0,b,w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24));B:{if(!n){break B}c=Sc(d,u[l+484414>>1]&1?16:8,1,0,0);v[23048]=0;W(384,c|0,k|0,d+8|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break B}e=P()|0;O()|0;yb(d+8|0);break b}yb(d+8|0)}e=e+1|0;if(e>>>0<(w[d+474|0]|w[d+475|0]<<8)>>>0){continue}break x}break}e=P()|0;O()|0;vb(d+8|0);break b}h=(w[d+474|0]|w[d+475|0]<<8)+h|0}if(m>>>0>=x[a+480192>>1]){break e}i=i+1|0;continue}}e=!q}gb=d+1328|0;return e&1}e=P()|0;O()|0;vb(d+96|0)}R(e|0);L()}a=P()|0;O()|0;vb(c+16|0);R(a|0);L()}function iga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-240|0;gb=e;yc(c);k=Ni(e+216|0,c);v[23048]=0;c=Q(1176,k|0,e+200|0)|0;f=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((f|0)!=1){if(!c|v[e+200>>2]!=1297239878|((w[e+208|0]|w[e+209|0]<<8|(w[e+210|0]<<16|w[e+211|0]<<24))!=1128679745?v[e+208>>2]!=1179011393:0)){break a}v[23048]=0;S(1177,e+184|0,k|0);c=v[23048];v[23048]=0;n:{o:{p:{q:{r:{if((c|0)!=1){v[23048]=0;T(1178,e+160|0,e+184|0,1129270605);c=v[23048];v[23048]=0;if((c|0)==1){break r}v[23048]=0;c=Q(1179,e+160|0,e+136|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break n}if(!c){break b}f=e+136|2;if(!Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break b}if(!Ib(w[e+136|0]|w[e+137|0]<<8)){break b}if(Ib(w[e+136|0]|w[e+137|0]<<8)>>>0>2){break b}c=e+136|6;if(!Ib(w[c|0]|w[c+1|0]<<8)){break b}if(Ib(w[c|0]|w[c+1|0]<<8)>>>0>64){break b}v[e+132>>2]=1162760014;h=1;if((w[e+208|0]|w[e+209|0]<<8|(w[e+210|0]<<16|w[e+211|0]<<24))==1128679745){v[23048]=0;h=Q(834,e+160|0,e+132|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break m}if(!h){break b}h=v[e+132>>2]!=1936684916}v[23048]=0;T(1178,e+112|0,e+184|0,1397968452);i=v[23048];v[23048]=0;if((i|0)==1){break q}v[23048]=0;g=Q(1180,e+112|0,e+104|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break o}i=0;if(!g){break c}g=Wb(w[e+104|0]|w[e+105|0]<<8|(w[e+106|0]<<16|w[e+107|0]<<24));v[23048]=0;g=Q(250,e+112|0,g|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break o}if(g){break p}break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}i=((Ib(w[c|0]|w[c+1|0]<<8)-1|0)/8|0)-1|0;g=i<<3;c=g&31;h=Sc(e+96|0,(i>>>0<7?(g&63)>>>0>=32?4196360>>>c|0:((1<<c)-1&4196360)<<32-c|136321040>>>c:8)&255,(Ib(w[e+136|0]|w[e+137|0]<<8)|0)==2?2:1,h,0);c=v[e+132>>2];s:{if((c|0)<=1463897152){if((c|0)!=875981926?!((c|0)==842222662|(c|0)==842230886):0){break s}tf(h,3);break s}t:{u:{if((c|0)<=2002873440){if((c|0)==1463897153){break t}if((c|0)==1463897173){break u}break s}if((c|0)==2002873441){break t}if((c|0)!=2002873461){break s}}tf(h,17);Li(h,16);break s}tf(h,18);Li(h,16)}if(d){dR(h)}c=Wb(w[e+104|0]|w[e+105|0]<<8|(w[e+106|0]<<16|w[e+107|0]<<24));v[23048]=0;Q(370,e+112|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break h}v[23048]=0;Q(1167,a|0,b|0)|0;c=v[23048];v[23048]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{if((c|0)==1){break D}v[23048]=0;i=(B(b,104)+a|0)+484380|0;S(372,i|0,0);c=v[23048];v[23048]=0;if((c|0)==1){break D}m=i,n=Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),v[m>>2]=n;d=e+136|0;c=w[d+13|0]|(w[d+11|0]<<16|w[d+10|0]<<24|w[d+12|0]<<8);g=(B(b,104)+a|0)+484404|0;f=30-w[d+9|0]|0;E:{if(f&255){while(1){d=c;c=c>>>1|0;f=f-1|0;if(f&255){continue}break}d=d&1;break E}d=0}v[g>>2]=c+d;v[23048]=0;W(384,h|0,i|0,e+112|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break D}v[23048]=0;T(1178,e+72|0,e+184|0,1296126539);c=v[23048];v[23048]=0;if((c|0)==1){break C}v[23048]=0;c=U(328,e+72|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break B}if(!c){break v}v[23048]=0;T(1178,e+24|0,e+184|0,1229869908);c=v[23048];v[23048]=0;if((c|0)==1){break A}v[23048]=0;c=Q(1181,e+24|0,e+48|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break z}yb(e+24|0);if(!c){break v}v[23048]=0;c=U(465,e+72|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break y}d=dd(e+24|0);v[23048]=0;S(1182,d|0,c|0);f=v[23048];v[23048]=0;if((f|0)!=1){F:{if(!c){break F}h=e|6;f=0;while(1){v[23048]=0;g=Q(1183,e+72|0,e|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break x}if(!g){break F}v[23048]=0;S(1184,d|0,e|0);g=v[23048];v[23048]=0;if((g|0)==1){break x}g=w[h|0];j=w[h|0];v[23048]=0;Q(370,e+72|0,g+((j^-1)&1)|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break x}f=f+1|0;if((c|0)!=(f|0)){continue}break}}if(Ib(w[e+56|0]|w[e+57|0]<<8)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|8;f=Ib(w[e+56|0]|w[e+57|0]<<8);u[c>>1]=x[c>>1]&65519|((f|0)==2)<<4}if(Ib(w[e+62|0]|w[e+63|0]<<8)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|2;f=Ib(w[e+62|0]|w[e+63|0]<<8);u[c>>1]=x[c>>1]&65531|((f|0)==2)<<2}m=e,n=Rb(d),v[m>>2]=n;m=e,n=Ub(d),v[m+16>>2]=n;if(Fb(e,e+16|0)){c=B(b,104)+a|0;h=c+484388|0;g=c+484384|0;j=c+484396|0;l=c+484392|0;f=e- -64|0;while(1){c=v[e>>2];if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+58|0]|w[e+59|0]<<8)|0)){m=l,n=Wb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[m>>2]=n}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+60|0]|w[e+61|0]<<8)|0)){m=j,n=Wb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[m>>2]=n}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[f|0]|w[f+1|0]<<8)|0)){m=g,n=Wb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[m>>2]=n}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+66|0]|w[e+67|0]<<8)|0)){m=h,n=Wb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[m>>2]=n}v[e>>2]=v[e>>2]+7;if(Fb(e,e+16|0)){continue}break}}v[23048]=0;pk(i);c=v[23048];v[23048]=0;if((c|0)!=1){break w}}break x}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(e+24|0);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;ZQ(d);break i}ZQ(d)}v[23048]=0;T(1178,e+24|0,e+184|0,1312902469);c=v[23048];v[23048]=0;if((c|0)==1){break l}v[23048]=0;c=U(328,e+24|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break k}G:{H:{I:{J:{if(c){v[23048]=0;c=U(247,e+24|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break k}v[23048]=0;W(518,e+24|0,((b<<5)+a|0)+946300|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break J}break k}v[23048]=0;c=Q(91,e|0,30916)|0;d=v[23048];v[23048]=0;if((d|0)==1){break I}v[23048]=0;Q(354,((b<<5)+a|0)+946300|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break H}vb(c)}b=v[a+480180>>2];v[23048]=0;T(1169,i|0,32,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break G}v[23048]=0;Sh(i,a,0);a=v[23048];v[23048]=0;if((a|0)==1){break k}yb(e+24|0);yb(e+72|0);i=1;break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break g}a=P()|0;O()|0;break f}a=P()|0;O()|0;break d}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0}yb(e+24|0)}yb(e+72|0);break g}a=P()|0;O()|0}yb(e+112|0)}yb(e+160|0)}Cd(e+184|0)}yb(k);R(a|0);L()}yb(e+112|0)}yb(e+160|0);Cd(e+184|0)}yb(k);gb=e+240|0;return i|0}function ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-208|0;gb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;fP(a+900380|0);Xz(a+946300|0);Pb(g+48|0,0,160);d=hP(g+48|0);v[23048]=0;e=a+906300|0;T(1319,e|0,e+4e4|0,d|0);e=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{if((e|0)!=1){Iq(d);if(Gp(b)){i=dd(g+48|0);e=0;g:{if(c&16){break g}v[23048]=0;h=(c|0)!=0;e=W(1320,i|0,b|0,h|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}d=4;h:{if(e){break h}v[23048]=0;e=W(1321,i|0,b|0,h|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}d=5;if(e){break h}v[23048]=0;e=W(1322,i|0,b|0,h|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}d=6;if(e){break h}e=0;v[23048]=0;h=W(1323,i|0,b|0,h|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}d=3;if(!h){break g}}if(!c){f=1;break b}if(!cd(i)){tw(b,v[i>>2]+12|0)}e=d}if(c&32){break b}d=32400;i:{j:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[23048]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){if(f){break i}d=d+12|0;if((d|0)==32904){break j}continue}break}a=V(90472)|0;break e}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break b}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}v[23048]=0;S(1150,a+1300264|0,1);b=v[23048];v[23048]=0;if((b|0)!=1){Rz(i);break d}a=V(90472)|0;break e}Ed(a,0);mk(a+1300264|0,1);v[a+1074300>>2]=19922997;break d}a=P()|0;O()|0;Iq(d);break c}a=V(90472)|0}b=O()|0;Rz(i);if((da(90472)|0)!=(b|0)){break c}Z(a|0)|0;v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)==1){a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break c}V(0)|0;O()|0;Ab()}L()}d=0;while(1){b=(d<<5)+a|0;og(b+480286|0,64);b=b+480284|0;if(x[b>>1]>=257){u[b>>1]=128}No((B(d,880)+a|0)+1074984|0,a,d&65535);d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1300300|0;f=1;while(1){d=B(f&65535,104)+a|0;b=d+484380|0;k:{if(Od(b)){Sh(b,a,0);break k}e=d+484414|0;h=x[e>>1];if(h&16384){break k}v[b>>2]=0;v[b+4>>2]=0;v[b+16>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;u[e>>1]=h&65505}b=d+484412|0;if(x[b>>1]>=65){u[b>>1]=64}l:{if(!(w[d+484415|0]&2)){break l}if(!ok(i)){break l}d=gb-16|0;gb=d;b=a;h=b+1300300|0;if(!Fd(h)){j=d+8|0;e=wf(532);b=v[b+24620>>2];v[23048]=0;b=Q(1330,e|0,b|0)|0;k=v[23048];v[23048]=0;m:{if((k|0)!=1){Ai(j,b);break m}a=P()|0;O()|0;Zb(e);R(a|0);L()}bP(h,Bd(d+8|0));fu(d+8|0)}gb=d+16|0}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;e=0;while(1){b=v[(((d&65535)<<2)+a|0)+900380>>2];if(b){f=v[a+480180>>2];tc(b,65536);tc(b+4|0,64);tc(b+8|0,256);og(b+28|0,16384);Af(b+30|0,128);Af(b+31|0,17);if(w[b+16|0]>=4){t[b+16|0]=0}if(w[b+17|0]>=5){t[b+17|0]=0}if(w[b+18|0]>=3){t[b+18|0]=0}Af(b+19|0,64);Af(b+20|0,100);e=224;i=t[b+26|0];n:{if((i|0)>=-32){e=32;if((i|0)<33){break n}}t[b+26|0]=e}Af(b+23|0,64);Af(b+24|0,64);WA(b+48|0,64);WA(b+68|0,64);WA(b+88|0,(f|0)==4096?255:64);f=b+108|0;e=0;while(1){o:{if(w[lc(f,e)|0]){if(w[lc(f,e)|0]<121){break o}}l=lc(f,e),m=e+1|0,t[l|0]=m}e=e+1|0;if(e>>>0<128){continue}break}if(!xp(w[b+14|0])){t[b+14|0]=5}e=d}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=e;b=a+480204|0;p:{if(y[a+480204>>2]<1e4){v[b>>2]=125e4;break p}tc(b,65535e4)}e=v[a+480196>>2];if(!e){v[a+480196>>2]=6;e=6}f=v[a+480220>>2];b=v[a+480216>>2];if(f>>>0<b>>>0){v[a+480220>>2]=b;f=b}v[a+1074408>>2]=e;v[a+1074412>>2]=v[a+480204>>2];v[a+1074404>>2]=f;v[a+1074400>>2]=b;v[a+1074448>>2]=v[a+480200>>2];iA(a+1074368|0);b=a+1074438|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=65535;v[a+1074384>>2]=-2;b=a+1074376|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074372>>2]=0;b=a+1074416|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074424>>2]=0;b=a+1074388|0;v[b>>2]=0;v[b+4>>2]=0;u[a+480276>>1]=0;Gq(a);b=a+484360|0;l=g,m=Rb(b),v[l+48>>2]=m;l=g,m=Ub(b),v[l+32>>2]=m;if(Fb(g+48|0,g+32|0)){while(1){b=v[g+48>>2];Cf(b,Gi(b));d=x[b+28>>1];if(uc(b)>>>0<=d>>>0){ff(b,0)}sS(g+48|0);if(Fb(g+48|0,g+32|0)){continue}break}}e=dd(g+48|0);q:{r:{s:{t:{u:{v:{w:{x:{y:{if((c&12)==12){d=0;while(1){h=B(d,160)+a|0;i=h+906300|0;b=i;z:{if(!(w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24)|(w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24)))){break z}v[23048]=0;Q(1325,i|0,a|0)|0;b=v[23048];v[23048]=0;A:{if((b|0)!=1){b=v[i>>2];if(!b){break A}c=v[h+906448>>2];f=v[v[b>>2]+56>>2];v[23048]=0;S(f|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){break z}}a=P()|0;O()|0;break q}f=Rb(e);c=Ub(e);b=gb-32|0;gb=b;v[b+16>>2]=c;v[b+24>>2]=f;v[b+8>>2]=i;if(Fb(b+24|0,b+16|0)){while(1){c=v[v[b+24>>2]>>2];f=v[b+8>>2];if((w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))==(w[f+20|0]|w[f+21|0]<<8|(w[f+22|0]<<16|w[f+23|0]<<24))){f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=v[b+8>>2];c=(f|0)==(w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24))}else{c=0}if(!c){Ag(b+24|0);if(Fb(b+24|0,b+16|0)){continue}}break}f=v[b+24>>2]}gb=b+32|0;v[g+32>>2]=f;l=g,m=Ub(e),v[l+16>>2]=m;if(Fb(g+32|0,g+16|0)){break z}v[23048]=0;v[g+32>>2]=h+906316;S(1326,e|0,g+32|0);b=v[23048];v[23048]=0;if((b|0)==1){break r}v[23048]=0;b=Q(2,g+16|0,32904)|0;c=v[23048];v[23048]=0;if((c|0)==1){break y}v[23048]=0;S(1327,g|0,i|0);c=v[23048];v[23048]=0;if((c|0)==1){break x}v[23048]=0;T(3,g+32|0,b|0,g|0);c=v[23048];v[23048]=0;if((c|0)==1){break w}v[23048]=0;T(601,a|0,2,g+32|0);c=v[23048];v[23048]=0;if((c|0)==1){break v}vb(g+32|0);vb(g);vb(b)}d=d+1|0;if((d|0)!=250){continue}break}}b=w[a+1074364|0];v[23048]=0;S(1328,a|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break s}b=v[a+480180>>2];B:{if(!b){break B}du(a+8|0,Hq(a));if(!v[a+1074304>>2]){break B}v[23048]=0;_(1329,a|0);a=v[23048];v[23048]=0;if((a|0)==1){break s}}sl(e);f=(b|0)!=0;break a}a=P()|0;O()|0;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;break u}a=P()|0;O()|0;vb(g+32|0)}vb(g)}vb(b);break q}a=P()|0;O()|0;break q}a=P()|0;O()|0}sl(e)}R(a|0);L()}Rz(i)}gb=g+208|0;return f|0}function gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=C(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=C(0),T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=C(0);a:{if(!w[a+5046|0]){break a}h=z[a+4268>>2];aM(a);if(h==z[a+4268>>2]){break a}Iy(a)}b:{if(!w[a+5045|0]){break b}p=a+44|0;if(!ei(p)){break b}q=Pd(p,0);x=Pd(p,1);m=qd(p,0);n=qd(p,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[m>>2]=z[a+5036>>2];z[n>>2]=z[a+5040>>2];t[a+5044|0]=0;x=x+4|0;q=q+4|0;n=n+4|0;m=m+4|0;k=d-1|0;break c}k=d}r=k;d:{if(!r){break d}X=a+4960|0;G=a+4648|0;H=a+4672|0;T=a+4936|0;I=a+4696|0;J=a+4720|0;K=a+4744|0;L=a+4768|0;U=a+4840|0;E=a+4504|0;M=a+4528|0;V=a+4912|0;N=a+4552|0;O=a+4576|0;P=a+4600|0;Q=a+4624|0;W=a+4816|0;s=a+4888|0;u=a+4864|0;while(1){h=z[q>>2];h=C(C(C(z[a+5008>>2]-h)*z[a+4276>>2])+h);z[a+5008>>2]=h;_=Ec(u,v[a+4880>>2]),$=h,z[_>>2]=$;h=z[x>>2];h=C(C(C(z[a+5012>>2]-h)*z[a+4276>>2])+h);z[a+5012>>2]=h;_=Ec(s,v[a+4904>>2]),$=h,z[_>>2]=$;h=Nh(u,v[a+4356>>2]);f=Nh(u,v[a+4360>>2]);e=Nh(u,v[a+4364>>2]);g=Nh(u,v[a+4368>>2]);h=C(C(C(h*C(.6800000071525574))+C(C(e+Nh(u,v[a+4372>>2]))*C(-.6200000047683716)))+C(C(g+f)*C(-.5)));if(t[a+4264|0]&1){f=h;h=C(z[Ec(W,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));_=Ec(W,v[a+4832>>2]),$=C(f-C(h*C(.6180340051651001))),z[_>>2]=$}R=z[a+4280>>2];_=a,$=C(Nh(u,v[a+4352>>2])+z[a+5020>>2]),z[_+5020>>2]=$;f=C(Nh(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];g=z[a+4980>>2];i=z[Ec(Q,v[a+4644>>2])>>2];y=z[a+4444>>2];g=C(z[Ec(Q,v[a+4644>>2])>>2]+C(y*C(g-i)));z[a+4980>>2]=g;i=z[a+4272>>2];j=C(e*C(-.7070000171661377));l=C(f*C(.7070000171661377));e=C(j+l);f=C(C(i*e)+C(z[a+4440>>2]*g));_=Ec(Q,v[a+4640>>2]),$=C(e-C(i*f)),z[_>>2]=$;e=z[a+4976>>2];g=z[Ec(P,v[a+4620>>2])>>2];i=z[a+4436>>2];e=C(z[Ec(P,v[a+4620>>2])>>2]+C(i*C(e-g)));z[a+4976>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4432>>2]*e));_=Ec(P,v[a+4616>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=z[a+4972>>2];g=z[Ec(O,v[a+4596>>2])>>2];i=z[a+4428>>2];f=C(z[Ec(O,v[a+4596>>2])>>2]+C(i*C(f-g)));z[a+4972>>2]=f;g=z[a+4272>>2];f=C(C(g*e)+C(z[a+4424>>2]*f));_=Ec(O,v[a+4592>>2]),$=C(e-C(g*f)),z[_>>2]=$;e=z[a+4968>>2];g=z[Ec(N,v[a+4572>>2])>>2];i=z[a+4420>>2];e=C(z[Ec(N,v[a+4572>>2])>>2]+C(i*C(e-g)));z[a+4968>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4416>>2]*e));_=Ec(N,v[a+4568>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(C(f*C(.3499999940395355))+y)+C(e*C(-.3799999952316284)))}_=Ec(V,v[a+4928>>2]),$=e,z[_>>2]=$;k=Ec(V,v[a+4932>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-f)*z[a+4500>>2])+f;f=z[a+4964>>2];e=z[Ec(M,v[a+4548>>2])>>2];g=z[a+4412>>2];f=C(z[Ec(M,v[a+4548>>2])>>2]+C(g*C(f-e)));z[a+4964>>2]=f;g=C(z[a+4408>>2]*f);f=z[a+4272>>2];e=z[a+5028>>2];g=C(g+C(f*e));_=Ec(M,v[a+4544>>2]),$=C(e-C(f*g)),z[_>>2]=$;f=z[a+4960>>2];e=z[Ec(E,v[a+4524>>2])>>2];i=z[a+4404>>2];f=C(z[Ec(E,v[a+4524>>2])>>2]+C(i*C(f-e)));z[a+4960>>2]=f;e=z[a+4272>>2];A=C(C(e*g)+C(z[a+4400>>2]*f));_=Ec(E,v[a+4520>>2]),$=C(g-C(e*A)),z[_>>2]=$;z[a+5020>>2]=A;f=Nh(s,v[a+4380>>2]);e=Nh(s,v[a+4384>>2]);i=Nh(s,v[a+4388>>2]);S=Nh(s,v[a+4392>>2]);f=C(C(C(f*C(.7070000171661377))+C(C(i+Nh(s,v[a+4396>>2]))*C(-.5)))+C(C(S+e)*C(-.6000000238418579)));if(t[a+4264|0]&1){e=f;f=C(z[Ec(U,v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));_=Ec(U,v[a+4856>>2]),$=C(e-C(f*C(.6180340051651001))),z[_>>2]=$}S=z[a+4280>>2];e=z[a+5004>>2];i=z[Ec(L,v[a+4788>>2])>>2];F=z[a+4492>>2];e=C(z[Ec(L,v[a+4788>>2])>>2]+C(F*C(e-i)));z[a+5004>>2]=e;F=z[a+4272>>2];j=C(j-l);i=C(C(F*j)+C(z[a+4488>>2]*e));_=Ec(L,v[a+4784>>2]),$=C(j-C(F*i)),z[_>>2]=$;e=z[a+5e3>>2];j=z[Ec(K,v[a+4764>>2])>>2];l=z[a+4484>>2];e=C(z[Ec(K,v[a+4764>>2])>>2]+C(l*C(e-j)));z[a+5e3>>2]=e;j=z[a+4272>>2];e=C(C(j*i)+C(z[a+4480>>2]*e));_=Ec(K,v[a+4760>>2]),$=C(i-C(j*e)),z[_>>2]=$;i=C(C(e*C(-.20000000298023224))+C(C(g*C(.3799999952316284))+C(i*C(-.15000000596046448))));if(t[a+4264|0]&1){g=z[a+4996>>2];j=z[Ec(J,v[a+4740>>2])>>2];l=z[a+4476>>2];g=C(z[Ec(J,v[a+4740>>2])>>2]+C(l*C(g-j)));z[a+4996>>2]=g;j=z[a+4272>>2];g=C(C(j*e)+C(z[a+4472>>2]*g));_=Ec(J,v[a+4736>>2]),$=C(e-C(j*g)),z[_>>2]=$;e=z[a+4992>>2];j=z[Ec(I,v[a+4716>>2])>>2];l=z[a+4468>>2];e=C(z[Ec(I,v[a+4716>>2])>>2]+C(l*C(e-j)));z[a+4992>>2]=e;j=z[a+4272>>2];e=C(C(j*g)+C(z[a+4464>>2]*e));_=Ec(I,v[a+4712>>2]),$=C(g-C(j*e)),z[_>>2]=$;i=C(C(C(g*C(.3499999940395355))+i)+C(e*C(-.3799999952316284)))}Y=x+4|0;Z=q+4|0;g=C(R*h);R=C(S*f);_=Ec(T,v[a+4952>>2]),$=e,z[_>>2]=$;k=Ec(T,v[a+4956>>2]);h=C(z[a+4496>>2]*z[k>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-h)*z[a+4500>>2])+h;h=z[a+4988>>2];f=z[Ec(H,v[a+4692>>2])>>2];e=z[a+4460>>2];h=C(z[Ec(H,v[a+4692>>2])>>2]+C(e*C(h-f)));z[a+4988>>2]=h;f=z[a+4272>>2];e=z[a+5032>>2];h=C(C(z[a+4456>>2]*h)+C(f*e));_=Ec(H,v[a+4688>>2]),$=C(e-C(f*h)),z[_>>2]=$;e=z[a+4284>>2];f=z[a+4984>>2];j=z[Ec(G,v[a+4668>>2])>>2];l=z[a+4452>>2];f=C(z[Ec(G,v[a+4668>>2])>>2]+C(l*C(f-j)));z[a+4984>>2]=f;j=z[a+4272>>2];f=C(C(j*h)+C(z[a+4448>>2]*f));_=Ec(G,v[a+4664>>2]),$=C(h-C(j*f)),z[_>>2]=$;z[a+5024>>2]=f;h=C(C(h-A)*C(.3799999952316284));A=z[a+4288>>2];k=E;while(1){o=k;B=v[o+16>>2];D=B-1|0;v[o+16>>2]=D;if((B|0)<=0){v[o+16>>2]=D+v[o+12>>2]}D=v[o+20>>2];B=D-1|0;v[o+20>>2]=B;if((D|0)<=0){v[o+20>>2]=B+v[o+12>>2]}k=k+24|0;if((X|0)!=(k|0)){continue}break}h=C(C(C(h+y)*e)+g);f=C(C(A*C(i+C(f*C(-.3799999952316284))))+R);e:{f:{if(w[a+4264|0]&2){q=Z;k=Y;break f}z[m>>2]=C(z[a+5036>>2]+h)*C(.5);z[n>>2]=C(z[a+5040>>2]+f)*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=h;if((r|0)==1){break e}r=r-1|0;q=q+8|0;n=n+4|0;m=m+4|0;k=x+8|0}x=k;z[m>>2]=h;z[n>>2]=f;n=n+4|0;m=m+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}si(a,b,c,qd(p,0),qd(p,1),d)}}function Mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0;f=gb-208|0;gb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!xh(b,18693)){break h}if(d){t[d|0]=1}i=a+1074308|0;rv(i);m=a+480216|0;n=a+480224|0;j=a+1074364|0;o=a+480200|0;k=a+480248|0;i:{if(!Nb(b,7)){break i}r=a+480220|0;s=a+480228|0;z=a+480232|0;A=a+484360|0;l=a+480268|0;C=a+1300320|0;while(1){d=_f(b);e=Fg(b);if((d|0)==(w[19147]|w[19148]<<8|(w[19149]<<16|w[19150]<<24))){kg(b,6);break i}if(!(d&1616928864)|d&-2139062144){break i}if(!Nb(b,e)){break i}td(f+184|0,b,e);j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break A}if((d|0)!=1129797166){break j}v[23048]=0;v[f+24>>2]=0;T(649,f+184|0,e|0,f+24|0);d=v[23048];v[23048]=0;if((d|0)==1){break x}v[a+1074300>>2]=v[f+24>>2];break j}if((d|0)==1130917459){break s}if((d|0)!=1145525806){break j}v[23048]=0;T(649,f+184|0,e|0,o|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}break j}if((d|0)<=1213486400){if((d|0)==1146367534){break C}if((d|0)!=1196316499|e>>>0<3){break j}v[23048]=0;S(650,f+8|0,f+184|0);d=v[23048];v[23048]=0;if((d|0)==1){break q}v[23048]=0;S(651,f+168|0,f+8|0);d=v[23048];v[23048]=0;if((d|0)==1){break p}v[23048]=0;d=W(652,f+24|0,f+168|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break o}vb(f+168|0);gc(f+8|0);v[23048]=0;e=U(247,f+184|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break m}v[23048]=0;T(653,f+24|0,k|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break m}ag(d);break j}if((d|0)==1213486401){break t}if((d|0)==1280530262){break w}if((d|0)!=1297303086){break j}rv(i);d=0;break l}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break y}if((d|0)!=1347244882){break j}v[23048]=0;T(654,f+184|0,e|0,l|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}if(xp(w[l|0])){break j}t[l|0]=5;break j}if((d|0)==1380340804){break B}if((d|0)==1380986414){break u}if((d|0)!=1380991534){break j}v[23048]=0;T(649,f+184|0,e|0,m|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}break j}if((d|0)<=1397768493){if((d|0)==1380994350){break k}if((d|0)!=1397052739|e>>>0<3){break j}v[23048]=0;d=U(340,f+184|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}if(!d|d>>>0>x[a+480190>>1]){break j}e=B(d,104)+a|0;d=e+484448|0;e=e+484484|0;while(1){v[23048]=0;g=U(376,f+184|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break r}v[d>>2]=g;d=d+4|0;if((e|0)!=(d|0)){continue}break}break j}if((d|0)==1397768494){break v}if((d|0)==1414344238){break z}if((d|0)!=1448301654){break j}v[23048]=0;T(649,f+184|0,e|0,z|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}break j}v[23048]=0;T(649,f+184|0,e|0,f+24|0);d=v[23048];v[23048]=0;if((d|0)==1){break g}v[a+480204>>2]=B(v[f+24>>2],1e4)+(y[a+480204>>2]%1e4|0);break j}v[23048]=0;T(649,f+184|0,e|0,f+24|0);d=v[23048];v[23048]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[f+24>>2]%1e4;break j}e=P()|0;O()|0;break a}if(c){break j}v[23048]=0;u[f+24>>1]=0;T(655,f+184|0,e|0,f+24|0);d=v[23048];v[23048]=0;if((d|0)!=1){D=a,E=Gd(x[f+24>>1],x[a+480188>>1],127),u[D+480188>>1]=E;break j}e=P()|0;O()|0;break a}v[23048]=0;T(656,f+184|0,e|0,n|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}break j}v[23048]=0;T(657,f+184|0,e|0,j|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}break j}e=P()|0;O()|0;break a}v[23048]=0;v[f+24>>2]=0;T(649,f+184|0,e|0,f+24|0);d=v[23048];v[23048]=0;if((d|0)==1){break f}d=v[f+24>>2];if(!d){break j}v[a+1074304>>2]=d;break j}v[23048]=0;T(649,f+184|0,e|0,s|0);d=v[23048];v[23048]=0;if((d|0)!=1){break j}break b}if(v[a+480180>>2]==4){break j}v[23048]=0;T(655,f+184|0,e|0,f+24|0);d=v[23048];v[23048]=0;if((d|0)!=1){ff(Qb(A),x[f+24>>1]);break j}e=P()|0;O()|0;break a}d=Jb(f+24|0);v[23048]=0;e=U(247,f+184|0)|0;g=v[23048];v[23048]=0;D:{if((g|0)==1){break D}v[23048]=0;W(658,f+184|0,d|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break D}v[23048]=0;T(13,f+168|0,0,d|0);e=v[23048];v[23048]=0;if((e|0)==1){break D}Eb(C,f+168|0);vb(f+168|0);vb(d);break j}e=P()|0;O()|0;vb(d);break a}if(e&1|e>>>0>126){break j}u[f+24>>1]=(e>>>1|0)- -64;v[23048]=0;u[f+168>>1]=127;d=Vc(f+24|0,f+168|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}p=x[d>>1];if(p>>>0<65){break j}e=64;while(1){v[23048]=0;S(452,f+24|0,f+184|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}d=rd(f+24|0);g=f+24|0;E:{if(w[g|0]==255){break E}h=w[d|0];d=(e<<5)+a|0;q=d+480284|0;u[q>>1]=128;u[d+480286>>1]=h;h=d+480280|0;v[h>>2]=0;v[h>>2]=(w[g|0]&128)<<3;d=w[g|0]&127;t[g|0]=d;if(d>>>0<65){u[q>>1]=d<<2;d=w[g|0]}if((d|0)!=100){break E}v[h>>2]=v[h>>2]|256}e=e+1|0;if((p|0)!=(e|0)){continue}break}break j}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break n}e=P()|0;O()|0;vb(f+168|0)}gc(f+8|0);break a}e=P()|0;O()|0;ag(d);break a}F:{G:{H:while(1){v[23048]=0;e=Q(250,f+184|0,1)|0;g=v[23048];v[23048]=0;if((g|0)==1){break G}if(e^1|d>>>0>111){break j}v[23048]=0;g=U(373,f+184|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break F}e=0;while(1){I:{if(!(!(g&1<<e)|d>>>0>111)){v[23048]=0;W(458,i|0,d|0,1)|0;h=v[23048];v[23048]=0;if((h|0)==1){break I}}d=d+1|0;e=e+1|0;if((e|0)!=8){continue}continue H}break}break}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}v[23048]=0;T(649,f+184|0,e|0,r|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}}yb(f+184|0);if(Nb(b,7)){continue}break}}Fp(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(w[a+480224|0]>=3){t[n|0]=0}if(w[j|0]>=6){t[j|0]=0}tc(o,256);if(cd(k)){break h}GC(k,v[m>>2],16777216)}gb=f+208|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0}yb(f+184|0);R(e|0);L()}function yo(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;g=gb-16|0;gb=g;h=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:h;s=v[b+752>>2];j=w[b+804|0];a:{if(!j){Db(g+8|0,a+1074308|0,11);if(Cb(g+8|0)){break a}}b:{c:{if(!h){break c}if(!ue(j)){break c}d:{k=h+236|0;l=j-1|0;if(x[ud(k,l)>>1]){break d}Db(g+8|0,a+1074308|0,43);if(!Cb(g+8|0)){break d}if(uj(h)){break d}v[b+656>>2]=h;break a}if(w[lc(h+108|0,l)|0]>120){break a}k=x[ud(k,l)>>1];l=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}l=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(j>>>0>250){break a}Db(g+8|0,a+1074308|0,43);if(Cb(g+8|0)){if(h){l=0;if(uj(h)){break b}}t[b+805|0]=0;v[b+656>>2]=0;break a}l=0}k=v[b+104>>2];m=(k|0)!=0&(k|0)!=(l|0);i=v[b+656>>2];p=!h|v[a+480180>>2]!=16777216?p:v[h+44>>2]!=0;q=d^1;j=(i|0)!=(h|0);if((q|j|m)==1){u[b+776>>1]=0}if(m?!(!(d&p)|v[b+656>>2]!=(h|0)):0){break a}e:{if(!(d&m)){break e}k=a+1074308|0;Db(g+8|0,k,32);if(!(!Cb(g+8|0)|!(w[a+480208|0]&8))){l=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:l}f:{if(v[a+480180>>2]==268435456|(v[a+480180>>2]&1048580?!(!h|j):0)){break f}if(v[a+480180>>2]==1){if(zi(b)){break f}}Db(g+8|0,k,79);if(!Cb(g+8|0)){break e}if(!zi(b)){break e}}n=1}g:{if(!v[b+16>>2]|(!m|(j|!x[a+480192>>1]))){break g}Db(g+8|0,a+1074308|0,87);if(!Cb(g+8|0)){break g}n=ne(b+790|0)^1|n}h:{i:{j:{k:{l:{if(zi(b)|!(v[a+480180>>2]&16777248)){break l}if(h){if(uj(h)){break l}}k=1;break k}if(!m&(i|0)==(h|0)){break j}k=(i|0)!=(h|0)}if(!d){break i}Db(g+8|0,a+1074308|0,61);if(!Cb(g+8|0)){break i}j=v[b+656>>2];if(!j){j=0;i=v[b+104>>2];if(!i){break i}break h}i=v[b+104>>2];break h}k=0}v[b+656>>2]=h;o=k;i=l;j=h}m:{n:{o:{if(!e){break o}p:{if(v[a+480180>>2]&3){if(i){if(Od(i)){break p}}if(!kk(b)){break o}}if(!i){break n}}if(u[i+34>>1]<0){break o}v[b+688>>2]=x[i+30>>1]}h=(i|0)!=0;if(!(m&h&n)){break m}Db(g+8|0,a+1074308|0,85);if(Cb(g+8|0)){u[b+774>>1]=t[i+37|0]}h=1;if(v[a+480180>>2]!=2){break m}if(!Od(i)){break m}v[b+704>>2]=v[i+24>>2];break m}if(!(!j|!w[j+34|0])){l=b;k=b;h=v[b+656>>2];q:{if(h){k=v[h+4>>2]<<2;break q}k=v[k+688>>2]}v[l+688>>2]=k;h=0;break m}h=0;v[b+688>>2]=0}if(n){break a}t[b+805|0]=0;r:{if(!j){break r}Db(g+8|0,a+1074308|0,29);if(z=0,A=!(Cb(g+8|0)?0:i),C=w[j+34|0]!=0|o,C?z:A){break r}t[b+800|0]=w[j+16|0]}n=j;r=64;l=b;v[b+752>>2]=64;k=i;if(i){r=x[k+32>>1];v[l+752>>2]=r}if(n){v[l+752>>2]=B(v[n+4>>2],r)>>>6}s:{if(v[a+480180>>2]&1048580?!e:0){break s}Db(g+8|0,a+1074308|0,48);if(Cb(g+8|0)){break s}NP(a,b,j,i)}t:{u:{v:{if(!f){break v}f=a+1074308|0;Db(g+8|0,f,19);w:{x:{y:{z:{A:{B:{C:{D:{if(Cb(g+8|0)){if(!v[b+76>>2]){e=1;break C}if(!(!c|q)){e=(w[a+480208|0]&8)>>>3|0;if(e){break C}break D}e=0;if(c){break D}break C}e=1;E:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break E}e=0;if(!(w[b+89|0]&16)){break E}e=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!j|o)){break A}if(!e){break z}c=v[b+88>>2];e=c&6144;break B}if(d){break C}if(!(w[b+89|0]&24)){e=0;break C}e=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|o){break A}if(!e){break z}c=v[b+88>>2];e=c&2048}v[b+88>>2]=c|2097152;if(!j){break w}if(e){break x}if(!(w[j+60|0]&8)){rj(b+724|0)}if(!(w[j+80|0]&8)){rj(b+732|0)}if(w[j+100|0]&8){break w}rj(b+740|0);break w}if(e){break y}}if(j){if(t[j+60|0]&1){break v}Db(g+8|0,f,32);if(Cb(g+8|0)){rj(b+724|0);break v}zm(b);break v}c=0;if(!i){break u}break t}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break w}}zm(b)}Db(g+8|0,f,21);if(Cb(g+8|0)){break v}t[b+820|0]=0;v[b+760>>2]=0}c=0;if(i){break t}if(!j){break u}c=1;if(uj(j)){break t}}v[b+752>>2]=0;v[b+104>>2]=0;break a}e=b;F:{G:{H:{I:{J:{if(!(!d|(h^1|v[b+104>>2]!=(i|0)))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break J}Db(g+8|0,a+1074308|0,40);if(!Cb(g+8|0)|w[b+791|0]){break J}d=v[b+88>>2];break I}v[b+88>>2]=v[b+88>>2]&-6145;f=a+1074308|0;Db(g+8|0,f,18);e=b;K:{if(!(z=!Cb(g+8|0),A=0,C=v[a+480180>>2]&16777248,C?z:A)){k=-640;if(!(v[b+104>>2]!=(i|0)|o)){break K}}k=-768}v[e+88>>2]=k&v[b+88>>2];L:{if(!j){break L}t[b+730|0]=w[j+60|0];t[b+738|0]=w[j+80|0];t[b+746|0]=w[j+100|0];M:{if((w[j+100|0]&17)!=17){break M}Db(g+8|0,f,36);if(Cb(g+8|0)|w[b+839|0]){break M}t[b+839|0]=127}if(lw(j)){z=b,A=QE(j),t[z+839|0]=A}if(!OE(j)){break L}z=b,A=PE(j),t[z+840|0]=A}if(c){break H}if(!d){break F}break G}d=v[b+88>>2]&-6145}v[e+88>>2]=d&-640;if(!c){break G}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break F}c=a+1074308|0;Db(g+8|0,c,54);if(!Cb(g+8|0)){Db(g,c,39);if(!Cb(g)){break F}}v[b+8>>2]=0;v[b+12>>2]=0}N:{if(w[b+790|0]!=255){break N}Db(g+8|0,a+1074308|0,100);if(!Cb(g+8|0)|(!m|!(v[a+480208>>2]&4))){break N}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[i+30>>1];if(!(w[i+34|0]&32)){break a}Mo(b,x[i+28>>1],a);break a}v[b+104>>2]=i;v[b+76>>2]=v[i>>2];v[b+80>>2]=v[i+4>>2];v[b+84>>2]=v[i+8>>2];e=a+1074308|0;Db(g+8|0,e,83);if(!(!Cb(g+8|0)|v[b+80>>2])){v[b+84>>2]=v[i>>2]}v[b+88>>2]=v[b+88>>2]|x[i+34>>1]&1023;Db(g+8|0,e,21);if(Cb(g+8|0)){t[b+820|0]=0;v[b+760>>2]=0}c=b;O:{P:{if(p){v[b+704>>2]=v[i+24>>2];t[b+853|0]=w[b+853|0]|8;d=0;break P}if(v[a+480180>>2]&5?!(m|q):0){break O}v[b+704>>2]=v[i+24>>2];d=t[i+37|0]}u[c+774>>1]=d}c=b;if(ep(a)){d=t[i+36|0]}else{d=0}u[c+772>>1]=d;Db(g+8|0,e,69);if(!(Cb(g+8|0)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+856>>2]=0;h=v[b+88>>2];if(h&8){v[b+80>>2]=v[i+12>>2];v[b+84>>2]=v[i+16>>2];h=h>>>2&4|h|2;v[b+88>>2]=h}Q:{if(!(h&2)){h=v[b+76>>2];break Q}h=v[b+76>>2];c=v[b+84>>2];if(h>>>0<=c>>>0){break Q}v[b+76>>2]=c;h=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<h>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}gb=g+16|0}function K5(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0,G=0,H=0;m=gb-560|0;gb=m;v[m+44>>2]=0;o(+b);p=j(1)|0;j(0)|0;a:{if((p|0)<-1?1:(p|0)<=-1){A=1;b=-b;o(+b);p=j(1)|0;j(0)|0;g=71920;break a}A=1;g=71923;if(e&2048){break a}g=71926;if(e&1){break a}A=0;z=1;g=71921}E=g;b:{if((p&2146435072)==2146435072){l=A+3|0;bg(a,32,c,l,e&-65537);xf(a,E,A);d=f&32;xf(a,b!=b?d?71947:71951:d?71939:71943,3);break b}s=m+16|0;c:{d:{e:{b=aJ(b,m+44|0);b=b+b;if(b!=0){g=v[m+44>>2];v[m+44>>2]=g-1;C=f|32;if((C|0)!=97){break e}break c}C=f|32;if((C|0)==97){break c}q=v[m+44>>2];n=(d|0)<0?6:d;break d}q=g-29|0;v[m+44>>2]=q;b=b*268435456;n=(d|0)<0?6:d}r=(q|0)<0?m+48|0:m+336|0;h=r;while(1){d=h;if(b<4294967296&b>=0){g=~~b>>>0}else{g=0}v[d>>2]=g;h=h+4|0;b=(b-+(g>>>0))*1e9;if(b!=0){continue}break}f:{if((q|0)<1){d=q;g=h;i=r;break f}i=r;d=q;while(1){G=(d|0)<29?d:29;g=h-4|0;g:{if(i>>>0>g>>>0){break g}k=G;d=0;p=0;while(1){y=g;H=v[g>>2];l=k&31;if((k&63)>>>0>=32){F=H<<l;l=0}else{F=(1<<l)-1&H>>>32-l;l=H<<l}l=l+d|0;F=p+F|0;p=l;d=Ipa(l,d>>>0>l>>>0?F+1|0:F,1e9,0);l=Fpa(d,jb,1e9,0);v[y>>2]=p-l;g=g-4|0;if(i>>>0<=g>>>0){p=0;continue}break}if(!d){break g}i=i-4|0;v[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[m+44>>2]-G|0;v[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25|0)/9|0;if((d|0)<=-1){u=h+1|0;l=(C|0)==102;while(1){y=(d|0)<-9?9:0-d|0;h:{if(g>>>0>i>>>0){p=1e9>>>y|0;k=-1<<y^-1;d=0;h=i;while(1){G=d;d=v[h>>2];v[h>>2]=G+(d>>>y|0);d=B(p,d&k);h=h+4|0;if(h>>>0<g>>>0){continue}break}i=v[i>>2]?i:i+4|0;if(!d){break h}v[g>>2]=d;g=g+4|0;break h}i=v[i>>2]?i:i+4|0}d=v[m+44>>2]+y|0;v[m+44>>2]=d;h=l?r:i;g=g-h>>2>(u|0)?h+(u<<2)|0:g;if((d|0)<0){continue}break}}h=0;i:{if(g>>>0<=i>>>0){break i}h=B(r-i>>2,9);k=v[i>>2];if(k>>>0<10){break i}d=100;while(1){h=h+1|0;if(d>>>0>k>>>0){break i}d=B(d,10);continue}}d=(n-((C|0)==102?0:h)|0)-((C|0)==103&(n|0)!=0)|0;if((d|0)<(B(g-r>>2,9)-9|0)){p=d+9216|0;k=(p|0)/9|0;l=((k<<2)+((q|0)<0?m+48|4:m+340|0)|0)-4096|0;d=10;j:{k=p-B(k,9)|0;if((k|0)>7){break j}d=100;while(1){k=k+1|0;if((k|0)==8){break j}d=B(d,10);continue}}q=v[l>>2];u=(q>>>0)/(d>>>0)|0;k:{p=q-B(d,u)|0;k=l+4|0;if((k|0)==(g|0)?!p:0){break k}b=(g|0)==(k|0)?1:1.5;k=d>>>1|0;x=k>>>0>p>>>0?.5:(k|0)==(p|0)?b:1.5;b=u&1?9007199254740994:9007199254740992;if(!(w[E|0]!=45|z)){x=-x;b=-b}k=q-p|0;v[l>>2]=k;if(b+x==b){break k}d=d+k|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<i>>>0){i=i-4|0;v[i>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}h=B(r-i>>2,9);k=v[i>>2];if(k>>>0<10){break k}d=100;while(1){h=h+1|0;if(d>>>0>k>>>0){break k}d=B(d,10);continue}}d=l+4|0;g=d>>>0<g>>>0?d:g}while(1){q=g;k=g>>>0<=i>>>0;if(!k){g=q-4|0;if(!v[g>>2]){continue}}break}l:{if((C|0)!=103){z=e&8;break l}g=n?n:1;d=(g|0)>(h|0)&(h|0)>-5;n=(d?h^-1:-1)+g|0;f=(d?-1:-2)+f|0;z=e&8;if(z){break l}g=-18;m:{if(k){break m}d=v[q-4>>2];if(!d){break m}g=-9;if((d>>>0)%10|0){break m}k=0;g=100;while(1){if(!((d>>>0)%(g>>>0)|0)){k=k+1|0;g=B(g,10);continue}break}g=-10-k|0}d=B(q-r>>2,9);if((f&-33)==70){z=0;d=d+g|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d;break l}z=0;d=d+(g+h|0)|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d}y=n|z;l=(y|0)!=0;d=a;k=c;p=f&-33;g=(h|0)>0?h:0;n:{if((p|0)==70){break n}g=h>>31;g=Xn(g+h^g,0,s);if((s-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((s-g|0)<2){continue}break}}u=g-2|0;t[u|0]=f;t[g-1|0]=(h|0)<0?45:43;g=s-u|0}l=(g+(l+(n+A|0)|0)|0)+1|0;bg(d,32,k,l,e);xf(a,E,A);bg(a,48,c,l,e^65536);o:{p:{q:{if((p|0)==70){d=m+16|8;h=m+16|9;f=i>>>0>r>>>0?r:i;i=f;while(1){g=Xn(v[i>>2],0,h);r:{if((f|0)!=(i|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(h|0)){break r}t[m+24|0]=48;g=d}xf(a,g,h-g|0);i=i+4|0;if(r>>>0>=i>>>0){continue}break}if(y){xf(a,71955,1)}if((n|0)<1|i>>>0>=q>>>0){break q}while(1){g=Xn(v[i>>2],0,h);if(g>>>0>m+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}xf(a,g,(n|0)<9?n:9);g=n-9|0;if((n|0)<10){break p}n=g;i=i+4|0;if(q>>>0>i>>>0){continue}break}break p}s:{if((n|0)<0){break s}f=i>>>0<q>>>0?q:i+4|0;k=m+16|9;d=m+16|8;h=i;while(1){g=Xn(v[h>>2],0,k);if((k|0)==(g|0)){t[m+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(m+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break t}xf(a,g,1);g=g+1|0;if((n|0)<1?!z:0){break t}xf(a,71955,1)}q=g;g=k-g|0;xf(a,q,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(f>>>0<=h>>>0){break s}if((n|0)>-1){continue}break}}bg(a,48,n+18|0,18,0);xf(a,u,s-u|0);break o}g=n}bg(a,48,g+9|0,9,0)}break b}n=f&32;q=n?E+9|0:E;u:{if(d>>>0>11){break u}g=12-d|0;if(!g){break u}x=8;while(1){x=x*16;g=g-1|0;if(g){continue}break}if(w[q|0]==45){b=-(x+(-b-x));break u}b=b+x-x}g=v[m+44>>2];h=g>>31;g=Xn(h^g+h,0,s);if((s|0)==(g|0)){t[m+15|0]=48;g=m+15|0}k=A|2;h=v[m+44>>2];p=g-2|0;t[p|0]=f+15;t[g-1|0]=(h|0)<0?45:43;g=e&8;i=m+16|0;while(1){f=i;r=n;if(D(b)<2147483648){h=~~b}else{h=-2147483648}t[i|0]=r|w[h+71904|0];i=f+1|0;b=(b-+(h|0))*16;if(!((i-(m+16|0)|0)!=1|(b==0?!(g|(d|0)>0):0))){t[f+1|0]=46;i=f+2|0}if(b!=0){continue}break}f=!d|((i-m|0)-18|0)>=(d|0)?(s-(p+(m+16|0)|0)|0)+i|0:((d+s|0)-p|0)+2|0;l=f+k|0;bg(a,32,c,l,e);xf(a,q,k);bg(a,48,c,l,e^65536);d=i-(m+16|0)|0;xf(a,m+16|0,d);g=d;d=s-p|0;bg(a,48,f-(g+d|0)|0,0,0);xf(a,p,d)}bg(a,32,c,l,e^8192);gb=m+560|0;return((c|0)>(l|0)?c:l)|0}function rP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),y=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=C(0),M=0,N=0,O=C(0),P=0;i=gb-48|0;gb=i;n=x[a+480192>>1]?v[(B(b,880)+a|0)+1075640>>2]:n;E=a+1074308|0;g=B(b,880)+a|0;F=g+1075785|0;I=g+1075672|0;J=g+1075762|0;G=g+1075736|0;H=g+1075732|0;K=g+1075704|0;p=g+1075676|0;o=g+1075668|0;r=g+1075648|0;y=g+1075772|0;A=g+1075072|0;k=e&127;L=C(k>>>0);j=g+1075836|0;s=C(w[j|0]);g=1;while(1){e=w[d+q|0];if(e){l=e-48|0;a:{b:{if((l&255)>>>0<10){break b}if((e-65&255)>>>0<=5){l=e-55|0;break b}c:{d:{e:{switch(e-97|0){case 2:f:{e=ym(a,b,3,0);if(!e|e-251>>>0<5){break f}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break f}e=Ww(e,46996,47028);if(!e){break f}e=kb[v[v[e>>2]+188>>2]](e,b)|0;h=(e|0)!=255;l=h?e:0;if(h|!n){break b}break c}if(n){break c}l=0;break b;case 13:e=0;if(!ue(w[F|0])){break d}e=w[F|0]-1|0;break d;case 21:Db(i+8|0,E,28);g:{if(!Cb(i+8|0)){Db(i,E,1);h=0;if(!Cb(i)){break g}}h=u[J>>1]}e=B(v[G>>2],v[H>>2]);m=e;l=e>>31;e=B(v[a+1074448>>2],h+v[I>>2]|0);e=ac((vc(Gpa(Fpa(m,l,e,e>>31),jb,1048576,0),jb)|0)/2|0,1,127);break d;case 23:v[i+8>>2]=v[p>>2]/2;v[i>>2]=127;e=v[sd(i+8|0,i)>>2];break d;case 24:v[i+8>>2]=v[o>>2]/2;v[i>>2]=127;e=v[sd(i+8|0,i)>>2];break d;case 0:e=0;if(!n){break d}h=x[n+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!n){break d}h=x[n+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=v[r>>2]>>>8|0;break d;case 7:e=b;if(e>>>0>=x[a+480188>>1]){e=w[y|0]-1|0}e=e&127;break d;case 12:e=v[A>>2]>>>7&1;break d;case 15:e=0;if(!n){break d}h=w[n+30|0];if(!h){break d}e=h-1&127;break d;case 25:h=j;e=k;h:{if(!c){break h}e=k;if(t[j|0]<0){break h}i:{if(f>>>0<3){break i}m=(i+16|0)+f|0;if(w[m-3|0]!=240){break i}e=k;if(w[m-2|0]>239){break h}}D=Kq(a,s,L);if(D<C(4294967296)&D>=C(0)){e=~~D>>>0;break h}e=0}t[h|0]=e;break d;case 18:e=f;j:{if(!e){e=0;break j}while(1){e=e-1|0;if(w[e+(i+16|0)|0]==240){break j}if(e){continue}break}}if(w[(i+16|0)+e|0]!=240|f-e>>>0<5){break a}l=0;e=e+5|0;h=0;k:{if((f|0)==(e|0)){break k}while(1){l=w[(i+16|0)+e|0]+l|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}h=0-l|0}e=h&127;break d;case 20:break e;default:break a}}e=B(v[G>>2],v[H>>2]);h=e;m=e>>31;e=B(v[a+1074448>>2],v[K>>2]);e=ac((vc(Gpa(Fpa(h,m,e,e>>31),jb,67108864,0),jb)|0)/2|0,1,127)}h=g^-1;g=1;f=(h&1)+f|0;t[f+(i+16|0)|0]=e;f=f+1|0;break a}l=n;e=a;m=0;h=b;l:{m:{if(h>>>0>=256){break m}if(w[l+31|0]==17){e=x[(e+B(h,880)|0)+1075772>>1];e=(e?e-1|0:h)&15;break l}if(!uj(l)){break m}m=w[l+31|0]-1&15}e=m}l=e}e=(i+16|0)+f|0;n:{if(g&1){t[e|0]=l;break n}t[e|0]=w[e|0]<<4|l;f=f+1|0}g=(g^-1)&1}q=q+1|0;if((q|0)!=31){continue}}break}e=((g^-1)&1)+f|0;o:{if(!e){break o}l=0;g=0;while(1){r=(i+16|0)+g|0;d=t[r|0];p:{q:{r:{if((d|0)==-16){if(e-g>>>0>=4){q=4;if((w[(g+i|0)+17|0]&254)==240){break q}}q=g;s:{while(1){q=q+1|0;if(q>>>0>=e>>>0){break s}if(w[(i+16|0)+q|0]!=247){continue}break}d=q-g|0;q=d+1|0;if(q>>>0>=d>>>0){break q}}t[(i+16|0)+e|0]=247;e=e+1|0;q=e-g|0;break r}if((d|0)>=0){if(l&255){g=g-1|0;t[g+(i+16|0)|0]=l;break p}g=g+1|0;l=0;break p}M=i,N=YS(d&255),v[M+8>>2]=N;v[i>>2]=e-g;q=v[Gb(i+8|0,i)>>2]}if(!q){break o}d=w[r|0];l=d>>>0<240?d:l}j=a;m=b;h=c;p=gb-32|0;gb=p;k=q;v[p+28>>2]=k;d=w[r|0];f=d-250|0;if(!(f>>>0>5|!(1<<f&37))){if(x[j+480188>>1]){o=0;while(1){d=(j+B(o,880)|0)+1075823|0;t[d|0]=127;t[d+1|0]=0;o=o+1|0;if(o>>>0<x[j+480188>>1]){continue}break}}d=w[r|0]}t:{u:{if((d&255)!=240){break u}n=w[r+1|0];if((n&254)!=240){break u}o=0;if(k>>>0<4){break t}A=(j+B(m,880)|0)+1074984|0;y=w[r+2|0];d=(n|0)==241;f=t[r+3|0];if(!(y|d|(f|0)<0)){n=j+B(m,880)|0;k=n+1075823|0;d=k;if(h){f=aA(Kq(j,C(w[k|0]),C((f&255)>>>0)))}t[d|0]=f;t[n+1075782|0]=0;o=4;d=n+1075072|0;k=Rq(j,A,!(v[d>>2]&32768),256);if((k|0)<0|!(w[d+1|0]&2)){break t}d=j+1300300|0;if(!Fd(d)){break t}_q(v[d>>2],m,k>>>2&255,1);break t}if(!(d|(y|0)!=1|(f|0)<0)){k=j+B(m,880)|0;d=k+1075824|0;v:{if(!h){break v}s=Kq(j,C(w[d|0]),C((f&255)>>>0));if(s<C(4294967296)&s>=C(0)){f=~~s>>>0;break v}f=0}t[d|0]=f;t[k+1075781|0]=0;Rq(j,A,!(v[k+1075072>>2]&32768),256);o=4;break t}d=(n|0)==241;if(!(d|(y|0)!=2)){o=4;if((f&255)>>>0>31){break t}d=j+B(m,880)|0;t[d+1075831|0]=(f&240)>>>4;Rq(j,A,!(v[d+1075072>>2]&32768),256);break t}if(!(d|(y|0)!=3)){o=4;d=ym(j,m,3,0);if((f|0)<0|(d+5&255)>>>0<6){break t}d=(j+B(d,160)|0)+906284|0;s=C(C(((f^127)&255)>>>0)*C(.007874015718698502));if(!h){z[d>>2]=s;break t}M=d,O=Kq(j,z[d>>2],s),z[M>>2]=O;break t}if(y&128?0:(n|0)!=241){break t}o=4;d=ym(j,m,3,0);if((d+5&255)>>>0<6){break t}k=v[(j+B(d,160)|0)+906140>>2];if(!k|(f|0)<0){break t}d=(n|0)==241?y+128|0:y&127;s=C(C((f&255)>>>0)*C(.007874015718698502));if(!h){kb[v[v[k>>2]+44>>2]](k,d,s);break t}N=k,P=d,O=Kq(j,C(kb[v[v[k>>2]+48>>2]](k,d)),s),M=v[v[k>>2]+44>>2],kb[M](N|0,P|0,C(O));break t}w:{x:{if(m>>>0<x[j+480188>>1]){o=m+1|0;break x}o=x[(j+B(m,880)|0)+1075772>>1];if(!o){break w}}if(w[(j+B(m,880)|0)+1075075|0]&4|x[j+480188>>1]<(o&65535)>>>0){break w}d=ym(j,m,3,0);if(!d|d-251>>>0<5){break w}f=v[(j+B(d,160)|0)+906140>>2];if(!f){break w}d=w[r|0];if((d|0)==240){cc(p+16|0,zb(r),k);k=v[v[f>>2]+72>>2];d=v[p+20>>2];v[p>>2]=v[p+16>>2];v[p+4>>2]=d;kb[k|0](f,p)|0;break w}M=p,P=YS(d),v[M+12>>2]=P;d=v[Gb(p+12|0,p+28|0)>>2];v[p+12>>2]=0;hc(p+12|0,r,d);kb[v[v[f>>2]+68>>2]](f,v[p+12>>2])|0}o=v[p+28>>2]}gb=p+32|0;g=(o?o:q)+g|0}if(e>>>0>g>>>0){continue}break}}gb=i+48|0}function tka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=gb-336|0;gb=d;Rc(b,60);i=15;a:{if(!xh(b,26140)){Rc(b,124);i=31;if(!xh(b,26145)){break a}}Ed(a,536870912);u[a+480190>>1]=i;yc(b);b:{if(x[a+480190>>1]){while(1){e=Lv(b);v[(d+208|0)+(f<<2)>>2]=e;if(e>>>0>131072){break b}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;jh(a,1);Vb(b,4);i=Kr(b);if(i>>>0<178){break a}e=a;o=177693e5/+(i>>>0);c:{if(o<4294967296&o>=0){f=~~o>>>0;break c}f=0}v[e+480204>>2]=f;Vb(b,14);d:{e:{f:{if(x[a+480190>>1]){p=d+62|0;k=1;i=0;m=1;while(1){sV(b,d+40|0);e=v[((k<<2)+d|0)+204>>2];l=gb-16|0;gb=l;h=(B(k,104)+a|0)+484380|0;wd(h,1);v[h>>2]=e;e=d+40|0;t[h+37|0]=w[e+24|0]<<4;t[l+15|0]=w[e+25|0];t[l+14|0]=64;q=h,r=w[$b(l+15|0,l+14|0)|0]<<2,u[q+30>>1]=r;f=e+26|0;g=Ib(w[f|0]|w[f+1|0]<<8);e=e+28|0;e=Ib(w[e|0]|w[e+1|0]<<8);f=v[h>>2];g:{if(!f){break g}v[h+4>>2]=g;e=(e<<1)+g|0;v[h+8>>2]=e;if(f>>>0<=g>>>0){g=f-1|0;v[h+4>>2]=g}if(e>>>0>f>>>0){v[h+8>>2]=f;e=f}if(!(e-g>>>0>3?!(e>>>0<g>>>0|e>>>0<4):0)){v[h+4>>2]=0;v[h+8>>2]=0;break g}if(e>>>0<=g>>>0){break g}u[h+34>>1]=x[h+34>>1]|2}gb=l+16|0;f=d+40|0;while(1){if((w[f|0]-1&255)>>>0<=30){t[f|0]=32;i=i+1|0}f=f+1|0;if((p|0)!=(f|0)){continue}break}if(i>>>0>127){break b}Fk(d+176|0,3,d+40|0);Fc(d+192|0,d+176|0);v[23048]=0;Q(354,((k<<5)+a|0)+946300|0,d+192|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break f}vb(d+192|0);m=m+1|0;k=m&65535;if(k>>>0<=x[a+480190>>1]){continue}break}}e=Tb(d+40|0,26150);v[23048]=0;h=a+946332|0;f=Q(919,h|0,e|0)|0;k=v[23048];v[23048]=0;i=1;h:{i:{j:{k:{if((k|0)!=1){if(!f){v[23048]=0;f=Q(91,d+192|0,26161)|0;i=v[23048];v[23048]=0;if((i|0)==1){break k}v[23048]=0;i=Q(919,h|0,f|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break j}vb(f)}vb(e);f=0;e=d+40|0;h=lV(b,e);if(!h){QB(e)}if(!h){break a}if(!iU(d+40|0)){break a}if(c){break h}break d}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(f)}vb(e);break e}u[d+38>>1]=0;if(w[d+40|0]){while(1){u[d+192>>1]=w[(d+f|0)+42|0]+1;q=d,r=x[Le(d+38|0,d+192|0)>>1],u[q+38>>1]=r;f=f+1|0;if(f>>>0<w[d+40|0]){continue}break}}e=d+40|1;f=w[e|0];h=w[d+40|0];k=a+484360|0;ff(Qb(k),f>>>0<h>>>0?w[e|0]:0);Hr(Qb(k),d+40|2,w[d+40|0]);if(x[a+480190>>1]==31){Vb(b,4)}k=0;v[d+32>>2]=0;v[d+28>>2]=0;v[d+24>>2]=0;t[d+23|0]=0;l=c&1;if(l){rg(a+484344|0,x[d+38>>1])}if(x[d+38>>1]){h=a+484344|0;while(1){l:{m:{if(l){m=0;if(Sg(h,k&65535,64)){break m}}Vb(b,1024);break l}while(1){p=Wc(Yb(h,k),m,0);f=0;while(1){nn(d+192|0,b);e=p+B(f,6)|0;n:{o:{p:{q:{if(w[lc(d+192|0,0)|0]!=255){break q}t[(d+32|0)+f|0]=0;t[(d+24|0)+f|0]=0;g=lc(d+192|0,1);j=w[g|0];if((j|0)==252&i){t[g|0]=254;break o}switch(j-252|0){case 1:break n;case 2:break o;case 0:break p;default:break q}}g=v[d+192>>2];v[d+16>>2]=g;v[d+8>>2]=g;kr(d+8|0,e);g=w[e|0];r:{if(!g){break r}t[(d+24|0)+f|0]=0;t[(d+32|0)+f|0]=g;if(g>>>0>48){break r}t[d+176|0]=8;q=d,r=w[Ff(d+23|0,d+176|0)|0],t[q+23|0]=r}s:{t:{u:{v:{w:{switch(w[e+3|0]){case 0:if(w[e+5|0]){break t}break s;case 1:t[e+3|0]=1;break n;case 2:g=w[e+5|0];if(g&240){t[e+3|0]=3;t[e+5|0]=g>>>4;break n}g=g&15;if(g){t[e+3|0]=2;t[e+5|0]=g;break n}t[e+5|0]=0;break t;case 3:if(w[(d+24|0)+f|0]){break u}t[e+3|0]=19;t[e+5|0]=0;break n;case 4:if(w[(d+24|0)+f|0]){break u}t[e+3|0]=19;t[e+5|0]=1;break n;case 5:if(!w[e+1|0]){break u}t[e+3|0]=13;t[d+176|0]=63;t[d+15|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);q=e,r=w[$b(d+176|0,d+15|0)|0],t[q+5|0]=r;if(!w[(d+24|0)+f|0]){break v}t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+5|0]=0;break t;case 6:g=w[e+1|0];if(!g){break u}t[e+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;j=w[e+5|0];g=g>>>0<j>>>0?0:g-j|0;t[e+5|0]=g;if(!w[(d+24|0)+f|0]){break v}t[e+4|0]=g;t[e+2|0]=1;t[e+5|0]=0;break t;case 8:j=w[(d+32|0)+f|0];g=w[e+5|0];n=j+(g>>>4|0)|0;t[(d+28|0)+f|0]=n;t[e+3|0]=2;g=g&15;t[(d+24|0)+f|0]=g;q=e,r=hU(g,j,n&255),t[q+5|0]=r;break v;case 9:t[d+176|0]=8;q=d,r=w[Ff(d+23|0,d+176|0)|0],t[q+23|0]=r;break t;case 7:break w;default:break t}}g=w[(d+32|0)+f|0];j=w[e+5|0];n=g-(j>>>4|0)|0;t[(d+28|0)+f|0]=n;t[e+3|0]=3;j=j&15;t[(d+24|0)+f|0]=j;q=e,r=hU(j,n&255,g),t[q+5|0]=r}if(w[e+3|0]){break n}break s}t[e+5|0]=0}t[e+3|0]=0}j=w[(d+24|0)+f|0];if(!j){break n}n=(d+28|0)+f|0;g=w[n|0];if(g){t[(d+32|0)+f|0]=g;t[e|0]=g;t[e+5|0]=j;t[n|0]=0}t[e+3|0]=4;break n}t[e+3|0]=14;t[d+23|0]=9;break n}t[e+3|0]=13}f=f+1|0;if((f|0)!=4){continue}break}m=m+1|0;if((m|0)!=64){continue}break}}k=k+1|0;if(k>>>0<x[d+38>>1]){continue}break}}x:{y:{z:{A:{if(c&2){i=x[a+480190>>1];if(!i){break z}f=1;while(1){c=(B(f&65535,104)+a|0)+484380|0;if(v[c>>2]){ug(Sc(d+192|0,8,1,0,0),c,b);i=x[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(i&65535)>>>0){continue}break}break A}i=x[a+480190>>1]}if((i&65535)!=15){break z}b=gb-16|0;gb=b;c=Tb(b,26170);Dc(d+176|0,c);vb(c);gb=b+16|0;v[23048]=0;T(507,d+192|0,d+176|0,d+23|0);b=v[23048];v[23048]=0;f=1;if((b|0)!=1){break y}a=P()|0;O()|0;Hb(d+176|0);break e}f=0;v[23048]=0;Q(2,d+192|0,26183)|0;b=v[23048];v[23048]=0;if((b|0)==1){break x}}Eb(a+1300344|0,d+192|0);vb(d+192|0);if(f){Hb(d+176|0)}Zc(a+1300356|0,x[a+480190>>1]==15?26214:26218);v[a+1300404>>2]=2;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+192|0)}R(a|0);L()}f=1;break a}f=0}gb=d+336|0;return f|0}function Rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=gb-1824|0;gb=d;yc(b);g=gb-32|0;gb=g;j=d+1224|0;iV(g+24|0,j);i=xb(g+24|0);e=v[g+28>>2];k=v[g+24>>2];v[g+8>>2]=k;v[g+12>>2]=e;v[g>>2]=k;v[g+4>>2]=e;e=b;fc(g+16|0,e,g);k=xb(g+16|0);if((k|0)==(i|0)){Vb(e,xb(g+24|0))}gb=g+32|0;e=(i|0)==(k|0);if(!e){hV(j)}a:{if(!e){break a}if(!rV(d+1224|0)){break a}if(!XB(b,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];e=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=e;e=d+1232|0;h=v[e+4>>2];v[d+1208>>2]=v[e>>2];v[d+1212>>2]=h;Ed(a,1);e=a+1074308|0;Cg(e,83);Kb(e,84,1);Kb(e,85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Rc(b,20);j=a+480188|0;h=1;l=1;while(1){g=B(h,104)+a|0;i=g+484380|0;e=((h<<5)+a|0)+946300|0;YB(b,d+16|0,i,e,1);k=v[i>>2];b:{if(!w[lc(e,0)|0]){break b}c:{if(zd(e,24498,3)){if(zd(e,24502,3)){break c}}if(w[lc(e,5)|0]==58){break b}}l=0}if(Ib(w[d+44|0]|w[d+45|0]<<8)>>>0>=2){z=g+484384|0,A=Ib(w[d+42|0]|w[d+43|0]<<8),v[z>>2]=A;z=g+484388|0,A=Ib(w[d+42|0]|w[d+43|0]<<8)+(Ib(w[d+44|0]|w[d+45|0]<<8)<<1)|0,v[z>>2]=A;pk(i)}d:{if(Ib(w[d+38|0]|w[d+39|0]<<8)>>>0<=4999){if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0<1e4){break d}}v[d+1064>>2]=5;z=d,A=v[Vo(d+1196|0,d+1064|0)>>2],v[z+1196>>2]=A}f=f+k|0;h=h+1|0;if((h|0)!=16){continue}break}xV(b,d+1064|0);p=a+484360|0;Hr(Qb(p),d+1064|2,128);h=0;k=wV(b,Qb(p),w[d+1064|0],f,j,0);e=d+1064|1;if(k>>>0<2?!(w[e|0]|w[d+1064|0]):0){break a}if(Bf(b)+65536>>>0<(k<<10)+f>>>0){break a}if(!c){h=1;break a}if(!w[e|0]){t[e|0]=120}if(!zd(d+1200|0,24506,6)){t[e|0]=120}v[a+480204>>2]=125e4;e:{if(w[e|0]==120){break e}f=a;r=145364549.18032786/+(240-w[e|0]|0);f:{if(r<4294967296&r>=0){e=~~r>>>0;break f}e=0}v[f+480204>>2]=e;if(v[d+1196>>2]>=2){v[d+16>>2]=l?4:5;z=d,A=v[Vo(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A;break e}v[d+16>>2]=l?1:2;z=d,A=v[Vo(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;Mj(d+1048|0,3,d+1200|0);Fc(d+16|0,d+1048|0);Eb(a+1300308|0,d+16|0);vb(d+16|0);i=0;jh(a,0);s=v[b+8>>2];u[d+1046>>1]=0;g:{if(k){while(1){f=Qb(p);z=d,A=VB(Rb(f),Ub(f),d+1046|0),v[z+16>>2]=A;z=d,A=Ub(f),v[z+1048>>2]=A;f=Fb(d+16|0,d+1048|0);qV(b,d+16|0);if(f){i=UB(d+16|0,0)+i|0;if(i>>>0>512){break g}}j=0;f=0;o=0;while(1){y=pV(d+16|0,j);h=0;while(1){e=f;m=Dj(y,h);q=w[lc(m,2)|0]&15;g=w[lc(m,3)|0];f=0;h:{if(!(e&255)|(w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))){break h}f=e+1|0;if((f&255)>>>0<33){break h}v[d+1196>>2]=6}i:{j:{k:{switch(q-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1?g>>>0>=32:0){break j}m=(q|0)!=1;if(!(m|!g|g>>>0>2)){v[d+1048>>2]=2;z=d,A=v[Vo(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break i}if(m){break i}if((g|0)!=55){if((g|0)!=71){break i}if((e|0)<3){break j}break i}if((e|0)<=2){break j}break i;case 10:v[d+1196>>2]=6;break i;case 11:case 12:case 13:v[d+1048>>2]=2;z=d,A=v[Vo(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;if((q|0)!=13){break i}o=((g|j)!=0)+o|0;f=1;break i;case 14:break k;default:break i}}v[d+1048>>2]=3;z=d,A=v[Vo(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break i}v[d+1196>>2]=l}h=h+1|0;if((h|0)!=4){continue}break}j=j+1|0;if((j|0)!=64){continue}break}if((o-1&255)>>>0<2){v[d+1196>>2]=6}n=(o&255)+n|0;f=x[d+1046>>1]+1|0;u[d+1046>>1]=f;if(k>>>0>(f&65535)>>>0){continue}break}}if(!(v[d+1196>>2]!=6|k+32>>>0>=n>>>0)){v[d+1196>>2]=5}Rc(b,s);o=c&1;if(o){rg(a+484344|0,k)}if(k){m=a+484344|0;j=0;while(1){qV(b,d+16|0);l:{if(!o){break l}if(!Sg(m,j&65535,64)){break l}v[d+1048>>2]=0;n=0;while(1){q=Wc(Yb(m,j),n,0);p=pV(d+16|0,n);g=0;while(1){f=Dj(p,g);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+8>>2]=f;v[d+12>>2]=f;e=q+B(g,6)|0;kr(d+8|0,e);m:{n:{o:{p:{q:{r:{s:{t:{f=w[e+5|0];if(f){h=e+3|0;l=(d+1048|0)+g|0;i=w[e+3|0];if((i|0)!=14){break t}t[l|0]=0;break q}h=(d+1048|0)+g|0;t[h|0]=0;i=w[e+3|0];if(!i){break r}h=e+3|0;break s}l=w[l|0];if(!l){break s}if(l>>>0>=16){t[e+2|0]=3;t[e+4|0]=l>>>4;break s}t[e+2|0]=4;t[e+4|0]=l}u:{v:{switch(i-12|0){case 1:l=v[d+1196>>2];if((l|0)==6){break u}i=10;t[h|0]=10;break o;case 0:f=f&127;t[e+5|0]=f;i=12;break p;case 2:break q;case 3:break v;default:break p}}i=15;f=f&15;t[e+5|0]=f;break p}t[e+5|0]=0;break n}t[h|0]=0;break m}if(v[d+1196>>2]>3?f>>>0<=1:0){break n}i=10;t[h|0]=10;t[(d+1048|0)+g|0]=f}l=v[d+1196>>2]}if((l|0)>1){break n}w:{x:{y:{switch(i|0){case 0:if(f>>>0>2){break x}break;case 2:break w;case 1:break x;default:break y}}t[h|0]=0;break m}t[h|0]=1;break m}i=f&15;if(i){t[h|0]=2;t[e+5|0]=i;break m}if(!(f&240)){break m}t[h|0]=3;t[e+5|0]=f>>>4;break m}Mf(e)}g=g+1|0;if((g|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}j=j+1|0;if((k|0)!=(j|0)){continue}break}}h=24512;f=v[d+1196>>2];if(f>>>0<7){h=v[(f<<2)+25152>>2]}f=Tb(d+16|0,24777);Eb(a+1300344|0,f);vb(f);f=Tb(d+16|0,24790);Eb(a+1300356|0,f);vb(f);Zc(a+1300368|0,h);v[a+1300404>>2]=2;h=1;if(!(c&2)){break a}g=1;while(1){c=B(g,104)+a|0;f=c+484384|0;Vb(b,v[f>>2]);e=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-e;c=c+484388|0;v[c>>2]=v[c>>2]-e;Sc(d+16|0,8,1,1,0);ug(d+16|0,f,b);g=g+1|0;if((g|0)!=16){continue}break}break a}h=0}gb=d+1824|0;return h|0}function gL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-448|0;gb=e;a:{if(jk(b)){break a}g=w[jl(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;wl(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}Md(e+184|0);f=v[e+184>>2];Md(e+416|0);h=il(f,v[e+420>>2],b);Md(e+184|0);f=v[b>>2];g=v[b+4>>2];c:{d:{e:{f:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=wc(e+432|0,56371);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Kc(e+16|0,e+8|0)){a=aa(8)|0;v[23048]=0;c=Q(2061,e+416|0,c|0)|0;b=v[23048];v[23048]=0;g:{h:{i:{if((b|0)!=1){v[23048]=0;T(2045,e+184|0,57575,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break i}rc(a,e+184|0);d=0;v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break c}b=P()|0;O()|0;vb(e+184|0);break h}b=P()|0;O()|0;break g}b=P()|0;d=1;O()|0}vb(c);if(!d){break d}}ca(a|0);break d}if(!d){break f}d=aa(8)|0;v[23048]=0;f=Q(2061,e+384|0,b|0)|0;b=v[23048];v[23048]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){v[23048]=0;T(2045,e+400|0,57454,f|0);a=v[23048];v[23048]=0;if((a|0)==1){break r}v[23048]=0;S(2057,e+416|0,e+400|0);b=v[23048];v[23048]=0;a=1;if((b|0)==1){break q}v[23048]=0;c=Q(2061,e+368|0,c|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break p}v[23048]=0;T(2062,e+184|0,e+416|0,c|0);b=v[23048];v[23048]=0;a=1;if((b|0)==1){break o}rc(d,e+184|0);v[23048]=0;T(84,d|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(e+184|0);a=0;break n}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;a=1;O()|0;break m}b=P()|0;O()|0}vb(c)}vb(e+416|0)}vb(e+400|0)}vb(f)}if(!a){break d}ca(d|0);break d}v[e+360>>2]=f;v[e+364>>2]=g;d=wc(e+352|0,56371);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Kc(e+176|0,e+168|0)){a=aa(8)|0;v[23048]=0;c=Q(2061,e+416|0,c|0)|0;b=v[23048];v[23048]=0;s:{t:{u:{if((b|0)!=1){v[23048]=0;T(2045,e+184|0,57575,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break u}rc(a,e+184|0);d=0;v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break c}b=P()|0;O()|0;vb(e+184|0);break t}b=P()|0;O()|0;break s}b=P()|0;d=1;O()|0}vb(c);if(!d){break d}}ca(a|0);break d}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=wc(e+336|0,57333);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Kc(e+160|0,e+152|0)){b=v[c+4>>2];d=v[c>>2];v[e+328>>2]=d;v[e+332>>2]=b;f=wc(e+320|0,57526);g=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=g;g=v[f+4>>2];v[e+56>>2]=v[f>>2];v[e+60>>2]=g;if(Kc(e- -64|0,e+56|0)){v[a+52>>2]=0;break f}v[e+312>>2]=d;v[e+316>>2]=b;f=wc(e+304|0,57534);g=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=g;g=v[f+4>>2];v[e+40>>2]=v[f>>2];v[e+44>>2]=g;if(Kc(e+48|0,e+40|0)){v[a+52>>2]=1;break f}v[e+296>>2]=d;v[e+300>>2]=b;b=wc(e+288|0,57543);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Kc(e+32|0,e+24|0)){v[a+52>>2]=2;break f}a=aa(8)|0;v[23048]=0;c=Q(2061,e+416|0,c|0)|0;b=v[23048];v[23048]=0;v:{w:{x:{if((b|0)!=1){v[23048]=0;T(2045,e+184|0,57637,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break x}rc(a,e+184|0);d=0;v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break c}b=P()|0;O()|0;vb(e+184|0);break w}b=P()|0;O()|0;break v}b=P()|0;d=1;O()|0}vb(c);if(!d){break d}}ca(a|0);break d}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=wc(e+272|0,57376);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Kc(e+144|0,e+136|0)){break f}d=v[c+4>>2];c=v[c>>2];v[e+264>>2]=c;v[e+268>>2]=d;b=wc(e+256|0,57548);f=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=f;f=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=f;b=0;y:{if(Kc(e+128|0,e+120|0)){break y}v[e+248>>2]=c;v[e+252>>2]=d;b=wc(e+240|0,57553);f=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=f;f=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=f;b=1;if(Kc(e+112|0,e+104|0)){break y}v[e+232>>2]=c;v[e+236>>2]=d;b=wc(e+224|0,57559);f=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=f;f=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=f;b=2;if(Kc(e+96|0,e+88|0)){break y}v[e+216>>2]=c;v[e+220>>2]=d;b=wc(e+208|0,57570);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Kc(e+80|0,e+72|0)){break y}a=aa(8)|0;v[23048]=0;c=Q(91,e+184|0,57662)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break f}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=wK(v[a+56>>2]),v[i+204>>2]=j;if(!By(e+184|0,v[b>>2]+24648|0)){break f}Hz(v[b>>2],e+184|0)}gb=e+448|0;return}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function Wx(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0;h=gb-80|0;gb=h;v[h+76>>2]=b;z=h+55|0;s=h+56|0;b=0;a:{b:{c:while(1){d:{if((q|0)<0){break d}if((2147483647-q|0)<(b|0)){v[115529]=61;q=-1;break d}q=b+q|0}e:{f:{j=v[h+76>>2];b=j;i=w[b|0];if(i){while(1){g:{i=i&255;h:{if(!i){i=b;break h}if((i|0)!=37){break g}i=b;while(1){if(w[b+1|0]!=37){break h}k=b+2|0;v[h+76>>2]=k;i=i+1|0;l=w[b+2|0];b=k;if((l|0)==37){continue}break}}b=i-j|0;if(a){xf(a,j,b)}if(b){continue c}k=h;i=!Lh(t[v[h+76>>2]+1|0]);b=v[h+76>>2];i:{if(!(i|w[b+2|0]!=36)){r=t[b+1|0]-48|0;y=1;b=b+3|0;break i}r=-1;b=b+1|0}v[k+76>>2]=b;k=0;m=t[b|0];i=m-32|0;j:{if(i>>>0>31){break j}i=1<<i;if(!(i&75913)){break j}while(1){k:{k=b+1|0;v[h+76>>2]=k;m=t[b+1|0];b=m-32|0;if(b>>>0>=32){break k}b=1<<b;if(!(b&75913)){break k}i=b|i;b=k;continue}break}b=k;k=i}l:{if((m|0)==42){i=h;m:{n:{if(!Lh(t[b+1|0])){break n}b=v[h+76>>2];if(w[b+2|0]!=36){break n}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;p=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break m}if(y){break b}y=0;p=0;if(a){b=v[c>>2];v[c>>2]=b+4;p=v[b>>2]}b=v[h+76>>2]+1|0}v[i+76>>2]=b;if((p|0)>-1){break l}p=0-p|0;k=k|8192;break l}p=fJ(h+76|0);if((p|0)<0){break b}b=v[h+76>>2]}n=-1;o:{if(w[b|0]!=46){break o}if(w[b+1|0]==42){p:{if(!Lh(t[b+2|0])){break p}b=v[h+76>>2];if(w[b+3|0]!=36){break p}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;n=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;v[h+76>>2]=b;break o}if(y){break b}if(a){b=v[c>>2];v[c>>2]=b+4;n=v[b>>2]}else{n=0}b=v[h+76>>2]+2|0;v[h+76>>2]=b;break o}v[h+76>>2]=b+1;n=fJ(h+76|0);b=v[h+76>>2]}i=0;while(1){x=i;o=-1;if(t[b|0]-65>>>0>57){break a}m=b+1|0;v[h+76>>2]=m;i=t[b|0];b=m;i=w[(i+B(x,58)|0)+71375|0];if(i-1>>>0<8){continue}break}q:{r:{if((i|0)!=19){if(!i){break a}if((r|0)>=0){v[(r<<2)+e>>2]=i;b=(r<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break r}if(!a){break e}eJ(h- -64|0,i,c,g);m=v[h+76>>2];break q}if((r|0)>-1){break a}}b=0;if(!a){continue c}}l=k&-65537;i=k&8192?l:k;o=0;r=71421;k=s;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{b=t[m-1|0];b=x?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break s;case 9:case 13:case 14:case 15:break t;case 27:break y;case 12:case 17:break B;case 23:break C;case 0:case 32:break D;case 24:break E;case 22:break F;case 29:break G;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break f;default:break H}}I:{switch(b-65|0){case 0:case 4:case 5:case 6:break t;case 2:break w;case 1:case 3:break f;default:break I}}if((b|0)==83){break x}break f}l=v[h+64>>2];j=v[h+68>>2];r=71421;break A}b=0;J:{switch(x&255){case 0:v[v[h+64>>2]>>2]=q;continue c;case 1:v[v[h+64>>2]>>2]=q;continue c;case 2:i=v[h+64>>2];v[i>>2]=q;v[i+4>>2]=q>>31;continue c;case 3:u[v[h+64>>2]>>1]=q;continue c;case 4:t[v[h+64>>2]]=q;continue c;case 6:v[v[h+64>>2]>>2]=q;continue c;case 7:break J;default:continue c}}i=v[h+64>>2];v[i>>2]=q;v[i+4>>2]=q>>31;continue c}n=n>>>0>8?n:8;i=i|8;b=120}m=s;C=b&32;x=v[h+68>>2];j=x;l=v[h+64>>2];if(j|l){while(1){m=m-1|0;t[m|0]=C|w[(l&15)+71904|0];x=j;j=j>>>4|0;l=(x&15)<<28|l>>>4;if(l|j){continue}break}}j=m;if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break z}r=(b>>>4|0)+71421|0;o=2;break z}b=s;m=v[h+68>>2];j=m;l=v[h+64>>2];if(j|l){while(1){b=b-1|0;t[b|0]=l&7|48;m=j;j=j>>>3|0;l=(m&7)<<29|l>>>3;if(l|j){continue}break}}j=b;if(!(i&8)){break z}b=s-j|0;n=(b|0)<(n|0)?n:b+1|0;break z}b=v[h+68>>2];j=b;l=v[h+64>>2];if((b|0)<-1?1:(b|0)<=-1){j=0-(j+((l|0)!=0)|0)|0;l=0-l|0;v[h+64>>2]=l;v[h+68>>2]=j;o=1;r=71421;break A}if(i&2048){o=1;r=71422;break A}o=i&1;r=o?71423:71421}j=Xn(l,j,s)}i=(n|0)>-1?i&-65537:i;b=v[h+68>>2];l=b;m=v[h+64>>2];if(!(!!(b|m)|n)){n=0;j=s;break f}b=!(l|m)+(s-j|0)|0;n=(b|0)<(n|0)?n:b;break f}b=v[h+64>>2];j=b?b:71431;b=kt(j,0,n);k=b?b:j+n|0;i=l;n=b?b-j|0:n;break f}k=v[h+64>>2];if(n){break v}b=0;bg(a,32,p,0,i);break u}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];v[h+64>>2]=h+8;n=-1;k=h+8|0}b=0;K:{while(1){j=v[k>>2];if(!j){break K}j=_I(h+4|0,j);l=(j|0)<0;if(!(l|j>>>0>n-b>>>0)){k=k+4|0;b=b+j|0;if(n>>>0>b>>>0){continue}break K}break}o=-1;if(l){break a}}bg(a,32,p,b,i);if(!b){b=0;break u}k=0;m=v[h+64>>2];while(1){j=v[m>>2];if(!j){break u}j=_I(h+4|0,j);k=j+k|0;if((k|0)>(b|0)){break u}xf(a,h+4|0,j);m=m+4|0;if(b>>>0>k>>>0){continue}break}}bg(a,32,p,b,i^8192);b=(b|0)<(p|0)?p:b;continue c}b=kb[f|0](a,A[h+64>>3],p,n,i,b)|0;continue c}t[h+55|0]=v[h+64>>2];n=1;j=z;i=l;break f}k=b+1|0;v[h+76>>2]=k;i=w[b+1|0];b=k;continue}}o=q;if(a){break a}if(!y){break e}b=1;while(1){a=v[(b<<2)+e>>2];if(a){eJ((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break a}break}o=1;if(b>>>0>9){break a}while(1){o=1;b=b+1|0;if((b|0)==10){break a}o=-1;if(!v[(b<<2)+e>>2]){continue}break}break a}l=k-j|0;m=(l|0)>(n|0)?l:n;k=m+o|0;b=(k|0)>(p|0)?k:p;bg(a,32,b,k,i);xf(a,r,o);bg(a,48,b,k,i^65536);bg(a,48,m,l,0);xf(a,j,l);bg(a,32,b,k,i^8192);continue}break}o=0;break a}o=-1}gb=h+80|0;return o}function BJ(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),v=0,w=0,x=0,y=C(0),A=0,D=0,E=0,F=C(0),G=C(0),H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0,R=0;if((d|0)>=1){while(1){A=B(v,2304)+b|0;q=c;k=0;s=gb-128|0;while(1){l=A+(k<<2)|0;j=s;o=0;while(1){i=z[B(31-o|0,72)+l>>2];w=B(o,72)+l|0;h=z[w>>2];m=C(i+h);n=z[w+1152>>2];t=z[B(15-o|0,72)+l>>2];y=C(n+t);z[j>>2]=m+y;w=B(o,12);i=C(z[w+68244>>2]*C(h-i));h=C(z[w+68240>>2]*C(t-n));z[j+64>>2]=i+h;n=z[w+68248>>2];z[j+32>>2]=n*C(m-y);z[j+96>>2]=C(i-h)*n;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=1;j=s;while(1){m=z[j+28>>2];n=z[j>>2];i=C(m+n);t=z[j+16>>2];y=z[j+12>>2];h=C(t+y);F=C(i+h);G=z[j+24>>2];J=z[j+4>>2];K=C(G+J);L=z[j+20>>2];M=z[j+8>>2];N=C(L+M);O=C(K+N);z[j>>2]=F+O;z[j+16>>2]=C(F-O)*C(.7071067690849304);i=C(i-h);h=C(C(i+C(K-N))*C(.7071067690849304));z[j+24>>2]=C(i-h)*C(1.3065630197525024);z[j+8>>2]=C(h+i)*C(.5411961078643799);h=C(J-G);F=C(M-L);G=C(C(h+F)*C(.7071067690849304));i=C(n-m);m=C(G+i);h=C(i+h);n=C(C(C(y-t)+F)+C(h*C(-.1989123672246933)));h=C(C(n*C(.3826834261417389))+h);z[j+28>>2]=C(m-h)*C(2.562915563583374);z[j+4>>2]=C(h+m)*C(.509795606136322);h=C(n+C(h*C(-.1989123672246933)));i=C(i-G);z[j+20>>2]=C(h+i)*C(.8999761939048767);z[j+12>>2]=C(i-h)*C(.601344883441925);if((o|0)!=4){j=j+32|0;o=o+1|0;continue}break}o=0;i=z[s+32>>2];h=z[s+96>>2];n=z[s+64>>2];while(1){j=l;z[j>>2]=z[s+(o<<2)>>2];o=o+1|0;l=s+(o<<2)|0;m=z[l+96>>2];t=C(m+h);z[j+72>>2]=t+n;h=z[l+32>>2];z[j+144>>2]=h+i;n=z[l- -64>>2];z[j+216>>2]=n+t;l=j+288|0;i=h;h=m;if((o|0)!=7){continue}break}z[j+288>>2]=z[s+28>>2];i=z[s+124>>2];z[j+360>>2]=i+z[s+92>>2];h=z[s+60>>2];z[j+504>>2]=i;z[j+432>>2]=h;k=k+1|0;if((q|0)!=(k|0)){continue}break}v=v+1|0;if((v|0)!=(d|0)){continue}break}}I=hc(f,a,3840);P=d<<5;v=0;while(1){l=gb-32|0;gb=l;o=(v<<8)+I|0;w=(v<<2)+b|0;z[o+4080>>2]=z[w+1152>>2];j=d;f=j-1|0;A=w+B(f,2304)|0;z[o+4084>>2]=z[A+1152>>2];z[o+4088>>2]=z[w>>2];z[o+4092>>2]=z[A>>2];z[o+4336>>2]=z[w+1156>>2];z[o+4340>>2]=z[A+1156>>2];z[o+4344>>2]=z[w+4>>2];z[o+4348>>2]=z[A+4>>2];D=(B(v,P)<<1)+e|0;E=D+(f<<1)|0;ot(E,j,o+244|0);f=j<<6;ot(f+E|0,j,o+500|0);ot(D,j,o+240|0);ot(f+D|0,j,o+496|0);H=o+3840|0;q=68336;f=14;while(1){s=f;g=f<<4;k=g+H|0;p=B(31-f|0,72);m=z[p+w>>2];z[k>>2]=m;z[(g|4)+H>>2]=z[p+A>>2];p=p|4;z[(g|8)+H>>2]=z[p+w>>2];z[(g|12)+H>>2]=z[p+A>>2];p=B(f,72);r=p+76|0;z[k+256>>2]=z[r+w>>2];z[k+260>>2]=z[r+A>>2];p=p+72|0;z[k-248>>2]=z[p+w>>2];z[k-244>>2]=z[p+A>>2];i=z[q>>2];p=g+o|0;t=z[p>>2];h=z[q+4>>2];n=C(C(m*i)-C(t*h));z[l+16>>2]=n;m=C(C(t*i)+C(m*h));z[l>>2]=m;r=f<<2;f=1;while(1){g=f<<2;t=z[g+k>>2];y=z[g+p>>2];z[g+(l+16|0)>>2]=C(t*i)-C(y*h);z[g+l>>2]=C(y*i)+C(t*h);f=f+1|0;if((f|0)!=4){continue}break}k=(r<<2)+H|0;p=k-3584|0;r=k-256|0;i=z[q+12>>2];h=z[q+8>>2];f=0;while(1){g=f<<2;t=z[g+p>>2];y=z[g+r>>2];z[g+(l+16|0)>>2]=C(C(t*i)-C(y*h))+n;z[g+l>>2]=C(C(t*h)+C(y*i))+m;f=f+1|0;if((f|0)!=4){g=f<<2;n=z[g+(l+16|0)>>2];m=z[g+l>>2];continue}break}p=k-3328|0;r=k-512|0;i=z[q+20>>2];h=z[q+16>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=k-3072|0;r=k-768|0;i=z[q+28>>2];h=z[q+24>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(m*i)-C(n*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=k-2816|0;r=k-1024|0;i=z[q+36>>2];h=z[q+32>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=k-2560|0;r=k-1280|0;i=z[q+44>>2];h=z[q+40>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(m*i)-C(n*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=k-2304|0;r=k-1536|0;i=z[q+52>>2];h=z[q+48>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=k-2048|0;p=k-1792|0;i=z[q+60>>2];h=z[q+56>>2];f=0;while(1){k=f<<2;r=k+l|0;m=z[g+k>>2];n=z[k+p>>2];z[r>>2]=C(C(m*h)+C(n*i))+z[r>>2];k=k+(l+16|0)|0;z[k>>2]=C(C(m*i)-C(n*h))+z[k>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(j,15-s|0)<<1;Q=f+E|0,R=kj(z[l+20>>2]),u[Q>>1]=R;k=B(j,s+17|0)<<1;Q=k+E|0,R=kj(z[l+4>>2]),u[Q>>1]=R;Q=f+D|0,R=kj(z[l+16>>2]),u[Q>>1]=R;Q=k+D|0,R=kj(z[l>>2]),u[Q>>1]=R;f=B(j,47-s|0)<<1;Q=f+E|0,R=kj(z[l+28>>2]),u[Q>>1]=R;k=B(j,s+49|0)<<1;Q=k+E|0,R=kj(z[l+12>>2]),u[Q>>1]=R;Q=f+D|0,R=kj(z[l+24>>2]),u[Q>>1]=R;Q=k+D|0,R=kj(z[l+8>>2]),u[Q>>1]=R;f=s-1|0;q=q- -64|0;if(s){continue}break}gb=l+32|0;v=v+2|0;if((v|0)<(c|0)){continue}break}b=c<<6;a:{if((d|0)==1){v=0;while(1){z[(v<<2)+a>>2]=z[(b+v<<2)+I>>2];c=v>>>0<958;v=v+2|0;if(c){continue}break}break a}hc(a,(b<<2)+I|0,3840)}}function dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-160|0;gb=d;yc(c);a:{b:{c:{d:{e:{if(!(!Dr(c,d+144|0)|v[d+144>>2]!=1297239878|((w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))!=1146437965?!(v[d+152>>2]==1482052408|(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))==1448293937):0))){n=Ni(d+120|0,c);v[23048]=0;S(1187,d+104|0,n|0);c=v[23048];v[23048]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{if((c|0)!=1){v[23048]=0;j=U(270,d+80|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break n}l=Sc(d+76|0,8,1,1,0);if((w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))!=1146437965){break k}v[23048]=0;T(1188,d+56|0,d+104|0,1296581714);c=v[23048];v[23048]=0;if((c|0)==1){break m}v[23048]=0;T(1188,d+32|0,d+104|0,1296318804);c=v[23048];v[23048]=0;if((c|0)==1){break j}id(j,d+32|0);yb(d+32|0);v[23048]=0;c=U(1189,d+56|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break j}if(!c){break i}v[23048]=0;c=U(328,j|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break j}if(!c){break i}v[23048]=0;f=U(474,d+56|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break j}v[23048]=0;i=U(465,d+56|0)|0;c=v[23048];v[23048]=0;o:{if((c|0)==1){break o}v[23048]=0;Q(370,d+56|0,2)|0;c=v[23048];v[23048]=0;if((c|0)==1){break o}v[23048]=0;c=U(474,d+56|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break l}}break j}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}v[23048]=0;S(1190,d+32|0,d+56|0);g=v[23048];v[23048]=0;e=1;if((g|0)==1){break j}g=d+38|0;h=d+32|0;p:{if(!Ib(w[h|0]|w[h+1|0]<<8)){break p}k=dc(d+32|0);m=Df(d+32|0);c=(c>>>0)/(Ib(w[h|0]|w[h+1|0]<<8)>>>0)|0;if((Ib(w[k|0]|w[k+1|0]<<8)|0)!=(Ib(w[m|0]|w[m+1|0]<<8)+1|0)){break p}if((Ib(w[k|0]|w[k+1|0]<<8)|0)==2){Bp(l,2)}q:{if((i|0)!=16){if((i|0)!=8){break p}if(!Ib(w[g|0]|w[g+1|0]<<8)){tf(l,1);break q}if((Ib(w[g|0]|w[g+1|0]<<8)|0)==2){tf(l,18);break q}if((Ib(w[g|0]|w[g+1|0]<<8)|0)!=3){break p}tf(l,17);break q}if(Ib(w[g|0]|w[g+1|0]<<8)){break p}Li(l,16)}e=0}h=!e;break h}v[23048]=0;T(1188,d+56|0,d+104|0,1447576658);c=v[23048];v[23048]=0;r:{s:{t:{if((c|0)!=1){v[23048]=0;T(1188,d+32|0,d+104|0,1128808782);c=v[23048];v[23048]=0;if((c|0)==1){break t}v[23048]=0;T(1188,d+8|0,d+104|0,1112491097);c=v[23048];v[23048]=0;if((c|0)==1){break s}id(j,d+8|0);yb(d+8|0);v[23048]=0;e=U(328,j|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break s}c=0;f=0;u:{if(!e){break u}v[23048]=0;e=U(328,d+56|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break s}c=0;f=0;if(!e){break u}v[23048]=0;e=Q(1191,d+56|0,d+8|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break s}c=0;f=0;if(!e){break u}c=w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24);v[23048]=0;e=U(474,d+32|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break s}g=(c|0)!=1482052408;if(g){Sc(d+4|0,16,1,0,0);v[d+76>>2]=v[d+4>>2]}if((e|0)==6){Bp(l,3)}c=d+8|0;h=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=d+8|4;i=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=d+20|0;c=Ib(w[c|0]|w[c+1|0]<<8);f=d+24|0;k=Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[23048]=0;m=U(247,j|0)|0;f=v[23048];v[23048]=0;o=1;if((f|0)==1){break s}f=B((e|0)==6?2:1,g?2:1);g=(h>>>0)/(f>>>0)|0;i=(i>>>0)/(f>>>0)|0;f=(m>>>0)/(f>>>0)|0}yb(d+32|0);yb(d+56|0);e=0;if(o){break g}break f}e=P()|0;O()|0;break c}e=P()|0;O()|0;break r}e=P()|0;O()|0;yb(d+32|0)}yb(d+56|0);break c}e=P()|0;O()|0;yb(d+56|0);break c}c=0;h=0}yb(d+56|0);k=0;i=0;g=0;e=0;if(!h){break f}}v[23048]=0;Q(1167,a|0,b|0)|0;e=v[23048];v[23048]=0;v:{w:{if((e|0)!=1){v[23048]=0;h=B(b,104)+a|0;e=h+484380|0;S(372,e|0,0);m=v[23048];v[23048]=0;if((m|0)==1){break w}v[e>>2]=f;i=g+i|0;v[h+484388>>2]=i;v[h+484384>>2]=g;if(!(f>>>0<i>>>0|i>>>0<=g+4>>>0)){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]|2}f=B(b,104)+a|0;v[f+484404>>2]=c?c:22050;c=k>>>8|0;u[f+484410>>1]=(k&16776960)>>>0>65536?256:c&65535?c:256;c=v[a+480180>>2];v[23048]=0;T(1169,e|0,32,c|0);c=v[23048];v[23048]=0;x:{y:{z:{A:{if((c|0)!=1){v[23048]=0;T(1188,d+56|0,d+104|0,1312902469);c=v[23048];v[23048]=0;if((c|0)==1){break A}v[23048]=0;c=U(328,d+56|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break e}if(!c){break z}v[23048]=0;c=U(247,d+56|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break e}v[23048]=0;W(374,d+56|0,((b<<5)+a|0)+946300|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break y}break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}v[23048]=0;c=Q(91,d+32|0,30916)|0;f=v[23048];v[23048]=0;if((f|0)==1){break x}v[23048]=0;Q(354,((b<<5)+a|0)+946300|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break v}vb(c)}v[23048]=0;W(384,l|0,e|0,j|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;Sh(e,a,0);a=v[23048];v[23048]=0;if((a|0)==1){break e}yb(d+56|0);e=1;break f}e=P()|0;O()|0;break d}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(c);break d}yb(j);Cd(d+104|0);yb(n)}gb=d+160|0;return e|0}e=P()|0;O()|0}yb(d+56|0)}yb(j)}Cd(d+104|0)}yb(n);R(e|0);L()}function Cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;d=gb-752|0;gb=d;yc(b);f=gb-32|0;gb=f;h=d+144|0;oU(f+24|0,h);i=xb(f+24|0);e=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=e;v[f>>2]=g;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);g=xb(f+16|0);if((g|0)==(i|0)){Vb(e,xb(f+24|0))}gb=f+32|0;e=(g|0)==(i|0);if(!e){nU(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(!e){break m}if(!qU(d+144|0)){break m}if(!Nb(b,Xc(pU(d+144|0),jb))){break m}if(!c){o=1;break m}Ed(a,262144);Ak(d+104|0,2,d+144|0);Fc(d+24|0,d+104|0);Eb(a+1300308|0,d+24|0);vb(d+24|0);e=Tb(d+24|0,25920);Eb(a+1300344|0,e);vb(e);e=Tb(d+24|0,25932);Eb(a+1300356|0,e);vb(e);e=gb-16|0;gb=e;f=Tb(e,25936);Dc(d+104|0,f);vb(f);gb=e+16|0;t[d+8|0]=w[d+174|0];e=w[d+173|0];v[23048]=0;t[d+127|0]=e;S(909,d+128|0,d+127|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}v[23048]=0;Y(433,d+24|0,d+104|0,d+8|0,d+128|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}Eb(a+1300368|0,d+24|0);vb(d+24|0);vb(d+128|0);Hb(d+104|0);v[a+480208>>2]=12;v[a+1300404>>2]=5;u[a+480188>>1]=w[d+182|0]|w[d+183|0]<<8;u[d+24>>1]=w[d+178|0]|w[d+179|0]<<8;u[d+104>>1]=3999;A=a,C=x[Vc(d+24|0,d+104|0)>>1],u[A+480190>>1]=C;wX(Qb(a+484360|0),d+240|0,w[d+176|0]|w[d+177|0]<<8);if(x[a+480188>>1]){e=0;while(1){f=(e<<5)+a|0;We(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}td(d+104|0,b,B(w[d+178|0]|w[d+179|0]<<8,80));if(x[a+480190>>1]){i=c&2;h=d+72|0;e=0;while(1){v[23048]=0;S(910,d+104|0,d+24|0);f=v[23048];v[23048]=0;if((f|0)==1){break l}v[23048]=0;Ak(d+8|0,2,h);f=v[23048];v[23048]=0;n:{o:{p:{if((f|0)==1){break p}v[23048]=0;S(398,d+128|0,d+8|0);f=v[23048];v[23048]=0;if((f|0)==1){break p}v[23048]=0;e=e+1|0;Q(354,((e<<5)+a|0)+946300|0,d+128|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break o}vb(d+128|0);v[23048]=0;f=(B(e,104)+a|0)+484380|0;T(911,d+128|0,d+24|0,f|0);g=v[23048];v[23048]=0;q:{if((g|0)==1){break q}if(!i|!v[f>>2]){break n}g=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[23048]=0;g=Q(248,b|0,g|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break q}if(!g){break n}v[23048]=0;W(384,d+128|0,f|0,b|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){break n}}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+128|0);break e}if(x[a+480190>>1]>e>>>0){continue}break}}o=1;r:{if(!(c&1)){break r}c=w[d+180|0]|w[d+181|0]<<8;g=0;v[23048]=0;l=a+484344|0;S(385,l|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break k}if(!(w[d+180|0]|w[d+181|0]<<8)){break r}p=d+24|4;q=d+24|2;r=d+24|5;s=d+24|3;y=d+24|1;while(1){v[23048]=0;c=W(386,l|0,g&65535,64)|0;e=v[23048];v[23048]=0;if((e|0)==1){break j}s:{if(!c){break s}c=(g<<1)+d|0;e=c+496|0;if(!(w[e|0]|w[e+1|0]<<8)){break s}c=w[c+496|0]|w[c+497|0]<<8;v[23048]=0;c=Q(248,b|0,c<<4)|0;e=v[23048];v[23048]=0;if((e|0)==1){break j}if(!c){break s}m=0;c=Yb(l,g);v[23048]=0;c=Wc(c,0,0);e=v[23048];v[23048]=0;if((e|0)==1){break f}while(1){v[23048]=0;e=Q(250,b|0,1)|0;f=v[23048];v[23048]=0;t:{u:{v:{if((f|0)!=1){if(!e){break s}v[23048]=0;k=U(373,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break v}if(k){break u}m=m+1|0;c=B(x[a+480188>>1],6)+c|0;break t}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}u[d+28>>1]=0;v[d+24>>2]=0;e=k&31;i=B(e,6)+c|0;n=Pi(d+24|0);h=e>>>0<x[a+480188>>1];w:{if(!(k&32)){break w}v[23048]=0;S(452,d+128|0,b|0);e=v[23048];v[23048]=0;if((e|0)==1){break i}f=rd(d+128|0);j=h?i:d+24|0;e=w[d+128|0];t[j|0]=e;t[(h?i+1|0:y)|0]=w[f|0];x:{if(e){if((e|0)==254){break x}if(e>>>0<121){break w}}e=0}t[j|0]=e}y:{if(!(k&64)){break y}v[23048]=0;S(452,d+128|0,b|0);e=v[23048];v[23048]=0;if((e|0)==1){break h}z=rd(d+128|0);e=h?i+3|0:s;f=w[d+128|0];t[e|0]=f;j=h?i+5|0:r;t[j|0]=w[z|0];z:{A:{B:{if(f>>>0<=15){v[23048]=0;Mf(h?i:n);f=v[23048];v[23048]=0;if((f|0)!=1){break B}a=P()|0;O()|0;break e}if(f>>>0>23){break z}n=e;e=w[f+25938|0];t[n|0]=e;break A}e=w[e|0]}e=e&255;if((e|0)!=23){if((e|0)!=9){break y}e=w[j|0];C:{D:{if(e>>>0>=136){f=e&127;break D}f=128;if(e>>>0<129){break C}}t[j|0]=f;e=f}t[j|0]=(B(e&127,255)>>>0)/127;break y}v[23048]=0;t[d+8|0]=64;e=$b(j,d+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){t[j|0]=w[e|0]<<1;break y}a=P()|0;O()|0;break e}t[e|0]=0}if(!(k&128)){break t}t[(h?i+2|0:q)|0]=1;v[23048]=0;e=U(373,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break g}t[(h?i+4|0:p)|0]=e}if(m>>>0<64){continue}break}}g=g+1|0;if(g>>>0<(w[d+180|0]|w[d+181|0]<<8)>>>0){continue}break}}yb(d+104|0)}gb=d+752|0;return o|0}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}yb(d+104|0);break a}a=P()|0;O()|0;vb(d+128|0);break b}a=P()|0;O()|0}Hb(d+104|0)}R(a|0);L()}function Nla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-224|0;gb=d;yc(b);a:{b:{c:{d:{e:{f:{if(!Dr(b,d+208|0)){break f}if(!oV(d+208|0)){break f}h=Ah(d+184|0);i=Jb(d+168|0);WC(d+104|0);v[23048]=0;f=Q(819,b|0,d+96|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}g:{if(!f){break g}f=d+96|4;g=Wb(Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))-4|0);t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=0;h:{i:{j:{while(1){e=Wb(Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))-8|0);t[f|0]=e;t[f+1|0]=e>>>8;t[f+2|0]=e>>>16;t[f+3|0]=e>>>24;k:{if(c){break k}e=d+96|0;if((Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0)!=1347699796){break k}g=1;break g}e=Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[23048]=0;T(341,d+16|0,b|0,e|0);e=v[23048];v[23048]=0;l:{m:{n:{o:{p:{if((e|0)!=1){v[23048]=0;e=U(328,d+16|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break o}if(e){break p}yb(d+16|0);break l}a=P()|0;O()|0;break a}e=d+96|0;e=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));if((e|0)<=1347699795){if((e|0)==1129139796){break n}if((e|0)!=1229866575){break m}v[23048]=0;k=Q(820,d+16|0,d+104|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break o}break m}if((e|0)!=1347699796){if((e|0)!=1447383635){break m}v[23048]=0;Q(370,d+16|0,4)|0;e=v[23048];v[23048]=0;if((e|0)==1){break o}v[23048]=0;e=U(821,d+16|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break o}if(!e){break m}if(Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<7){break m}e=Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[23048]=0;T(822,d+16|0,i|0,e-6|0);e=v[23048];v[23048]=0;if((e|0)==1){break o}break m}v[23048]=0;g=W(823,a|0,d+16|0,c|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break m}}a=P()|0;O()|0;yb(d+16|0);break a}tw(h,d+16|0)}yb(d+16|0);v[23048]=0;e=Q(819,b|0,d+96|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break j}if(e){continue}}break}if(hd(i)){v[23048]=0;b=Q(2,d+16|0,24890)|0;c=v[23048];v[23048]=0;if((c|0)==1){break i}Eb(i,b);vb(b)}if(!(g&k&1)){break h}b=d+146|0;b=Ib(w[b|0]|w[b+1|0]<<8);v[23048]=0;c=b&256;W(458,a+1074308|0,5,!c|0)|0;b=v[23048];v[23048]=0;q:{r:{s:{if((b|0)!=1){b=d+142|0;if(Ib(w[b|0]|w[b+1|0]<<8)){u[d+16>>1]=64;b=Ib(w[b|0]|w[b+1|0]<<8);v[23048]=0;u[d+80>>1]=b;b=Vc(d+16|0,d+80|0);f=v[23048];v[23048]=0;if((f|0)==1){break s}v[a+480228>>2]=x[b>>1]}b=d+144|0;if(!(!c|!Ib(w[b|0]|w[b+1|0]<<8))){l=a,m=B(Ib(w[b|0]|w[b+1|0]<<8),1e4),v[l+480204>>2]=m}if(w[d+104|0]){v[23048]=0;df(d+80|0,2,d+104|0);b=v[23048];v[23048]=0;if((b|0)==1){break r}v[23048]=0;S(398,d+16|0,d+80|0);b=v[23048];v[23048]=0;if((b|0)==1){break r}Eb(a+1300308|0,d+16|0);vb(d+16|0)}b=x[d+150>>1];u[d+78>>1]=b;u[d+14>>1]=b;if(!jr(d+14|0,1,12)){break h}b=x[d+148>>1];u[d+76>>1]=b;u[d+12>>1]=b;if(!jr(d+12|0,1,31)){break h}b=x[d+154>>1];u[d+74>>1]=b;u[d+10>>1]=b;if(!jr(d+10|0,0,23)){break h}b=x[d+156>>1];u[d+72>>1]=b;u[d+8>>1]=b;if(!jr(d+8|0,0,59)){break h}b=x[d+158>>1];u[d+70>>1]=b;u[d+6>>1]=b;if(jr(d+6|0,0,59)){break q}break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}b=Gr(d+16|0);c=d+152|0;l=b,m=Ib(w[c|0]|w[c+1|0]<<8),v[l+20>>2]=m;c=d+150|0;l=b,m=Ib(w[c|0]|w[c+1|0]<<8)-1|0,v[l+16>>2]=m;c=d+148|0;l=b,m=Ib(w[c|0]|w[c+1|0]<<8),v[l+12>>2]=m;c=d+154|0;l=b,m=Ib(w[c|0]|w[c+1|0]<<8),v[l+8>>2]=m;c=d+156|0;l=b,m=Ib(w[c|0]|w[c+1|0]<<8),v[l+4>>2]=m;c=d+158|0;l=b,m=Ib(w[c|0]|w[c+1|0]<<8),v[l>>2]=m;v[23048]=0;S(642,a+1300408|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(g&1){v[23048]=0;b=U(328,h|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}if(b){b=Jb(d+16|0);v[23048]=0;W(462,h|0,b|0,32)|0;c=v[23048];v[23048]=0;if((c|0)==1){break b}if(Br(b,24894)){v[23048]=0;T(13,d+80|0,2,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}Eb(a+1300320|0,d+80|0);vb(d+80|0)}v[23048]=0;c=U(824,h|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}if(!c){v[23048]=0;c=U(511,h|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}v[23048]=0;ga(517,a+1300332|0,h|0,c|0,40,0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break b}}vb(b)}v[23048]=0;b=Q(2,d+80|0,24909)|0;c=v[23048];v[23048]=0;if((c|0)==1){break e}v[23048]=0;T(693,d+16|0,b|0,i|0);c=v[23048];v[23048]=0;if((c|0)==1){break d}Eb(a+1300368|0,d+16|0);vb(d+16|0);vb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[23048]=0;a=a+1074308|0;W(458,a|0,84,1)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;W(458,a|0,83,1)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;W(458,a|0,85,1)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}}vb(i);yb(h)}gb=d+224|0;return g&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b)}vb(i);yb(h);R(a|0);L()}function sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=gb-208|0;gb=g;yc(b);a:{b:{c:{d:{e:{if(!NC(b,g+160|0)){break e}if(!nT(g+160|0)){break e}if(!c){h=1;break e}if(!Nb(b,Xc(mT(g+160|0),jb))){break e}Ed(a,128);df(g+144|0,2,g+175|0);Fc(g+72|0,g+144|0);Eb(a+1300308|0,g+72|0);vb(g+72|0);d=Tb(g+72|0,26832);Eb(a+1300344|0,d);vb(d);d=Tb(g+72|0,26845);Eb(a+1300356|0,d);vb(d);d=Tb(g+144|0,26849);v[23048]=0;T(980,g+72|0,d|0,v[(w[g+174|0]<<2)+26620>>2]);e=v[23048];v[23048]=0;h=1;if((e|0)==1){break b}Eb(a+1300368|0,g+72|0);vb(g+72|0);vb(d);v[a+480208>>2]=12;v[a+1300404>>2]=5;bB(a+1300332|0,b,w[g+207|0]<<5,32,0);y=a,z=Hd(b),u[y+480190>>1]=z;if(x[a+480190>>1]){j=1;while(1){f:{if(w[g+174|0]>=52){d=g+72|0;if(!_X(b,d)){_C(d)}break f}e=gb-48|0;gb=e;v[e+44>>2]=64;v[e+24>>2]=66;d=b;i=v[Gb(e+44|0,e+24|0)>>2];if(!Nb(d,i)){i=Bf(d)}f=g+72|0;Bv(e+24|0,f);k=_d(e+32|0,v[e+24>>2],i);l=v[k+4>>2];v[e+8>>2]=v[k>>2];v[e+12>>2]=l;fc(e+16|0,d,e+8|0);Bv(e+24|0,f);Pb(v[e+24>>2]+i|0,0,66-i|0);Vb(d,v[e+44>>2]);gb=e+48|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}i=gb-32|0;gb=i;e=(B(h,104)+a|0)+484380|0;wd(e,0);d=g+72|0;zk(i,2,d+32|0);Fc(i+16|0,i);v[23048]=0;Q(355,e+43|0,i+16|0)|0;f=v[23048];v[23048]=0;g:{if((f|0)!=1){vb(i+16|0);h:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break h}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[i+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);y=e,z=v[Gb(i+16|0,e)>>2],v[y+16>>2]=z;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=d- -64|0;if(w[f|0]|w[f+1|0]<<8){Jo(e,+((w[f|0]|w[f+1|0]<<8)<<16>>16)*25431315104166665e-22)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break h}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}gb=i+32|0;break g}a=P()|0;O()|0;vb(i+16|0);R(a|0);L()}df(g+56|0,2,g+72|0);Fc(g+144|0,g+56|0);v[23048]=0;Q(354,((h<<5)+a|0)+946300|0,g+144|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}vb(g+144|0);j=j+1|0;h=j&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}fp(Qb(a+484360|0),b,256,255,254);h=0;d=Hd(b);if(d>>>0>=127){break e}u[a+480188>>1]=d+1;d=Hd(b);r=d+1|0;if(x[a+480188>>1]){while(1){e=(h<<5)+a|0;We(e+480280|0);i=e+480284|0;i:{if(w[g+174|0]>=51){e=(Hd(b)<<4|8)&248;break i}e=h&1?192:64}u[i>>1]=e;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}l=a+484344|0;rg(l,r);h=0;j=0;while(1){e=j&65535;if(!Sg(l,e,64)){break e}j=j+1|0;if(d>>>0>e>>>0){continue}break}if(x[a+480188>>1]){while(1){i=Pi(g+72|0);n=0;while(1){if(Nb(b,5)){j=0;h=Wc(Yb(l,n),0,o&65535);while(1){s=64-j|0;m=w[g+174|0];f=gb-16|0;gb=f;p=1;d=i;q=d;e=b;k=Hd(e);if((k|0)==252){p=Hd(e);k=Hd(e)}t[q|0]=(k-1&255)>>>0<60?k+36|0:0;nn(f+8|0,e);e=rd(f+8|0);k=Df(f+8|0);q=Ri(f+8|0);t[d+1|0]=w[f+8|0];t[f+7|0]=w[e|0]&15;t[f+6|0]=w[e|0]>>>4;t[f+5|0]=w[k|0];t[f+4|0]=w[q|0];lT(f+7|0,f+5|0,m);lT(f+6|0,f+4|0,m);j:{k:{l:{m:{k=w[f+7|0];m=(k|0)!=10;e=w[f+6|0];if(!(m|(e|0)!=10)){t[f+7|0]=0;y=f,z=_o((w[f+4|0]|w[f+5|0]<<8)>>>6|0),t[y+5|0]=z;break m}if(!m){y=f,z=_o(w[f+5|0]<<2),t[y+5|0]=z;break m}if((e|0)==10){y=f,z=_o(w[f+4|0]<<2),t[y+4|0]=z;break m}if((e|0)!=(k|0)){break m}t[f+6|0]=0;break l}e=w[f+6|0];if((e|0)==13){break k}if(e){break j}k=w[f+7|0]}if((k&255)==13){break j}}th(f+7|0,f+6|0);th(f+5|0,f+4|0)}cz(f+6|0,f+4|0,f+7|0,f+5|0);oo(f,f+7|0,f+5|0,f+6|0,f+4|0);t[d+2|0]=w[f+7|0];t[d+4|0]=w[f+5|0];t[d+3|0]=w[f+6|0];t[d+5|0]=w[f+4|0];gb=f+16|0;e=j+p|0;j=e>>>0>64?s:p;if(j){while(1){d=v[g+72>>2];t[h|0]=d;t[h+1|0]=d>>>8;t[h+2|0]=d>>>16;t[h+3|0]=d>>>24;d=x[g+76>>1];t[h+4|0]=d;t[h+5|0]=d>>>8;h=B(x[a+480188>>1],6)+h|0;j=j-1|0;if(j){continue}break}j=e>>>0<64?e:64;if(j>>>0<64){continue}}break}n=n+1|0;if((r|0)!=(n|0)){continue}}break}o=o+1|0;if(x[a+480188>>1]>(o&65535)>>>0){continue}break}}e=x[a+480188>>1];d=g+8|0;i=av(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[23048]=0;T(982,i|0,e|0,0);e=v[23048];v[23048]=0;if((e|0)==1){a=P()|0;O()|0;Ee(i);R(a|0);L()}v[23048]=0;T(981,g+32|0,l|0,d|0);e=v[23048];v[23048]=0;h=1;if((e|0)==1){break d}Ee(g+32|0);Ee(d);if(!(c&2)|!x[a+480190>>1]){break e}j=1;while(1){c=B(j&65535,104)+a|0;ug(Sc(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);j=j+1|0;if(x[a+480190>>1]>=(j&65535)>>>0){continue}break}}gb=g+208|0;return h|0}h=P()|0;O()|0;Ee(d);break a}h=P()|0;O()|0;vb(g+144|0);break a}h=P()|0;O()|0;vb(d)}R(h|0);L()}function Dd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;l=gb-96|0;gb=l;p=c;u=(g&131071)<<15|f>>>17;j=i&65535;s=j;k=h;C=k<<15|g>>>17;n=(e^i)&-2147483648;o=e&65535;x=o;m=d;y=o;o=0;D=(j&131071)<<15|k>>>17;F=i>>>16&32767;M=e>>>16&32767;a:{b:{if(M-1>>>0<=32765){j=0;if(F-1>>>0<32766){break b}}q=e&2147483647;w=q;j=d;if(!(!j&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){z=d;n=e|32768;break a}e=i&2147483647;q=e;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;n=i|32768;b=f;c=g;break a}if(!(b|j|(w^2147418112|c))){if(!(d|f|(g|q))){n=2147450880;b=0;c=0;break a}n=n|2147418112;b=0;c=0;break a}if(!(d|f|(q^2147418112|g))){d=b|j;e=c|w;b=0;c=0;if(!(d|e)){n=2147450880;break a}n=n|2147418112;break a}if(!(b|j|(c|w))){b=0;c=0;break a}if(!(d|f|(g|q))){b=0;c=0;break a}if((w|0)==65535|w>>>0<65535){h=b;i=c;d=!(m|x);e=d<<6;j=E(d?b:m)+32|0;b=E(d?c:x);b=e+((b|0)==32?j:b)|0;Uf(l+80|0,h,i,m,x,b-15|0);m=v[l+88>>2];p=v[l+84>>2];y=v[l+92>>2];t=16-b|0;b=v[l+80>>2]}j=t;if(q>>>0>65535){break b}c=!(k|s);d=c<<6;e=E(c?f:k)+32|0;c=E(c?g:s);c=d+((c|0)==32?e:c)|0;i=c;Uf(l- -64|0,f,g,k,s,c-15|0);e=v[l+76>>2];c=e;h=v[l+72>>2];d=h;d=d<<15;e=v[l+68>>2];C=e>>>17|d;d=0;f=v[l+64>>2];u=d|((e&131071)<<15|f>>>17);D=(c&131071)<<15|h>>>17;j=(t-i|0)+16|0}t=j;d=u;c=b;s=0;q=Fpa(d,0,b,s);b=jb;G=b;e=f;A=e<<15&-32768;k=p;g=Fpa(A,0,k,0);f=g+q|0;e=jb+b|0;e=f>>>0<g>>>0?e+1|0:e;h=f;j=f;i=0;g=Fpa(c,s,A,B);f=i+g|0;b=j;j=j+jb|0;j=f>>>0<g>>>0?j+1|0:j;u=f;g=j;J=(b|0)==(j|0)&f>>>0<i>>>0|b>>>0>j>>>0;N=Fpa(d,r,k,H);K=jb;p=m;f=Fpa(A,B,m,0);b=f+N|0;j=jb+K|0;O=b;m=Fpa(C,0,c,s);i=b+m|0;b=b>>>0<f>>>0?j+1|0:j;f=b+jb|0;w=i;f=i>>>0<m>>>0?f+1|0:f;x=f;j=f;f=(e|0)==(G|0)&h>>>0<q>>>0|e>>>0<G>>>0;h=e+w|0;j=f+j|0;q=h;j=h>>>0<e>>>0?j+1|0:j;m=j;e=h;h=j;Q=Fpa(d,r,p,P);G=jb;f=A;I=y|65536;A=o;i=Fpa(f,B,I,o);f=i+Q|0;j=jb+G|0;j=f>>>0<i>>>0?j+1|0:j;R=f;B=Fpa(C,S,k,H);i=f+B|0;o=j;f=j+jb|0;f=i>>>0<B>>>0?f+1|0:f;L=i;D=D&2147483647|-2147483648;i=Fpa(c,s,D,0);c=L+i|0;s=f;j=f+jb|0;B=c;c=c>>>0<i>>>0?j+1|0:j;y=J;i=0;f=i+e|0;j=h+B|0;J=f;h=f;e=y+f|0;y=f>>>0<i>>>0?j+1|0:j;f=y;f=e>>>0<h>>>0?f+1|0:f;h=e;i=f;t=(t+(F+M|0)|0)-16383|0;f=Fpa(p,P,C,S);e=jb;r=Fpa(d,r,I,A);d=r+f|0;j=jb+e|0;j=d>>>0<r>>>0?j+1|0:j;r=d;f=(e|0)==(j|0)&f>>>0>d>>>0|e>>>0>j>>>0;e=j;F=f;f=Fpa(D,T,k,H);d=f+d|0;j=jb+j|0;j=d>>>0<f>>>0?j+1|0:j;f=d;d=j;k=(j|0)==(e|0)&f>>>0<r>>>0|e>>>0>j>>>0;j=F+k|0;e=0;e=j>>>0<k>>>0?1:e;r=f;k=d;F=j;f=(b|0)==(x|0)&w>>>0<O>>>0|b>>>0>x>>>0;b=f+((b|0)==(K|0)&N>>>0>O>>>0|b>>>0<K>>>0)|0;j=0;j=b>>>0<f>>>0?1:j;f=b;b=r+f|0;j=d+j|0;j=b>>>0<f>>>0?j+1|0:j;H=b;d=j;j=(j|0)==(k|0)&b>>>0<r>>>0|j>>>0<k>>>0;b=F+j|0;f=e;f=b>>>0<j>>>0?f+1|0:f;e=Fpa(D,T,I,A);b=e+b|0;j=jb+f|0;r=b;e=b>>>0<e>>>0?j+1|0:j;k=Fpa(D,T,p,P);f=jb;p=Fpa(C,S,I,A);b=p+k|0;j=jb+f|0;j=b>>>0<p>>>0?j+1|0:j;p=b;b=j;j=(f|0)==(j|0)&k>>>0>p>>>0|f>>>0>j>>>0;k=b+r|0;e=e+j|0;e=k>>>0<b>>>0?e+1|0:e;r=k;k=0;b=k+H|0;j=d+p|0;j=b>>>0<k>>>0?j+1|0:j;f=j;k=(d|0)==(j|0)&b>>>0<H>>>0|d>>>0>j>>>0;d=r+k|0;j=e;C=d;d=d>>>0<k>>>0?j+1|0:j;p=b;k=f;f=(o|0)==(s|0)&R>>>0>L>>>0|o>>>0>s>>>0;e=f+((o|0)==(G|0)&Q>>>0>R>>>0|o>>>0<G>>>0)|0;f=e;e=f+((c|0)==(s|0)&B>>>0<L>>>0|c>>>0<s>>>0)|0;f=e;b=c+b|0;e=f+k|0;e=b>>>0<c>>>0?e+1|0:e;o=b;c=b;b=e;e=(e|0)==(k|0)&c>>>0<p>>>0|e>>>0<k>>>0;c=e+C|0;j=d;j=c>>>0<e>>>0?j+1|0:j;d=c;k=d;e=(m|0)==(y|0)&q>>>0>J>>>0|m>>>0>y>>>0;d=e+((m|0)==(x|0)&q>>>0<w>>>0|m>>>0<x>>>0)|0;f=0;f=d>>>0<e>>>0?1:f;m=d;d=d+o|0;e=b+f|0;e=d>>>0<m>>>0?e+1|0:e;c=(b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0;b=k+c|0;j=b>>>0<c>>>0?j+1|0:j;c=j;c:{if(j&65536){t=t+1|0;break c}m=g>>>31|0;j=c<<1|b>>>31;b=b<<1|e>>>31;c=j;j=e<<1|d>>>31;d=d<<1|i>>>31;e=j;o=u;j=g<<1|o>>>31;u=o<<1;g=j;j=i<<1|h>>>31;h=h<<1|m;i=j}if((t|0)>=32767){n=n|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){f=1-t|0;if(f>>>0>=128){b=0;c=0;break a}j=t+127|0;Uf(l+48|0,u,g,h,i,j);Uf(l+32|0,d,e,b,c,j);Hn(l+16|0,u,g,h,i,f);Hn(l,d,e,b,c,f);u=(v[l+48>>2]|v[l+56>>2])!=0|(v[l+52>>2]|v[l+60>>2])!=0|(v[l+32>>2]|v[l+16>>2]);g=v[l+36>>2]|v[l+20>>2];h=v[l+40>>2]|v[l+24>>2];i=v[l+44>>2]|v[l+28>>2];d=v[l>>2];e=v[l+4>>2];c=v[l+12>>2];b=v[l+8>>2];break d}c=c&65535|t<<16}z=b|z;n=c|n;if(!(!h&(i|0)==-2147483648?!(g|u):(i|0)>-1)){j=e;b=d+1|0;j=b>>>0<1?j+1|0:j;f=b;c=j;f=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=f+z|0;e=n;z=d;n=d>>>0<f>>>0?e+1|0:e;break a}if(h|u|(i^-2147483648|g)){b=d;c=e;break a}c=d&1;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;e=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=e+z|0;j=n;z=d;n=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=n;gb=l+96|0}function Bpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-3056|0;gb=e;yc(b);f=gb-32|0;gb=f;k=e+1096|0;JY(f+24|0,k);i=xb(f+24|0);g=v[f+28>>2];j=v[f+24>>2];v[f+8>>2]=j;v[f+12>>2]=g;v[f>>2]=j;v[f+4>>2]=g;g=b;fc(f+16|0,g,f);j=xb(f+16|0);if((j|0)==(i|0)){Vb(g,xb(f+24|0))}gb=f+32|0;g=(i|0)==(j|0);if(!g){IY(k)}a:{if(!g){break a}if(!NY(e+1096|0)){break a}if(!c){d=1;break a}if(!Nb(b,Xc(1024,0))){break a}MY(b,e+576|0);MY(b,e- -64|0);while(1){g=h<<2;f=g+(e+576|0)|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0>16777215){break a}g=g+(e- -64|0)|0;if((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))>>>0<3|(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))>>>0>4096){break a}if(!LY(b,((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))+(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))|0)+2978|0)){break a}h=h+1|0;if((h|0)!=128){continue}break}Ed(a,2);sg(a);d=Tb(e+24|0,16845);Eb(a+1300344|0,d);vb(d);d=Tb(e+24|0,16850);Eb(a+1300356|0,d);vb(d);d=Tb(e+24|0,16854);Eb(a+1300368|0,d);vb(d);v[a+1300404>>2]=5;d=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;i=a+484360|0;ff(Qb(i),w[e+1097|0]);v[a+480188>>2]=4194317;Kb(a+1074308|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){g=d+1|0;h=B(g,104)+a|0;f=h+484380|0;wd(f,2);Pj(e+48|0,1,(B(d,13)+e|0)+1098|0);Fc(e+24|0,e+48|0);v[23048]=0;Q(354,((g<<5)+a|0)+946300|0,e+24|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break e}vb(e+24|0);m=f;d=(e+1096|0)+(d<<4)|0;f=d+422|0;v[m>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[h+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[h+484414>>1]=2;v[h+484388>>2]=d}v[h+484404>>2]=8287;d=g;if((d|0)!=32){continue}break}h=0;while(1){d=h+33|0;g=(B(d,104)+a|0)+484380|0;wd(g,2);Pj(e+48|0,1,(B(h,13)+e|0)+2026|0);Fc(e+24|0,e+48|0);v[23048]=0;Q(354,((d<<5)+a|0)+946300|0,e+24|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}vb(e+24|0);v[e+32>>2]=0;v[e+24>>2]=0;v[e+28>>2]=0;d=(e+1096|0)+B(h,11)|0;f=w[d+1347|0];o=lc(e+24|0,0),p=f,t[o|0]=p;f=w[d+1352|0];o=lc(e+24|0,1),p=f,t[o|0]=p;f=w[d+1348|0];o=lc(e+24|0,2),p=f,t[o|0]=p;f=w[d+1353|0];o=lc(e+24|0,3),p=f,t[o|0]=p;f=w[d+1349|0];o=lc(e+24|0,4),p=f,t[o|0]=p;f=w[d+1354|0];o=lc(e+24|0,5),p=f,t[o|0]=p;f=w[d+1350|0];o=lc(e+24|0,6),p=f,t[o|0]=p;f=w[d+1355|0];o=lc(e+24|0,7),p=f,t[o|0]=p;f=w[d+1351|0];o=lc(e+24|0,8),p=f,t[o|0]=p;f=w[d+1356|0];o=lc(e+24|0,9),p=f,t[o|0]=p;d=w[d+1346|0];o=lc(e+24|0,10),p=d,t[o|0]=p;v[e+16>>2]=v[e+32>>2];d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;Lo(g,1,e+8|0);h=h+1|0;if((h|0)!=32){continue}break}Sr(Qb(i),e+2794|0,256,255,65535);k=a+484344|0;rg(k,128);m=c&1;g=0;f:{while(1){h=g<<2;d=h+(e+576|0)|0;Rc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);d=h+(e- -64|0)|0;td(e+24|0,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));g:{if(!m){break g}v[23048]=0;d=W(386,k|0,g&65535,64)|0;h=v[23048];v[23048]=0;if((h|0)==1){break c}if(!d){break g}h=0;f=Yb(k,g);while(1){v[23048]=0;d=Q(250,e+24|0,1)|0;i=v[23048];v[23048]=0;h:{i:{if((i|0)!=1){if(!d){break g}v[23048]=0;d=U(373,e+24|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}if(d>>>0>12){break i}v[23048]=0;i=Wc(f,h,d);j=v[23048];v[23048]=0;if((j|0)==1){break c}v[23048]=0;S(452,e+48|0,e+24|0);j=v[23048];v[23048]=0;if((j|0)==1){break c}j=rd(e+48|0);l=e+48|0;n=w[l|0];d=d>>>0>3;t[i|0]=((n&15)+(d?13:37)|0)+B(n>>>4&7,12);t[i+1|0]=((w[j|0]>>>4|0)+(d?33:1)|0)+(w[l|0]>>>3&16);KY(i,w[j|0],d);break h}break c}i=d-32|0;if((i&255)>>>0<=12){v[23048]=0;i=Wc(f,h,i&65535);j=v[23048];v[23048]=0;if((j|0)==1){break c}v[23048]=0;j=U(373,e+24|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break c}KY(i,j,d>>>0>35);break h}if((d|0)!=64){if((d|0)!=96){break f}if(!h){break g}v[23048]=0;d=Wc(f,h-1|0,0);h=v[23048];v[23048]=0;if((h|0)==1){break c}t[d+3|0]=14;break g}v[23048]=0;d=U(373,e+24|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}h=d+h|0}if(h>>>0<64){continue}break}}yb(e+24|0);g=g+1|0;if((g|0)!=128){continue}break}d=1;if(!(c&2)){break a}h=1;while(1){ug(Sc(e+24|0,8,1,0,1),(B(h,104)+a|0)+484380|0,b);h=h+1|0;if((h|0)!=33){continue}break}break a}yb(e+24|0);d=0;break a}d=P()|0;O()|0;vb(e+24|0);break b}d=P()|0;O()|0;vb(e+24|0);break b}d=P()|0;O()|0;yb(e+24|0)}R(d|0);L()}gb=e+3056|0;return d|0}function koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;d=gb-320|0;gb=d;yc(b);g=gb-32|0;gb=g;mX(g+24|0,d+96|0);i=xb(g+24|0);f=v[g+28>>2];h=v[g+24>>2];v[g+8>>2]=h;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=f;f=b;fc(g+16|0,f,g);h=xb(g+16|0);if((h|0)==(i|0)){Vb(f,xb(g+24|0))}gb=g+32|0;a:{b:{c:{d:{if((i|0)!=(h|0)){break d}if(!qX(d+96|0)){break d}if(!Nb(b,Xc(pX(d+96|0),jb))){break d}if(!c){e=1;break d}Ed(a,2);sg(a);v[a+480204>>2]=455e3;v[a+480188>>2]=524296;Kb(a+1074308|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;df(d- -64|0,2,d+127|0);Fc(d+80|0,d- -64|0);Eb(a+1300308|0,d+80|0);vb(d+80|0);e:{f:{g:{h:{i:{while(1){f=(d+96|0)+B(e,19)|0;MC(d+80|0,f+63|0);Fc(d- -64|0,d+80|0);v[23048]=0;Q(449,((e<<5)+a|0)+480289|0,d- -64|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break h}vb(d- -64|0);e=e+1|0;h=B(e,104)+a|0;j=h+484380|0;wd(j,2);v[d+72>>2]=0;v[d+64>>2]=0;v[d+68>>2]=0;g=d- -64|0;i=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[g+7|0]=i;t[g+8|0]=i>>>8;t[g+9|0]=i>>>16;t[g+10|0]=i>>>24;i=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);t[g|0]=f;t[g+1|0]=f>>>8;t[g+2|0]=f>>>16;t[g+3|0]=f>>>24;t[g+4|0]=i;t[g+5|0]=i>>>8;t[g+6|0]=i>>>16;t[g+7|0]=i>>>24;v[d+8>>2]=v[d+72>>2];f=v[d+68>>2];v[d>>2]=v[d+64>>2];v[d+4>>2]=f;Lo(j,1,d);v[h+484404>>2]=8215;Fc(d+48|0,d+80|0);v[23048]=0;Q(354,((e<<5)+a|0)+946300|0,d+48|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break i}vb(d+48|0);if((e|0)!=8){continue}break}p=w[d+312|0];n=p+1|0;k=a+484360|0;fp(Qb(k),b,n,65535,65535);f=nc(d+80|0);v[23048]=0;W(419,b|0,f|0,n|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}z=d,A=Rb(f),v[z+64>>2]=A;z=d,A=Ub(f),v[z+48>>2]=A;if(Fb(d- -64|0,d+48|0)){while(1){if((w[v[d- -64>>2]]-1&255)>>>0>7){break f}Se(d- -64|0);if(Fb(d- -64|0,d+48|0)){continue}break}}z=a,A=w[oc(f,0)|0],v[z+480196>>2]=A;e=w[d+311|0];q=w[d+313|0];g=nc(d- -64|0);v[23048]=0;h=q+1|0;W(419,b|0,g|0,h|0)|0;i=v[23048];v[23048]=0;j:{if((i|0)==1){break j}v[23048]=0;i=a+484344|0;S(385,i|0,h|0);h=v[23048];v[23048]=0;if((h|0)==1){break j}r=e+1|0;k:{l:{if(!(c&1)){break l}h=0;while(1){c=w[oc(g,h)|0];v[23048]=0;c=W(386,i|0,c|0,r|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break k}if(!c){break l}l=0;c=1;o=Yb(i,w[oc(g,h)|0]);while(1){e=0;if(v[o+12>>2]){while(1){v[23048]=0;j=U(373,b|0)|0;m=v[23048];v[23048]=0;m:{n:{if((m|0)!=1){if(!(j&128)){break n}e=(j&127)+e|0;break m}e=P()|0;O()|0;break c}v[23048]=0;m=Wc(o,e,l&65535);s=v[23048];v[23048]=0;o:{if((s|0)!=1){p:{switch(j|0){case 0:break m;case 1:break p;default:break o}}t[m|0]=254;break m}e=P()|0;O()|0;break c}if(j>>>0>97){break m}t[m+1|0]=c;t[m|0]=j+12}e=e+1|0;if(e>>>0<y[o+12>>2]){continue}break}}if((l&65535)>>>0<=6){l=l+1|0;c=l+1|0;continue}break}c=(h|0)==(q|0);h=h+1|0;if(!c){continue}break}}b=0;e=0;q:{r:{s:{t:{u:{v:{w:{while(1){c=Qb(k);v[23048]=0;h=e&65535;c=Q(516,c|0,h|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break w}x:{if(!c){v[23048]=0;c=W(585,i|0,r|0,0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break v}if((c|0)==65535){break x}z=sc(Qb(k),b),A=c,u[z>>1]=A}z=d,A=Ub(Yb(i,x[sc(Qb(k),b)>>1])),v[z+32>>2]=A;z=d,A=LC(d+32|0,1),v[z+48>>2]=A;b=w[oc(f,(b+1>>>0)%(n>>>0)|0)|0];if((b|0)==w[v[d+48>>2]+5|0]){break x}y:{if(w[v[d+48>>2]+3|0]!=16){break y}c=Qb(k);v[23048]=0;c=Q(586,c|0,h|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break q}if((c|0)==65535){break y}z=d,A=Ub(Yb(i,c)),v[z+32>>2]=A;z=d,A=LC(d+32|0,1),v[z+48>>2]=A}t[v[d+48>>2]+3|0]=16;t[v[d+48>>2]+5|0]=b}e=e+1|0;b=e&65535;if(p>>>0>=b>>>0){continue}break}v[23048]=0;b=Q(2,d+48|0,17572)|0;c=v[23048];v[23048]=0;if((c|0)==1){break u}Eb(a+1300344|0,b);vb(b);v[23048]=0;b=Q(2,d+48|0,17583)|0;c=v[23048];v[23048]=0;if((c|0)==1){break t}Eb(a+1300356|0,b);vb(b);v[23048]=0;Mj(d+16|0,2,d+107|0);b=v[23048];v[23048]=0;if((b|0)==1){break s}v[23048]=0;S(398,d+32|0,d+16|0);b=v[23048];v[23048]=0;if((b|0)==1){break s}v[23048]=0;T(13,d+48|0,5,d+32|0);b=v[23048];v[23048]=0;e=1;if((b|0)==1){break r}Eb(a+1300368|0,d+48|0);vb(d+48|0);vb(d+32|0);v[a+1300404>>2]=5;gc(g);break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+32|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+48|0);break a}e=P()|0;O()|0;vb(d- -64|0);break a}e=P()|0;O()|0;break b}e=0}gc(f)}gb=d+320|0;return e|0}gc(g)}gc(f)}R(e|0);L()}function iZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-112|0;gb=e;yc(b);a:{if(!Pr(b,16712)){break a}if(!Xv(b,e+96|0)){break a}if(!KD(e+96|0)){break a}if(!Nb(b,Xc(JD(e+96|0),jb))){break a}if(!Vb(b,w[e+105|0]|w[e+106|0]<<8)){break a}b:{if(!c){break b}Ed(a,4096);v[a+480208>>2]=12;d=1;u[a+480188>>1]=(w[e+96|2]&31)+1;i=e+96|3;u[a+480190>>1]=w[i|0];jh(a,1);f=Tb(e,16720);Eb(a+1300344|0,f);vb(f);f=Tb(e,16738);Eb(a+1300356|0,f);vb(f);f=gb-16|0;gb=f;g=Tb(f,16742);Dc(e+80|0,g);vb(g);gb=f+16|0;v[23048]=0;Y(410,e|0,e+80|0,e+96|1,e+96|0);f=v[23048];v[23048]=0;c:{d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){Eb(a+1300368|0,e);vb(e);Hb(e+80|0);v[a+1300404>>2]=5;g=w[i|0];f=gb-16|0;gb=f;i=e+80|0;v[i>>2]=0;v[i+4>>2]=0;v[f+12>>2]=0;gf(i+8|0,f+12|0,f+8|0);if(g){Vr(i,g);NE(i,g,0)}gb=f+16|0;k:{if(x[a+480190>>1]){f=1;while(1){v[23048]=0;S(411,b|0,e|0);g=v[23048];v[23048]=0;if((g|0)==1){break k}v[23048]=0;S(412,e|0,(B(d,104)+a|0)+484380|0);g=v[23048];v[23048]=0;if((g|0)==1){break k}g=w[e+16|0];ve(e- -64|0,i,d-1|0);Ef(e- -64|0,(g&3)!=0);f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[23048]=0;W(413,b|0,a+1300308|0,-1)|0;f=v[23048];v[23048]=0;d=1;l:{m:{if((f|0)!=1){if(x[a+480190>>1]){while(1){v[23048]=0;W(414,b|0,(((d&65535)<<5)+a|0)+946300|0,-1)|0;f=v[23048];v[23048]=0;if((f|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[23048]=0;f=(d<<5)+a|0;We(f+480280|0);g=v[23048];v[23048]=0;if((g|0)==1){break e}v[23048]=0;T(416,b|0,f+480289|0,-1);f=v[23048];v[23048]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+96|4;g=w[f|0]|w[f+1|0]<<8;d=0;v[23048]=0;k=a+484344|0;S(385,k|0,g|0);g=v[23048];v[23048]=0;if((g|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(w[f|0]|w[f+1|0]<<8){while(1){v[23048]=0;T(417,b|0,e|0,-1);g=v[23048];v[23048]=0;n:{o:{if((g|0)==1){break o}v[23048]=0;g=W(386,k|0,d&65535,64)|0;h=v[23048];v[23048]=0;if((h|0)==1){break o}if(!g){break n}g=Yb(k,d);v[23048]=0;S(418,g|0,e|0);g=v[23048];v[23048]=0;if((g|0)!=1){break n}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}v[23048]=0;h=U(340,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}p:{if(!h){break p}v[23048]=0;d=Q(250,b|0,h|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break f}if(!d){break p}g=nc(e);v[23048]=0;W(419,b|0,g|0,h|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break h}d=Jb(e- -64|0);v[23048]=0;S(111,d|0,h|0);h=v[23048];v[23048]=0;if((h|0)==1){break i}l=e,m=Rb(g),v[l+24>>2]=m;l=e,m=Ub(g),v[l+56>>2]=m;if(Fb(e+24|0,e+56|0)){while(1){q:{h=w[v[e+24>>2]];if(h&128){l=e,m=hf(d),v[l+40>>2]=m;Sd(e+48|0,e+40|0);v[23048]=0;ba(420,d|0,v[e+48>>2],h&127,32)|0;h=v[23048];v[23048]=0;if((h|0)!=1){break q}break i}v[23048]=0;S(110,d|0,h<<24>>24);h=v[23048];v[23048]=0;if((h|0)!=1){break q}break i}Se(e+24|0);if(Fb(e+24|0,e+56|0)){continue}break}}v[23048]=0;Y(421,e+24|0,5,6,d|0);h=v[23048];v[23048]=0;if((h|0)==1){break i}Eb(d,e+24|0);vb(e+24|0);h=zb(Ob(d));j=Bb(d);v[23048]=0;ga(422,a+1300332|0,h|0,j|0,76,0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break i}vb(d);gc(g)}g=Qb(a+484360|0);d=e+96|6;h=w[d|0]|w[d+1|0]<<8;d=0;v[23048]=0;ga(423,g|0,b|0,h|0,65535,65535)|0;g=v[23048];v[23048]=0;if((g|0)==1){break f}r:{s:{t:{u:{if(!(w[f|0]|w[f+1|0]<<8)){break u}g=c&1;while(1){v[23048]=0;h=Q(250,b|0,4)|0;j=v[23048];v[23048]=0;v:{if((j|0)!=1){if(h){break v}break u}b=P()|0;O()|0;break d}v[23048]=0;h=U(376,b|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break s}v[23048]=0;T(341,e|0,b|0,h|0);h=v[23048];v[23048]=0;if((h|0)==1){break r}w:{if(!g){break w}v[23048]=0;h=oe(k,d&65535);j=v[23048];v[23048]=0;if((j|0)==1){break t}if(!h){break w}h=Yb(k,d);v[23048]=0;T(425,h|0,0,e|0);h=v[23048];v[23048]=0;if((h|0)==1){break t}}yb(e);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){d=1;c=1;while(1){f=B(d,104)+a|0;g=x[f+484414>>1];ve(e,i,d-1|0);d=Sc(e- -64|0,g&1?16:8,1,0,Cb(e)?6:0);v[23048]=0;W(384,d|0,f+484380|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break j}c=c+1|0;d=c&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}Ee(i);break b}b=P()|0;O()|0;yb(e);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Hb(e+80|0);break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(d);break g}b=P()|0;O()|0}gc(g);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}Ee(i)}R(b|0);L()}d=1}gb=e+112|0;return d|0}function Ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-336|0;gb=d;yc(b);a:{if(!Dr(b,d+320|0)){break a}if(!QX(d+320|0)){break a}if(v[d+320>>2]==1179472708){Vb(b,4)}if(!dh(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}l=d+312|4;g=l;CD(b,d+120|0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Ed(a,8192);e=Tb(d+32|0,17318);Eb(a+1300344|0,e);vb(e);e=Tb(d+32|0,17330);Eb(a+1300356|0,e);vb(e);v[a+1300404>>2]=5;Ak(d+96|0,2,d+120|0);Fc(d+32|0,d+96|0);Eb(a+1300308|0,d+32|0);vb(d+32|0);u[d+32>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+96>>1]=1;p=a,q=x[Le(d+32|0,d+96|0)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[$b(d+32|0,d+96|0)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=a;b:{if(w[d+165|0]==128){v[d+32>>2]=256/x[a+480188>>1];v[d+96>>2]=128;g=v[Gb(d+32|0,d+96|0)>>2];break b}g=w[d+165|0]&127}v[e+480228>>2]=g;e=0;while(1){g=(e<<5)+a|0;We(g+480280|0);f=d+e|0;if(w[f+168|0]<=128){u[g+480284>>1]=w[f+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}h=a+484360|0;i=Qb(h);k=d+184|0;e=gb-16|0;gb=e;v[e+12>>2]=w[d+156|0]|w[d+157|0]<<8;tc(e+12|0,128);tc(e+12|0,65535);j=x[e+12>>1];Cf(i,j);if(j){g=0;while(1){f=w[g+k|0];c:{if((f|0)==255){f=65535;break c}if((f|0)!=254){break c}f=65534}p=Si(i,g),q=f,u[p>>1]=q;g=g+1|0;if((j|0)!=(g|0)){continue}break}}gb=e+16|0;if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){ff(Qb(h),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!dh(b,d+312|0)){break a}k=c&2;j=a+484344|0;n=c&1;o=d+68|0;i=0;while(1){c=l;td(d+96|0,b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));d:{e:{f:{if(!(!n|v[d+312>>2]!=1414807888)){v[23048]=0;m=i&65535;c=W(386,j|0,m|0,64)|0;e=v[23048];v[23048]=0;if((e|0)==1){break f}if(!c){break d}v[23048]=0;Q(370,d+96|0,2)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}$h(d+32|0);g=0;g:{while(1){v[23048]=0;c=Q(250,d+96|0,1)|0;e=v[23048];v[23048]=0;h:{i:{if((e|0)!=1){if(c^1|g>>>0>63){break g}v[23048]=0;e=U(373,d+96|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break i}if(e){break h}g=g+1|0;continue}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}c=d+32|0;j:{k:{l:{f=e&15;m:{if(f>>>0<x[a+480188>>1]){c=Yb(j,m);v[23048]=0;c=Wc(c,g,f);f=v[23048];v[23048]=0;if((f|0)==1){break m}}n:{if(!(e&128)){break n}v[23048]=0;f=U(373,d+96|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break l}if(!f){break n}t[c|0]=f>>>0<109?f+12|0:f}if(!(e&64)){break j}v[23048]=0;f=U(373,d+96|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){break k}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}t[c+1|0]=f}o:{p:{q:{r:{s:{t:{u:{v:{if(e&32){t[c+2|0]=1;v[23048]=0;f=U(373,d+96|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break v}t[d+16|0]=f;v[23048]=0;t[d|0]=64;f=$b(d+16|0,d);h=v[23048];v[23048]=0;if((h|0)==1){break u}t[c+4|0]=w[f|0]}if(!(e&16)){continue}v[23048]=0;S(452,d+16|0,d+96|0);e=v[23048];v[23048]=0;if((e|0)==1){break t}h=rd(d+16|0);f=d+16|0;e=w[f|0];switch(e-17|0){case 2:break r;case 0:case 1:break s;default:break q}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}e=e&15;break p}t[f|0]=33;t[h|0]=145;e=w[f|0];break o}if(e>>>0<17){break o}e=(e&240)==32?9:-1}t[f|0]=e}t[c+3|0]=e;t[c+5|0]=w[h|0];v[23048]=0;Mf(c);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break e}i=i+1|0;break d}if(v[d+312>>2]!=1414745673){break d}if(!Zh(a)){break d}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[23048]=0;S(539,d+96|0,d+32|0);e=v[23048];v[23048]=0;w:{x:{y:{if((e|0)==1){break y}v[23048]=0;f=(B(c&65535,104)+a|0)+484380|0;S(540,d+32|0,f|0);c=v[23048];v[23048]=0;if((c|0)==1){break y}v[23048]=0;Ak(d,2,o);c=v[23048];v[23048]=0;if((c|0)==1){break x}v[23048]=0;S(398,d+16|0,d|0);c=v[23048];v[23048]=0;if((c|0)==1){break x}c=x[a+480190>>1];v[23048]=0;Q(354,((c<<5)+a|0)+946300|0,d+16|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break w}vb(d+16|0);if(!k){break d}c=Sc(d+16|0,8,1,0,1);e=2;g=d+45|0;z:{if(!(w[g|0]&64)){e=0;if(!(w[g|0]&2)){break z}}tf(c,e)}if(w[g|0]&4){Li(c,16)}v[23048]=0;W(384,d+16|0,f|0,d+96|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(d+16|0);break e}b=P()|0;O()|0}yb(d+96|0);R(b|0);L()}yb(d+96|0);e=1;if(dh(b,d+312|0)){continue}break}}gb=d+336|0;return e|0}function qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-176|0;gb=d;yc(b);a:{if(!NC(b,d+128|0)){break a}if(!fU(d+128|0)){break a}if(!Nb(b,Xc(eU(d+128|0),jb))){break a}b:{if(!c){break b}Ed(a,256);Mj(d+16|0,2,d+128|0);Fc(d+48|0,d+16|0);Eb(a+1300308|0,d+48|0);vb(d+48|0);e=Tb(d+48|0,26223);Eb(a+1300344|0,e);vb(e);e=Tb(d+48|0,26240);Eb(a+1300356|0,e);vb(e);of(d+16|0,26244);v[23048]=0;S(432,d+112|0,d+159|0);e=v[23048];v[23048]=0;c:{d:{e:{f:{g:{if((e|0)!=1){v[23048]=0;Y(920,d+48|0,d+16|0,d+158|0,d+112|0);e=v[23048];v[23048]=0;if((e|0)==1){break g}Eb(a+1300368|0,d+48|0);vb(d+48|0);vb(d+112|0);Hb(d+16|0);v[a+1300404>>2]=5;v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+160|0];if(w[d+159|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}g=(f&255?f:96)&255;e=OP(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=e;if(w[d+159|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d+112|0)}Hb(d+16|0);break c}t[d+48|0]=64;p=a,q=w[$b(d+162|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;We(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;h:{i:{while(1){dv(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break i}i=gb-32|0;gb=i;h=(B(f,104)+a|0)+484380|0;wd(h,0);g=d+16|0;zk(i,2,g);Fc(i+16|0,i);v[23048]=0;Q(355,h+43|0,i+16|0)|0;e=v[23048];v[23048]=0;j:{k:{if((e|0)!=1){vb(i+16|0);e=g+24|0;v[h+24>>2]=w[e|0]|w[e+1|0]<<8;t[i+16|0]=w[g+22|0];t[i|0]=64;p=h,q=w[$b(i+16|0,i)|0]<<2,u[p+30>>1]=q;e=g+16|0;v[h>>2]=w[e|0]|w[e+1|0]<<8;e=g+18|0;v[h+4>>2]=w[e|0]|w[e+1|0]<<8;e=g+20|0;j=w[e|0]|w[e+1|0]<<8;v[h+8>>2]=j;g=v[h>>2];if(g>>>0>1){break k}v[h>>2]=0;break j}a=P()|0;O()|0;vb(i+16|0);R(a|0);L()}e=v[h+4>>2];if(g>>>0<=e>>>0|e>>>0>=j>>>0|(j|0)==65535){break j}u[h+34>>1]=2;p=h,q=v[Gb(h+8|0,h)>>2],v[p+8>>2]=q}gb=i+32|0;zk(d,2,d+16|0);Fc(d+112|0,d);v[23048]=0;Q(354,((f<<5)+a|0)+946300|0,d+112|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break h}vb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;fp(Qb(e),b,w[d+159|0]?128:64,65535,65535);e=Qb(e);p=d,q=Rb(e),v[p+16>>2]=q;p=d,q=Ub(e),v[p+112>>2]=q;if(Fb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];g=x[e>>1];l:{if(!((g|0)!=99?(g|0)!=255:0)){u[e>>1]=65535;break l}if(g>>>0>63){break i}}sf(d+16|0);if(Fb(d+16|0,d+112|0)){continue}break}}i=c&1;if(i){rg(a+484344|0,w[d+161|0])}if(w[d+161|0]){n=a+484344|0;while(1){m:{n:{if(i){if(Sg(n,l&65535,64)){break n}}f=0;while(1){if((Hd(b)+5&255)>>>0>=3){Vb(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break m}p=d,q=Rb(Yb(n,l)),v[p+112>>2]=q;v[d>>2]=63;k=65535;m=0;while(1){f=0;while(1){g=f;j=0;f=0;o=0;h=0;o:{p:{q:{r:{s:{t:{e=Hd(b);switch(e-251|0){case 1:break o;case 0:break r;case 2:break t;default:break s}}t[v[d+112>>2]]=254;break o}wp(d+16|0,b);f=w[lc(d+16|0,0)|0];o=w[lc(d+16|0,1)|0];h=w[lc(d+16|0,2)|0];j=254;if((e|0)==254){break q}j=e;if(e>>>0>95){break p}}j=(B(j>>>4|0,12)+(j&15)|0)+37|0}e=j;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=o>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(o&15)+26272|0];t[v[d+112>>2]+5|0]=h;u:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:j=v[d+112>>2];e=w[j+5|0];if(w[v[d+112>>2]+5|0]&15){t[j+5|0]=e&15;break o}t[j+5|0]=e&240;break o;case 3:t[v[d+112>>2]+5|0]=B(w[v[d+112>>2]+5|0]&240,10)|w[v[d+112>>2]+5|0]&15;v:{if((k|0)!=65535){if(w[v[d+112>>2]+5|0]){break v}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=k}k=65535}tc(d,m);break o;case 1:k=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break o;case 5:if(w[d+159|0]<=20){t[v[d+112>>2]+5|0]=w[v[d+112>>2]+5|0]%10|w[v[d+112>>2]+5|0]/10<<4}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0;break o;case 7:break o;default:break u}}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0}Oj(d+112|0);f=g+1|0;if((g&65535)>>>0<3){continue}break}m=m+1|0;if((m|0)!=64){continue}break}if((k|0)==65535){break m}wm(Yb(n,l),mp(Ve(De(d+16|0,12,k&255),v[d>>2])))}l=l+1|0;if(l>>>0<w[d+161|0]){continue}break}}f=1;if(!(c&2)){break a}g=Sc(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;w:{if(!v[e>>2]|!x[c+484410>>1]){break w}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break w}if(!Rc(b,c<<4)){break w}ug(g,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;vb(d+112|0)}R(f|0);L()}f=1}gb=d+176|0;return f|0}function doa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-704|0;gb=k;a:{b:{if(d>>>0<=511){d=0;a=gb-32|0;gb=a;i=k+24|0;cc(a+24|0,i,554);h=xb(a+24|0);f=v[a+28>>2];e=v[a+24>>2];v[a+8>>2]=e;v[a+12>>2]=f;v[a>>2]=e;v[a+4>>2]=f;fc(a+16|0,b,a);f=xb(a+16|0);if((f|0)==(h|0)){Vb(b,xb(a+24|0))}gb=a+32|0;a=(f|0)==(h|0);if(!a){Pb(i,0,554)}if(!a){break b}d=gb-32|0;gb=d;c:{d:{a=k+24|0;e:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1229999433){break e}Cp(d,3,a+32|0);Fc(d+16|0,d);v[23048]=0;Q(354,c+492|0,d+16|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break d}vb(d+16|0);Pj(d,1,a+4|0);Fc(d+16|0,d);v[23048]=0;Q(354,c+524|0,d+16|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break d}vb(d+16|0);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];i=c+108|0;e=c+236|0;b=0;h=a- -64|0;while(1){g=b<<1;f=w[g+h|0];g=w[h+(g|1)|0];o=ud(e,b),p=g,u[o>>1]=p;o=lc(i,b),p=(f>>>0<120?f:b)+1|0,t[o|0]=p;b=b+1|0;if((b|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[a+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[a+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[a+17|0]&4;i=c+61|0;t[i|0]=w[a+18|0];e=c+62|0;t[e|0]=w[a+19|0];g=c+63|0;t[g|0]=w[a+20|0];j=c- -64|0;t[j|0]=w[a+21|0];h=c+48|0;Eg(h,25);b=0;while(1){f:{l=b<<1;f=w[(l+a|0)+504|0];o=Mb(h,b),p=f,u[o>>1]=p;if((f|0)==255){Eg(h,b);break f}f=w[(a+(l|1)|0)+504|0];o=Mb(h,b),p=f,t[o+2|0]=p;b=b+1|0;if((b|0)!=25){continue}}break}a=w[Ff(i,e)|0];if(Lb(h)>>>0<=a>>>0){t[c+60|0]=w[c+60|0]&253}a=w[Ff(g,j)|0];if(Lb(h)>>>0>a>>>0){break e}t[c+60|0]=w[c+60|0]&251}gb=d+32|0;break c}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}d=554;break b}h=v[b+8>>2];f=gb-48|0;gb=f;v[f+44>>2]=674;v[f+24>>2]=674;d=b;i=v[Gb(f+44|0,f+24|0)>>2];if(!Nb(d,i)){i=Bf(d)}e=k+24|0;KW(f+24|0,e);g=_d(f+32|0,v[f+24>>2],i);j=v[g+4>>2];v[f+8>>2]=v[g>>2];v[f+12>>2]=j;fc(f+16|0,d,f+8|0);KW(f+24|0,e);Pb(v[f+24>>2]+i|0,0,674-i|0);Vb(d,v[f+44>>2]);gb=f+48|0;m=b;i=c;d=c;l=v[a+480180>>2];a=0;g=gb-32|0;gb=g;g:{h:{j=k+24|0;e=j;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))==1229999433){Cp(g,3,e+32|0);Fc(g+16|0,g);v[23048]=0;Q(354,d+492|0,g+16|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break h}vb(g+16|0);Pj(g,1,e+4|0);Fc(g+16|0,g);v[23048]=0;Q(354,d+524|0,g+16|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break h}vb(g+16|0);v[d>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[d+4>>2]=w[e+24|0]>>>1;tc(d+4|0,64);a=w[e+25|0]&127;v[d+8>>2]=a>>>0>64?128:a<<2;t[d+15|0]=w[d+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[g+16|0]=w[e+26|0];t[g|0]=100;o=d,p=w[$b(g+16|0,g)|0],t[o+20|0]=p;t[g+16|0]=w[e+27|0];t[g|0]=64;o=d,p=w[$b(g+16|0,g)|0],t[o+19|0]=p;t[d+16|0]=w[e+17|0];t[d+17|0]=w[e+18|0];t[d+18|0]=w[e+19|0];t[d+26|0]=w[e+22|0];t[d+27|0]=w[e+23|0];Zl(d,w[e+58|0]&127,w[e+58|0]>>>7|0);Yl(d,w[e+59|0]&127,w[e+59|0]>>>7|0);i:{j:{k:{if(!((w[e+28|0]|w[e+29|0]<<8)==514|(w[e+28|0]|w[e+29|0]<<8)==529|(w[e+28|0]|w[e+29|0]<<8)==544)){if((w[e+28|0]|w[e+29|0]<<8)!=532){break k}}if(w[e+61|0]==255){break k}if(w[e+61|0]<=128){t[d+30|0]=w[e+61|0]}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break j}break i}a=0;if(t[e+61|0]>=0){t[d+30|0]=w[e+61|0]+1}a=t[e+62|0]>=0?w[e+62|0]+1|0:a;if(t[e+63|0]<0){break j}a=(w[e+63|0]<<7)+a|0}u[d+28>>1]=a}a=t[e+60|0];t[d+31|0]=a;if((a|0)<=-1){t[d+31|0]=0;t[d+34|0]=a^128}a=0;l=l&16777216?240:25;mw(e+304|0,d+48|0,0,l);mw(e+386|0,d+68|0,32,l);mw(e+468|0,d+88|0,32,l);t[d+100|0]=w[d+100|0]&239|w[e+468|0]>>>3&16;l=d+108|0;n=d+236|0;d=e- -64|0;while(1){f=a<<1;e=w[f+d|0];f=w[d+(f|1)|0];o=ud(n,a),p=f,u[o>>1]=p;o=lc(l,a),p=(e>>>0<120?e:a)+1|0,t[o|0]=p;a=a+1|0;if((a|0)!=120){continue}break}a=554}gb=g+32|0;break g}a=P()|0;O()|0;vb(g+16|0);R(a|0);L()}d=0;l:{if(!a){break l}if(!((w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1297110104?(w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1481920589:0)){d=i+236|0;a=0;while(1){i=w[(a+j|0)+554|0];e=ud(d,a);u[e>>1]=x[e>>1]|i<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}d=a}Rc(m,h+d|0);if(!xh(b,18052)){break b}td(k,b,_f(b));v[23048]=0;b=U(247,k|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}v[23048]=0;a=Q(596,k|0,18057)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}if(a){v[23048]=0;a=U(373,k|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}t[c+34|0]=a>>>0>250?0:a}d=(b+d|0)+8|0;yb(k)}gb=k+704|0;return d|0}a=P()|0;O()|0;yb(k);R(a|0);L()}function jL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-416|0;gb=e;t[e+415|0]=c;a:{if(jk(b)){break a}f=w[jl(b)|0];c=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}c=0}d=c;wl(e+160|0,b,v[b+4>>2]-1|0);c=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=c}Md(e+160|0);c=v[e+160>>2];Md(e+376|0);g=il(c,v[e+380>>2],b);Md(e+160|0);c=v[b>>2];f=v[b+4>>2];c:{d:{e:{f:{if((g|0)==v[e+164>>2]){v[e+400>>2]=c;v[e+404>>2]=f;a=wc(e+392|0,56371);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Kc(e+8|0,e)){a=aa(8)|0;v[23048]=0;S(2060,e+376|0,e+415|0);b=v[23048];v[23048]=0;g:{h:{i:{if((b|0)!=1){v[23048]=0;T(2045,e+160|0,57575,e+376|0);b=v[23048];v[23048]=0;if((b|0)==1){break i}rc(a,e+160|0);d=0;v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break e}b=P()|0;O()|0;vb(e+160|0);break h}b=P()|0;O()|0;break g}b=P()|0;d=1;O()|0}vb(e+376|0);if(!d){break f}}ca(a|0);break f}if(!d){break c}a=aa(8)|0;v[23048]=0;d=Q(2061,e+344|0,b|0)|0;b=v[23048];v[23048]=0;c=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){v[23048]=0;T(2045,e+360|0,57454,d|0);b=v[23048];v[23048]=0;if((b|0)==1){break r}v[23048]=0;S(2057,e+376|0,e+360|0);b=v[23048];v[23048]=0;if((b|0)==1){break q}v[23048]=0;S(2060,e+328|0,e+415|0);b=v[23048];v[23048]=0;if((b|0)==1){break p}v[23048]=0;T(2062,e+160|0,e+376|0,e+328|0);b=v[23048];v[23048]=0;if((b|0)==1){break o}rc(a,e+160|0);v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break e}b=P()|0;O()|0;vb(e+160|0);c=0;break n}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break m}b=P()|0;O()|0}vb(e+328|0)}vb(e+376|0)}vb(e+360|0)}vb(d)}if(!c){break f}ca(a|0);break f}v[e+320>>2]=c;v[e+324>>2]=f;c=wc(e+312|0,56371);d=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=d;d=v[c+4>>2];v[e+144>>2]=v[c>>2];v[e+148>>2]=d;if(!Kc(e+152|0,e+144|0)){break d}a=aa(8)|0;v[23048]=0;S(2060,e+376|0,e+415|0);b=v[23048];v[23048]=0;s:{t:{u:{if((b|0)!=1){v[23048]=0;T(2045,e+160|0,57575,e+376|0);b=v[23048];v[23048]=0;if((b|0)==1){break u}rc(a,e+160|0);d=0;v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break e}b=P()|0;O()|0;vb(e+160|0);break t}b=P()|0;O()|0;break s}b=P()|0;d=1;O()|0}vb(e+376|0);if(!d){break f}}ca(a|0)}R(b|0)}L()}c=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=c;c=wc(e+296|0,57192);d=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=d;d=v[c+4>>2];v[e+128>>2]=v[c>>2];v[e+132>>2]=d;v:{if(!Kc(e+136|0,e+128|0)){c=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=c;c=wc(e+280|0,57489);d=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=d;d=v[c+4>>2];v[e+112>>2]=v[c>>2];v[e+116>>2]=d;if(!Kc(e+120|0,e+112|0)){break v}}t[a+60|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=c;c=wc(e+264|0,57210);d=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=d;d=v[c+4>>2];v[e+96>>2]=v[c>>2];v[e+100>>2]=d;w:{if(!Kc(e+104|0,e+96|0)){c=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=c;c=wc(e+248|0,57507);d=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=d;d=v[c+4>>2];v[e+80>>2]=v[c>>2];v[e+84>>2]=d;if(!Kc(e+88|0,e+80|0)){break w}}t[a+61|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=c;c=wc(e+232|0,57229);d=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=d;d=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=d;if(Kc(e+72|0,e- -64|0)){t[a+62|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=c;c=wc(e+216|0,57247);d=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=d;d=v[c+4>>2];v[e+48>>2]=v[c>>2];v[e+52>>2]=d;if(Kc(e+56|0,e+48|0)){t[a+63|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=c;c=wc(e+200|0,57271);d=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=d;d=v[c+4>>2];v[e+32>>2]=v[c>>2];v[e+36>>2]=d;if(Kc(e+40|0,e+32|0)){t[a+64|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=c;b=wc(e+184|0,57345);c=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=c;c=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=c;if(!Kc(e+24|0,e+16|0)){break c}c=a+24|0;b=v[c>>2];d=b+24664|0;f=v[d+4>>2];v[e+176>>2]=v[d>>2];v[e+180>>2]=f;d=b+24656|0;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;d=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=d;b=e;if(w[e+415|0]){a=wK(v[a+56>>2])}else{a=0}v[b+180>>2]=a;if(!By(e+160|0,v[c>>2]+24648|0)){break c}Hz(v[c>>2],e+160|0)}gb=e+416|0}function gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=gb-80|0;gb=f;yc(b);a:{b:{c:{d:{e:{if(SU(b,25561)){g=nc(f- -64|0);h=nc(f+48|0);l=av(f+32|0);v[23048]=0;S(428,a|0,32768);d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;d=Q(2,f|0,25570)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}Eb(a+1300344|0,d);vb(d);v[23048]=0;d=Q(2,f|0,25580)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}Eb(a+1300356|0,d);vb(d);v[a+1300404>>2]=2;j=a+484360|0;i=f+24|4;f:{g:{h:{i:{j:{while(1){v[23048]=0;d=Q(250,b|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break i}k:{l:{m:{n:{if(!d){break n}v[23048]=0;d=Q(863,b|0,f+24|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break m}if(!d){break n}d=i;d=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));v[23048]=0;T(341,f|0,b|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break l}v[23048]=0;d=U(328,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}if(d){break k}yb(f)}if(x[a+480188>>1]){break j}e=0;break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{d=f+24|0;d=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if((d|0)<=1347175757){if((d|0)==1129140036){break t}if((d|0)==1346458708){break r}if((d|0)!=1346522948){break p}if(cf(g)>>>0>255){break p}v[23048]=0;S(577,g|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break e}break p}if((d|0)<=1396854595){if((d|0)==1347175758){break s}if(x[a+480190>>1]|(d|0)!=1396788560){break p}v[23048]=0;T(864,f|0,l|0,a|0);d=v[23048];v[23048]=0;if((d|0)==1){break e}break p}if((d|0)==1396854596){break q}if((d|0)!=1397769541){break p}v[23048]=0;d=U(247,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}if(d>>>0<2){break p}v[23048]=0;d=U(465,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}o=a,p=Gd(d,1,255),v[o+480196>>2]=p;break p}if(x[a+480188>>1]){break p}v[23048]=0;e=U(247,f|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}d=0;if(e>>>0<8){break p}while(1){v[23048]=0;k=U(373,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break o}v[23048]=0;m=U(373,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}e=x[a+480188>>1];if(k|m){v[23048]=0;We(((e<<5)+a|0)+480280|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}k=x[a+480188>>1];e=k+1|0;u[a+480188>>1]=e;u[((k<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64}v[23048]=0;We((((e&65535)<<5)+a|0)+480280|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}e=x[a+480188>>1];u[a+480188>>1]=e+1;u[((e<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64;d=d+1|0;if((d|0)!=4){continue}break}if(c){break p}yb(f);break g}v[23048]=0;d=U(247,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}if(d>>>0<2){break p}v[23048]=0;n=U(465,f|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}break p}d=Qb(j);v[23048]=0;e=U(247,f|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break e}v[23048]=0;ga(560,d|0,f|0,e|0,255,254)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break p}break e}if(cf(h)>>>0>3998){break p}v[23048]=0;d=U(247,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}if(!d){break p}v[23048]=0;S(577,h|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break e}}yb(f);continue}break}break e}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Qb(j);v[23048]=0;S(547,b|0,n&65535);b=v[23048];v[23048]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=cf(g);v[23048]=0;S(385,a+484344|0,b&65535);b=v[23048];v[23048]=0;if((b|0)==1){break b}if(!cf(g)){break u}b=0;while(1){d=Dg(g,d);v[23048]=0;T(865,d|0,b&65535,a|0);d=v[23048];v[23048]=0;if((d|0)==1){break h}b=b+1|0;d=b&65535;if(cf(g)>>>0>d>>>0){continue}break}}b=1;if(x[a+480190>>1]<2){break g}i=c&2;d=0;v:{while(1){if(!i|cf(h)>>>0<=d>>>0){break g}w:{c=(B(b,104)+a|0)+484380|0;if(v[c>>2]){e=Dg(h,d);v[23048]=0;e=U(247,e|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break w}tc(c,e);ve(f,l,b-1|0);e=Sc(f+24|0,8,1,1,Cb(f)?10:0);j=Dg(h,d);v[23048]=0;W(384,e|0,c|0,j|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break v}d=d+1|0}e=1;b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break f}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=1}Ee(l);kd(h);kd(g)}gb=f+80|0;return e|0}a=P()|0;O()|0;yb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ee(l);kd(h);kd(g);R(a|0);L()}function qla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gb-256|0;gb=e;yc(b);a:{if(!jY(b,e+184|0)){break a}if(!YU(e+184|0)){break a}if(!Nb(b,Xc(XU(e+184|0),jb))){break a}b:{if(!c){break b}Ed(a,16);Mj(e+8|0,2,e+184|4);Fc(e+32|0,e+8|0);Eb(a+1300308|0,e+32|0);vb(e+32|0);u[a+480190>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];d=Tb(e+32|0,25384);Eb(a+1300344|0,d);vb(d);d=Tb(e+32|0,25397);Eb(a+1300356|0,d);vb(d);of(e+8|0,25401);d=e+184|3;v[e+168>>2]=w[d|0]>>>4;d=w[d|0];v[23048]=0;v[e+180>>2]=d&15;Y(504,e+32|0,e+8|0,e+168|0,e+180|0);f=v[23048];v[23048]=0;d=1;c:{d:{e:{if((f|0)!=1){Eb(a+1300368|0,e+32|0);vb(e+32|0);Hb(e+8|0);v[a+1300404>>2]=5;if(x[a+480190>>1]){f=1;while(1){pE(b,e+32|0);i=gb-16|0;gb=i;g=(B(d,104)+a|0)+484380|0;wd(g,0);h=e+32|0;u[i+14>>1]=w[h+35|0]<<2;u[i+12>>1]=256;p=g,q=x[Vc(i+14|0,i+12|0)>>1],u[p+30>>1]=q;f:{if((w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24))>>>0<3){break f}v[g>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);v[g+4>>2]=w[h+26|0]|w[h+27|0]<<8|(w[h+28|0]<<16|w[h+29|0]<<24);v[i+8>>2]=w[h+30|0]|w[h+31|0]<<8|(w[h+32|0]<<16|w[h+33|0]<<24);v[i+4>>2]=1;p=g,q=v[Jc(i+8|0,i+4|0)>>2]-1|0,v[p+8>>2]=q;tc(g+8|0,v[g>>2]);g:{if(y[g+8>>2]<=v[g+4>>2]+4>>>0){v[g+4>>2]=0;v[g+8>>2]=0;break g}u[g+34>>1]=x[g+34>>1]|2}t[g+37|0]=w[h+34|0];p=g,q=Fu(0,t[h+34|0]<<4),v[p+24>>2]=q;if(!(t[h+36|0]&1)){break f}u[g+34>>1]=x[g+34>>1]|1;v[g>>2]=v[g>>2]>>>1;v[g+4>>2]=v[g+4>>2]>>>1;v[g+8>>2]=v[g+8>>2]>>>1}gb=i+16|0;Fk(e+168|0,2,e+32|0);Fc(e+8|0,e+168|0);v[23048]=0;Q(354,((d<<5)+a|0)+946300|0,e+8|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}vb(e+8|0);f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){d=0;while(1){f=(d<<5)+a|0;We(f+480280|0);u[f+480284>>1]=(w[(e+d|0)+218|0]<<4|8)&248;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+32|0;g=gb-32|0;gb=g;d=b;h:{if(Nb(d,128)){wW(g+24|0,f);f=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=f;gd(g+16|0,d,g+8|0);break h}d=gb-16|0;gb=d;h=f+128|0;while(1){Re(f);f=f+1|0;if((h|0)!=(f|0)){continue}break}gb=d+16|0}gb=g+32|0;zE(Qb(a+484360|0),e+32|0,w[e+211|0]+1|0);if(w[e+216|0]){g=w[e+216|0]}else{g=64}i=g;td(e+8|0,b,B(w[e+208|0]|w[e+209|0]<<8,192));d=c&1;if(d){f=w[e+210|0];v[23048]=0;S(385,a+484344|0,f+1|0);f=v[23048];v[23048]=0;if((f|0)==1){break d}}i:{j:{if(!d){break j}n=a+484344|0;while(1){v[23048]=0;f=W(386,n|0,k&65535,i|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break i}d=0;if(!f){break j}while(1){v[23048]=0;f=U(340,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}l=d;k:{if(!f|f>>>0>(w[e+208|0]|w[e+209|0]<<8)>>>0){break k}d=l&65535;if(d>>>0>=x[a+480188>>1]){break k}v[23048]=0;Q(248,e+8|0,B(f,192)-192|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break d}f=Yb(n,k);v[23048]=0;d=Wc(f,0,d);f=v[23048];v[23048]=0;if((f|0)==1){break d}m=0;if(!i){break k}while(1){v[23048]=0;S(760,e+168|0,e+8|0);f=v[23048];v[23048]=0;if((f|0)==1){break d}j=rd(e+168|0);h=Df(e+168|0);g=d;f=w[e+168|0];if(f>>>0>=4){t[d|0]=(f>>>2|0)+37;f=w[e+168|0]}t[g+1|0]=f<<4&48|w[j|0]>>>4;f=w[h|0];g=0;h=0;l:{m:{n:{o:{p:{q:{j=w[j|0]&15;switch(j-8|0){case 0:break n;case 6:break p;case 2:break q;default:break o}}f=f&240?f&-16:f&15;j=10;break m}j=14;o=(f+16&240)>>>4|0;if(o>>>0>8){break m}if(1<<o&435){break n}break m}g=j;h=f}j=g;f=h;if(!((g|f)&255)){break l}}t[d+5|0]=f;t[d+3|0]=j;v[23048]=0;Mf(d);f=v[23048];v[23048]=0;if((f|0)!=1){break l}break d}d=B(x[a+480188>>1],6)+d|0;m=m+1|0;if((m|0)!=(i|0)){continue}break}}d=l+1|0;if((l&65535)>>>0<31){continue}break}d=w[e+210|0]>k>>>0;k=k+1|0;if(d){continue}break}}if(w[e+212|0]|w[e+213|0]<<8){d=w[e+212|0]|w[e+213|0]<<8;v[23048]=0;ga(517,a+1300332|0,b|0,d|0,39,1)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){d=1;while(1){c=B(d&65535,104)+a|0;f=Sc(e+168|0,u[c+484414>>1]&1?16:8,1,0,1);v[23048]=0;W(384,f|0,c+484380|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break d}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;yb(e+8|0);break b}break d}d=P()|0;O()|0;Hb(e+8|0);break c}d=P()|0;O()|0;vb(e+8|0);break c}d=P()|0;O()|0;yb(e+8|0)}R(d|0);L()}d=1}gb=e+256|0;return d|0}function zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-112|0;gb=e;h=a+140|0;Fm(e+88|0,h,1296125513);v[23048]=0;f=U(328,e+88|0)|0;g=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((g|0)!=1){if(f){f=Jb(e+32|0);v[23048]=0;g=U(247,e+88|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break o}v[23048]=0;T(1453,e+88|0,f|0,g|0);g=v[23048];v[23048]=0;if((g|0)==1){break o}g=x[a+174>>1];v[23048]=0;Y(1454,e+72|0,g|0,8,f|0);g=v[23048];v[23048]=0;if((g|0)==1){break n}v[23048]=0;T(9,e+8|0,c|0,e+72|0);c=v[23048];v[23048]=0;if((c|0)==1){break m}v[23048]=0;Q(354,d|0,e+8|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break l}vb(e+8|0);vb(e+72|0);vb(f)}if(w[a+176|0]){v[23048]=0;S(1455,e+32|0,d|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}v[23048]=0;Q(355,b+43|0,e+32|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break h}vb(e+32|0)}v[23048]=0;T(1445,e+32|0,h|0,1413894985);c=v[23048];v[23048]=0;if((c|0)==1){break g}v[23048]=0;h=U(1456,e+32|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}yb(e+32|0);c=a+40|0;yc(c);v[23048]=0;f=Q(1457,c|0,e+32|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}if(!f){break d}f=e+60|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<2){break e}v[23048]=0;f=Q(1458,c|0,e+8|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}if(!f){break e}f=v[b>>2];v[23048]=0;kz(e+8|0,b+12|0,b+16|0,f,b+34|0,8,16,h);f=v[23048];v[23048]=0;if((f|0)!=1){break e}break b}c=P()|0;O()|0;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0;vb(e+8|0)}vb(e+72|0)}vb(f);break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(e+32|0);break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;yb(e+32|0);break a}v[23048]=0;c=Q(1458,c|0,e+8|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}if(c){c=v[b>>2];v[23048]=0;kz(e+8|0,b+4|0,b+8|0,c,b+34|0,2,4,h);c=v[23048];v[23048]=0;if((c|0)==1){break b}}c=e+44|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+42|0]=c&128?0:c+1|0;v[23048]=0;pk(b);c=v[23048];v[23048]=0;if((c|0)==1){break b}}p:{q:{r:{s:{t:{if(w[b+42|0]){break t}v[23048]=0;c=a+60|0;f=Q(899,c|0,7)|0;h=v[23048];v[23048]=0;if((h|0)==1){break c}if(!f){break t}yc(c);v[23048]=0;c=Q(1460,c|0,e+8|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break s}if(!c){break t}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}v[23048]=0;g=a+120|0;c=U(328,g|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break c}if(!c){break p}c=0;v[23048]=0;f=U(376,g|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break q}v[e+72>>2]=f;i=b+68|0;tc(e+72|0,9);if(!v[e+72>>2]){f=0;break r}h=e+8|4;while(1){u:{v[23048]=0;S(1461,g|0,e+8|0);f=v[23048];v[23048]=0;if((f|0)==1){break u}f=h;v[((c<<2)+b|0)+68>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);c=c+1|0;f=v[e+72>>2];if(c>>>0<f>>>0){continue}break r}break}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}v[23048]=0;Qy(i+(f<<2)|0,gk(i),30888);c=v[23048];v[23048]=0;if((c|0)!=1){break p}}c=P()|0;O()|0;break a}a=a+80|0;yc(a);v[23048]=0;c=Q(1463,a|0,e+8|0)|0;f=v[23048];v[23048]=0;v:{w:{x:{y:{z:{if((f|0)==1){break z}if(!c){break w}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}c=e+8|4;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[23048]=0;u[e+6>>1]=256;c=Vc(e+72|0,e+6|0);f=v[23048];v[23048]=0;if((f|0)==1){break v}u[b+28>>1]=x[c>>1];c=e+8|6;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[23048]=0;u[e+6>>1]=256;c=Vc(e+72|0,e+6|0);f=v[23048];v[23048]=0;if((f|0)==1){break y}u[b+30>>1]=x[c>>1];c=e+16|0;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[23048]=0;u[e+6>>1]=64;c=Vc(e+72|0,e+6|0);f=v[23048];v[23048]=0;if((f|0)==1){break x}u[b+32>>1]=x[c>>1];t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];v[23048]=0;c=Q(250,a|0,32)|0;f=v[23048];v[23048]=0;if((f|0)==1){break z}if(!c){break w}v[23048]=0;W(1464,a|0,d|0,32)|0;c=v[23048];v[23048]=0;if((c|0)==1){break z}v[23048]=0;c=U(511,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break z}v[23048]=0;W(375,a|0,b+43|0,c|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break w}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}yb(e+88|0);gb=e+112|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0}yb(e+88|0);R(c|0);L()}function yK(a,b,c,d,e,f){var g=0,h=0,i=0;g=gb-48|0;gb=g;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(Bt(c)){b=b+24|0;if(oe(v[b>>2]+484344|0,c&65535)){break j}}c=a;a=Jb(g+32|0);b=Jb(g+16|0);pi(c,a,b);vb(b);vb(a);break i}c=Yb(v[b>>2]+484344|0,c);if(!(v[c+12>>2]>(d|0)?(d|0)>=0:0)){c=a;a=Jb(g+32|0);b=Jb(g+16|0);pi(c,a,b);vb(b);vb(a);break i}if(!(x[v[b>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){c=a;a=Jb(g+32|0);b=Jb(g+16|0);pi(c,a,b);vb(b);vb(a);break i}if(f>>>0>=6){c=a;a=Jb(g+32|0);b=Jb(g+16|0);pi(c,a,b);vb(b);vb(a);break i}c=Wc(c,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!ne(c)){if(!Xt(c)){break n}}SO(g+16|0,v[b>>2],w[c|0],w[c+1|0]);v[23048]=0;T(9,g+32|0,0,g+16|0);d=v[23048];v[23048]=0;b=1;if((d|0)!=1){break m}c=P()|0;O()|0;break b}b=0;v[23048]=0;Q(91,g+32|0,57035)|0;d=v[23048];v[23048]=0;if((d|0)==1){break l}}v[23048]=0;d=ne(c);e=v[23048];v[23048]=0;if((e|0)==1){break c}o:{if(d){v[23048]=0;Q(91,g|0,57039)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}break o}if(Xt(c)){v[23048]=0;Q(91,g|0,57043)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break o}break c}v[23048]=0;Q(91,g|0,57035)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}}pi(a,g+32|0,g);vb(g);vb(g+32|0);if(!b){break i}vb(g+16|0);break i}c=P()|0;O()|0;break a;case 1:b=c+1|0;p:{if(w[c+1|0]){iv(g+32|0,b);break p}Tb(g+32|0,57047)}q:{if(w[b|0]){v[23048]=0;Q(91,g+16|0,57050)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break q}break d}v[23048]=0;Q(91,g+16|0,57047)|0;b=v[23048];v[23048]=0;if((b|0)==1){break d}}pi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 2:r:{if(tg(c)){Tb(g+32|0,57053);break r}if(w[c+2|0]){$g(g+32|0,1,gz(v[v[b>>2]+8>>2],w[c+2|0]));break r}Tb(g+32|0,57053)}v[23048]=0;b=tg(c);d=v[23048];v[23048]=0;if((d|0)==1){break e}s:{if(b){v[23048]=0;Q(91,g+16|0,57053)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}break s}if(w[c+2|0]){v[23048]=0;Q(91,g+16|0,57055)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break s}break e}v[23048]=0;Q(91,g+16|0,57053)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}}pi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 4:t:{if(tg(c)){h=g,i=Pq(c)&255,v[h>>2]=i;aC(g+32|0,g);break t}if(w[c+2|0]){iv(g+32|0,c+4|0);break t}Tb(g+32|0,57047)}v[23048]=0;b=tg(c);d=v[23048];v[23048]=0;if((d|0)==1){break f}u:{if(b){v[23048]=0;Q(91,g+16|0,57057)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}break u}if(w[c+2|0]){v[23048]=0;Q(91,g+16|0,57057)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break u}break f}v[23048]=0;Q(91,g+16|0,57047)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}}pi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 3:v:{if(tg(c)){h=g,i=(zo(c)&3840)!=0,t[h|0]=i;b=gb-32|0;gb=b;t[b+24|0]=44;v[b+16>>2]=-1;v[b+20>>2]=0;v[b+8>>2]=1058;v[b+12>>2]=1;d=gb-16|0;gb=d;v[d+12>>2]=w[g|0];Ay(g+32|0,d+12|0,b+8|0);gb=d+16|0;gb=b+32|0;break v}if(w[c+3|0]){$g(g+32|0,1,fz(v[v[b>>2]+8>>2],w[c+3|0]));break v}Tb(g+32|0,57060)}v[23048]=0;b=tg(c);d=v[23048];v[23048]=0;if((d|0)==1){break g}w:{if(b){v[23048]=0;Q(91,g+16|0,57062)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}break w}if(w[c+3|0]){v[23048]=0;Q(91,g+16|0,57062)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break w}break g}v[23048]=0;Q(91,g+16|0,57060)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}}pi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 5:x:{if(tg(c)){h=g,i=zo(c)&255,v[h>>2]=i;aC(g+32|0,g);break x}if(w[c+3|0]){iv(g+32|0,c+5|0);break x}Tb(g+32|0,57047)}v[23048]=0;b=tg(c);d=v[23048];v[23048]=0;if((d|0)==1){break h}y:{if(b){v[23048]=0;Q(91,g+16|0,57064)|0;b=v[23048];v[23048]=0;if((b|0)==1){break h}break y}if(w[c+3|0]){v[23048]=0;Q(91,g+16|0,57064)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break y}break h}v[23048]=0;Q(91,g+16|0,57047)|0;b=v[23048];v[23048]=0;if((b|0)==1){break h}}pi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;default:break k}}c=a;a=Jb(g+32|0);b=Jb(g+16|0);pi(c,a,b);vb(b);vb(a)}gb=g+48|0;return}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);if(!b){break a}}vb(g+16|0)}R(c|0);L()}function LP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=gb-16|0;gb=i;a:{if(!ue(d&255)){break a}j=(B(b,880)+a|0)+1074984|0;b:{if(e?0:!(!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break b}if(kk(j)){break b}d=B(b,880)+a|0;e=d+1075060|0;if(!v[e>>2]|w[d+1075073|0]&4){break a}c=B(b,880)+a|0;h=c+1075004|0;g=c+1075008|0;if(!(v[h>>2]|v[g>>2])){break a}c=gA(a,b);if((c|0)==65535){break a}f=a+1074984|0;c=f+B(c,880)|0;lu(c,j);t[c+833|0]=0;t[c+807|0]=0;u[c+788>>1]=b+1;v[c+88>>2]=v[c+88>>2]&-918529;Vm(c+790|0);v[c+696>>2]=0;v[c+88>>2]=v[c+88>>2]|2101248;v[e>>2]=0;v[j>>2]=0;v[j+4>>2]=0;c=f+B(b,880)|0;v[c+92>>2]=0;v[c+96>>2]=0;v[h>>2]=0;v[g>>2]=0;if(!(w[d+1075073|0]&2)){break a}a=a+1300300|0;if(!Fd(a)){break a}Qh(v[a>>2],b,1);break a}e=B(b,880)+a|0;l=v[e+1075088>>2];c=x[a+480192>>1]<c>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];c:{if(!g){break c}f=d-1|0;c=x[ud(g+236|0,f)>>1];h=a+1074308|0;Db(i+8|0,h,104);d:{if(Cb(i+8|0)){Db(i,h,34);if(Cb(i)){break d}}d=w[lc(g+108|0,f)|0]}if((c-1&65535)>>>0<=3998){l=(B(c,104)+a|0)+484380|0;break c}Db(i+8|0,h,43);if(!Cb(i+8|0)){break c}if(!uj(g)){break a}}if(w[e+1075073|0]&4){break a}h=a+1300300|0;m=a+1074308|0;if(b>>>0<256){q=b+1|0;c=b;while(1){f=(b|0)==(c|0);e:{if(x[a+480188>>1]>c>>>0?!f:0){break e}e=B(c,880)+a|0;if(x[e+1075772>>1]!=(q|0)?!f:0){break e}p=e+1075640|0;f=v[p>>2];if(!f){break e}k=e+1074984|0;f:{g:{h:{i:{j:{k:{l:{switch(w[f+17|0]-1|0){case 0:if(!d){break e}n=w[e+1075783|0]==(d|0)&(g|0)==(f|0);o=n;if(!g){break k}if(n){break h}break e;case 1:if(!l|v[e+1075088>>2]!=(l|0)){break e}if((g|0)==(f|0)){break f}Db(i+8|0,m,104);if(!Cb(i+8|0)){break f}break e;case 3:break j;case 2:break l;default:break e}}if(g){break i}o=(g|0)==(f|0)}if(o){break f}break e}if(!g){break e}n=w[g+34|0];if(!n){break e}if((n|0)==w[f+34|0]){break g}break e}if((g|0)!=(f|0)){break e}}if(!w[g+34|0]){break f}}if(!w[e+1075783|0]|w[f+18|0]>2){break f}Db(i+8|0,m,34);tl(a,c&65535,LS(k,Cb(i+8|0))+255|0,0);t[e+1075786|0]=0}m:{n:{switch(w[v[p>>2]+18|0]){case 0:wo(a,k);v[e+1075672>>2]=0;if(!(w[e+1075073|0]&2)){break m}if(!Fd(h)){break m}Qh(v[h>>2],c&65535,1);break m;case 1:wo(a,k);if(!(w[e+1075073|0]&2)){break m}if(!Fd(h)){break m}nk(v[h>>2],c&65535);break m;case 2:break n;default:break m}}k=e+1075072|0;f=v[k>>2];v[k>>2]=f|4096;if(!(f&512)){break m}if(!Fd(h)){break m}Db(i+8|0,m,105);if(Cb(i+8|0)){break m}nk(v[h>>2],c&65535)}if(v[e+1075672>>2]){break e}v[e+1075680>>2]=0;e=e+1075072|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}c=0;e=0;o:{if(!kk(j)){break o}if(!ue(w[(B(b,880)+a|0)+1075783|0])){break o}p:{d=ym(a,b,2,1);if(d-251>>>0<5){break p}if(!d){break o}e=v[(B(d,160)+a|0)+906140>>2];if(!e){break p}Db(i+8|0,m,34);c=(s=e,y=LS(j,Cb(i+8|0)),z=b,r=v[v[e>>2]+100>>2],kb[r](s|0,y|0,z|0)|0);break o}e=0}if(zi(j)?0:!c){break a}g=gA(a,b);if((g|0)==65535){break a}f=B(g,880)+a|0;d=f+1075072|0;l=f+1074984|0;q:{if(!(w[f+1075073|0]&2)){break q}if(!Fd(h)){break q}Qh(v[h>>2],g,1)}lu(l,j);v[d>>2]=v[d>>2]&-917505;t[f+1075817|0]=0;k=x[a+480188>>1];t[f+1075791|0]=0;u[f+1075772>>1]=b>>>0<k>>>0?b+1|0:0;r:{if(!e|c^1){break r}c=w[(B(b,880)+a|0)+1075784|0];if(c>>>0>3|(c|0)==1){break r}tl(a,b,255,0);t[(B(b,880)+a|0)+1075786|0]=0}s:{t:{switch(w[(B(b,880)+a|0)+1075784|0]){case 2:wo(a,l);if(!(w[d+1|0]&2)){break s}if(!Fd(h)){break s}nk(v[h>>2],b);Db(i+8|0,m,105);if(!Cb(i+8|0)){break s}KA(v[h>>2],b,g);break s;case 0:v[(B(g,880)+a|0)+1075680>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break s}if(!Fd(h)){break s}Qh(v[h>>2],b,1);break s;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break s}if(!Fd(h)){break s}Db(i+8|0,m,105);e=Cb(i+8|0);c=v[h>>2];if(e){KA(c,b,g);break s}nk(c,b);break s;case 1:break t;default:break s}}if(!(w[d+1|0]&2)){break s}if(!Fd(h)){break s}KA(v[h>>2],b,g)}if(!v[(B(g,880)+a|0)+1075672>>2]){v[(B(g,880)+a|0)+1075680>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,880)+a|0;v[a+1075060>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075076|0;v[a>>2]=0;v[a+4>>2]=0}gb=i+16|0}function wda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0;d=gb-128|0;gb=d;h=-1;a:{b:{c:{d:{if(!Sf(v[v[b>>2]-12>>2]+b|0)){break d}we(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];Sj(d+104|0);cl(b,d+104|0,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=ph(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;Xj(b,d+8|0);break d}u[d+86>>1]=0;Yf(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}Sj(d+78|0);cl(b,d+78|0,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;Yf(b,d+76|0);e=u[d+76>>1];if((e-3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Jb(d+112|0);v[23048]=0;f=W(694,b|0,e|0,65535)|0;i=v[23048];v[23048]=0;if((i|0)==1){break b}if(!f){break j}v[23048]=0;T(13,d- -64|0,c|0,e|0);f=v[23048];v[23048]=0;if((f|0)!=1){break k}break b}e=Jb(d+112|0);v[23048]=0;f=W(696,b|0,e|0,255)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}if(!f){break i}v[23048]=0;T(13,d- -64|0,c|0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}}Eb(a+40|0,d- -64|0);vb(d- -64|0);vb(e);u[d+62>>1]=0;Yf(b,d+62|0);u[d+60>>1]=0;Yf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;uk(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=Fv(e);u[d+58>>1]=e;break l}Yf(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Jb(d+112|0);v[23048]=0;u[d+40>>1]=0;Q(1527,b|0,d+40|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[23048]=0;g=W(694,b|0,e|0,65535)|0;j=v[23048];v[23048]=0;if((j|0)==1){break g}if(g){break q}break e}v[23048]=0;g=W(696,b|0,e|0,255)|0;j=v[23048];v[23048]=0;if((j|0)==1){break g}if(!g){break e}}v[23048]=0;T(13,d- -64|0,c|0,e|0);g=v[23048];v[23048]=0;if((g|0)==1){break p}v[23048]=0;g=Q(1528,i|0,d+40|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break o}Eb(g,d- -64|0);vb(d- -64|0);vb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}Sj(d- -64|0);cl(b,d- -64|0,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if(sN(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(d- -64|0);break f}if(!rN(b,c)){break d}}c=a+16|0;r:{if(u[d+86>>1]<=2){if(sN(b,c)){break r}break d}if(!rN(b,c)){break d}}l=a,m=Lb(a+16|0),v[l+36>>2]=m;u[d+56>>1]=0;Yf(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c+200&65535)>>>0>400){break d}u[d+54>>1]=0;Yf(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break d}v[d+48>>2]=0;rq(b,d+48|0);k=z[d+48>>2];z[a+32>>2]=k;if(k<C(0)){break d}Sj(d+40|0);cl(b,d+40|0,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}c=a+4|0;if(Lb(c)>>>0>32767){break d}f=a+32|0;s:{if(!(z[f>>2]>C(0)?u[a+30>>1]>=1:0)){if(!x[a>>1]){break s}break d}t:{switch(x[a>>1]-1|0){case 0:case 2:break t;default:break s}}if(Lb(c)>>>0<u[a+30>>1]>>>0){break d}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}l=d,m=Ii(b),v[l+112>>2]=m;v[d+32>>2]=0;l=a,m=v[Gm(d+112|0,d+32|0,46024)>>2],v[l+36>>2]=m;sq(a);h=1;if(x[a>>1]!=3){break d}if((wN(Lb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=nc(d+112|0);b=0;if(u[a+30>>1]>0){while(1){h=Mb(c,b-u[a+28>>1]|0);v[23048]=0;S(1529,e|0,h|0);h=v[23048];v[23048]=0;if((h|0)==1){break h}b=b+1|0;if((b|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;l=d,m=(Lb(c)+b|0)-1|0,u[l+34>>1]=m;v[23048]=0;u[d+30>>1]=0;ga(1525,a|0,e|0,f|0,d+32|0,d+30|0)|0;a=v[23048];v[23048]=0;h=1;if((a|0)!=1){Qc(e);break d}break h}vb(e);break d}vb(e);break d}b=P()|0;O()|0;Qc(e);break a}b=P()|0;O()|0}vb(e);break a}vb(e)}gb=d+128|0;return h|0}b=P()|0;O()|0;vb(e);break a}b=P()|0;O()|0;vb(e)}R(b|0);L()}function $I(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;i=gb-560|0;gb=i;g=c;c=(c-3|0)/24|0;r=(c|0)>0?c:0;l=g+B(r,-24)|0;n=v[(e<<2)+71968>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=r-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+71984>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}p=l-24|0;h=(n|0)>0?n:0;g=0;while(1){f=0;if((d|0)>0){k=g+j|0;c=0;while(1){f=f+A[(c<<3)+a>>3]*A[(i+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=n;while(1){f=A[(g<<3)+i>>3];c=0;h=g;q=(g|0)<1;if(!q){while(1){k=(i+480|0)+(c<<2)|0;m=f;f=f*5.960464477539063e-8;a:{if(D(f)<2147483648){j=~~f;break a}j=-2147483648}f=+(j|0);m=m+f*-16777216;b:{if(D(m)<2147483648){j=~~m;break b}j=-2147483648}v[k>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Qi(f,p);f=f+H(f*.125)*-8;c:{if(D(f)<2147483648){k=~~f;break c}k=-2147483648}f=f-+(k|0);d:{e:{f:{u=(p|0)<1;g:{if(!u){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>t;s=h;h=j-(c<<t)|0;v[s+476>>2]=h;k=c+k|0;j=h>>y;break g}if(p){break f}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<1){break d}break e}j=2;if(f>=.5){break e}j=0;break d}h:{if(q){h=0;break h}c=0;w=1;while(1){h=(i+480|0)+(c<<2)|0;q=v[h>>2];s=h;i:{if(w){h=0;if(!q){break i}h=16777216-q|0}else{h=16777215-q|0}v[s>>2]=h;h=1}c=c+1|0;if((g|0)==(c|0)){break h}w=!h;continue}}j:{if(u){break j}k:{switch(z|0){case 0:c=(g<<2)+i|0;v[c+476>>2]=v[c+476>>2]&8388607;break j;case 1:break k;default:break j}}c=(g<<2)+i|0;v[c+476>>2]=v[c+476>>2]&4194303}k=k+1|0;if((j|0)!=2){break d}f=1-f;j=2;if(!h){break d}f=f-Qi(1,p)}l:{m:{if(f==0){h=0;c=g;if((n|0)>=(c|0)){break l}while(1){c=c-1|0;h=v[(i+480|0)+(c<<2)>>2]|h;if((c|0)>(n|0)){continue}break}if(!h){break l}l=p;while(1){l=l-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break m}f=Qi(f,24-l|0);n:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f;f=f*5.960464477539063e-8;o:{if(D(f)<2147483648){c=~~f;break o}c=-2147483648}f=m+ +(c|0)*-16777216;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}l=p}v[(i+480|0)+(g<<2)>>2]=c}f=Qi(1,l);if((g|0)>=0){c=g;while(1){A[(c<<3)+i>>3]=f*+v[(i+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c-1|0;if(a){continue}break}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){q:{f=f+A[(c<<3)+74752>>3]*A[(a+c<<3)+i>>3];if((c|0)>=(n|0)){break q}h=c>>>0<d>>>0;c=c+1|0;if(h){continue}}break}A[(i+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<1){break u}d=(i+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;a=c-1|0;e=(i+160|0)+(a<<3)|0;x=A[e>>3];f=f+x;A[(i+160|0)+(c<<3)>>3]=m+(x-f);A[e>>3]=f;e=(c|0)>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;a=c-1|0;d=(i+160|0)+(a<<3)|0;o=A[d>>3];f=f+o;A[(i+160|0)+(c<<3)>>3]=m+(o-f);A[d>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}o=0;while(1){o=o+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break s}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=o;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){f=f+A[(i+160|0)+(g<<3)>>3];a=(g|0)>0;g=g-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){c=g;while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)>0;c=c-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-o;A[b+8>>3]=-f}gb=i+560|0;return k&7}c=1;while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(n-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(r+g<<2)+71984>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}}function Cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-144|0;gb=e;d=-1;a:{b:{c:{d:{if(!cp(v[v[b>>2]-12>>2]+b|0)){b=bm(e+40|0,b);v[23048]=0;d=Q(662,e+24|0,46028)|0;f=v[23048];v[23048]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((f|0)!=1){v[23048]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;T(663,b|0,d|0,e+16|0);f=v[23048];v[23048]=0;if((f|0)==1){break E}Hb(d);t[e+15|0]=0;v[23048]=0;d=Q(662,e+24|0,46038)|0;f=v[23048];v[23048]=0;if((f|0)==1){break D}v[23048]=0;W(664,b|0,e+15|0,d|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break C}Hb(d);v[23048]=0;f=w[e+15|0];d=Q(662,e+24|0,46043)|0;g=v[23048];v[23048]=0;if((g|0)==1){break B}v[23048]=0;f=f?0:c;Y(1519,b|0,a+40|0,d|0,f|0);c=v[23048];v[23048]=0;if((c|0)==1){break A}Hb(d);u[e+12>>1]=65535;v[23048]=0;c=Q(662,e+24|0,46045)|0;d=v[23048];v[23048]=0;if((d|0)==1){break z}v[23048]=0;W(1120,b|0,e+12|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break y}Hb(c);u[e+10>>1]=0;v[23048]=0;c=Q(662,e+24|0,46047)|0;d=v[23048];v[23048]=0;if((d|0)==1){break x}v[23048]=0;W(1120,b|0,e+10|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break w}Hb(c);u[a>>1]=x[e+10>>1];v[23048]=0;c=Q(662,e+24|0,46049)|0;d=v[23048];v[23048]=0;if((d|0)==1){break v}v[23048]=0;Y(1520,b|0,a+52|0,c|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break u}Hb(c);v[23048]=0;c=Q(662,e+24|0,46051)|0;d=v[23048];v[23048]=0;if((d|0)==1){break t}v[23048]=0;W(1492,b|0,a+36|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break s}Hb(c);v[23048]=0;c=Q(662,e+24|0,46053)|0;d=v[23048];v[23048]=0;if((d|0)==1){break r}v[23048]=0;f=a+4|0;T(1521,b|0,f|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break q}Hb(c);v[23048]=0;c=Q(662,e+24|0,46058)|0;d=v[23048];v[23048]=0;if((d|0)==1){break p}v[23048]=0;g=a+28|0;T(1522,b|0,g|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break o}Hb(c);v[23048]=0;c=Q(662,e+24|0,46063)|0;d=v[23048];v[23048]=0;if((d|0)==1){break n}v[23048]=0;T(1522,b|0,a+30|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break m}Hb(c);v[23048]=0;c=Q(662,e+24|0,46068)|0;d=v[23048];v[23048]=0;if((d|0)==1){break l}v[23048]=0;T(1523,b|0,a+32|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break k}Hb(c);u[e+8>>1]=0;v[23048]=0;c=Q(662,e+24|0,46073)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;W(1120,b|0,e+8|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break j}Hb(c);d=-1;if(v[b>>2]&1073741824|(x[g>>1]+300&65535)>>>0>=601){break e}c=x[a>>1];if(c>>>0>3|(c|0)==2|u[a+30>>1]<0){break e}i=e,j=Ii(v[a+36>>2]),v[i+24>>2]=j;v[23048]=0;v[e+16>>2]=0;c=Gm(e+24|0,e+16|0,46024);h=v[23048];v[23048]=0;if((h|0)==1){break c}v[a+36>>2]=v[c>>2];if(Lb(f)>>>0>32767){break e}switch(x[a>>1]-1|0){case 2:break i;case 0:break h;default:break g}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;Hb(c);break a}c=u[e+8>>1];if((c|0)<1){break e}u[e+6>>1]=x[a+30>>1];z[e+24>>2]=z[a+32>>2];f=x[a+28>>1];u[e+16>>1]=f;v[23048]=0;u[e+18>>1]=(c+f|0)-1;a=ba(1524,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}c=u[e+8>>1];if((c|0)<1){break e}z[e+24>>2]=z[a+32>>2];h=x[a+28>>1];u[e+16>>1]=h;v[23048]=0;u[e+18>>1]=(c+h|0)-1;a=ga(1525,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}v[23048]=0;_(1526,a|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}}d=1}Yg(b)}gb=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Yg(b);R(a|0);L()}function ML(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;m=gb-48|0;gb=m;v[m+44>>2]=0;if(!(i?0:!(d|g|h))){k=g?m+44|0:0;a:{if(!k){break a}j=v[k>>2];if(!j){break a}Zb(j);v[k>>2]=0}v[23048]=0;X(1324);j=v[23048];v[23048]=0;b:{c:{if((j|0)==1){l=Sa(90496,55612,55668,56328,90672,90776,90724,90616,90604,90920,90888,90856,90844,90472,0)|0;d:{e:{n=O()|0;if((n|0)==(da(90496)|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=277;if((k|0)==1){break e}break b}if((da(55612)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=358;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(55668)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=359;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(56328)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=357;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(90672)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=300;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(90776)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=299;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(90724)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=298;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(90616)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=297;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(90604)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=296;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(90920)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=289;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(90888)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=288;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(90856)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=287;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}if((da(90844)|0)==(n|0)){j=Z(l|0)|0;v[23048]=0;S(2036,k|0,j|0);k=v[23048];v[23048]=0;j=286;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break d}o=da(90472)|0;j=257;l=Z(l|0)|0;if((n|0)!=(o|0)){break b}v[23048]=0;S(2036,k|0,l|0);k=v[23048];v[23048]=0;j=267;if((k|0)!=1){break b}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break d}break c}j=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}}V(0)|0;O()|0;Ab()}L()}R(j|0);L()}$()}l=!g;if(d){k=kb[d|0](j,e)|0}else{k=3}if(!(l|!(k&2))){v[g+16>>2]=j;l=v[m+44>>2];f:{if(l){l=ie(l);break f}l=ie(52181)}v[g+20>>2]=l}if(h){v[h>>2]=j}if(i){g=v[m+44>>2];g:{if(g){g=ie(g);break g}g=ie(52181)}v[i>>2]=g}g=v[m+44>>2];if(g){Zb(g);v[m+44>>2]=0}h:{if(!(k&1)){break h}v[23048]=0;S(1921,m+32|0,a|0);g=v[23048];v[23048]=0;i:{j:{if((g|0)!=1){k:{if(f){v[23048]=0;S(1922,f|0,m+32|0);g=v[23048];v[23048]=0;if((g|0)!=1){break k}break j}g=Ob(m+32|0);if(b){v[23048]=0;S(b|0,g|0,c|0);g=v[23048];v[23048]=0;if((g|0)==1){break j}break k}Jt(g,m)}vb(m+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;vb(m+32|0)}Z(g|0)|0;v[m+28>>2]=f;v[m+24>>2]=e;v[m+20>>2]=d;v[m+16>>2]=c;v[m+12>>2]=b;v[m+8>>2]=a?a:52181;v[m+4>>2]=248;v[m>>2]=55537;hJ(55407,m);jt(91496);$()}gb=m+48|0}function moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-976|0;gb=e;yc(b);f=gb-32|0;gb=f;j=e+872|0;uX(f+24|0,j);h=xb(f+24|0);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;d=b;fc(f+16|0,d,f);i=xb(f+16|0);if((i|0)==(h|0)){Vb(d,xb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){tX(j)}a:{if(!d){break a}if(!yX(e+872|0)){break a}if(!Nb(b,Xc(xX(e+872|0),jb))){break a}b:{if(!c){break b}Ed(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Kb(a+1074308|0,7,1);d=Tb(e+96|0,17517);Eb(a+1300344|0,d);vb(d);d=Tb(e+96|0,17536);Eb(a+1300356|0,d);vb(d);v[a+1300404>>2]=5;OC(e+24|0,2,e+872|4);Fc(e+96|0,e+24|0);Eb(a+1300308|0,e+96|0);vb(e+96|0);while(1){d=(g<<5)+a|0;f=d+480280|0;We(f);h=f;f=(e+872|0)+g|0;v[h>>2]=!w[f+50|0]<<10;u[d+480284>>1]=(w[f+76|0]<<4|8)&248;g=g+1|0;if((g|0)!=16){continue}break}if(w[e+968|0]|w[e+969|0]<<8){bB(a+1300332|0,b,w[e+968|0]|w[e+969|0]<<8,132,0)}g=0;f=gb-32|0;gb=f;j=e+96|0;cc(f+24|0,j,771);h=xb(f+24|0);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;d=b;fc(f+16|0,d,f);i=xb(f+16|0);if((i|0)==(h|0)){Vb(d,xb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){Pb(j,0,771)}if(!d){break a}d=a+484360|0;wX(Qb(d),e+96|0,w[e+353|0]);ff(Qb(d),w[e+354|0]);Rc(b,w[e+919|0]|w[e+920|0]<<8);i=a+484344|0;q=c&1;f=0;c:{d:{while(1){d=(f<<1)+e|0;if(w[d+355|0]|w[d+356|0]<<8){td(e+24|0,b,w[d+355|0]|w[d+356|0]<<8);d=w[d+355|0]|w[d+356|0]<<8;j=(d-2|0)/64|0;e:{if(!q){break e}v[23048]=0;g=W(386,i|0,f&65535,j|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(!g){break e}v[23048]=0;m=U(373,e+24|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}v[23048]=0;Q(370,e+24|0,1)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}if(d>>>0>=66){r=j>>>0>1?j:1;l=0;while(1){d=Yb(i,f);v[23048]=0;n=Of(d,l);d=v[23048];v[23048]=0;g=0;if((d|0)==1){break d}f:{while(1){g:{v[23048]=0;S(571,e+80|0,e+24|0);d=v[23048];v[23048]=0;if((d|0)==1){break g}h=rd(e+80|0);d=Df(e+80|0);o=Ri(e+80|0);k=w[e+80|0];if((k-1&255)>>>0<=71){p=B(g,6)+n|0;t[p|0]=k+36;t[p+1|0]=w[h|0]+1}if((w[d|0]-1&255)>>>0<=15){h=B(g,6)+n|0;t[h+2|0]=1;t[h+4|0]=((w[d|0]<<6)+-64>>>0)/15}d=B(g,6)+n|0;k=w[o|0];h=k&15;t[d+5|0]=h;h:{i:{switch((w[o|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break h;case 2:t[d+5|0]=h<<2;break h;case 3:t[d+5|0]=(6/(h+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=h<<3;break h;case 9:t[d+4|0]=(h<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=h|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(h+1>>>0)|0)+1|13}t[d+3|0]=w[(w[o|0]>>>4|0)+17552|0];g=g+1|0;if((g|0)!=16){continue}break f}break}break d}l=l+1|0;if((r|0)!=(l|0)){continue}break}}d=Yb(i,f);v[23048]=0;g=De(e+80|0,14,0);h=v[23048];v[23048]=0;if((h|0)==1){break d}g=wh(Ve(g,m?j-2>>>0>m>>>0?m+1|0:-1:-1));v[23048]=0;Q(479,d|0,g|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}}yb(e+24|0)}f=f+1|0;if((f|0)!=256){continue}break}g=1;if(!(c&2)){break a}EY(b,e+72|0);g=0;while(1){j:{k:{if(!(w[e+72+(g>>>3)|0]>>>(g&7)&1)){g=g+1|0;break k}if(!NC(b,e+24|0)){break b}g=g+1|0;u[a+480190>>1]=g;df(e+8|0,1,e+24|0);Fc(e+80|0,e+8|0);c=x[a+480190>>1];v[23048]=0;Q(354,((c<<5)+a|0)+946300|0,e+80|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break j}vb(e+80|0);f=(B(g,104)+a|0)+484380|0;d=f;wd(d,0);c=e+24|0;v[d>>2]=w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24);v[d+4>>2]=w[c+38|0]|w[c+39|0]<<8|(w[c+40|0]<<16|w[c+41|0]<<24);h=w[c+42|0]|w[c+43|0]<<8|(w[c+44|0]<<16|w[c+45|0]<<24);v[d+24>>2]=16726;v[d+8>>2]=h;u[d+30>>1]=w[c+37|0]<<4;if(t[c+46|0]&1){v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}if(!(!(w[c+47|0]&8)|y[d+8>>2]<=y[d+4>>2])){u[d+34>>1]=x[d+34>>1]|2}Sc(e+80|0,t[e+70|0]&1?16:8,1,0,0);ug(e+80|0,f,b)}if((g|0)!=64){continue}break b}break}g=P()|0;O()|0;vb(e+80|0);break c}g=P()|0;O()|0;yb(e+24|0)}R(g|0);L()}g=1}gb=e+976|0;return g|0}function mk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=gb-112|0;gb=d;p=FA(a);q=Gi(p);e=q;f=a;c=Gc(f);a:{if(e>>>0>c>>>0){n=gb-32|0;gb=n;b:{l=e-c|0;c:{if(l>>>0<=(v[wb(f)>>2]-v[f+4>>2]|0)/12>>>0){e=gb-16|0;gb=e;i=$p(e,f,l);if(v[i+4>>2]!=v[i+8>>2]){while(1){wb(f);oR(v[i+4>>2]);c=v[i+4>>2]+12|0;v[i+4>>2]=c;if((c|0)!=v[i+8>>2]){continue}break}}_b(i);gb=e+16|0;break c}c=wb(f);e=AB(f,Gc(f)+l|0);i=Gc(f);j=gb-16|0;gb=j;v[j+12>>2]=0;g=n+8|0;vd(g+12|0,c);if(e){c=e;if(c>>>0>=357913942){xc(30794);L()}k=jc(B(c,12),4)}v[g>>2]=k;c=B(i,12)+k|0;v[g+8>>2]=c;v[g+4>>2]=c;r=bc(g),s=B(e,12)+k|0,v[r>>2]=s;gb=j+16|0;v[23048]=0;S(1158,g|0,l|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}cq(f);wb(f);e=g+4|0;j=e;k=v[f+4>>2];c=v[f>>2];if((k|0)!=(c|0)){i=v[j>>2];while(1){k=k-12|0;FB(i-12|0,k);i=v[j>>2]-12|0;v[j>>2]=i;if((c|0)!=(k|0)){continue}break}}zc(f,e);zc(f+4|0,g+8|0);zc(wb(f),bc(g));v[g>>2]=v[g+4>>2];$w(f,Gc(f));pR(g)}gb=n+32|0;break a}a=P()|0;O()|0;pR(g);R(a|0);L()}if(c>>>0>e>>>0){e=v[f>>2]+B(e,12)|0;Gc(f);rR(f,e);qR(f)}}if(b){c=a+12|0;Uq(c,$d(c));r=wb(c),s=0,v[r>>2]=s;r=c,s=dc(c),v[r>>2]=s;r=dc(c),s=0,v[r>>2]=s;v[a+28>>2]=0}o=nc(d+96|0);c=v[a+24>>2];v[23048]=0;e=uq(c+484344|0);c=v[23048];v[23048]=0;d:{e:{f:{g:{if((c|0)==1){break g}v[23048]=0;k=W(832,d+80|0,e|0,30792)|0;c=v[23048];v[23048]=0;if((c|0)==1){break g}u[d+78>>1]=0;if(q){g=a+12|0;while(1){l=x[sc(p,m)>>1];c=BR(a,l);v[d+72>>2]=c;f=Id(a,x[d+78>>1]);h:{if(b){v[23048]=0;t[d+32|0]=0;T(1152,f|0,c|0,d+32|0);c=v[23048];v[23048]=0;if((c|0)!=1){break h}h=P()|0;O()|0;break e}v[23048]=0;T(982,f|0,c|0,0);c=v[23048];v[23048]=0;if((c|0)==1){break f}}v[23048]=0;e=Q(516,p|0,x[d+78>>1])|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}i:{if(!e){break i}h=0;h=b?h:v[f+4>>2];v[23048]=0;v[d+32>>2]=h;e=Gb(d+32|0,d+72|0);c=v[23048];v[23048]=0;j:{k:{if((c|0)!=1){v[d+68>>2]=v[e>>2];i=Xg(g);if(x[sc(k,l)>>1]!=65535){e=EA(g,Hm(d+32|0,sc(k,l),d+68|0));v[d+64>>2]=e;r=d,s=Xg(g),v[r+8>>2]=s;j=d;l:{if(Xf(d- -64|0,d+8|0)){f=EA(g,Hm(d+32|0,sc(k,l),d+72|0));break l}f=Xg(g)}v[j+56>>2]=f;v[d+48>>2]=e;if(!Xf(d+48|0,d+56|0)){break i}while(1){m:{f=dd(d+32|0);c=mg(se(d+48|0)+8|0);v[23048]=0;S(1153,f|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break m}kB(d+16|0,i);c=Hm(d+8|0,d+78|0,se(d+48|0)+4|0);v[23048]=0;e=ba(1154,g|0,v[d+16>>2],c|0,f|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break m}v[d+24>>2]=e;zR(d+24|0);i=v[d+24>>2];Vq(f);if(Xf(zR(d+48|0),d+56|0)){continue}break i}break}h=P()|0;O()|0;Vq(f);break e}f=Yb(v[a+24>>2]+484344|0,l);v[23048]=0;e=wi(f);c=v[23048];v[23048]=0;n:{o:{if((c|0)!=1){v[23048]=0;t[d+32|0]=0;T(1156,o|0,e|0,d+32|0);c=v[23048];v[23048]=0;if((c|0)==1){break o}j=v[d+72>>2];if((j|0)!=v[d+68>>2]){break n}break j}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}p:while(1){q:{m=0;v[23048]=0;j=j-1|0;v[d+64>>2]=j;h=Of(f,j);c=v[23048];v[23048]=0;n=1;if((c|0)==1){break k}while(1){r:{v[23048]=0;e=wi(f);c=v[23048];v[23048]=0;s:{if((c|0)!=1){if(e>>>0>m>>>0?n>>>0<=15:0){break s}if(n>>>0>1){e=dd(d+32|0);v[23048]=0;S(1153,e|0,n|0);c=v[23048];v[23048]=0;if((c|0)==1){break r}kB(d,i);c=Hm(d+8|0,d+78|0,d- -64|0);v[23048]=0;i=ba(1154,g|0,v[d>>2],c|0,e|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break q}Vq(e)}if(v[d+68>>2]==(j|0)){break j}continue p}h=P()|0;O()|0;break e}e=w[oc(o,m)|0];t:{u:{v:{switch(w[h+3|0]-19|0){case 1:c=w[h+5|0];if((c&240)==176){break u}break t;case 0:break v;default:break t}}c=w[h+5|0];if((c&240)!=96){break t}}r=oc(o,m),s=c&15,t[r|0]=s;if(!w[oc(o,m)|0]){break t}e=w[oc(o,m)|0]}n=B(e?e+1|0:1,n);h=h+6|0;m=m+1|0;continue}break}}break}h=P()|0;O()|0;Vq(e);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}if(j){break i}c=x[d+78>>1];r=sc(k,l),s=c,u[r>>1]=s}c=x[d+78>>1]+1|0;u[d+78>>1]=c;m=c&65535;if(q>>>0>m>>>0){continue}break}}Ze(k);gc(o);gb=d+112|0;return}h=P()|0;O()|0;break d}h=P()|0;O()|0}Ze(k)}gc(o);R(h|0);L()}function B2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb+-64|0;gb=h;v[h+56>>2]=b;v[e>>2]=0;Ic(h,d);v[23048]=0;i=U(2375,h|0)|0;j=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Xb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Xb(h);R(a|0);L()}oH(a,f+24|0,h+56|0,c,e,i);break b}nH(a,f+16|0,h+56|0,c,e,i);break b}b=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=Vj(a,v[h+56>>2],c,d,e,f,Ob(b),Ob(b)+(Bb(b)<<2)|0),v[k+56>>2]=l;break b}a=e;b=aj(h+56|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}g=v[21043];v[h+24>>2]=v[21042];v[h+28>>2]=g;g=v[21041];v[h+16>>2]=v[21040];v[h+20>>2]=g;g=v[21039];v[h+8>>2]=v[21038];v[h+12>>2]=g;g=v[21037];v[h>>2]=v[21036];v[h+4>>2]=g;k=h,l=Vj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[21051];v[h+24>>2]=v[21050];v[h+28>>2]=g;g=v[21049];v[h+16>>2]=v[21048];v[h+20>>2]=g;g=v[21047];v[h+8>>2]=v[21046];v[h+12>>2]=g;g=v[21045];v[h>>2]=v[21044];v[h+4>>2]=g;k=h,l=Vj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=aj(h+56|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=aj(h+56|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=aj(h+56|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=aj(h+56|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=aj(h+56|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+56|0;H:{if(!lm(b,a+8|0)){break H}while(1){if(!bl(i,8192,km(b))){break H}jm(b);if(lm(b,a+8|0)){continue}break}}if(al(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+56|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(a)|0)==(0-Bb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Ks(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=hc(h,84208,44);k=g,l=Vj(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[21068];g=v[21067];v[h+8>>2]=v[21066];v[h+12>>2]=g;g=v[21065];v[h>>2]=v[21064];v[h+4>>2]=g;k=h,l=Vj(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=e;b=aj(h+56|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}g=v[21079];v[h+24>>2]=v[21078];v[h+28>>2]=g;g=v[21077];v[h+16>>2]=v[21076];v[h+20>>2]=g;g=v[21075];v[h+8>>2]=v[21074];v[h+12>>2]=g;g=v[21073];v[h>>2]=v[21072];v[h+4>>2]=g;k=h,l=Vj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=aj(h+56|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=Vj(a,v[h+56>>2],c,d,e,f,Ob(b),Ob(b)+(Bb(b)<<2)|0),v[k+56>>2]=l;break b}mH(f+20|0,h+56|0,c,e,i);break b}a=aj(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(al(c,a+8|0)){break M}b=4;if((In(i,km(c))|0)!=37){break M}b=2;if(!al(jm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+56>>2]}gb=h- -64|0;return a|0}function dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-80|0;gb=f;a:{if(!Nb(c,8)){break a}Vb(c,4);while(1){l=vr(c);if(l){break a}o=gb-288|0;gb=o;g=TR(o);e=0;i=gb-384|0;gb=i;TR(i+96|0);j=hc(g,i+96|0,282);k=c;b:{c:{d:{e:{f:{g:{h:{if(xh(c,29692)){kg(k,4);m=Me(i+72|0,k);v[23048]=0;g=Q(1131,m|0,j|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break e}i:{if(!g){break i}g=w[j+26|0];v[23048]=0;g=Q(250,m|0,g|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break e}if(!g){break i}h=0;j:{k:{l:{if(w[j+26|0]){while(1){v[23048]=0;g=U(360,m|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break l}t[(h+j|0)+27|0]=g;e=e+g|0;h=h+1|0;if(h>>>0<w[j+26|0]){continue}break}h=e&65535}e=0;v[23048]=0;g=Q(250,m|0,h|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break d}if(!g){break i}v[23048]=0;Q(370,m|0,h|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}kg(m,UR(j));g=yk(i- -64|0);IA(i+96|0);v[23048]=0;S(1132,m|0,i+96|0);e=v[23048];v[23048]=0;if((e|0)==1){break k}u[i+118>>1]=0;u[i+120>>1]=0;SR(g,i+96|0,i+123|0);e=w[j+26|0];v[23048]=0;Q(370,m|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break k}e=j+27|0;SR(g,e,e+w[j+26|0]|0);v[23048]=0;T(341,i+40|0,m|0,h|0);e=v[23048];v[23048]=0;if((e|0)!=1){break j}h=P()|0;O()|0;break c}h=P()|0;O()|0;break c}h=P()|0;O()|0;break c}v[23048]=0;S(795,i+16|0,i+40|0);e=v[23048];v[23048]=0;if((e|0)==1){break h}v[23048]=0;Zv(i+8|0,i+16|0);e=v[23048];v[23048]=0;if((e|0)==1){break g}h=g;n=i+8|0;e=v[n>>2];n=v[n+4>>2];if((e|0)!=(n|0)){while(1){QR(h,zb(w[e|0]));e=e+1|0;if((n|0)!=(e|0)){continue}break}}Ac(i+16|0);yb(i+40|0);e=0;if(v[g>>2]!=(w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24))){break i}e=UR(j);v[23048]=0;Q(370,k|0,e|0)|0;g=v[23048];v[23048]=0;e=1;if((g|0)==1){break d}}yb(m)}gb=i+384|0;break b}h=P()|0;O()|0;break f}h=P()|0;O()|0;Ac(i+16|0)}yb(i+40|0);break c}h=P()|0;O()|0;break c}h=P()|0;O()|0}yb(m);R(h|0);L()}gb=o+288|0;if(e){continue}break}}t[d|0]=w[d|0]!=0|l;yc(c);m:{n:{o:{p:{q:{r:{if(l){d=_f(c);td(f+56|0,c,Bf(c));u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=d>>>(b&1)>>>(b>>>6&1);v[f+52>>2]=0;v[f+48>>2]=0;v[23048]=0;S(795,f+24|0,f+56|0);b=v[23048];v[23048]=0;if((b|0)==1){break r}v[23048]=0;c=Wd(f+24|0);b=v[23048];v[23048]=0;if((b|0)!=1){d=v[f+24>>2];b=zb(c);e=Ii(d);v[23048]=0;b=ga(794,b|0,e|0,f+52|0,f+48|0,0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break o}v[23048]=0;Q(370,f+56|0,v[f+52>>2])|0;e=v[23048];v[23048]=0;if((e|0)==1){break o}if(!b){break p}e=v[f+52>>2];v[23048]=0;U(446,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break o}d=d-e|0;e=c+e|0;c=v[f+48>>2];l=0;while(1){s:{if(c){if(!d|(c|0)!=1){break q}if(y[a>>2]>l>>>0){break s}break q}if(y[a>>2]<=l>>>0){break q}}if(!Od(a)){break q}v[f+20>>2]=0;v[f+16>>2]=0;c=zb(e);g=Ii(d);v[23048]=0;c=la(796,b|0,c|0,g|0,f+20|0,f+12|0,f+16|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break o}v[23048]=0;v[f+52>>2]=c;Q(370,f+56|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break o}g=v[f+52>>2];Hl(f+16|0,Ii(v[a>>2]-l|0));t:{if(v[f+16>>2]<1){break t}if(v[f+20>>2]!=(ld(a)|0)){break t}c=0;if(v[f+20>>2]<=0){break t}while(1){u:{if(t[a+34|0]&1){k=v[a+20>>2];h=ld(a);i=v[v[f+12>>2]+(c<<2)>>2];v[23048]=0;ea(797,k+(B(h,l)<<1)|0,i|0,v[f+20>>2],v[f+16>>2],c|0);k=v[23048];v[23048]=0;if((k|0)!=1){break u}break o}k=v[a+20>>2];h=ld(a);i=v[v[f+12>>2]+(c<<2)>>2];v[23048]=0;ea(798,k+B(h,l)|0,i|0,v[f+20>>2],v[f+16>>2],c|0);k=v[23048];v[23048]=0;if((k|0)==1){break o}}c=c+1|0;if((c|0)<v[f+20>>2]){continue}break}}v[23048]=0;k=v[f+16>>2];c=cy(b);h=v[23048];v[23048]=0;if((h|0)==1){break o}d=d-g|0;e=e+g|0;v[f+48>>2]=c;l=k+l|0;continue}}break o}ug(b,a,c);c=1;break m}c=P()|0;O()|0;break n}v[23048]=0;dy(b);a=v[23048];v[23048]=0;if((a|0)!=1){break p}break o}c=(b|0)!=0;Ac(f+24|0);yb(f+56|0);break m}c=P()|0;O()|0;Ac(f+24|0)}yb(f+56|0);R(c|0);L()}gb=f+80|0;return c|0}function SO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;a:{b:{c:{if(!ue(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break c}d=v[((d<<2)+b|0)+900380>>2];if(!d){break c}d=v[d+44>>2];if(!d){break c}u[h+14>>1]=c-61;b=gb-80|0;gb=b;e=u[d+28>>1];f=h+14|0;c=u[f>>1];g=d+4|0;Lb(g);d:{e:{if((c|0)>=(e|0)){if((c|0)<=(x[d+28>>1]+Lb(g)<<16)-65536>>16){break e}}Jb(a);break d}f:{c=x[d+30>>1];if(!c){c=d+52|0;l=b,m=Yy(c,f),v[l+56>>2]=m;l=b,m=Xg(c),v[l+40>>2]=m;if(!Xf(b+56|0,b+40|0)){break f}cg(a,se(b+56|0)+4|0);break d}e=mo(u[f>>1],c<<16>>16);u[b+78>>1]=e;c=Jb(a);a=d+52|0;l=b,m=Yy(a,b+78|0),v[l+72>>2]=m;l=b,m=Xg(a),v[l+56>>2]=m;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if(Xf(b+72|0,b+56|0)){a=se(b+72|0);v[23048]=0;Q(224,c|0,a+4|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break w}a=u[d+30>>1];d=u[f>>1];v[23048]=0;l=b,m=Xy(d,a)+5|0,v[l+40>>2]=m;S(221,b+56|0,b+40|0);a=v[23048];v[23048]=0;if((a|0)==1){break h}v[23048]=0;Q(183,c|0,b+56|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){vb(b+56|0);break d}a=P()|0;O()|0;vb(b+56|0);break g}if(u[d+30>>1]>26){break t}v[23048]=0;e=W(753,b+40|0,1,(e<<24)+1090519040>>24)|0;a=v[23048];v[23048]=0;if((a|0)==1){break v}v[23048]=0;T(13,b+56|0,0,e|0);a=v[23048];v[23048]=0;if((a|0)==1){break u}Eb(c,b+56|0);vb(b+56|0);vb(e);v[23048]=0;Q(222,c|0,46021)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break s}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(e);break g}v[23048]=0;a=(e<<16>>16)/16|0;v[b+36>>2]=e-(a<<4)<<16>>16;S(1516,b+40|0,b+36|0);g=v[23048];v[23048]=0;if((g|0)==1){break r}v[23048]=0;v[b+20>>2]=(a<<16>>16)%16;S(1516,b+24|0,b+20|0);a=v[23048];v[23048]=0;if((a|0)==1){break q}v[23048]=0;T(3,b+56|0,b+40|0,b+24|0);a=v[23048];v[23048]=0;if((a|0)==1){break p}Eb(c,b+56|0);vb(b+56|0);vb(b+24|0);vb(b+40|0);if(e<<16>>16<256){break s}v[23048]=0;T(9,b+8|0,0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break n}v[23048]=0;Hy(b+40|0,b+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break m}v[23048]=0;T(13,b+56|0,0,b+40|0);a=v[23048];v[23048]=0;if((a|0)==1){break l}Eb(c,b+56|0);vb(b+56|0);vb(b+40|0);vb(b+8|0)}a=u[d+30>>1];d=u[f>>1];v[23048]=0;l=b,m=Xy(d,a)+5|0,v[l+40>>2]=m;S(221,b+56|0,b+40|0);a=v[23048];v[23048]=0;if((a|0)==1){break j}v[23048]=0;Q(183,c|0,b+56|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break i}vb(b+56|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;break o}a=P()|0;O()|0;vb(b+24|0)}vb(b+40|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break k}a=P()|0;O()|0;vb(b+40|0)}vb(b+8|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(b+56|0);break g}a=P()|0;O()|0}vb(c);R(a|0);L()}e=gb-16|0;gb=e;c=gb-16|0;gb=c;d=$g(e,1,0);x:{while(1){g=Ob(d);i=Ob(d);j=Bb(d);k=u[f>>1];v[23048]=0;Y(126,c+8|0,g|0,i+j|0,k|0);g=v[23048];v[23048]=0;if((g|0)==1){break a}if(!v[c+12>>2]){break x}g=Bb(d);v[23048]=0;v[c+4>>2]=g;g=Bj(c+4|0);i=v[23048];v[23048]=0;if((i|0)!=1){v[23048]=0;T(123,d|0,g|0,0);g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break a}f=v[c+8>>2];g=Ob(d);v[23048]=0;S(124,d|0,f-g|0);f=v[23048];v[23048]=0;if((f|0)==1){break a}gb=c+16|0;v[23048]=0;T(13,a|0,0,e|0);a=v[23048];v[23048]=0;y:{if((a|0)!=1){vb(e);gb=e+16|0;break y}a=P()|0;O()|0;vb(e);R(a|0);L()}}gb=b+80|0;break b}f=v[b>>2];b=gb-32|0;gb=b;z:{if(RO(c)){v[b+16>>2]=v[8236];d=v[8235];v[b+8>>2]=v[8234];v[b+12>>2]=d;d=v[8233];v[b>>2]=v[8232];v[b+4>>2]=d;Tb(a,(b+(c<<2)|0)-1004|0);break z}if(ue(c)){d=Jb(b);v[23048]=0;e=c-1|0;c=(e<<16>>16)/12|0;f=Q(1339,d|0,f+(e-B(c,12)<<16>>16<<2)|0)|0;e=v[23048];v[23048]=0;A:{if((e|0)==1){break A}v[23048]=0;c=Q(1340,f|0,(c<<16)+3145728>>16)|0;f=v[23048];v[23048]=0;if((f|0)==1){break A}v[23048]=0;Q(4,a|0,c|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break A}vb(d);break z}break a}if(!c){Tb(a,32948);break z}Tb(a,32952)}gb=b+32|0}gb=h+16|0;return}a=P()|0;O()|0;vb(d);R(a|0);L()}function re(a,b){var c=C(0),d=C(0),e=C(0),f=0,g=0,h=0,i=0,k=0,m=C(0),n=0,o=C(0),r=C(0),s=0,t=C(0),u=C(0),v=C(0),w=C(0);d=C(1);a:{b:{c:{k=(p(a),j(2));d:{if((k|0)==1065353216){break d}i=(p(b),j(2));f=i&2147483647;if(!f){break d}h=k&2147483647;c=C(a+b);if(!(f>>>0<2139095041?h>>>0<=2139095040:0)){break a}e:{f:{if((k|0)>-1){break f}n=2;if(f>>>0>1266679807){break e}if(f>>>0<1065353216){break f}g=150-(f>>>23|0)|0;s=f>>>g|0;n=0;if((f|0)!=s<<g){break e}n=2-(s&1)|0;break e}n=0}g=n;g:{if((f|0)!=1065353216){if((f|0)!=2139095040){break g}if((h|0)==1065353216){break d}c=(i|0)>-1?b:C(0);if(h>>>0>=1065353217){break a}c=(i|0)>-1?C(0):C(-b);break a}c=(i|0)>-1?a:C(C(1)/a);break a}c=C(a*a);if((i|0)==1073741824){break a}c=C(K(a));if(!((i|0)!=1056964608|(k|0)<0)){break a}d=C(D(a));if(!(h?(k&1073741823)!=1065353216:0)){d=(i|0)<0?C(C(1)/d):d;if((k|0)>-1){break d}if(!(g|h-1065353216)){a=C(d-d);c=C(a/a);break a}c=(g|0)==1?C(-d):d;break a}o=C(1);h:{if((k|0)>-1){break h}i:{switch(g|0){case 0:a=C(a-a);c=C(a/a);break a;case 1:break i;default:break h}}o=C(-1)}j:{if(f>>>0>=1291845633){c=(i|0)<0?C(C(o*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(o*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(h>>>0<=1065353207){break a}c=(i|0)>0?C(C(o*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(o*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(h>>>0>=1065353224){break a}a=C(d+C(-1));r=C(a*C(1.44268798828125));d=C(C(a*C(7052607543300837e-21))+C(C(C(a*a)*C(C(.5)-C(a*C(C(a*C(-.25))+C(.3333333432674408)))))*C(-1.4426950216293335)));e=(l(2,(p(C(r+d)),j(2))&-4096),q());r=C(e-r);break j}f=h>>>0<8388608;h=f?(p(C(d*C(16777216))),j(2)):h;k=h&8388607;g=k|1065353216;h=(h>>23)+(f?-151:-127)|0;f=0;k:{if(k>>>0<1885298){break k}if(k>>>0<6140887){f=1;break k}g=g-8388608|0;h=h+1|0}k=f<<2;r=z[k+91472>>2];d=(l(2,g),q());m=z[k+91456>>2];c=C(d-m);t=C(C(1)/C(m+d));e=C(c*t);a=(l(2,(p(e),j(2))&-4096),q());u=C(a*a);v=a;w=c;c=(l(2,((g>>1&-536875008)+(f<<21)|0)+541065216|0),q());d=C(t*C(C(w-C(a*c))-C(a*C(d-C(c-m)))));c=C(C(e+a)*d);a=C(e*e);m=C(c+C(C(a*a)*C(C(a*C(C(a*C(C(a*C(C(a*C(C(a*C(.20697501301765442))+C(.23066075146198273)))+C(.2727281153202057)))+C(.3333333432674408)))+C(.4285714328289032)))+C(.6000000238418579))));a=(l(2,(p(C(C(u+C(3))+m)),j(2))&-4096),q());c=C(v*a);e=C(C(d*a)+C(e*C(m-C(C(a+C(-3))-u))));a=(l(2,(p(C(c+e)),j(2))&-4096),q());m=C(a*C(.9619140625));d=C(z[k+91464>>2]+C(C(C(e-C(a-c))*C(.9617967009544373))+C(a*C(-.00011736857413779944))));a=C(h|0);e=(l(2,(p(C(C(r+C(m+d))+a)),j(2))&-4096),q());r=C(C(C(e-a)-r)-m)}m=(l(2,i&-4096),q());a=C(e*m);b=C(C(C(d-r)*b)+C(C(b-m)*e));e=C(a+b);g=(p(e),j(2));if((g|0)>=1124073473){break c}l:{m:{if((g|0)==1124073472){n=134;if(!(C(b+C(4.299566569443414e-8))>C(e-a))){break m}break c}i=g&2147483647;if(!(!(b<=C(e-a))|(g|0)!=-1021968384)|i>>>0>=1125515265){break b}f=0;if(i>>>0<1056964609){break l}n=i>>>23|0}i=(8388608>>>n-126|0)+g|0;h=i>>>23&255;f=(i&8388607|8388608)>>>150-h|0;f=(g|0)<0?0-f|0:f;a=C(a-(l(2,i&-8388608>>h-127),q()));g=(p(C(b+a)),j(2))}e=(l(2,g&-32768),q());d=C(e*C(.693145751953125));e=C(C(e*C(14286065379565116e-22))+C(C(b-C(e-a))*C(.6931471824645996)));a=C(d+e);b=C(a*a);b=C(a-C(b*C(C(b*C(C(b*C(C(b*C(C(b*C(4.138136944220605e-8))+C(-16533901998627698e-22)))+C(661375597701408e-19)))+C(-.0027777778450399637)))+C(.1666666716337204))));c=C(C(a*b)/C(b+C(-2)));b=C(e-C(a-d));a=C(C(a-C(c-C(b+C(a*b))))+C(1));g=(p(a),j(2))+(f<<23)|0;n:{if((g|0)<=8388607){a=bJ(a,f);break n}a=(l(2,g),q())}d=C(o*a)}c=d;break a}c=C(C(o*C(1.0000000150474662e30))*C(1.0000000150474662e30));break a}c=C(C(o*C(1.0000000031710769e-30))*C(1.0000000031710769e-30))}return c}function H2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=b;v[e>>2]=0;Ic(h+8|0,d);v[23048]=0;i=U(21,h+8|0)|0;j=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Xb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Xb(h+8|0);R(a|0);L()}rH(a,f+24|0,h+24|0,c,e,i);break b}qH(a,f+16|0,h+24|0,c,e,i);break b}b=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=Wj(a,v[h+24>>2],c,d,e,f,Ob(b),Ob(b)+Bb(b)|0),v[k+24>>2]=l;break b}a=e;b=bj(h+24|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=bj(h+24|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=bj(h+24|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=bj(h+24|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=bj(h+24|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=bj(h+24|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+24|0;H:{if(!_j(b,a+8|0)){break H}while(1){if(!fh(i,8192,fl(b))){break H}el(b);if(_j(b,a+8|0)){continue}break}}if(Zj(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+24|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(a)|0)==(0-Bb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Ls(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[84127]|w[84128]<<8|(w[84129]<<16|w[84130]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[84124]|w[84125]<<8|(w[84126]<<16|w[84127]<<24);v[h+8>>2]=w[84120]|w[84121]<<8|(w[84122]<<16|w[84123]<<24);v[h+12>>2]=g;k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[84135];v[h+8>>2]=w[84131]|w[84132]<<8|(w[84133]<<16|w[84134]<<24);k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=e;b=bj(h+24|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=bj(h+24|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=Wj(a,v[h+24>>2],c,d,e,f,Ob(b),Ob(b)+Bb(b)|0),v[k+24>>2]=l;break b}pH(f+20|0,h+24|0,c,e,i);break b}a=bj(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(Zj(c,a+8|0)){break M}b=4;if((Jn(i,fl(c))|0)!=37){break M}b=2;if(!Zj(el(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+24>>2]}gb=h+32|0;return a|0}function hL(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=gb-256|0;gb=e;A[e+248>>3]=c;a:{if(jk(b)){break a}g=w[jl(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;wl(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}Md(e+216|0);f=v[e+216>>2];Md(e+200|0);h=il(f,v[e+204>>2],b);Md(e+216|0);f=v[b>>2];g=v[b+4>>2];c:{d:{e:{f:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=wc(e+232|0,56371);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Kc(e+16|0,e+8|0)){d=aa(8)|0;v[23048]=0;S(2064,e+200|0,e+248|0);a=v[23048];v[23048]=0;g:{h:{i:{if((a|0)!=1){v[23048]=0;T(2045,e+216|0,57575,e+200|0);a=v[23048];v[23048]=0;if((a|0)==1){break i}rc(d,e+216|0);a=0;v[23048]=0;T(84,d|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break c}b=P()|0;O()|0;vb(e+216|0);break h}b=P()|0;O()|0;break g}b=P()|0;a=1;O()|0}vb(e+200|0);if(!a){break d}}ca(d|0);break d}if(!d){break f}d=aa(8)|0;v[23048]=0;f=Q(2061,e+168|0,b|0)|0;b=v[23048];v[23048]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){v[23048]=0;T(2045,e+184|0,57454,f|0);a=v[23048];v[23048]=0;if((a|0)==1){break r}v[23048]=0;S(2057,e+200|0,e+184|0);b=v[23048];v[23048]=0;a=1;if((b|0)==1){break q}v[23048]=0;S(2064,e+152|0,e+248|0);a=v[23048];v[23048]=0;if((a|0)==1){break p}v[23048]=0;T(2062,e+216|0,e+200|0,e+152|0);b=v[23048];v[23048]=0;a=1;if((b|0)==1){break o}rc(d,e+216|0);v[23048]=0;T(84,d|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(e+216|0);a=0;break n}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;a=1;O()|0;break m}b=P()|0;O()|0}vb(e+152|0)}vb(e+200|0)}vb(e+184|0)}vb(f)}if(!a){break d}ca(d|0);break d}v[e+144>>2]=f;v[e+148>>2]=g;d=wc(e+136|0,56371);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Kc(e+80|0,e+72|0)){d=aa(8)|0;v[23048]=0;S(2064,e+200|0,e+248|0);a=v[23048];v[23048]=0;s:{t:{u:{if((a|0)!=1){v[23048]=0;T(2045,e+216|0,57575,e+200|0);a=v[23048];v[23048]=0;if((a|0)==1){break u}rc(d,e+216|0);a=0;v[23048]=0;T(84,d|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break c}b=P()|0;O()|0;vb(e+216|0);break t}b=P()|0;O()|0;break s}b=P()|0;a=1;O()|0}vb(e+200|0);if(!a){break d}}ca(d|0);break d}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=wc(e+120|0,57297);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Kc(e- -64|0,e+56|0)){if(!w[a+28|0]){break f}c=A[e+248>>3];if(!(c<=4?!(c<=0):0)){a=aa(8)|0;v[23048]=0;d=Q(91,e+216|0,57595)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}rc(a,d);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(d);break d}b=oh(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;Gq(v[a>>2]);break f}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=wc(e+104|0,57315);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Kc(e+48|0,e+40|0)){if(!w[a+28|0]){break f}c=A[e+248>>3];if(!(c<=4?!(c<=0):0)){a=aa(8)|0;v[23048]=0;d=Q(91,e+216|0,57616)|0;b=v[23048];v[23048]=0;if((b|0)!=1){rc(a,d);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(d);break d}b=P()|0;O()|0;ca(a|0);break d}b=oh(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;Gq(v[a>>2]);break f}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=wc(e+88|0,57412);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Kc(e+32|0,e+24|0)){break f}b=Ko(A[e+248>>3]*65536);v[v[a+24>>2]+480236>>2]=b}gb=e+256|0;return}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function FZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-576|0;gb=e;yc(b);f=gb-32|0;gb=f;h=e+72|0;xE(f+24|0,h);g=xb(f+24|0);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;d=b;fc(f+16|0,d,f);i=xb(f+16|0);if((i|0)==(g|0)){Vb(d,xb(f+24|0))}gb=f+32|0;d=(g|0)==(i|0);if(!d){wE(h)}a:{if(!d){break a}if(!BE(e+72|0)){break a}b:{if(!c){break b}if(!Nb(b,Xc(AE(e+72|0),jb))){break a}Ed(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;d=Tb(e+40|0,16441);Eb(a+1300344|0,d);vb(d);d=Tb(e+40|0,16454);Eb(a+1300356|0,d);vb(d);Zc(a+1300368|0,x[e+72>>1]==26217?16441:16458);v[a+1300404>>2]=5;d=w[e+182|0];u[a+480190>>1]=d;c:{d:{e:{if(d){f=1;i=1;while(1){h=gb-32|0;gb=h;g=e+40|0;cc(h+24|0,g,25);k=xb(h+24|0);d=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=d;v[h>>2]=j;v[h+4>>2]=d;d=b;fc(h+16|0,d,h);j=xb(h+16|0);if((j|0)==(k|0)){Vb(d,xb(h+24|0))}gb=h+32|0;if((k|0)!=(j|0)){t[g|0]=0;t[g+1|0]=0;t[g+2|0]=0;t[g+3|0]=0;t[g+4|0]=0;t[g+5|0]=0;t[g+6|0]=0;t[g+7|0]=0;t[g+24|0]=0;t[g+16|0]=0;t[g+17|0]=0;t[g+18|0]=0;t[g+19|0]=0;t[g+20|0]=0;t[g+21|0]=0;t[g+22|0]=0;t[g+23|0]=0;t[g+8|0]=0;t[g+9|0]=0;t[g+10|0]=0;t[g+11|0]=0;t[g+12|0]=0;t[g+13|0]=0;t[g+14|0]=0;t[g+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}d=(B(f,104)+a|0)+484380|0;wd(d,0);v[d+24>>2]=8363;v[d>>2]=w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24);v[d+4>>2]=w[e+57|0]|w[e+58|0]<<8|(w[e+59|0]<<16|w[e+60|0]<<24);g=w[e+61|0]|w[e+62|0]<<8|(w[e+63|0]<<16|w[e+64|0]<<24);g=g>>>0>y[d>>2]?v[d+4>>2]?g:0:g;v[d+8>>2]=g;if(g){u[d+34>>1]=2;pk(d)}Pj(e+8|0,2,e+40|0);Fc(e+24|0,e+8|0);v[23048]=0;Q(354,((f<<5)+a|0)+946300|0,e+24|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}vb(e+24|0);i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}d=e+72|2;Xe(e+24|0,3,d,36);Fc(e+40|0,e+24|0);Eb(a+1300308|0,e+40|0);vb(e+40|0);f=0;US(a+1300332|0,zb(d),108,36,0);d=a+484360|0;zE(Qb(d),e+185|0,128);if(x[sc(Qb(d),w[e+184|0])>>1]<w[e+183|0]){break d}break c}a=P()|0;O()|0;vb(e+24|0);R(a|0);L()}ff(Qb(d),w[e+184|0])}while(1){d=(f<<5)+a|0;We(d+480280|0);u[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}h=a+484344|0;rg(h,w[e+183|0]);n=1;if(w[e+183|0]){o=c&1;g=0;while(1){f:{g:{if(o){if(Sg(h,g&65535,64)){break g}}Vb(b,1536);break f}v[e+24>>2]=-1;v[e+28>>2]=-1;j=0;while(1){f=Of(Yb(h,g),j);k=0;while(1){wp(e+40|0,b);d=rd(e+40|0);l=Df(e+40|0);i=w[d|0];d=w[e+40|0];if(d>>>0<=253){t[f|0]=(d>>>2|0)+37;t[f+1|0]=(d<<4&48|i>>>4)+1;t[(e+24|0)+k|0]=255;d=w[e+40|0]}if((d&255)!=255){t[f+2|0]=1;t[f+4|0]=(((i&15)<<6|8)>>>0)/15}m=(e+24|0)+k|0;h:{i:{i=w[l|0];j:{if((i|0)!=255){t[m|0]=i;d=i&15;if(d|(i|0)==48){break j}break i}i=w[m|0];if((i|0)==255){break h}d=i&15}t[f+5|0]=d;k:{if(i<<24>>24<0){break k}l=i>>>4|0;t[f+3|0]=w[l+16467|0];l:{switch(l-3|0){case 0:t[f+5|0]=d|32;break i;case 1:t[f+5|0]=B(d,17);break h;case 2:break i;case 3:break l;default:break h}}m:{switch(i&15){case 0:t[f+5|0]=79;break h;case 1:break m;default:break k}}t[f+5|0]=244;break h}t[f+3|0]=0;break h}t[m|0]=255}f=f+6|0;k=k+1|0;if((k|0)!=8){continue}break}j=j+1|0;if((j|0)!=64){continue}break}d=(e+72|0)+g|0;f=d;if(w[d+369|0]<63){wm(Yb(h,g),wh(Ve(De(e+40|0,14,0),w[f+369|0])))}wm(Yb(h,g),wh(De(e+40|0,16,w[d+241|0])))}g=g+1|0;if(g>>>0<w[e+183|0]){continue}break}}if(!(c&2)){break a}f=1;c=Sc(e+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){ug(c,(B(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}n=1}gb=e+576|0;return n|0}function h7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-352|0;gb=d;a:{if(jk(b)){break a}e=w[jl(b)|0];f=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}f=0}c=f;wl(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}Md(d+320|0);e=v[d+320>>2];Md(d+304|0);e=il(e,v[d+308>>2],b);Md(d+320|0);c:{d:{e:{f:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=wc(d+336|0,56371);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Kc(d+8|0,d)){a=aa(8)|0;v[23048]=0;c=Q(91,d+320|0,57444)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}e=0;if(!c){break f}c=aa(8)|0;v[23048]=0;e=Q(2061,d+304|0,b|0)|0;a=v[23048];v[23048]=0;g:{h:{i:{if((a|0)!=1){v[23048]=0;T(2045,d+320|0,57454,e|0);a=v[23048];v[23048]=0;if((a|0)==1){break i}rc(c,d+320|0);a=0;v[23048]=0;T(84,c|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break c}b=P()|0;O()|0;vb(d+320|0);break h}b=P()|0;O()|0;break g}b=P()|0;a=1;O()|0}vb(e);if(!a){break d}}ca(c|0);break d}if(v[e+4>>2]){a=aa(8)|0;v[23048]=0;c=Q(91,d+320|0,57468)|0;b=v[23048];v[23048]=0;if((b|0)!=1){rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=wc(d+288|0,56371);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Kc(d+152|0,d+144|0)){a=aa(8)|0;v[23048]=0;c=Q(91,d+320|0,57444)|0;b=v[23048];v[23048]=0;if((b|0)!=1){rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=wc(d+272|0,57192);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;j:{if(!Kc(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=wc(d+256|0,57489);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Kc(d+120|0,d+112|0)){break j}}e=w[a+60|0]!=0;break f}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=wc(d+240|0,57210);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;k:{if(!Kc(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=wc(d+224|0,57507);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Kc(d+88|0,d+80|0)){break k}}e=w[a+61|0]!=0;break f}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=wc(d+208|0,57229);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Kc(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break f}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=wc(d+192|0,57247);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Kc(d+56|0,d+48|0)){e=w[a+63|0]!=0;break f}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=wc(d+176|0,57271);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Kc(d+40|0,d+32|0)){e=w[a+64|0]!=0;break f}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=wc(d+160|0,57345);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Kc(d+24|0,d+16|0)){break f}e=v[v[a+24>>2]+24668>>2]!=0}gb=d+352|0;return e|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function rma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0;f=gb-48|0;gb=f;a:{b:{c:{d:{if(!c){break d}z=f,A=Hd(a),t[z+32|0]=A;g=f+32|0;d=b;e:{if(y[d+4>>2]<y[wb(d)>>2]){h=gb-16|0;gb=h;e=Jj(h,d,1);wb(d);Qd(v[e+4>>2],g);v[e+4>>2]=v[e+4>>2]+1;_b(e);gb=h+16|0;break e}h=gb-32|0;gb=h;e=wb(d);e=Zg(h+8|0,qh(d,qc(d)+1|0),qc(d),e);Qd(v[e+8>>2],g);v[e+8>>2]=v[e+8>>2]+1;v[23048]=0;S(349,d|0,e|0);d=v[23048];v[23048]=0;f:{if((d|0)!=1){ee(e);gb=h+32|0;break f}a=P()|0;O()|0;ee(e);break a}}m=c-1|0;if(!m){break c}c=0;while(1){g:{h:{i=c&254;i:{if(!i){if(!pf(a,f+32|0)){break d}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0<256){break i}break h}if((c&65535)>>>0>255){break h}}if(!pf(a,f+32|0)){break d}e=f+32|0;c=b;j:{if(v[c+4>>2]!=v[wb(c)>>2]){g=gb-16|0;gb=g;d=Jj(g,c,1);c=wb(c);h=v[d+4>>2];v[23048]=0;Ml(c,h,e);c=v[23048];v[23048]=0;if((c|0)!=1){v[d+4>>2]=v[d+4>>2]+1;_b(d);gb=g+16|0;break j}a=P()|0;O()|0;_b(d);break a}g=gb-32|0;gb=g;h=wb(c);d=Zg(g+8|0,qh(c,qc(c)+1|0),qc(c),h);k=v[d+8>>2];v[23048]=0;Ml(h,k,e);e=v[23048];v[23048]=0;k:{l:{if((e|0)==1){break l}v[d+8>>2]=v[d+8>>2]+1;v[23048]=0;S(349,c|0,d|0);c=v[23048];v[23048]=0;if((c|0)==1){break l}ee(d);gb=g+32|0;break k}a=P()|0;O()|0;ee(d);break a}}m=m-1|0;break g}e=1;while(1){m:{n:{o:{c=i<<1&254;d=i>>>0>127;p:{q:{if(c){break q}if(!pf(a,f+32|0)){break p}d=w[f+32|0]<<1|1;c=d&255;d=d>>>0>255}e=d|e<<1;i=c<<1&254;if(i){break n}if(pf(a,f+32|0)){break o}}i=0;break m}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break m}if(c>>>0>127){continue}}break}r:{if((e|0)<=2){d=0;g=e-2|0;break r}c=pf(a,f+32|0);if(!c){break d}c=c?(w[f+32|0]|e<<8)-768|0:o;d=((c|0)>1279?2:1)+((c|0)>31999)|0;o=c^-1;g=0}c=i<<1&254;e=i>>>0>127;s:{if(c){break s}if(!pf(a,f+32|0)){break d}e=w[f+32|0]<<1|1;c=e&255;e=e>>>0>255}i=c<<1&254;c=c>>>0>127;t:{if(i){break t}if(!pf(a,f+32|0)){break d}c=w[f+32|0]<<1|1;i=c&255;c=c>>>0>255}e=c|(g<<2|(e?2:0));if(!e){e=1;while(1){u:{v:{w:{c=i<<1&254;g=i>>>0>127;x:{y:{if(c){break y}if(!pf(a,f+32|0)){break x}g=w[f+32|0]<<1|1;c=g&255;g=g>>>0>255}e=g|e<<1;i=c<<1&254;if(i){break v}if(pf(a,f+32|0)){break w}}i=0;break u}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break u}if(c>>>0>127){continue}}break}e=e+2|0}c=0;if((o|0)>-1){break b}h=e+d|0;if(h>>>0>m>>>0|(h|0)<1){break b}if((0-qc(b)|0)>(o|0)){break b}z=f,A=Ub(b),v[z+32>>2]=A;Sd(f+40|0,f+32|0);t[f+24|0]=0;k=f+24|0;n=gb-32|0;gb=n;v[n+24>>2]=v[f+40>>2];c=b;d=v[c>>2];z=n,A=Rb(c),v[z>>2]=A;e=Hk(n+24|0,n)+d|0;z:{A:{g=h;d=v[wb(c)>>2];j=v[c+4>>2];B:{if(g>>>0<=d-j>>>0){d=g;l=j-e|0;if(d>>>0>l>>>0){sn(c,g-l|0,k);d=l;if(!d){break B}}q=gb-16|0;gb=q;s=c;u=j;x=e;r=v[c+4>>2];l=(r-(e+g|0)|0)+e|0;p=Jj(q,c,j-l|0);if(j>>>0>l>>>0){j=l;while(1){wb(s);Qd(v[p+4>>2],j);v[p+4>>2]=v[p+4>>2]+1;j=j+1|0;if(u>>>0>j>>>0){continue}break}}_b(p);Sm(x,l,r);gb=q+16|0;j=e;if(e>>>0<=k>>>0){k=y[c+4>>2]>k>>>0?g+k|0:k}bi(j,d,k);break B}d=wb(c);d=Zg(n,qh(c,qc(c)+g|0),e-v[c>>2]|0,d);v[23048]=0;T(679,d|0,g|0,k|0);g=v[23048];v[23048]=0;if((g|0)==1){break A}e=HX(c,d,e);ee(d)}Uh(e);gb=n+32|0;break z}a=P()|0;O()|0;ee(d);break a}z=f,A=Ub(b),v[z+16>>2]=A;z=f,A=IV(f+16|0,h),v[z+24>>2]=A;z=f,A=Ne(f+24|0,o),v[z+32>>2]=A;z=f,A=Ub(b),v[z+16>>2]=A;z=f,A=IV(f+16|0,h),v[z+24>>2]=A;c=h;while(1){z=f,A=HV(f+32|0),v[z+16>>2]=A;d=w[v[f+16>>2]];z=f,A=HV(f+24|0),v[z+8>>2]=A;t[v[f+8>>2]]=d;d=(c|0)>1;c=c-1|0;if(d){continue}break}m=m-h|0}if(!m){break c}c=i<<1;continue}}c=0;break b}c=1}gb=f+48|0;return c|0}R(a|0);L()}function zfa(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-48|0;gb=f;a:{b:{c:{d:{if(v[23056]){break d}k=Bb(92204);b=gb-48|0;gb=b;i=b+40|0;a=i;v[a>>2]=-1;v[a+4>>2]=-1;c=b;d=gb-48|0;gb=d;v[23048]=0;a=Q(2218,0,d+32|0)|0;g=v[23048];v[23048]=0;e:{f:{g:{h:{if((g|0)==1){break h}if(!a){break g}v[23048]=0;b=v[23048];v[23048]=0;if((b|0)==1){break h}b=v[115529];v[23048]=0;S(2220,b|0,74816);b=v[23048];v[23048]=0;if((b|0)!=1){break f}}V(0)|0;O()|0;Ab();L()}h=ct(d+16|0,d+32|0);v[d+4>>2]=v[d+36>>2]/1e3;j=ct(d+8|0,d+4|0);g=gb-32|0;gb=g;a=gb-16|0;gb=a;e=gb-16|0;gb=e;m=e,n=Fpa(v[h>>2],v[h+4>>2],1e6,0),v[m>>2]=n;v[e+4>>2]=jb;h=ql(e+8|0,e);l=v[h+4>>2];gb=e+16|0;v[a+8>>2]=v[h>>2];v[a+12>>2]=l;h=v[a+12>>2];e=g+8|0;v[e>>2]=v[a+8>>2];v[e+4>>2]=h;gb=a+16|0;a=v[e>>2];e=v[e+4>>2];h=v[j+4>>2];v[g>>2]=v[j>>2];v[g+4>>2]=h;e=v[g+4>>2]+e|0;j=e+1|0;h=e;e=v[g>>2];a=a+e|0;e=a>>>0<e>>>0?j:h;v[g+16>>2]=a;v[g+20>>2]=e;a=ql(g+24|0,g+16|0);e=v[a+4>>2];gb=g+32|0;v[d+24>>2]=v[a>>2];v[d+28>>2]=e;a=ql(d+40|0,d+24|0);g=v[a+4>>2];a=v[a>>2];gb=d+48|0;break e}L()}v[c+8>>2]=a;v[c+12>>2]=g;a=v[b+12>>2];v[b+16>>2]=v[b+8>>2];v[b+20>>2]=a;a=gb-16|0;gb=a;m=a,n=Fpa(v[b+16>>2],v[b+20>>2],1e3,0),v[m>>2]=n;v[a+4>>2]=jb;c=ql(a+8|0,a);d=v[c+4>>2];gb=a+16|0;v[b+24>>2]=v[c>>2];v[b+28>>2]=d;a=Yz(v[b+24>>2],v[b+28>>2]);t[b+32|0]=a;t[b+33|0]=a>>>8;t[b+34|0]=a>>>16;t[b+35|0]=a>>>24;a=jb;t[b+36|0]=a;t[b+37|0]=a>>>8;t[b+38|0]=a>>>16;t[b+39|0]=a>>>24;a=v[b+36>>2];v[b+24>>2]=v[b+32>>2];v[b+28>>2]=a;$O(i,b+24|0,wb(b+24|0));a=gb-48|0;gb=a;v[23048]=0;c=Q(2218,1,a+32|0)|0;d=v[23048];v[23048]=0;i:{j:{k:{if((d|0)==1){break k}if(c){v[23048]=0;b=v[23048];v[23048]=0;if((b|0)==1){break k}b=v[115529];v[23048]=0;S(2220,b|0,74853);b=v[23048];v[23048]=0;if((b|0)!=1){break j}break k}c=ct(a+16|0,a+32|0);d=ct(a+8|0,a+32|4);v[23048]=0;e=Ga(2221,c|0,d|0)|0;c=O()|0;d=e|0;g=v[23048];v[23048]=0;if((g|0)!=1){break i}}V(0)|0;O()|0;Ab()}L()}v[a+24>>2]=d;v[a+28>>2]=c;c=ql(a+40|0,a+24|0);d=v[c+4>>2];gb=a+48|0;v[b+8>>2]=v[c>>2];v[b+12>>2]=d;a=v[b+12>>2];v[b+16>>2]=v[b+8>>2];v[b+20>>2]=a;a=gb-16|0;gb=a;c=v[b+20>>2];v[a>>2]=v[b+16>>2];v[a+4>>2]=c;c=ql(a+8|0,a);d=v[c+4>>2];gb=a+16|0;v[b+24>>2]=v[c>>2];v[b+28>>2]=d;a=Yz(v[b+24>>2],v[b+28>>2]);t[b+32|0]=a;t[b+33|0]=a>>>8;t[b+34|0]=a>>>16;t[b+35|0]=a>>>24;a=jb;t[b+36|0]=a;t[b+37|0]=a>>>8;t[b+38|0]=a>>>16;t[b+39|0]=a>>>24;a=v[b+36>>2];v[b+24>>2]=v[b+32>>2];v[b+28>>2]=a;$O(i,b+24|0,wb(b+24|0));a=v[i>>2];c=v[i+4>>2];gb=b+48|0;if(k){b=nc(f+32|0);v[23048]=0;v[f+16>>2]=c;S(93,b|0,f+16|0);c=v[23048];v[23048]=0;l:{m:{n:{if((c|0)!=1){v[23048]=0;v[f+16>>2]=a;S(93,b|0,f+16|0);a=v[23048];v[23048]=0;if((a|0)==1){break n}if(Bb(92204)){a=0;while(1){c=w[pc(92204,a)|0];v[23048]=0;v[f+16>>2]=c;S(93,b|0,f+16|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}a=a+1|0;if(Bb(92204)>>>0>a>>>0){continue}break}}a=Rb(b);c=Ub(b);v[23048]=0;c=W(94,f+16|0,a|0,c|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break m}v[23048]=0;S(95,f+8|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break l}sP(f+8|0);Dm(f+8|0);Qc(c);Qc(b);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Qc(c);break a}jb=a;v[f+16>>2]=c;v[f+20>>2]=jb;b=f+32|0;a=nc(b);v[23048]=0;T(98,b|0,f+16|0,f+24|0);c=v[23048];v[23048]=0;if((c|0)==1){b=P()|0;O()|0;Qc(a);R(b|0);L()}v[23048]=0;S(95,f+8|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}sP(f+8|0);Dm(f+8|0);Qc(b)}gb=f+48|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}Qc(b);R(a|0);L()}function EP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;h=a+1074368|0;f=B(b,880);d=(h+f|0)+616|0;e=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+f|0)+1075072|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(wj(d)){a=B(b,880)+a|0;u[a+1075758>>1]=e-8;a=a+1075837|0;t[a|0]=w[a|0]|8;break a}if(v[a+480180>>2]!=64){b=B(b,880)+a|0;u[b+1075758>>1]=e<<28>>24;c=x[(e<<1)+34448>>1];v[b+1075688>>2]=c;d=b+1075684|0;if(!v[d>>2]){break a}k=d,l=Vg(a,w[b+1075783|0],e<<28>>24,c),v[k>>2]=l;break a}a=B(b,880)+a|0;b=v[a+1075088>>2];if(!b){break a}v[a+1075688>>2]=v[b+24>>2]+B(e,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,880)+a|0)+1075808|0]=c&3;break a}Db(g+8|0,a+1074308|0,21);if(Cb(g+8|0)){t[(B(b,880)+a|0)+1075808|0]=e>>>0<4?e:0;break a}t[(B(b,880)+a|0)+1075808|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,880)+a|0)+1075811|0]=c&3;break a}Db(g+8|0,a+1074308|0,21);if(Cb(g+8|0)){t[(B(b,880)+a|0)+1075811|0]=e>>>0<4?e:0;break a}t[(B(b,880)+a|0)+1075811|0]=c&7;break a;case 4:Db(g+8|0,a+1074308|0,21);if(Cb(g+8|0)){a=B(b,880)+a|0;t[a+1075807|0]=0;t[a+1075814|0]=e>>>0<4?e:0;break a}t[(B(b,880)+a|0)+1075814|0]=c&7;break a;case 5:if(v[a+1074384>>2]|!(w[a+480209|0]&16)){break a}a=a+1074392|0;v[a>>2]=v[a>>2]+e;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(e>>>0<=2){e=x[a+480188>>1];if(e>>>0>255){break a}d=a+1300300|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(e,880)+a|0;c:{if((i|0)!=x[c+1075772>>1]){break c}d:{e:{switch(j|0){case 0:wo(a,c+1074984|0);if(!(w[c+1075073|0]&2)){break d}if(!Fd(d)){break d}nk(v[d>>2],e&65535);break d;case 1:f=c+1075072|0;h=v[f>>2];v[f>>2]=h|4096;if(!(h&512)){break d}if(!Fd(d)){break d}nk(v[d>>2],e&65535);break d;default:break e}}v[c+1075680>>2]=0;f=c+1075072|0;h=v[f>>2];v[f>>2]=h|4096;if(!(h&512)){break d}if(!Fd(d)){break d}Qh(v[d>>2],e&65535,1)}h=v[c+1075640>>2];if(!h){break c}f=w[h+34|0];if(!f){break c}f=v[(B(f,160)+a|0)+906140>>2];if(!f){break c}kb[v[v[f>>2]+92>>2]](f,h,w[c+1075783|0]+255|0,0,b)}e=e+1|0;if((e&65535)!=256){continue}break}break a}XA(d,e,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}Bm(a,d,e,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e&15){case 0:v[d+88>>2]=v[d+88>>2]&-257;break f;case 1:v[d+692>>2]=128;v[d+88>>2]=v[d+88>>2]|256;break f;case 8:v[d+88>>2]=v[d+88>>2]&-25165825|16777216;break f;case 9:v[d+88>>2]=v[d+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[d+88>>2]=v[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[d+76>>2]|(v[d>>2]|v[d+4>>2])){break h}if(k=!ne(d+790|0),l=0,m=w[d+88|0]&2,m?k:l){break h}a=d;b=v[a+76>>2]-1|0;v[a>>2]=-1;v[a+4>>2]=b}v[d+88>>2]=v[d+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,880)+a|0;t[c+1075822|0]=e;Db(g+8|0,a+1074308|0,35);if(Cb(g+8|0)){break a}if(!ne(c+1075774|0)){break a}b=v[(B(b,880)+a|0)+1075060>>2];a=e<<16;if(b>>>0<=a>>>0){break a}v[d+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}pu(a,h,d,e);break a;case 11:i:{if(e){break i}if(v[a+480180>>2]&16777248){e=1;break i}if(v[a+480180>>2]==2){break a}e=0}Db(g+8|0,a+1074308|0,30);c=a;if(Cb(g+8|0)){a=1}else{a=v[a+480180>>2]==2}fA(c,b,e,a);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,880)+a|0)+1075830|0]=e}gb=g+16|0}function Ena(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-288|0;gb=e;d=e+128|0;g=gb-48|0;gb=g;CC(g+24|0,b);v[23048]=0;Qr(g+16|0,g+24|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)==1){break b}v[23048]=0;b=v[g+20>>2];v[g+8>>2]=v[g+16>>2];v[g+12>>2]=b;S(681,d|0,g+8|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}Ac(g+24|0);gb=g+48|0;break a}a=P()|0;O()|0;Ac(g+24|0);R(a|0);L()}v[23048]=0;S(651,e+24|0,e+128|0);b=v[23048];v[23048]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((b|0)!=1){v[23048]=0;g=W(652,e+144|0,e+24|0,8)|0;b=v[23048];v[23048]=0;if((b|0)==1){break D}vb(e+24|0);gc(e+128|0);if(c>>>0<2189){break i}v[23048]=0;b=Q(661,e+24|0,g|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break e}v[23048]=0;c=Q(662,e+8|0,19021)|0;d=v[23048];v[23048]=0;if((d|0)==1){break B}v[23048]=0;v[e>>2]=19922997;v[e+4>>2]=0;T(663,b|0,c|0,e|0);d=v[23048];v[23048]=0;if((d|0)==1){break A}Hb(c);t[e|0]=0;v[23048]=0;c=Q(662,e+8|0,19029)|0;d=v[23048];v[23048]=0;if((d|0)==1){break k}d=0;v[23048]=0;W(664,b|0,e|0,c|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break z}Hb(c);if(!w[e|0]){v[23048]=0;d=wk(a);c=v[23048];v[23048]=0;if((c|0)==1){break y}}f=v[a+4>>2];v[23048]=0;c=Q(662,e+8|0,19040)|0;h=v[23048];v[23048]=0;if((h|0)==1){break x}v[23048]=0;Y(666,b|0,f|0,c|0,d|0);f=v[23048];v[23048]=0;if((f|0)==1){break w}Hb(c);v[23048]=0;c=Q(662,e+8|0,19042)|0;f=v[23048];v[23048]=0;if((f|0)==1){break v}v[23048]=0;Y(667,b|0,a|0,c|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break u}Hb(c);v[23048]=0;c=Q(662,e+8|0,19044)|0;d=v[23048];v[23048]=0;if((d|0)==1){break t}v[23048]=0;d=a+484360|0;T(668,b|0,d|0,c|0);f=v[23048];v[23048]=0;if((f|0)==1){break s}Hb(c);v[23048]=0;c=Q(662,e+8|0,19046)|0;f=v[23048];v[23048]=0;if((f|0)==1){break r}v[23048]=0;T(669,b|0,a+484344|0,c|0);f=v[23048];v[23048]=0;if((f|0)==1){break q}Hb(c);v[23048]=0;f=wk(a);c=v[23048];v[23048]=0;if((c|0)==1){break p}v[23048]=0;c=Q(662,e+8|0,19052)|0;h=v[23048];v[23048]=0;if((h|0)==1){break o}v[23048]=0;Y(670,b|0,d|0,c|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break n}Hb(c);if(v[b>>2]&1073741824){v[23048]=0;c=Q(2,e+8|0,19060)|0;d=v[23048];v[23048]=0;if((d|0)==1){break m}v[23048]=0;T(601,a|0,1,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break l}vb(c)}Yg(b);break h}a=P()|0;O()|0;break C}a=P()|0;O()|0;vb(e+24|0)}gc(e+128|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0}Yg(b);break d}b=Jb(e+24|0);d=v[a+4>>2];v[23048]=0;f=wk(a);h=v[23048];v[23048]=0;if((h|0)==1){break g}v[23048]=0;d=ba(671,d|0,g|0,b|0,f|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break g}E:{if((d|0)!=1){v[23048]=0;c=Q(2,e+8|0,19109)|0;d=v[23048];v[23048]=0;F:{if((d|0)!=1){v[23048]=0;T(601,a|0,1,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break F}vb(c);break E}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[23048]=0;d=wk(a);f=v[23048];v[23048]=0;if((f|0)==1){break g}v[23048]=0;Y(672,g|0,a|0,d|0,c>>>0<2188|0);a=v[23048];v[23048]=0;if((a|0)==1){break g}}vb(b)}ag(g);gb=e+288|0;return}a=P()|0;O()|0}vb(b);break d}a=P()|0;O()|0}ag(g)}R(a|0);L()}function nga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-11360|0;gb=g;yc(c);a:{b:{if(!Nb(c,4)){break b}c:{while(1){d:{kE(c,g+16|0);e:{if(!zd(g+16|0,30863,3)){d=g+4648|0;f=gb-32|0;gb=f;h=c;f:{if(Nb(c,7)){jn(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;gd(f+16|0,h,f+8|0);break f}h=gb-16|0;gb=h;j=d+7|0;while(1){Re(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}gb=h+16|0}gb=f+32|0;f=3;d=0;while(1){h=w[(g+4648|0)+f|0];if(h&128){break c}d=h|d<<7;f=f+1|0;if((f|0)!=7){continue}break}Vb(c,d);break e}g:{if(zd(g+16|0,30867,3)){break g}if(!vV(c,30871)){break g}Vb(c,_f(c)+16|0);break e}if(!zd(g+16|0,30877,3)){break e}if(!zd(g+16|0,30881,3)){break e}if(w[g+16|0]){break d}kg(c,2)}if(Nb(c,4)){continue}break b}break}if(VS(g+16|0)){break b}}f=0;break a}yc(c);CC(g+11336|0,c);k=v[g+11336>>2];v[23048]=0;c=Wd(g+11336|0);d=v[23048];v[23048]=0;h:{i:{j:{k:{if((d|0)!=1){c=zb(c);i=nc(g+11320|0);Pb(g+4648|0,0,6668);v[23048]=0;qt(g+4648|0);d=v[23048];v[23048]=0;if((d|0)!=1){d=g+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=g+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[g+4624>>2]=0;v[g+4628>>2]=0;h=0;d=0;while(1){f=vc(k,l);v[23048]=0;m=ga(1164,g+4648|0,c|0,f|0,g+16|0,g+4624|0)|0;f=v[23048];v[23048]=0;l:{m:{if((f|0)!=1){if((m|0)<0){break j}f=v[g+4624>>2];if((f|0)<0){break j}n=(m|0)<1;if(!(f|m)|(f?0:!n)){break j}if((f|0)<1){break l}j=v[g+4636>>2];if((j|0)!=(h|0)?h:0){break j}f=v[g+4632>>2];if((f|0)!=(d|0)?d:0){break j}if((j|0)<1|f-1>>>0>1){break k}v[g+12>>2]=0;d=vc(k,l);v[23048]=0;v[g+8>>2]=d;d=Gm(g+4624|0,g+12|0,g+8|0);h=v[23048];v[23048]=0;n:{if((h|0)!=1){d=v[d>>2];v[g+12>>2]=0;h=vc(k,l);v[23048]=0;v[g+8>>2]=h;h=Gm(g+4624|0,g+12|0,g+8|0);o=v[23048];v[23048]=0;if((o|0)==1){break n}c=c+d|0;d=k;h=v[h>>2];k=d-h|0;l=l-((h>>31)+(d>>>0<h>>>0)|0)|0;if(n){break m}v[23048]=0;T(1166,i|0,g+16|0,(g+16|0)+(B(f,m)<<1)|0);d=v[23048];v[23048]=0;if((d|0)!=1){break m}d=V(90496)|0;if((O()|0)!=(da(90496)|0)){break i}Z(d|0)|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;h=j;d=f;if((c|0)!=1){break j}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}h=j;d=f}f=uc(i);if((l|0)<0?1:(l|0)<=0?k>>>0<1:0){break j}if((f>>>0)/(d>>>0)>>>0<268435457){continue}break}break j}d=P()|0;O()|0;break i}d=P()|0;O()|0;break h}h=j;d=f}f=0;o:{p:{q:{r:{s:{if(!d|!h){break s}if(cd(i)){break s}if((uc(i)>>>0)/(d>>>0)>>>0>268435456){break s}v[23048]=0;Q(1167,a|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break o}if(!e){v[23048]=0;c=Q(91,g+16|0,30885)|0;f=v[23048];v[23048]=0;if((f|0)==1){break r}v[23048]=0;Q(354,((b<<5)+a|0)+946300|0,c|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break q}vb(c);v[23048]=0;c=B(b,104)+a|0;S(372,c+484380|0,0);f=v[23048];v[23048]=0;if((f|0)==1){break o}v[c+484404>>2]=h}h=B(b,104)+a|0;c=h+484380|0;p=c,q=(uc(i)>>>0)/(d>>>0)|0,v[p>>2]=q;f=h+484414|0;h=x[f>>1];u[f>>1]=(d|0)==2?h|65:h&65470|1;v[23048]=0;U(446,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break o}if(Od(c)){d=Rb(i);h=Ub(i);b=v[(B(b,104)+a|0)+484400>>2];v[23048]=0;W(1168,d|0,h|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break o}}if(!e){b=v[a+480180>>2];v[23048]=0;T(1169,c|0,32,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break p}v[23048]=0;Sh(c,a,0);a=v[23048];v[23048]=0;if((a|0)==1){break o}}f=Od(c)}Ze(i);Ac(g+11336|0);break a}d=P()|0;O()|0;break i}d=P()|0;O()|0;vb(c);break i}d=P()|0;O()|0;break i}d=P()|0;O()|0}Ze(i)}Ac(g+11336|0);R(d|0);L()}gb=g+11360|0;return f|0}function qg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=gb-112|0;gb=k;l=h;o=i&2147483647;m=c-(b>>>0<1)|0;j=b-1|0;q=(j|0)==-1&(m|0)==-1;r=d;p=(c|0)==(m|0)&b>>>0>j>>>0|c>>>0>m>>>0;n=d+p|0;m=e&2147483647;j=m;j=n>>>0<p>>>0?j+1|0:j;p=n-1|0;a:{b:{j=j-(n>>>0<1)|0;if(!((p|0)==-1&(j|0)==2147418111?q:j>>>0>2147418111)){j=f;n=g-(j>>>0<1)|0;j=j-1|0;q=(j|0)!=-1|(n|0)!=-1;p=(g|0)==(n|0)&f>>>0>j>>>0|g>>>0>n>>>0;n=p+l|0;j=o;j=n>>>0<p>>>0?j+1|0:j;p=n;n=n-1|0;j=j-(p>>>0<1)|0;if((n|0)==-1&(j|0)==2147418111?q:(j|0)==2147418111&(n|0)!=-1|j>>>0<2147418111){break b}}if(!(!r&(m|0)==2147418112?!(b|c):m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!l&(o|0)==2147418112?!(f|g):o>>>0<2147418112)){i=i|32768;break a}if(!(b|r|(m^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|l|(o^2147418112|g))){break a}if(!(b|r|(c|m))){if(f|l|(g|o)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|l|(g|o)){break b}f=b;g=c;h=d;i=e;break a}q=(l|0)==(r|0)&(m|0)==(o|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:(m|0)==(o|0)&l>>>0>r>>>0|m>>>0<o>>>0;j=q;n=j?f:b;o=j?g:c;l=j?i:e;r=l;m=j?h:d;j=l&65535;i=q?e:i;e=i;h=q?d:h;p=i>>>16&32767;l=l>>>16&32767;if(!l){d=!(j|m);i=d<<6;l=E(d?n:m)+32|0;d=E(d?o:j);d=i+((d|0)==32?l:d)|0;Uf(k+96|0,n,o,m,j,d-15|0);m=v[k+104>>2];n=v[k+96>>2];o=v[k+100>>2];l=16-d|0;j=v[k+108>>2]}f=q?b:f;g=q?c:g;i=e&65535;if(!p){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;Uf(k+80|0,f,g,h,i,b-15|0);p=16-b|0;h=v[k+88>>2];i=v[k+92>>2];g=v[k+84>>2];f=v[k+80>>2]}b=h;c=i<<3|b>>>29;h=b<<3|g>>>29;i=c|524288;b=m;d=j<<3|b>>>29;m=b<<3|o>>>29;s=d;q=e^r;b=f;j=g<<3|b>>>29;b=b<<3;c=j;d=l-p|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;j=0;e=1;break c}Uf(k- -64|0,b,c,h,i,128-d|0);Hn(k+48|0,b,c,h,i,d);h=v[k+56>>2];i=v[k+60>>2];j=v[k+52>>2];e=v[k+48>>2]|((v[k+64>>2]|v[k+72>>2])!=0|(v[k+68>>2]|v[k+76>>2])!=0)}f=j;d=m;p=s|524288;b=n;j=o<<3|b>>>29;c=b<<3;d:{if((q|0)<-1?1:(q|0)<=-1){o=e;b=c-e|0;m=h;n=d-h|0;e=(f|0)==(j|0)&c>>>0<e>>>0|f>>>0>j>>>0;h=n-e|0;c=j-((c>>>0<o>>>0)+f|0)|0;i=(p-((d>>>0<m>>>0)+i|0)|0)-(e>>>0>n>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=E(d?b:h)+32|0;b=E(d?c:i);b=e+((b|0)==32?g:b)|0;b=b-12|0;Uf(k+32|0,f,c,h,i,b);l=l-b|0;h=v[k+40>>2];i=v[k+44>>2];b=v[k+32>>2];c=v[k+36>>2];break d}b=c;g=b+e|0;c=f+j|0;c=b>>>0>g>>>0?c+1|0:c;b=g;g=(c|0)==(f|0)&e>>>0>b>>>0|c>>>0<f>>>0;e=d;f=d+h|0;d=i+p|0;d=e>>>0>f>>>0?d+1|0:d;e=g+f|0;h=e;i=h>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);c=h<<31|c>>>1;l=l+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}o=0;r=r&-2147483648;if((l|0)>=32767){h=o;i=r|2147418112;f=0;g=0;break a}if((l|0)>=1){e=l}else{Uf(k+16|0,b,c,h,i,l+127|0);Hn(k,b,c,h,i,1-l|0);b=v[k>>2]|((v[k+16>>2]|v[k+24>>2])!=0|(v[k+20>>2]|v[k+28>>2])!=0);c=v[k+4>>2];h=v[k+8>>2];i=v[k+12>>2];e=0}j=(c&7)<<29|b>>>3;l=b&7;b=j+(l>>>0>4)|0;d=h<<29|c>>>3;c=b>>>0<j>>>0?d+1|0:d;f=b;g=c;b=(d|0)==(c|0)&b>>>0<j>>>0|c>>>0<d>>>0;d=o|((i&7)<<29|h>>>3);b=b+d|0;j=r|(i>>>3&65535|e<<16);h=b;i=b>>>0<d>>>0?j+1|0:j;e:{if((l|0)==4){j=i;c=0;d=g+c|0;e=f&1;b=f+e|0;d=b>>>0<f>>>0?d+1|0:d;f=b;g=d;c=(c|0)==(d|0)&b>>>0<e>>>0|c>>>0>d>>>0;b=c+h|0;h=b;i=b>>>0<c>>>0?j+1|0:j;break e}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;gb=k+112|0}function _Z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-160|0;gb=d;yc(b);ps(a);f=gb-32|0;gb=f;h=d+120|0;fF(f+24|0,h);g=xb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);i=xb(f+16|0);if((i|0)==(g|0)){Vb(e,xb(f+24|0))}gb=f+32|0;e=(g|0)==(i|0);if(!e){gF(h)}a:{if(!e){break a}if(!gO(d+120|0)){break a}f=b;i=0;k=Lf(16132);if(k){p=v[f+8>>2];if(Rc(f,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){b:{if(!(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))){break b}while(1){if(!Nb(f,5)){break b}c:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((xi(f)|0)<1){break c}}e=Hd(f);d:{if(e){g=1;i=0;while(1){q=pq(e<<24>>24);l=i>>>0>=k>>>0;h=l&g;e=h;e:{if(l){break e}e=h;if(!(g&1)){break e}e=w[i+16132|0]==(q&255)}g=e;i=i+1|0;e=Hd(f);if(e){continue}break}e=(i|0)==(k|0)&g;break d}e=!k}Vb(f,4);m=e?1:m}n=n+1|0;if(n>>>0<(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0){continue}break}}i=m&1}Rc(f,p)}if(!i){break a}if(!Nb(b,fO(d+120|0))){break a}if(!c){j=1;break a}f=gb-16|0;gb=f;c=b;e=d+120|0;Rc(c,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));g=nc(d+104|0);h=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[23048]=0;S(1436,g|0,h|0);h=v[23048];v[23048]=0;f:{g:{h:{if((h|0)!=1){i:{j:{k:{if(!(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))){break k}while(1){v[23048]=0;h=Q(250,c|0,5)|0;i=v[23048];v[23048]=0;if((i|0)==1){break h}if(!h){break k}h=w[e+4|0]|w[e+5|0]<<8;v[23048]=0;T(1437,f|0,c|0,h|0);h=v[23048];v[23048]=0;if((h|0)==1){break j}v[23048]=0;S(1438,g|0,f|0);h=v[23048];v[23048]=0;if((h|0)==1){break i}vb(f);o=o+1|0;if(o>>>0<(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){continue}break}}gb=f+16|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(f);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}yd(g);R(a|0);L()}v[23048]=0;Y(326,d+88|0,b|0,d+120|0,d+104|0);c=v[23048];v[23048]=0;l:{m:{if((c|0)!=1){c=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);v[23048]=0;Q(248,b|0,c|0)|0;c=v[23048];v[23048]=0;n:{if((c|0)!=1){if(!(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))){break l}e=d+36|0;o:{p:{q:{r:{while(1){v[23048]=0;c=Q(250,b|0,8)|0;f=v[23048];v[23048]=0;s:{if((f|0)!=1){if(c){break s}break l}b=P()|0;O()|0;break n}v[23048]=0;ka(327,d- -64|0,b|0,d+120|0,d+88|0,d+104|0,16132);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;f=d- -64|0;c=U(328,f|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break r}if(c){v[23048]=0;c=U(329,d+24|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break q}g=v[d+84>>2];t:{if((g|0)<0){break t}if(Gc(d+104|0)>>>0<=g>>>0){break t}g=Id(d+104|0,v[d+84>>2]);v[23048]=0;T(13,d+8|0,2,g|0);g=v[23048];v[23048]=0;if((g|0)==1){break p}Eb(d+24|0,d+8|0);vb(d+8|0)}tw(e,f);v[23048]=0;S(330,a|0,c|0);f=v[23048];v[23048]=0;if((f|0)==1){break p}ww(c)}yb(d- -64|0);j=j+1|0;if(j>>>0<(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0){continue}break l}break}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;ww(c)}yb(d- -64|0);break n}b=P()|0;O()|0}Qc(d+88|0);break m}b=P()|0;O()|0}yd(d+104|0);R(b|0);L()}j=cd(a)^1;Qc(d+88|0);yd(d+104|0)}gb=d+160|0;return j|0}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-176|0;gb=e;we(e+160|0,b);m=a;k=c;g=d;i=gb-48|0;gb=i;v[i+44>>2]=0;f=b;uk(f,i+44|0);a:{b:{c:{if(v[i+44>>2]!=(qn(46161)|0)){break c}v[i+40>>2]=0;h=gb-16|0;gb=h;v[h+12>>2]=0;Zi(h,f,h+12|0,4);xb(h);v[h>>2]=v[h+12>>2];v[i+40>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);gb=h+16|0;h=-1;j=v[i+40>>2];if(j-1>>>0>1){break c}d:{e:{f:{if((j|0)<=1){j=Jb(i+24|0);v[23048]=0;l=W(694,f|0,j|0,256)|0;n=v[23048];v[23048]=0;if((n|0)==1){break b}if(!l){break e}v[23048]=0;T(13,i+8|0,g|0,j|0);l=v[23048];v[23048]=0;if((l|0)!=1){break f}break b}j=Jb(i+24|0);v[23048]=0;l=W(696,f|0,j|0,255)|0;n=v[23048];v[23048]=0;if((n|0)==1){break b}if(!l){break d}v[23048]=0;T(13,i+8|0,g|0,j|0);l=v[23048];v[23048]=0;if((l|0)==1){break b}}Eb(k,i+8|0);vb(i+8|0);vb(j);u[i+8>>1]=0;Yf(f,i+8|0);v[i+24>>2]=0;uk(f,i+24|0);k=v[i+24>>2];if(k>>>0>50){break c}g:{if(!k){break g}k=1;while(1){if(!hN(m,f,g)){break c}if(y[i+24>>2]<=k>>>0){break g}k=k+1|0;continue}}v[i+24>>2]=0;uk(f,i+24|0);h=v[i+24>>2]==(qn(46166)|0)?1:-1;break c}vb(j);break c}vb(j)}gb=i+48|0;f=h;break a}a=P()|0;O()|0;vb(j);R(a|0);L()}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!f){bp(v[v[b>>2]-12>>2]+b|0,0);f=v[e+172>>2];v[e+8>>2]=v[e+168>>2];v[e+12>>2]=f;f=v[e+164>>2];v[e>>2]=v[e+160>>2];v[e+4>>2]=f;Xj(b,e);b=bm(e+56|0,b);v[23048]=0;f=Q(662,e+40|0,46147)|0;g=v[23048];v[23048]=0;if((g|0)==1){break i}v[23048]=0;v[e+32>>2]=3;v[e+36>>2]=0;T(663,b|0,f|0,e+32|0);g=v[23048];v[23048]=0;if((g|0)==1){break j}Hb(f);t[e+31|0]=0;v[23048]=0;f=Q(662,e+40|0,46150)|0;g=v[23048];v[23048]=0;if((g|0)==1){break k}v[23048]=0;W(664,b|0,e+31|0,f|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break l}Hb(f);v[23048]=0;f=w[e+31|0];g=U(1533,b|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break m}v[23048]=0;h=U(1534,b|0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break n}v[e+32>>2]=h;v[e+24>>2]=g;if(Fb(e+24|0,e+32|0)){f=f?0:d;while(1){u[e+22>>1]=65535;v[23048]=0;d=Q(662,e+40|0,46155)|0;g=v[23048];v[23048]=0;if((g|0)==1){break q}v[23048]=0;g=W(1535,b|0,e+24|0,d|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break p}Hb(d);t:{if(!g){v[23048]=0;Y(1536,b|0,e+24|0,c|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break o}break t}v[23048]=0;d=Q(662,e+40|0,46157)|0;g=v[23048];v[23048]=0;u:{v:{if((g|0)!=1){v[23048]=0;g=W(1535,b|0,e+24|0,d|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break v}Hb(d);if(g){break u}v[23048]=0;T(1537,b|0,e+24|0,e+22|0);d=v[23048];v[23048]=0;if((d|0)!=1){break t}break o}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(d);break h}v[23048]=0;d=Q(662,e+40|0,46159)|0;g=v[23048];v[23048]=0;if((g|0)==1){break s}v[23048]=0;g=W(1535,b|0,e+24|0,d|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break r}Hb(d);if(g){break t}v[23048]=0;Y(1538,b|0,e+24|0,a|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break o}}Ro(e+24|0);if(Fb(e+24|0,e+32|0)){continue}break}}a=v[b>>2];Yg(b);f=a&1073741824?-1:1}gb=e+176|0;return f|0}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(f);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(f);break h}a=P()|0;O()|0}Yg(b);R(a|0);L()}function q1(){var a=0,b=0,c=0;Zd(467216);v[116804]=84368;v[23048]=0;X(2421);a=v[23048];v[23048]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23048]=0;Q(91,467392,84357)|0;a=v[23048];v[23048]=0;if((a|0)==1){break e}Rd(467232);Zd(466896);v[116724]=85792;v[23048]=0;X(2422);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(466904);v[116726]=85824;v[23048]=0;X(2423);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(466912);v[116728]=84388;t[466924]=0;v[116730]=0;b=466920,c=aq(),v[b>>2]=c;v[23048]=0;X(2424);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(466928);v[116732]=84972;v[23048]=0;X(2425);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(466936);v[116734]=85120;v[23048]=0;X(2426);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;X(2427);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;X(2428);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(466960);v[116740]=85268;v[23048]=0;X(2429);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(466968);v[116742]=85384;v[23048]=0;X(2430);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(466976);u[233492]=11310;v[116744]=84488;Jb(466988);v[23048]=0;X(2431);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467008);v[116754]=46;v[116755]=44;v[116752]=84528;Jb(467024);v[23048]=0;X(2432);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467040);v[116760]=85856;v[23048]=0;X(2433);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467048);v[116762]=86100;v[23048]=0;X(2434);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467056);v[116764]=86312;v[23048]=0;X(2435);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467064);v[116766]=86544;v[23048]=0;X(2436);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467072);v[116768]=87528;v[23048]=0;X(2437);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467080);v[116770]=87676;v[23048]=0;X(2438);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467088);v[116772]=87792;v[23048]=0;X(2439);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467096);v[116774]=87908;v[23048]=0;X(2440);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467104);v[116776]=88024;v[23048]=0;X(2441);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467112);v[116778]=88188;v[23048]=0;X(2442);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467120);v[116780]=88352;v[23048]=0;X(2443);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467128);v[116782]=88516;v[23048]=0;X(2444);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467136);v[116786]=9e4;v[116786]=86792;v[116784]=86744;v[23048]=0;X(2445);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467152);v[116790]=90036;v[116790]=87056;v[116788]=87008;v[23048]=0;X(2446);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;X(2447);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;X(2448);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;X(2449);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;X(2450);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467200);v[116800]=88680;v[23048]=0;X(2451);a=v[23048];v[23048]=0;if((a|0)==1){break d}Zd(467208);v[116802]=88800;v[23048]=0;X(2452);a=v[23048];v[23048]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(467392)}fx(467232)}R(a|0);L()}v[116398]=467216}function nO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if(b){h=a+327720|0;c=gb-400|0;gb=c;PR(c+384|0,8);v[23048]=0;ta(1134,c+368|0,9);g=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((g|0)!=1){v[23048]=0;g=Q(1135,c+352|0,14)|0;e=v[23048];v[23048]=0;if((e|0)==1){break l}v[23048]=0;S(1136,c+384|0,g|0);e=v[23048];v[23048]=0;if((e|0)==1){break k}v[23048]=0;S(1136,c+368|0,g|0);e=v[23048];v[23048]=0;if((e|0)==1){break k}OR(c+280|0,4900);OR(c+208|0,32e3);LR(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[23048]=0;e=Q(1137,c+104|0,c+384|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break j}Au(c+120|0,c+280|0,e);Kf(e);v[23048]=0;e=Q(1137,c+72|0,c+368|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break i}Au(c+88|0,c+208|0,e);Kf(e);v[23048]=0;e=Q(1137,c+40|0,c+120|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break h}Au(c+56|0,c+136|0,e);Kf(e);v[23048]=0;e=Q(1137,c+8|0,c+88|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break g}Au(c+24|0,c+136|0,e);Kf(e);Yq(c+120|0);Yq(c+56|0);Yq(c+88|0);Yq(c+24|0);Yq(c+368|0);Xq(c+120|0,sj(h,0));Xq(c+56|0,sj(h,1));Xq(c+88|0,sj(h,2));Xq(c+24|0,sj(h,3));Xq(c+368|0,sj(h,4));Kf(c+24|0);Kf(c+56|0);Kf(c+88|0);Kf(c+120|0);Wq(g);Kf(c+368|0);Kf(c+384|0);gb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Kf(c+56|0)}Kf(c+88|0)}Kf(c+120|0)}Wq(g)}Kf(c+368|0)}Kf(c+384|0);R(a|0);L()}uz(a+131112|0,9.6377,.97);uz(a+196648|0,8.5,.5);uz(a+262184|0,2.7625,.425)}g=a+368680|0;if(!(r=0,s=mO(g,a),t=b,t?r:s)){i=a+24|0;o=A[a+8>>3];c=w[a+16|0];e=gb+-64|0;gb=e;while(1){p=+(k-4096|0)*.0001220703125;l=0;b=0;while(1){j=o;h=c;f=1;m=e+(b<<3)|0;d=+(b|0)-p;n=d+-3.5;if(!(D(n)<1e-8)){m:{n:{switch(h|0){case 0:f=.5-Oe(d*.8975979010256552)*.5;break m;case 1:f=Oe(d*.8975979010256552)*-.46+.54;break m;case 2:f=Oe(d*1.7951958020513104);f=Oe(d*.8975979010256552)*-.5+.42+f*.08;break m;case 3:f=Oe(d*1.7951958020513104);f=Oe(d*.8975979010256552)*-.49364+.44959+f*.05677;break m;case 4:f=Oe(d*1.7951958020513104);f=Oe(d*.8975979010256552)*-.49755+.42323+f*.07922;break m;case 5:f=Oe(d*1.7951958020513104);f=Oe(d*.8975979010256552)*-.48829+.35875+f*.14128+Oe(d*2.6927937030769655)*-.01168;break m;case 6:f=Oe(d*1.7951958020513104);f=Oe(d*.8975979010256552)*-.49703+.40217+f*.09392+Oe(d*2.6927937030769655)*-.00183;break m;case 7:break n;default:break m}}f=Oe(d*1.7951958020513104);f=Oe(d*.8975979010256552)*-.49804+.40243+f*.09831+Oe(d*2.6927937030769655)*-.00122}d=n*3.141592653589793;j=ji(d*j)/d}j=j*f;A[m>>3]=j;l=j+l;b=b+1|0;if((b|0)!=8){continue}break}j=1/l;m=k<<3;b=0;while(1){q=i+(b+m<<1)|0;d=G(F(H(A[e+(b<<3)>>3]*32768*j+.5),32768),-32768);o:{if(D(d)<2147483648){h=~~d;break o}h=-2147483648}u[q>>1]=h;b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if((k|0)!=8193){continue}break}gb=e- -64|0;b=v[a+20>>2];v[g+16>>2]=v[a+16>>2];v[g+20>>2]=b;b=v[a+12>>2];v[g+8>>2]=v[a+8>>2];v[g+12>>2]=b;b=v[a+4>>2];v[g>>2]=v[a>>2];v[g+4>>2]=b}}function Sja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;f=gb-4144|0;gb=f;a:{g=a+14|0;b:{if(!Ib(w[g|0]|w[g+1|0]<<8)){break b}l=a;if(Ib(w[a+14|0]|w[a+15|0]<<8)>>>0>20|x[b+480190>>1]<=w[a+23|0]){break b}wd(d,32);u[d+34>>1]=1;a=a+20|0;_c(f+24|0,a,a+80|0);LT(f+4136|0,f+24|0,Ib(w[l+14|0]|w[l+15|0]<<8));a=El(b,w[Pu(f+4136|0,0)+3|0]+1|0);v[f+24>>2]=1;n=1/+y[Jc(a+24|0,f+24|0)>>2];g=f+24|0;h=f+4136|0;if(c){a=gr(f+4136|0)}else{a=1}LT(g,h,a);a=v[f+24>>2];g=v[f+28>>2];if((a|0)!=(g|0)){while(1){if(!(t[a+1|0]<0|x[b+480190>>1]<=w[a+3|0])){i=El(b,w[a+3|0]+1|0);h=v[i>>2];k=t[a+1|0];j=Pu(f+4136|0,0);s=d,z=oh(n*+(h>>>0)*+y[i+24>>2]*wg(+(k-t[j+1|0]|0)*-.08333333333333333))+v[d>>2]|0,v[s>>2]=z}a=a+4|0;if((g|0)!=(a|0)){continue}break}}q=Mm(d);if(q){h=(e<<12>>>0)/1e4|0;e=gr(f+4136|0);a=f+4120|0;i=Jg(a);c:{if(!e){break c}v[23048]=0;S(973,a|0,e|0);g=v[23048];v[23048]=0;if((g|0)!=1){v[23048]=0;S(974,a|0,e|0);e=v[23048];v[23048]=0;if((e|0)!=1){break c}}break a}i=a;d:{if(!gr(f+4136|0)){break d}a=0;while(1){e:{e=Pu(f+4136|0,a);g=KT(i,a);if(!(t[e+1|0]<0|x[b+480190>>1]<=w[e+3|0])){if(w[e+2|0]<=241|w[e+2|0]>=248){m=0}else{m=+t[w[e+2|0]+26438|0]}j=El(b,w[e+3|0]+1|0);e=t[e+1|0];k=Pu(f+4136|0,0);o=v[j+24>>2];k=t[k+1|0];v[23048]=0;p=Ma(968,+(n*+(o>>>0)*wg(+(e-k|0)*.08333333333333333+m*.010416666666666666)))|0;e=O()|0;o=p|0;k=v[23048];v[23048]=0;p=g;f:{g:{if((k|0)!=1){v[g+8>>2]=o;v[g+12>>2]=e;v[g+16>>2]=v[j+20>>2];e=v[j>>2];v[g+76>>2]=e;v[g+88>>2]=x[j+34>>1]&1023;if(!c){break g}v[g+664>>2]=r;m=xB(g+8|0);v[23048]=0;e=oh(+(e>>>0)/m);j=v[23048];v[23048]=0;if((j|0)==1){break e}r=e+r|0;e=h;break f}break a}e=(h>>>0)/(Ib(w[l+14|0]|w[l+15|0]<<8)>>>0)|0}v[p+20>>2]=e;v[g+24>>2]=e}a=a+1|0;if(gr(f+4136|0)>>>0>a>>>0){continue}break d}break}break a}a=v[d>>2];if(a){l=b+24648|0;c=0;while(1){Pb(f+24|0,0,4096);v[f+16>>2]=512;v[23048]=0;v[f+8>>2]=a-c;a=Gb(f+16|0,f+8|0);b=v[23048];v[23048]=0;h:{i:{if((b|0)!=1){b=v[a>>2];s=f,z=Rb(i),v[s+16>>2]=z;s=f,z=Ub(i),v[s+8>>2]=z;if(Fb(f+16|0,f+8|0)){break i}break h}break a}while(1){j:{a=v[f+16>>2];if(!v[a+16>>2]){break j}e=v[a+664>>2];if(e>>>0>=b>>>0){v[a+664>>2]=e-b;break j}g=v[a+88>>2];v[f+4>>2]=b-e;e=v[a+76>>2];n=xB(a);m=xB(a+8|0);v[23048]=0;e=oh((+(e>>>0)-n)/m);h=v[23048];v[23048]=0;if((h|0)==1){break a}v[23048]=0;v[f>>2]=e;e=Gb(f+4|0,f);h=v[23048];v[23048]=0;if((h|0)==1){break a}e=v[e>>2];h=v[a+664>>2];v[23048]=0;Y(v[((g&1|(g&64?18:16))<<2)+27712>>2],a|0,l|0,(f+24|0)+(h<<3)|0,e|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break j}v[a+16>>2]=0;break j}break a}v[f+16>>2]=v[f+16>>2]+880;if(Fb(f+16|0,f+8|0)){continue}break}}e=v[d+20>>2]+(c<<1)|0;g=f+24|0;a=gb-16|0;gb=a;v[a+12>>2]=b;tc(a+12|0,512);h=v[a+12>>2];v[a+12>>2]=h-1;if(h){while(1){h=jd(v[g>>2]+2048|0,12);h=(h|0)>-32768?h:-32768;u[e>>1]=(h|0)<32767?h:32767;h=v[a+12>>2];v[a+12>>2]=h-1;g=g+8|0;e=e+2|0;if(h){continue}break}}gb=a+16|0;a=v[d>>2];c=b+c|0;if(a>>>0>c>>>0){continue}break}}DT(i)}i=(q|0)!=0}gb=f+4144|0;return i|0}a=P()|0;O()|0;DT(i);R(a|0);L()}function aM(a){var b=0,c=C(0),d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=C(0),q=0,r=C(0),s=C(0),u=0,w=0,x=C(0);k=gb-16|0;gb=k;u=a,w=vj(C(z[a+4256>>2]*C(3))),v[u+4264>>2]=w;u=a,x=C(yf(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[u+4268>>2]=x;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);u=k,x=re(C(10),C(C($L(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[k+8>>2]=1065353216;u=a,x=C(z[um(k+12|0,k+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=x;e=a;c=re(C(10),C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))*C(.0010000000474974513)));if(c!=C(1)){d=Tp(C(C(_L(a)*C(6.2831854820251465))/z[a+4268>>2]));i=C(c+c);f=C(c*c);c=C(c*C(8));c=Ao(C(C(C(C(d*i)+C(-2))+C(K(C(C(C(f*C(-4))+c)+C(C(C(C(f*C(4))*d)-c)*d)))))/C(i+C(-2))),C(0),C(1))}else{c=C(0)}z[e+4276>>2]=c;j=gb-16|0;gb=j;e=a;c=z[a+4268>>2];d=C(z[a+4232>>2]*C(.30000001192092896));z[j+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[j+8>>2]=1000593162;b=a;i=z[Ny(j+12|0,j+8|0)>>2];f=C(c*C(C(d+C(.007000000216066837))+i));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}v[b+4352>>2]=g;b=1;while(1){l=((B(b&1,24)+e|0)+(b<<1&-4)|0)+4352|0;f=C(C(C(z[(b<<2)+49888>>2]*i)+d)*c);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}v[l>>2]=g;b=b+1|0;if((b|0)!=12){continue}break}z[j+12>>2]=C(C(z[e+4248>>2]*C(100))*C(.009091000072658062))+C(.09091000258922577);v[j+8>>2]=1065353216;d=C(z[um(j+12|0,j+8|0)>>2]*c);b=0;while(1){g=(b<<2)+e|0;q=g+4316|0;i=C(re(C(.9300000071525574),C(o|0))*d);f=C(i*C(.07500000298023224));c:{if(C(D(f))<C(2147483648)){l=~~f;break c}l=-2147483648}v[q>>2]=l;l=g+4292|0;i=C(i*C(.06700000166893005));d:{if(C(D(i))<C(2147483648)){g=~~i;break d}g=-2147483648}v[l>>2]=g;b=b+1|0;if((b|0)!=6){o=b+o|0;continue}break}g=e+4348|0;d=C(c*C(.0035299998708069324));e:{if(C(D(d))<C(2147483648)){b=~~d;break e}b=-2147483648}v[g>>2]=b;g=e+4344|0;d=C(c*C(.0032500000670552254));f:{if(C(D(d))<C(2147483648)){b=~~d;break f}b=-2147483648}v[g>>2]=b;g=e+4340|0;c=C(c*C(.009999999776482582));g:{if(C(D(c))<C(2147483648)){b=~~c;break g}b=-2147483648}v[g>>2]=b;b=0;while(1){bM((B(b,24)+e|0)+4504|0,v[((b<<2)+e|0)+4292>>2]);b=b+1|0;if((b|0)!=15){continue}break}gb=j+16|0;b=gb-16|0;gb=b;d=ih(a,5);f=ih(a,11);c=C(d*ih(a,4));i=C(C(c*C(.03999999910593033))+C(d*C(.02250000089406967)));d=C(f*ih(a,10));f=C(C(d*C(.03999999910593033))+C(f*C(.02250000089406967)));if(t[a+4264|0]&1){h=ih(e,3);m=ih(e,9);h=C(h*c);c=C(ih(e,2)*h);i=C(C(C(h*C(.12250000238418579))+i)+C(c*C(.1444000005722046)));h=C(m*d);d=C(ih(e,8)*h);f=C(C(C(h*C(.12250000238418579))+f)+C(d*C(.1444000005722046)))}ih(e,12);h=z[e+4496>>2];m=ih(e,1);n=ih(e,7);r=ih(e,0);s=ih(e,6);u=b,x=re(C(10),C(C($L(e)+C(C(z[e+4236>>2]*C(12e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[b+8>>2]=1065353216;p=z[um(b+12|0,b+8|0)>>2];h=C(h*h);d=C(n*C(h*d));n=C(s*d);c=C(m*C(h*c));h=C(r*c);m=C(C(C(n+h)*C(-.5))+C(1));z[e+4284>>2]=p*C(K(C(m/C(C(C(h+d)*C(.1444000005722046))+i))));z[e+4288>>2]=p*C(K(C(m/C(C(C(n+c)*C(.1444000005722046))+f))));gb=b+16|0;t[a+5046|0]=0;gb=k+16|0}function Zb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[116859]){break a}a=a+b|0;if(v[116860]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=467420,j=v[116855]&Jpa(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+467724|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=467424,j=v[116856]&Jpa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[116857]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[116861]==(f|0)){v[116861]=d;a=v[116858]+a|0;v[116858]=a;v[d+4>>2]=a|1;if(v[116860]!=(d|0)){break a}v[116857]=0;v[116860]=0;return}if(v[116860]==(f|0)){v[116860]=d;a=v[116857]+a|0;v[116857]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=467420,j=v[116855]&Jpa(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+467724|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=467424,j=v[116856]&Jpa(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[116860]!=(d|0)){break f}v[116857]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+467460|0;c=v[116855];a=1<<a;k:{if(!(c&a)){v[116855]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+467724|0;l:{m:{c=v[116856];b=1<<e;n:{if(!(c&b)){v[116856]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[116863]-1|0;v[116863]=a?a:-1}}function jpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-720|0;gb=e;yc(b);g=gb-32|0;gb=g;j=e+104|0;nY(g+24|0,j);i=xb(g+24|0);f=v[g+28>>2];k=v[g+24>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=k;v[g+4>>2]=f;f=b;fc(g+16|0,f,g);k=xb(g+16|0);if((k|0)==(i|0)){Vb(f,xb(g+24|0))}gb=g+32|0;f=(i|0)==(k|0);if(!f){mY(j)}a:{if(!f){break a}if(!pY(e+104|0)){break a}b:{if(!c){break b}Ed(a,67108864);sg(a);d=w[e+129|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Tb(e,17175);Eb(a+1300344|0,d);vb(d);d=Tb(e,17187);Eb(a+1300356|0,d);vb(d);of(e+72|0,17192);v[e+100>>2]=w[e+128|0]>>>4;d=w[e+128|0];v[23048]=0;v[e+96>>2]=d&15;Y(504,e|0,e+72|0,e+100|0,e+96|0);d=v[23048];v[23048]=0;c:{d:{if((d|0)!=1){Eb(a+1300368|0,e);vb(e);Hb(e+72|0);v[a+1300404>>2]=2;Hr(Qb(a+484360|0),e+152|0,w[e+151|0]+1|0);while(1){d=h+1|0;g=B(d,104)+a|0;i=g+484380|0;wd(i,1);f=(e+104|0)+(h<<2)|0;o=i,p=Wb(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[o>>2]=p;j=Wb(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[g+484384>>2]=j;o=g+484388|0,p=Wb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))+j|0,v[o>>2]=p;if(Wb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))){f=g+484414|0;u[f>>1]=x[f>>1]|2}pk(i);h=(e+104|0)+h|0;t[e|0]=w[h+548|0];t[e+72|0]=64;o=g+484410|0,p=w[$b(e,e+72|0)|0]<<2,u[o>>1]=p;t[g+484417|0]=w[h+579|0]<<4;h=d;if((d|0)!=31){continue}break}lD(b,a+1300308|0,32);d=1;while(1){lE(b,((d<<5)+a|0)+946300|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){rg(a+484344|0,w[e+150|0]+1|0)}j=a+484344|0;d=0;e:{while(1){f=d;g=Ah(e+72|0);f:{if(w[e+130|0]){v[23048]=0;d=U(465,b|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break e}v[23048]=0;T(341,e|0,b|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break e}break f}d=x[a+480188>>1];v[23048]=0;T(341,e|0,b|0,d<<8);d=v[23048];v[23048]=0;if((d|0)==1){break d}}id(g,e);yb(e);g:{if(!k){break g}v[23048]=0;d=W(386,j|0,f&65535,64)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(!d){break g}if(!w[e+130|0]){h=0;if(!x[a+480188>>1]){break g}while(1){d=0;while(1){i=Yb(j,f);v[23048]=0;i=Wc(i,d,h&65535);l=v[23048];v[23048]=0;if((l|0)==1){break d}v[23048]=0;S(505,g|0,i|0);i=v[23048];v[23048]=0;if((i|0)==1){break d}d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}break g}i=0;v[23048]=0;S(506,g|0,e|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}while(1){d=Yb(j,f);v[23048]=0;l=Of(d,i);d=v[23048];v[23048]=0;if((d|0)==1){break d}if(x[a+480188>>1]){m=e+i|0;d=128;h=0;while(1){h:{if(!(w[m|0]&d)){break h}v[23048]=0;S(505,g|0,l+B(h,6)|0);n=v[23048];v[23048]=0;if((n|0)!=1){break h}break d}d=d>>>1|0;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}i=i+1|0;if((i|0)!=64){continue}break}}yb(g);d=f+1|0;if(f>>>0<w[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=Sc(e,8,1,1,0);while(1){ug(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}break d}d=P()|0;O()|0;Hb(e+72|0);break c}d=P()|0;O()|0;yb(g)}R(d|0);L()}d=1}gb=e+720|0;return d|0}function VW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-128|0;gb=g;j=vk(g+112|0);a:{b:{c:{if(d){v[23048]=0;T(686,a|0,j|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){break c}break b}v[23048]=0;T(687,a|0,j|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}}k=nc(g+96|0);d:{e:{if(x[b+480192>>1]){d=1;c=1;while(1){v[23048]=0;u[g+94>>1]=0;Q(688,a|0,g+94|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break e}l=gb-16|0;gb=l;p=l+8|0;i=gb-16|0;gb=i;f=j;m=f;o=g+94|0;q=o;e=$d(f);h=dc(f);n=gb-16|0;gb=n;if(e){wb(m);while(1){m=zC(e+16|0,q);h=m?h:e;e=v[(m?4:0)+e>>2];if(e){continue}break}}e=v[Cc(n+8|0,h)>>2];gb=n+16|0;v[i+8>>2]=e;r=i,s=rh(f),v[r>>2]=s;f:{if(Nl(i+8|0,i)){if(!AC(wb(f),o,se(i+8|0))){break f}}e=rh(f)}gb=i+16|0;f=v[Cc(p,e)>>2];gb=l+16|0;v[g+88>>2]=f;i=((d<<2)+b|0)+900380|0;g:{if(!v[i>>2]){break g}r=g,s=Xg(j),v[r+72>>2]=s;if(Xf(g+88|0,g+72|0)){d=se(g+88|0);v[23048]=0;d=Q(4,g+72|0,d+4|0)|0;f=v[23048];v[23048]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((f|0)!=1){v[23048]=0;f=Q(2,g+56|0,19153)|0;e=v[23048];v[23048]=0;if((e|0)==1){break i}e=zr(d,f);vb(f);if(!e){break s}v[v[i>>2]+44>>2]=0;break r}b=P()|0;O()|0;break d}f=v[b+4>>2];v[23048]=0;f=Q(689,f|0,d|0)|0;e=v[23048];v[23048]=0;t:{u:{v:{w:{x:{y:{if((e|0)!=1){v[v[i>>2]+44>>2]=f;if(v[v[i>>2]+44>>2]){break r}v[23048]=0;f=Q(2,g+56|0,19173)|0;e=v[23048];v[23048]=0;if((e|0)==1){break y}z:{A:{if(zr(d,f)){vb(f);break A}v[23048]=0;e=Q(2,g+40|0,19199)|0;h=v[23048];v[23048]=0;if((h|0)==1){break x}h=zr(d,e);vb(e);vb(f);if(!h){break z}}v[23048]=0;S(690,g+56|0,d|0);f=v[23048];v[23048]=0;if((f|0)==1){break w}e=v[b+4>>2];f=gi(g+32|0,g+56|0);v[23048]=0;e=Q(691,e|0,f|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break v}yg(f);yg(g+56|0);if(e){break r}}h=Rb(k);l=Ub(k);f=d;e=gb-16|0;gb=e;v[e>>2]=l;v[e+8>>2]=h;if(Fb(e+8|0,e)){while(1){if(!zr(v[e+8>>2],f)){wr(e+8|0);if(Fb(e+8|0,e)){continue}}break}h=v[e+8>>2]}gb=e+16|0;v[g+56>>2]=h;r=g,s=Ub(k),v[r+40>>2]=s;if(Fb(g+56|0,g+40|0)){break t}v[23048]=0;S(692,k|0,d|0);f=v[23048];v[23048]=0;if((f|0)!=1){break u}}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(f);break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;yg(f);yg(g+56|0);break h}v[23048]=0;f=Q(2,g+16|0,19205)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}v[23048]=0;T(693,g+40|0,f|0,d|0);e=v[23048];v[23048]=0;if((e|0)==1){break p}v[23048]=0;e=Q(2,g|0,19214)|0;h=v[23048];v[23048]=0;if((h|0)==1){break o}v[23048]=0;T(3,g+56|0,g+40|0,e|0);h=v[23048];v[23048]=0;if((h|0)==1){break n}v[23048]=0;T(601,b|0,2,g+56|0);h=v[23048];v[23048]=0;if((h|0)==1){break m}vb(g+56|0);vb(e);vb(g+40|0);vb(f)}v[v[i>>2]+44>>2]=0}vb(d);break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(g+56|0)}vb(e)}vb(g+40|0)}vb(f);break h}b=P()|0;O()|0}vb(d);break d}if(!v[i>>2]){break g}v[v[i>>2]+44>>2]=0}c=c+1|0;d=c&65535;if(d>>>0<=x[b+480192>>1]){continue}break}}em(k);RW(j);gb=g+128|0;return}b=P()|0;O()|0}em(k);break a}b=P()|0;O()|0}RW(j);R(b|0);L()}function dA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0;g=gb-16|0;gb=g;h=B(b,880)+a|0;m=h+1075794|0;i=w[m|0];l=a+1074308|0;Db(g+8|0,l,23);f=c&15;a:{b:{if(Cb(g+8|0)){if(!(v[a+1074384>>2]|!w[(B(b,880)+a|0)+1075774|0])){t[m|0]=f;break b}e=w[m|0];if(e){j=e-1|0;t[m|0]=j;e=0;if(j&255){break b}}t[m|0]=f;e=1;break b}Db(g+8|0,l,52);j=c&256;if(!(!j|!Cb(g+8|0))){c:{if(!(w[a+480209|0]&16)){break c}e=B(b,880)+a|0;if(w[e+1075775|0]){i=KC(e+1075774|0)?1:i}if(!w[(B(b,880)+a|0)+1075778|0]|w[e+1075776|0]!=1){break c}t[m|0]=i;break a}e=0;if((i&255)>>>0<f>>>0){break b}if(w[a+480209|0]&16){if(ne((B(b,880)+a|0)+1075774|0)){break b}}i=0;e=1;break b}if(v[a+480180>>2]&16777250){j=i&255;e=0;d:{if(!j){break d}e=!((j>>>0)%((f?f:1)>>>0)|0)}i=i+1|0;break b}if(v[a+480180>>2]==16){e=v[a+1074384>>2]==(f|0)&(f|0)!=0;break b}e:{f:{g:{h:{i:{if(j){e=B(b,880)+a|0;if(w[e+1075776|0]==1){f=(w[e+1075779|0]>15)+f|0}f=f?f:1;break i}if(w[a+480209|0]&16){break f}f=f?f:1;if(v[a+1074408>>2]){break h}}e=0;break g}e=!(y[a+1074384>>2]%(f>>>0)|0)}i=i+1|0;break e}i=v[a+480180>>2]&1048580?0:i}if(!((i&255)<(f|0)|(w[(B(b,880)+a|0)+1075774|0]|!j?!v[a+1074384>>2]:0))){e=1}Db(g+8|0,l,52);if(!Cb(g+8|0)|c){break b}e=!v[a+1074384>>2]}j=h+1074984|0;k=(B(b,880)+a|0)+1075060|0;j:{if(v[k>>2]){break j}Db(g+8|0,l,38);if(!Cb(g+8|0)){break j}if(!kk(j)){break a}}Db(g+8|0,l,106);if(u=0,z=Cb(g+8|0),A=v[(B(b,880)+a|0)+1075680>>2],A?u:z){break a}if(e){f=B(b,880)+a|0;o=f+1075672|0;v[g+4>>2]=v[o>>2];e=c>>>4&15;k:{if(!e){f=v[f+1075072>>2];break k}Db(g+8|0,l,52);l:{if(u=Cb(g+8|0),z=0,A=w[(B(b,880)+a|0)+1075776|0]==1,A?u:z){break l}if(!(16191>>>e&1)){v[g+4>>2]=B(v[g+4>>2],t[e+34864|0])>>4;break l}v[g+4>>2]=v[g+4>>2]+(t[e+34880|0]<<2)}Vd(g+4|0,0,256);e=(B(b,880)+a|0)+1075072|0;f=v[e>>2]|2097152;v[e>>2]=f}n=B(b,880)+a|0;p=n+1075684|0;q=v[p>>2];e=w[n+1075788|0];h=0;if(f&512){Db(g+8|0,l,108);h=Cb(g+8|0)}if(!(!v[k>>2]|h^1|(e-1&255)>>>0>119)){LP(a,b,0,e,1)}m:{if(!(v[a+480180>>2]&1048580)){f=0;break m}f=(c|0)<256;if((c|0)>255){break m}k=w[(B(b,880)+a|0)+1075775|0];if(!k){break m}f=1;yo(a,j,k,0,0,1)}n=n+1075072|0;n:{if(!h){break n}k=(B(b,880)+a|0)+1075088|0;if(!v[k>>2]){break n}h=a+1300300|0;if(!Fd(h)){break n}Qh(v[h>>2],b,1);Zq(v[h>>2],b,v[k>>2]+68|0)}h=B(b,880)+a|0;k=h+1075644|0;r=v[k>>2];s=v[n>>2];v[k>>2]=0;Db(g+8|0,l,23);ou(a,j,e,Cb(g+8|0),f,0,b);if(!w[h+1075775|0]){v[k>>2]=r}if(!(!(s&4096)|v[a+480180>>2]!=4)){v[n>>2]=v[n>>2]|4096}f=h+1075774|0;v[o>>2]=v[g+4>>2];if(x[a+480192>>1]){t[f|0]=e;tO(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[f|0]|!q))){v[p>>2]=q}e=v[a+480180>>2];Db(g+8|0,l,23);if(Cb(g+8|0)){v[j>>2]=0;v[j+4>>2]=0}e=e&16777250;o:{if((d|0)<1){break o}f=(B(b,880)+a|0)+1075088|0;h=d-1|0;if((h|0)>9){break o}f=v[f>>2];if(!f){break o}p:{if(!h){b=v[(B(b,880)+a|0)+1075648>>2];break p}h=(B(b,880)+a|0)+1075648|0;b=v[(f+(d<<2)|0)+60>>2];v[h>>2]=b}Am(a,j,b)}i=e?i:0}Db(g+8|0,l,52);a=Cb(g+8|0);Db(g+8|0,l,23);if(Cb(g+8|0)){break a}t[m|0]=(a&c>>>8)+i}gb=g+16|0}function XL(a){var b=C(0),c=C(0),d=0,e=C(0),f=0,g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=C(0),r=C(0),s=0,t=C(0);aQ(a+4208|0,z[a+4272>>2]);c=C(C(z[a+4208>>2]*C(15920))+C(80));d=yf(v[a+16>>2]);o=re(C(10),C(C(C(z[a+4216>>2]*C(30))+C(-15))*C(.02500000037252903)));b=C(C(c*C(6.2831854820251465))/C(d>>>0));c=yG(b);r=Tp(b);s=a;t=c;k=C(C(C(b*C(.02888113260269165))*C(C(z[a+4212>>2]*C(35))+C(1)))/c);i=(l(2,(p(k),j(2))&-2147483648|1056964608),q());h=(p(k),j(2))&2147483647;c=(l(2,h),q());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{f=(p(c),j(2));d=f&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((f|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((f|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=b;c=C(c-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}m=C(c*C(.5));g=C(c*m);b=C(C(g*C(C(g*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));n=b;b=C(C(3)-C(m*b));m=C(g*C(C(n-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*m)-g));if(!d){break b}e=C(C(C(c*C(m-e))-e)-g);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}c=C(c-e);b=C(C(c+c)+C(1));break b;default:break i}}f=d<<23;b=(l(2,f+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}g=(l(2,1065353216-f|0),q());d=(d|0)<23;c=C(C((d?C(C(1)-g):C(c-C(e+g)))+(d?C(c-e):C(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}k=C(i*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}k=C(i*C(b+C(b/C(b+C(1)))));break a}g=C(i+i);i=C(0);c=C(c+C(-162.88958740234375));h=(p(c),j(2));f=h>>>31|0;j:{k:{l:{m:{n:{n=c;o:{p:{d=h&2147483647;q:{if(d>>>0>=1118743632){b=c;if(d>>>0>2139095040){break j}b=C(c*C(1.7014118346046923e38));if(!((h|0)<0|d>>>0<1118925336)){break j}if(d>>>0<=1120924084|(h|0)>-1){break q}break l}if(d>>>0<1051816473){break n}if(d>>>0<1065686419){break p}}c=C(C(c*C(1.4426950216293335))+z[(f<<2)+71960>>2]);if(C(D(c))<C(2147483648)){d=~~c;break o}d=-2147483648;break o}d=!f-f|0}b=C(d|0);c=C(n+C(b*C(-.693145751953125)));i=C(b*C(1428606765330187e-21));b=C(c-i);break m}if(d>>>0<=956301312){break k}d=0;b=c}n=c;e=C(b*b);c=C(b-C(e*C(C(e*C(-.0027667332906275988))+C(.16666625440120697))));e=C(C(n+C(C(C(b*c)/C(C(2)-c))-i))+C(1));if(!d){break l}e=bJ(e,d)}b=e;break j}b=C(c+C(1))}k=C(g*C(C(b*C(1.661534994731145e35))*C(1.661534994731145e35)))}b=C(t*k);e=C(b/o);c=C(e+C(1));z[s+4236>>2]=C(C(1)-e)/c;e=C(C(r*C(-2))/c);z[a+4232>>2]=e;b=C(b*o);z[a+4228>>2]=C(C(1)-b)/c;z[a+4224>>2]=e;z[a+4220>>2]=C(b+C(1))/c}function ws(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[116860]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=467420,j=v[116855]&Jpa(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+467724|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=467424,j=v[116856]&Jpa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[116857]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[116861]==(f|0)){v[116861]=a;b=v[116858]+b|0;v[116858]=b;v[a+4>>2]=b|1;if(v[116860]!=(a|0)){break a}v[116857]=0;v[116860]=0;return}if(v[116860]==(f|0)){v[116860]=a;b=v[116857]+b|0;v[116857]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=467420,j=v[116855]&Jpa(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+467724|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=467424,j=v[116856]&Jpa(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[116860]!=(a|0)){break g}v[116857]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+467460|0;d=v[116855];b=1<<b;l:{if(!(d&b)){v[116855]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+467724|0;m:{d=v[116856];c=1<<e;n:{if(!(d&c)){v[116856]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function Nw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-96|0;gb=d;l=a;n=a;a:{b:{c:{d:{e:{if(!(o=0,p=!nd(a,11),q=v[a+4>>2],q?o:p)){f=v[a+28>>2];k=v[a+12>>2];c=v[a+64>>2];g=c+v[a+8>>2]|0;g=ph(d+80|0,g,c>>>0>g>>>0?k+1|0:k);c=v[g+12>>2];b=d;v[b+32>>2]=v[g+8>>2];v[b+36>>2]=c;b=v[g+4>>2];v[d+24>>2]=v[g>>2];v[d+28>>2]=b;Xj(f,d+24|0);b=v[a+28>>2];if(cp(v[v[b>>2]-12>>2]+b|0)){eh(a,1073741826);break a}c=v[a+92>>2];j=a+44|0;e=j;b=vf(e);f:{if(c>>>0>b>>>0){g=gb-32|0;gb=g;g:{m=c-b|0;h:{if(m>>>0<=v[wb(e)>>2]-v[e+4>>2]>>4>>>0){c=gb-16|0;gb=c;f=Pp(c,e,m);if(v[f+4>>2]!=v[f+8>>2]){while(1){wb(e);iG(v[f+4>>2]);b=v[f+4>>2]+16|0;v[f+4>>2]=b;if((b|0)!=v[f+8>>2]){continue}break}}_b(f);gb=c+16|0;break h}b=wb(e);c=Mw(e,vf(e)+m|0);f=vf(e);k=gb-16|0;gb=k;v[k+12>>2]=0;i=g+8|0;vd(i+12|0,b);if(c){b=c;if(b>>>0>=268435456){xc(11118);L()}h=jc(b<<4,4)}v[i>>2]=h;b=(f<<4)+h|0;v[i+8>>2]=b;v[i+4>>2]=b;o=bc(i),p=(c<<4)+h|0,v[o>>2]=p;gb=k+16|0;v[23048]=0;oG(i,m);b=v[23048];v[23048]=0;if((b|0)==1){break g}Lw(e);wb(e);b=i+4|0;Tk(v[e>>2],v[e+4>>2],b);zc(e,b);zc(e+4|0,i+8|0);zc(wb(e),bc(i));v[i>>2]=v[i+4>>2];jG(e,vf(e));nG(i)}gb=g+32|0;break f}a=P()|0;O()|0;nG(i);R(a|0);L()}if(b>>>0>c>>>0){b=v[e>>2]+(c<<4)|0;vf(e);mG(e,b);hi(e);vf(e)}}f=a+32|0;uG(f,v[a+92>>2]<<2);if(v[a+92>>2]){h=0;while(1){b=v[a+28>>2];if(cp(v[v[b>>2]-12>>2]+b|0)){eh(a,1073741828);break a}c=x[a+16>>1];u[d+78>>1]=c;if((c|0)==65535){Ow(v[a+28>>2],d+78|0);c=x[d+78>>1]}g=qc(f);v[d+72>>2]=g;i:{if(!c){break i}b=c;g=v[d+72>>2];if(b>>>0>-1-g>>>0){break i}Rp(f,b+g|0);cl(v[a+28>>2],oc(f,v[d+72>>2]),b);g=v[d+72>>2]}o=Tc(j,h),p=c,u[o+12>>1]=p;o=Tc(j,h),p=g,v[o>>2]=p;if(nd(a,6)){Uk(v[a+28>>2],d+56|0);if(y[d+60>>2]>2147483647){break e}o=Tc(j,h),p=v[d+56>>2],v[o+4>>2]=p}b=v[a+4>>2];j:{if(b){o=Tc(j,h),p=b,v[o+8>>2]=p;break j}if(!nd(a,7)){break j}Uk(v[a+28>>2],d+56|0);if(y[d+60>>2]>2147483647){break d}o=Tc(j,h),p=v[d+56>>2],v[o+8>>2]=p}k:{if(v[Tc(j,h)+8>>2]==-1){break k}if(nd(a,6)){break k}if(h){b=Tc(j,h-1|0);b=v[b+8>>2]+v[b+4>>2]|0}else{b=0}o=Tc(j,h),p=b,v[o+4>>2]=p}if(nd(a,8)){u[d+56>>1]=0;Ow(v[a+28>>2],d+56|0);b=nd(a,9);mm(v[a+28>>2],x[d+56>>1]<<b,-1)}h=h+1|0;if(h>>>0<y[a+92>>2]){continue}break}}we(d+56|0,v[a+28>>2]);b=v[d+68>>2];v[a+72>>2]=v[d+64>>2];v[a+76>>2]=b}Vk(a,4,1);b=v[a+88>>2];if((b|0)!=v[a+64>>2]){break c}c=v[a+76>>2];b=v[a+72>>2];break b}eh(a,1073741829);break a}eh(a,1073741829);break a}c=v[a+12>>2];f=b+v[a+8>>2]|0;c=f>>>0<b>>>0?c+1|0:c;b=f}v[n+80>>2]=b;v[l+84>>2]=c;l=v[a+28>>2];c=ph(d+40|0,b,c);b=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=b;b=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=b;Xj(l,d+8|0);if(nd(a,6)){break a}if(o=0,p=!nd(a,7),q=v[a+4>>2],q?o:p){break a}f=v[a+92>>2];if(!f){break a}c=a+44|0;b=v[a+80>>2];a=v[a+8>>2];l=b-a|0;a=0;while(1){b=Tc(c,a);v[b+4>>2]=l+v[b+4>>2];a=a+1|0;if((f|0)!=(a|0)){continue}break}}gb=d+96|0}function qfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=45380;v[a+4>>2]=0;v[a>>2]=33152;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;dr(a+24604|0);jP(a+24648|0,0);b=a+393352|0;v[b>>2]=8;v[b+4>>2]=0;u[b+4128>>1]=0;c=b+4120|0;v[c>>2]=0;v[c+4>>2]=0;c=b+4112|0;v[c>>2]=0;v[c+4>>2]=0;v[b+4104>>2]=0;v[b+4108>>2]=0;Pb(b+4132|0,0,40);PS(b+8|0,1024);Pb(b+4172|0,0,49824);Pb(b+53996|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=Co(a+480248|0);v[a+480272>>2]=0;b=a+484344|0;c=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){v[23048]=0;c=iP(c);e=v[23048];v[23048]=0;if((e|0)==1){break k}c=c+32|0;if((b|0)!=(c|0)){continue}break}e=a+484344|0;dd(e);v[e+12>>2]=a;v[23048]=0;l=Q(1305,a+484360|0,a|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break j}b=a+900380|0;c=a+484380|0;while(1){v[23048]=0;c=Q(930,c|0,0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break i}c=c+104|0;if((b|0)!=(c|0)){continue}break}v[23048]=0;U(1306,a+901404|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break h}c=a+946300|0;f=a+906300|0;b=f;while(1){b=hP(b)+160|0;if((c|0)!=(b|0)){continue}break}d=a+1074300|0;g=a+946300|0;b=g;while(1){v[23048]=0;b=br(b);h=v[23048];v[23048]=0;if((h|0)==1){break g}b=b+32|0;if((d|0)!=(b|0)){continue}break}v[a+1074300>>2]=0;v[a+1074304>>2]=0;$z(a+1074308|0);v[23048]=0;b=fa(1307)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}v[23048]=0;b=U(1308,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}v[a+1074324>>2]=b;v[23048]=0;rO(a+1074328|0);b=v[23048];v[23048]=0;if((b|0)==1){break f}v[23048]=0;U(1310,a+1074368|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}v[23048]=0;d=W(1271,a+1300264|0,a|0,255)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}h=lh(a+1300300|0);b=gb-16|0;gb=b;v[b+12>>2]=0;i=a+1300304|0;Eq(i,b+12|0);gb=b+16|0;m=Jb(a+1300308|0);n=Jb(a+1300320|0);j=a+1300332|0;Jb(j);o=gP(a+1300344|0);p=dd(a+1300408|0);t[a+1300420|0]=0;b=a+1300424|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1300464>>2]=0;Jq(a+12|0);er(a+8204|0);er(a+12300|0);b=a+1074400|0;v[b>>2]=4;v[b+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;fP(a+900380|0);v[23048]=0;Xz(g);b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;b=U(1312,12)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;_g(b);v[a+4>>2]=b;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Zz(p);hu(o);vb(j);vb(n);vb(m);gu(i);fu(h);Mq(d)}while(1){c=Iq(c-160|0);if((f|0)!=(c|0)){continue}break}}Eu(l)}Wz(e)}Qc(k);R(b|0);L()}function DO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=0,n=0,o=C(0),p=0,q=0,r=C(0),s=0,t=0,w=0,A=0,E=C(0),G=0;if(b){Dq(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;TO(a)}CO(a+24648|0);s=v[a+24620>>2];h=gb-144|0;gb=h;f=a+393352|0;c=v[f+4>>2];a:{if(c>>>0<=28){g=B(c,44)+50448|0;break a}v[f+4>>2]=0;g=50448}if(!(b?0:(g|0)==v[f+4112>>2])){v[f+4112>>2]=g;r=C(s>>>0);i=r;c=h+8|0;d=v[g+24>>2];v[c>>2]=d;e=v[g+16>>2];v[c+4>>2]=e;v[c+8>>2]=v[g+4>>2];m=(d|0)>(e|0)?d:e;if((m|0)<=-601){j=e;e=m+600|0;v[c+4>>2]=j-e;v[c>>2]=d-e}e=c;k=C(z[g+36>>2]*C(79.30999755859375));b:{if(C(D(k))<C(2147483648)){d=~~k;break b}d=-2147483648}v[e+16>>2]=d- -8192;d=c;k=C(C(z[g+32>>2]*C(117.9612045288086))+C(4915.05029296875));c:{if(C(D(k))<C(2147483648)){e=~~k;break c}e=-2147483648}v[d+20>>2]=(e|0)<32512?e:32512;m=0;k=z[g+8>>2];e=c;o=C(C(F(z[g+20>>2],C(.10000000149011612)))*i);d:{if(C(D(o))<C(2147483648)){d=~~o;break d}d=-2147483648}j=(d|0)<96;p=j?96:d;l=(p|0)>7500;o=C(z[g+28>>2]*i);e:{if(C(D(o))<C(2147483648)){n=~~o;break e}n=-2147483648}d=(n+(j?d-96|0:0)|0)+(l?p-7500|0:0)|0;j=(d|0)<128;n=j?128:d;t=(n|0)>3800;w=t?3800:n;v[e+24>>2]=w;j=j?d-128|0:0;e=c;i=C(k*i);f:{if(C(D(i))<C(2147483648)){d=~~i;break f}d=-2147483648}j=(d+j|0)+(t?n-3800|0:0)|0;v[e+32>>2]=j;p=l?7500:p;while(1){d=B(m,12);e=d+c|0;u[e+42>>1]=x[d+52042>>1];u[e+36>>1]=x[d+52036>>1];l=d+52038|0;l=x[l>>1]|x[l+2>>1]<<16;u[e+38>>1]=l;u[e+40>>1]=l>>>16;v[e+44>>2]=p+((B(v[d+52032>>2],w)+50|0)/100|0);m=m+1|0;if((m|0)!=8){continue}break}e=c;i=C(j|0);k=C(re(C(.0010000000474974513),(j|0)<4721?C(1):C(C(4720)/i))*C(32768));g:{if(C(D(k))<C(2147483648)){d=~~k;break g}d=-2147483648}v[e+12>>2]=d;i=C(z[g+12>>2]*i);A=c,E=re(C(.0010000000474974513),i>C(4720)?C(C(4720)/i):C(1)),z[A+28>>2]=E;v[f+4124>>2]=v[h+40>>2];c=OL(QL(v[h+16>>2]),r);u[f+4190>>1]=c;u[f+4188>>1]=c;c=x[h+24>>1]<<1;u[f+4198>>1]=c;u[f+4196>>1]=c;while(1){c=(q<<4)+f|0;g=(h+8|0)+B(q,12)|0;d=v[g+44>>2];v[c+4204>>2]=d;v[c+4208>>2]=d;u[c+4212>>1]=x[g+36>>1];u[c+4214>>1]=x[g+42>>1];u[c+4216>>1]=x[g+40>>1];u[c+4218>>1]=x[g+38>>1];q=q+1|0;if((q|0)!=8){continue}break}v[f+53996>>2]=v[h+32>>2];e=f+4184|0;c=v[h+12>>2];if((c|0)>-9e3){c=NL(c)}else{c=0}v[e>>2]=c;e=f+54052|0;c=v[h+8>>2];if((c|0)>=-8999){c=NL(c)}else{c=0}v[e>>2]=c;c=v[h+28>>2];g=f+54036|0;v[g>>2]=268464128;v[g+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[f+54010>>1]=c;u[f+54008>>1]=c;u[f+54006>>1]=c;u[f+54004>>1]=c;v[h+4>>2]=v[h+20>>2];Vd(h+4|0,0,32752);c=x[h+4>>1];u[f+54018>>1]=c;g=f+54014|0;u[g>>1]=0;u[g+2>>1]=0;u[f+54012>>1]=c;i=z[h+36>>2];A=h,G=OL(C(i*i),r),v[A>>2]=G;Vd(h,256,32512);c=x[h>>1];u[f+54026>>1]=c;g=f+54022|0;u[g>>1]=0;u[g+2>>1]=0;u[f+54020>>1]=c}if(b){v[f+4120>>2]=0;SL(f)}b=B(s,5);if(b>>>0>y[f+4124>>2]){v[f+4124>>2]=b}gb=h+144|0;b=a+1300300|0;if(Fd(b)){XR(v[b>>2],v[a+24620>>2])}}function iL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-224|0;gb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(jk(b)){break a}d=w[jl(b)|0];c=1;b:{if((d|0)==33){break b}if((d|0)!=63){break a}c=0}e=c;wl(f+184|0,b,v[b+4>>2]-1|0);c=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=c}Md(f+184|0);c=v[f+184>>2];Md(f+168|0);g=il(c,v[f+172>>2],b);Md(f+184|0);c=v[b>>2];d=v[b+4>>2];c:{d:{e:{f:{if((g|0)==v[f+188>>2]){v[f+208>>2]=c;v[f+212>>2]=d;a=wc(f+200|0,56371);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Kc(f+16|0,f+8|0)){a=aa(8)|0;v[23048]=0;S(2063,f+168|0,f+216|0);b=v[23048];v[23048]=0;g:{h:{i:{if((b|0)!=1){v[23048]=0;T(2045,f+184|0,57575,f+168|0);b=v[23048];v[23048]=0;if((b|0)==1){break i}rc(a,f+184|0);e=0;v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break e}b=P()|0;O()|0;vb(f+184|0);break h}b=P()|0;O()|0;break g}b=P()|0;e=1;O()|0}vb(f+168|0);if(!e){break f}}ca(a|0);break f}if(!e){break c}c=aa(8)|0;v[23048]=0;d=Q(2061,f+136|0,b|0)|0;b=v[23048];v[23048]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){v[23048]=0;T(2045,f+152|0,57454,d|0);a=v[23048];v[23048]=0;if((a|0)==1){break r}v[23048]=0;S(2057,f+168|0,f+152|0);b=v[23048];v[23048]=0;a=1;if((b|0)==1){break q}v[23048]=0;S(2063,f+120|0,f+216|0);a=v[23048];v[23048]=0;if((a|0)==1){break p}v[23048]=0;T(2062,f+184|0,f+168|0,f+120|0);b=v[23048];v[23048]=0;a=1;if((b|0)==1){break o}rc(c,f+184|0);v[23048]=0;T(84,c|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break e}b=P()|0;O()|0;vb(f+184|0);a=0;break n}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;a=1;O()|0;break m}b=P()|0;O()|0}vb(f+120|0)}vb(f+168|0)}vb(f+152|0)}vb(d)}if(!a){break f}ca(c|0);break f}v[f+112>>2]=c;v[f+116>>2]=d;c=wc(f+104|0,56371);d=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=d;d=v[c+4>>2];v[f+56>>2]=v[c>>2];v[f+60>>2]=d;if(!Kc(f- -64|0,f+56|0)){break d}a=aa(8)|0;v[23048]=0;S(2063,f+168|0,f+216|0);b=v[23048];v[23048]=0;s:{t:{u:{if((b|0)!=1){v[23048]=0;T(2045,f+184|0,57575,f+168|0);b=v[23048];v[23048]=0;if((b|0)==1){break u}rc(a,f+184|0);e=0;v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break e}b=P()|0;O()|0;vb(f+184|0);break t}b=P()|0;O()|0;break s}b=P()|0;e=1;O()|0}vb(f+168|0);if(!e){break f}}ca(a|0)}R(b|0)}L()}c=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=c;c=wc(f+88|0,57289);d=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=d;d=v[c+4>>2];v[f+40>>2]=v[c>>2];v[f+44>>2]=d;if(Kc(f+48|0,f+40|0)){YK(a,vc(v[f+216>>2],v[f+220>>2]));break c}c=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=c;b=wc(f+72|0,57437);c=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=c;c=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=c;if(!Kc(f+32|0,f+24|0)){break c}b=vc(v[f+216>>2],v[f+220>>2]);v[v[a+32>>2]+52>>2]=b>>>0>3?1:b}gb=f+224|0}function Xea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=gb-144|0;gb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){lz(a+96|0,c);v[23048]=0;c=Q(2,a+80|0,1024)|0;d=v[23048];v[23048]=0;if((d|0)==1){break E}v[23048]=0;T(3,a+112|0,a+96|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break D}v[23048]=0;d=Q(4,a+48|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break C}v[23048]=0;e=Q(2,a+32|0,1027)|0;f=v[23048];v[23048]=0;if((f|0)==1){break B}v[23048]=0;T(5,a- -64|0,d|0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break A}v[23048]=0;T(3,a+128|0,a+112|0,a- -64|0);f=v[23048];v[23048]=0;if((f|0)==1){break z}vb(a- -64|0);vb(e);vb(d);vb(a+112|0);vb(c);vb(a+96|0);c=v[b>>2];v[23048]=0;T(6,a+112|0,1,(c?c:1030)|0);c=v[23048];v[23048]=0;if((c|0)==1){break t}c=v[b+4>>2];v[23048]=0;T(6,a+96|0,1,(c?c:1030)|0);c=v[23048];v[23048]=0;if((c|0)==1){break s}b=v[b+8>>2];v[23048]=0;v[a+64>>2]=b;S(7,a+80|0,a- -64|0);b=v[23048];v[23048]=0;if((b|0)==1){break r}v[23048]=0;b=Q(8,464792,1031)|0;c=v[23048];v[23048]=0;if((c|0)==1){break q}v[23048]=0;T(9,a- -64|0,0,a+112|0);c=v[23048];v[23048]=0;if((c|0)==1){break p}v[23048]=0;b=Q(10,b|0,a- -64|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break o}v[23048]=0;b=Q(8,b|0,1044)|0;c=v[23048];v[23048]=0;if((c|0)==1){break o}v[23048]=0;T(9,a+32|0,0,a+80|0);c=v[23048];v[23048]=0;if((c|0)==1){break n}v[23048]=0;b=Q(10,b|0,a+32|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break m}v[23048]=0;b=Q(8,b|0,1046)|0;c=v[23048];v[23048]=0;if((c|0)==1){break m}v[23048]=0;b=Q(8,b|0,1024)|0;c=v[23048];v[23048]=0;if((c|0)==1){break m}v[23048]=0;T(9,a+16|0,0,a+128|0);c=v[23048];v[23048]=0;if((c|0)==1){break l}v[23048]=0;b=Q(10,b|0,a+16|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break k}v[23048]=0;b=Q(8,b|0,1048)|0;c=v[23048];v[23048]=0;if((c|0)==1){break k}v[23048]=0;T(9,a|0,0,a+96|0);c=v[23048];v[23048]=0;if((c|0)==1){break j}v[23048]=0;b=Q(10,b|0,a|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break i}v[23048]=0;b=Q(8,b|0,1051)|0;c=v[23048];v[23048]=0;if((c|0)==1){break i}v[23048]=0;Q(11,b|0,12)|0;b=v[23048];v[23048]=0;if((b|0)==1){break i}vb(a);vb(a+16|0);vb(a+32|0);vb(a- -64|0);vb(a+80|0);vb(a+96|0);vb(a+112|0);vb(a+128|0)}gb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;vb(a- -64|0)}vb(e)}vb(d)}vb(a+112|0)}vb(c)}vb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a)}vb(a+16|0)}vb(a+32|0)}vb(a- -64|0)}vb(a+80|0)}vb(a+96|0)}vb(a+112|0)}vb(a+128|0)}R(b|0);L()}function d$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-336|0;gb=d;h=gb-16|0;gb=h;v[a>>2]=0;e=a+32|0;uG(e,32);t[h+15|0]=0;j=h+15|0;a:{if(y[e+4>>2]<y[wb(e)>>2]){tG(e,j);break a}i=gb-32|0;gb=i;f=wb(e);f=Zg(i+8|0,qh(e,qc(e)+1|0),qc(e),f);Qp(v[f+8>>2],j);v[f+8>>2]=v[f+8>>2]+1;v[23048]=0;S(199,e|0,f|0);e=v[23048];v[23048]=0;b:{if((e|0)!=1){ee(f);gb=i+32|0;break b}a=P()|0;O()|0;ee(f);R(a|0);L()}}gb=h+16|0;e=v[a+28>>2];c:{if(!Sf(v[v[e>>2]-12>>2]+e|0)){eh(a,1073741825);break c}we(d- -64|0,v[a+28>>2]);e=d- -64|0;f=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=f;e=d- -64|0;v[e>>2]=3;f=v[a+28>>2];h=d+24|0;if(v[e>>2]){while(1){Eh(f,g+h|0);g=g+1|0;if(g>>>0<y[e>>2]){continue}break}}if(zd(d+24|0,11115,3)){eh(a,1073741827);break c}t[d+335|0]=0;Eh(v[a+28>>2],d+335|0);f=gb-16|0;gb=f;e=d- -64|0;g=e+256|0;while(1){Re(e);e=e+1|0;if((g|0)!=(e|0)){continue}break}gb=f+16|0;f=b;g=d+24|0;h=d- -64|0;e=w[d+335|0];if(e){cl(v[a+28>>2],d- -64|0,e);b=w[d+335|0]}else{b=0}b=En(g,h,b);e=Pw(f,b);Hb(b);if(!e){eh(a,1073741830)}if(w[a+3|0]&64){break c}Eh(v[a+28>>2],d+63|0);e=w[d+63|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(_i(e,6)){Vk(a,9,1)}v[d+56>>2]=0;qG(v[a+28>>2],d+56|0);b=v[d+56>>2];t[d+55|0]=0;if(b>>>0>=2){Eh(v[a+28>>2],d+63|0);g=w[d+63|0];if(!g){Eh(v[a+28>>2],d+55|0);g=w[d+63|0]}mm(v[a+28>>2],b+(g?-1:-2)|0,-1)}v[d+40>>2]=0;v[d+44>>2]=0;d:{if(!_i(e,4)){break d}Uk(v[a+28>>2],d+40|0);b=v[d+44>>2];f=v[d+40>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break d}eh(a,536871424)}if(_i(e,5)){Eh(v[a+28>>2],d+63|0);mm(v[a+28>>2],w[d+63|0],-1)}e:{if(!_i(w[d+55|0],0)){break e}Eh(v[a+28>>2],d+63|0);b=w[d+63|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break e}eh(a,536871168)}v[a+4>>2]=0;b=1;if(_i(w[d+55|0],1)){qG(v[a+28>>2],a+4|0)}Vk(a,6,_i(e,2));Vk(a,7,_i(e,3));Vk(a,5,x[a+16>>1]!=0);Vk(a,8,_i(e,7));f:{if(nd(a,5)){break f}if(nd(a,6)){break f}if(nd(a,7)){break f}b=nd(a,8)}Vk(a,11,b);nd(a,11);b=w[d+55|0];if(_i(b,2)){u[d+24>>1]=0;Ow(v[a+28>>2],d+24|0);mm(v[a+28>>2],B(x[d+24>>1],nd(a,9)?2:1),-1);b=w[d+55|0]}if(_i(b&255,3)){mm(v[a+28>>2],5,-1)}Uk(v[a+28>>2],d+40|0);c=v[d+44>>2];b=v[d+40>>2];if(!c&b>>>0>=16001|c){eh(a,1073741831);break c}v[a+92>>2]=b;if(!b){eh(a,536871040)}g:{if(!nd(a,11)){break g}Uk(v[a+28>>2],d+40|0);b=v[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break g}eh(a,1073741829);break c}we(d+8|0,v[a+28>>2]);sG(d+24|0,d+8|0,v[a+8>>2],v[a+12>>2]);b=v[d+36>>2];e=v[d+32>>2];if(!(b?0:(b|0)>0?1:(b|0)>=0)){eh(a,1073741832);break c}v[a+88>>2]=e;b=a;h:{if(nd(a,11)){c=v[d+40>>2];break h}c=v[a+88>>2]}v[b+64>>2]=c;if(!nd(a,11)){c=v[a+12>>2];e=v[a+88>>2];f=e+v[a+8>>2]|0;c=f>>>0<e>>>0?c+1|0:c;v[a+72>>2]=f;v[a+76>>2]=c}Vk(a,10,1)}gb=d+336|0}function Om(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;f=nc(a);v[23048]=0;e=U(474,b|0)|0;a=v[23048];v[23048]=0;a:{b:{c:{d:{e:{if((a|0)==1){break e}v[23048]=0;a=Q(250,b|0,e|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}if(a){break d}v[23048]=0;a=U(511,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}v[23048]=0;Q(370,b|0,a|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break c}}b=P()|0;O()|0;break a}v[23048]=0;T(341,c+56|0,b|0,e|0);b=v[23048];v[23048]=0;f:{g:{a=c;h:{i:{if((b|0)!=1){if(e>>>0<10){break g}v[23048]=0;b=U(964,c+56|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(!b){break g}v[23048]=0;b=U(474,c+56|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}v[c+52>>2]=b;v[c+48>>2]=e-10;b=v[c+48>>2];if(b>>>0>25264513){break i}b=B(b,170);break h}b=P()|0;O()|0;break a}b=-1}v[a+48>>2]=b;tc(c+52|0,b);v[23048]=0;S(488,f|0,v[c+52>>2]);a=v[23048];v[23048]=0;if((a|0)==1){break b}e=v[c+52>>2];b=0;while(1){j:{v[23048]=0;a=U(965,c+56|0)|0;d=v[23048];v[23048]=0;k:{l:{m:{n:{if((d|0)!=1){if(a){break j}v[23048]=0;a=U(746,c+56|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}switch(a|0){case 3:break k;case 2:break l;case 1:break m;case 0:break n;default:break j}}break b}v[23048]=0;a=U(373,c+56|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(a>>>0>e>>>0){break j}v[23048]=0;d=Q(250,c+56|0,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}if(!d){break j}v[23048]=0;me(c+8|0,f);d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;Y(966,c+32|0,c+8|0,b|0,a|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;d=v[c+36>>2];v[c>>2]=v[c+32>>2];v[c+4>>2]=d;T(675,c+24|0,c+56|0,c|0);d=v[23048];v[23048]=0;if((d|0)!=1){e=e-a|0;b=a+b|0;continue}break b}v[23048]=0;a=U(373,c+56|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}d=a<<2;if(d>>>0>e>>>0){break j}v[23048]=0;g=Q(967,c+56|0,c+40|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break b}if(!g){break j}e=e-d|0;if(!a){continue}while(1){d=dc(c+40|0);i=c,j=Rb(f),v[i+8>>2]=j;Tu(c+40|0,d,Ne(c+8|0,b));b=b+4|0;a=a-1|0;if(a&255){continue}break}continue}if(e>>>0<8){break j}v[23048]=0;a=Q(967,c+56|0,c+40|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(!a){break j}a=dc(c+40|0);i=c,j=Rb(f),v[i+8>>2]=j;Tu(c+40|0,a,Ne(c+8|0,b));a=dc(c+40|0);i=c,j=Rb(f),v[i+24>>2]=j;i=c,j=Ne(c+24|0,b),v[i+8>>2]=j;Tu(c+40|0,a,Ne(c+8|0,4));e=e-8|0;b=b+8|0;continue}v[23048]=0;a=U(373,c+56|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(a>>>0>e>>>0){break j}e=e-a|0;b=a+b|0;continue}break}if(!e){break f}a=nc(c+8|0);mc(a,f);mc(a+4|0,f+4|0);mc(wb(a),wb(f));wb(a);wb(f);gc(a);break f}v[23048]=0;W(543,c+56|0,f|0,e|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}}yb(c+56|0)}gb=c+80|0;return}b=P()|0;O()|0;yb(c+56|0)}gc(f);R(b|0);L()}function Mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-96|0;gb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(w[a|0]==23){e=t[a+1|0];f=d,g=oA(c,+w[a+2|0]*41.666666666666664),t[f+8|0]=g;v[d+80>>2]=127;v[d+64>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[sd(d+80|0,d- -64|0)>>2],t[f+95|0]=g;n:{switch(((e>>>0)%5|0)-1|0){case 0:of(d- -64|0,26686);v[23048]=0;S(775,d+48|0,d+8|0);a=v[23048];v[23048]=0;o:{p:{q:{r:{s:{t:{if((a|0)!=1){v[23048]=0;S(775,d+32|0,d+95|0);a=v[23048];v[23048]=0;if((a|0)==1){break t}v[23048]=0;Y(776,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break s}v[23048]=0;Ye(d+16|0,b);a=v[23048];v[23048]=0;if((a|0)==1){break r}v[23048]=0;Q(450,d+16|0,d+80|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break r}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break m}b=P()|0;O()|0;break o}b=P()|0;O()|0;break p}b=P()|0;O()|0;break q}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break a;case 1:of(d- -64|0,26713);v[23048]=0;S(775,d+48|0,d+8|0);a=v[23048];v[23048]=0;u:{v:{w:{x:{y:{z:{if((a|0)!=1){v[23048]=0;S(775,d+32|0,d+95|0);a=v[23048];v[23048]=0;if((a|0)==1){break z}v[23048]=0;Y(776,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[23048];v[23048]=0;if((a|0)==1){break y}v[23048]=0;Ye(d+16|0,b);a=v[23048];v[23048]=0;if((a|0)==1){break x}v[23048]=0;Q(450,d+16|0,d+80|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break x}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break m}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break a;default:break n}}a=Tb(d+80|0,26740);v[23048]=0;Ye(d- -64|0,b);b=v[23048];v[23048]=0;if((b|0)==1){break b}v[23048]=0;Q(450,d- -64|0,a|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break b}vb(a);break m}if(w[a|0]!=24){break c}t[d+95|0]=t[a+1|0]<=4?w[a+1|0]:0;t[d+31|0]=t[a+2|0]>=0?w[a+2|0]:127;t[d+30|0]=t[a+3|0]>=0?w[a+3|0]:127;a=gb-16|0;gb=a;c=Tb(a,26758);Dc(d- -64|0,c);vb(c);gb=a+16|0;v[23048]=0;S(775,d+48|0,d+95|0);a=v[23048];v[23048]=0;if((a|0)==1){break l}v[23048]=0;S(775,d+32|0,d+31|0);a=v[23048];v[23048]=0;if((a|0)==1){break k}v[23048]=0;S(775,d+16|0,d+30|0);a=v[23048];v[23048]=0;if((a|0)==1){break j}v[23048]=0;ea(971,d+80|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[23048];v[23048]=0;if((a|0)==1){break i}v[23048]=0;Ye(d+8|0,b);a=v[23048];v[23048]=0;if((a|0)==1){break h}v[23048]=0;Q(450,d+8|0,d+80|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break h}vb(d+80|0);vb(d+16|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0)}gb=d+96|0;return 1}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(d+80|0)}vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break a}gb=d+96|0;return 0}b=P()|0;O()|0;vb(a)}R(b|0);L()}function Vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=gb-48|0;gb=c;if(ai(b)){h=wi(b);j=v[b+12>>2];f=c+32|0;e=Bg(f);a:{d=h;if(!d){break a}v[23048]=0;S(659,f|0,d|0);g=v[23048];v[23048]=0;if((g|0)!=1){v[23048]=0;LN(f,d);d=v[23048];v[23048]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;qv(e);R(a|0);L()}b:{if(!j){break b}while(1){d=v[v[a>>2]-12>>2];v[23048]=0;d=Sf(a+d|0);e=v[23048];v[23048]=0;c:{if((e|0)!=1){d:{if(!d){break b}v[23048]=0;t[c+31|0]=0;Q(1497,a|0,c+31|0)|0;d=v[23048];v[23048]=0;e:{if((d|0)!=1){d=t[c+31|0];if(d){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((d|0)>-1){break f}v[23048]=0;Q(1497,a|0,c+30|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break f}break d}t[c+29|0]=0;$h(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=d&127;d=(d?d-1|0:0)&65535;k=d>>>0>=h>>>0;B:{C:{if(!k){v[23048]=0;g=Wc(b,i,d);e=v[23048];v[23048]=0;if((e|0)==1){break d}if(t[c+30|0]&1){break C}break z}g=c+16|0;e=w[c+30|0];if(!(e&1)){break B}}v[23048]=0;Q(1497,a|0,c+29|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break A}e=w[c+30|0]}if(e&2){break y}break x}e=w[c+29|0];l=ad(f,d),m=e,t[l|0]=m}l=g,m=w[ad(f,d)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[23048]=0;Q(1497,a|0,c+29|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break w}e=w[c+30|0]}if(e&4){break u}break t}e=w[c+29|0];l=ad(f,d),m=e,t[l+1|0]=m}l=g,m=w[ad(f,d)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[23048]=0;Q(1497,a|0,c+29|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break s}e=w[c+30|0]}if(e&8){break q}break p}e=w[c+29|0];l=ad(f,d),m=e,t[l+2|0]=m}l=g,m=w[ad(f,d)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[23048]=0;Q(1497,a|0,c+29|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break o}e=w[c+30|0]}if(e&16){break m}break l}e=w[c+29|0];l=ad(f,d),m=e,t[l+4|0]=m}l=g,m=w[ad(f,d)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[23048]=0;Q(1497,a|0,c+29|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break k}e=w[c+30|0]}if(e&32){break i}break g}e=w[c+29|0];l=ad(f,d),m=e,t[l+3|0]=m}l=g,m=w[ad(f,d)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[23048]=0;Q(1497,a|0,c+29|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}if(k){break g}e=w[c+29|0];l=ad(f,d),m=e,t[l+5|0]=m}l=g,m=w[ad(f,d)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[23048]=0;Q(1497,a|0,c+15|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){d=w[c+15|0];v[23048]=0;W(1498,a|0,d|0,-1)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break c}}}}a=P()|0;O()|0;_m(f);R(a|0);L()}if(i>>>0<j>>>0){continue}break}}_m(f)}gb=c+48|0}function d7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-192|0;gb=d;a:{if(jk(b)){break a}e=w[jl(b)|0];g=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}g=0}c=g;wl(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}Md(d+160|0);e=v[d+160>>2];Md(d+144|0);e=il(e,v[d+148>>2],b);Md(d+160|0);c:{d:{e:{f:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=wc(d+176|0,56371);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Kc(d+8|0,d)){a=aa(8)|0;v[23048]=0;c=Q(91,d+160|0,57444)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}f=0;if(!c){break f}a=aa(8)|0;v[23048]=0;e=Q(2061,d+144|0,b|0)|0;b=v[23048];v[23048]=0;g:{h:{i:{if((b|0)!=1){v[23048]=0;T(2045,d+160|0,57454,e|0);b=v[23048];v[23048]=0;if((b|0)==1){break i}rc(a,d+160|0);c=0;v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break c}b=P()|0;O()|0;vb(d+160|0);break h}b=P()|0;O()|0;break g}b=P()|0;c=1;O()|0}vb(e);if(!c){break d}}ca(a|0);break d}if(v[e+4>>2]!=2){a=aa(8)|0;v[23048]=0;c=Q(91,d+160|0,57468)|0;b=v[23048];v[23048]=0;if((b|0)!=1){rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=wc(d+128|0,56371);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Kc(d+72|0,d- -64|0)){a=aa(8)|0;v[23048]=0;c=Q(91,d+160|0,57444)|0;b=v[23048];v[23048]=0;if((b|0)!=1){rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=wc(d+112|0,57297);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Kc(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break f}f=65536/+y[v[a+24>>2]+480244>>2];break f}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=wc(d+96|0,57315);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Kc(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break f}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break f}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=wc(d+80|0,57412);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Kc(d+24|0,d+16|0)){break f}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}gb=d+192|0;return+f}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function Pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=gb-560|0;gb=f;a:{if(!Rc(b,1464)){break a}if(!dp(b,f+556|0)){break a}Ed(a,1);d=a+1074308|0;Cg(d,83);Kb(d,84,1);Kb(d,85,1);b:{if(ke(f+556|0,24794)){d=Tb(f+32|0,24804);Eb(a+1300344|0,d);vb(d);d=Tb(f+32|0,24827);Eb(a+1300356|0,d);vb(d);d=Tb(f+32|0,24832);Eb(a+1300368|0,d);break b}if(!ke(f+556|0,24799)){break a}d=Tb(f+32|0,24849);Eb(a+1300344|0,d);vb(d);d=Tb(f+32|0,24861);Eb(a+1300356|0,d);vb(d);d=Tb(f+32|0,24865);Eb(a+1300368|0,d)}vb(d);v[a+1300404>>2]=2;d=0;Rc(b,0);HC(b,a+1300308|0,20);u[a+480190>>1]=31;e=1;while(1){d=YB(b,f+32|0,(B(e,104)+a|0)+484380|0,((e<<5)+a|0)+946300|0,1)+d|0;e=e+1|0;if((e|0)!=32){continue}break}if(d>>>0>40){break a}Rr(f+552|0,b);m=rd(f+552|0);i=f+552|0;if(w[i|0]>128){break a}g=f+32|0;e=gb-32|0;gb=e;d=b;c:{if(Nb(d,512)){mD(e+24|0,g);g=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=g;gd(e+16|0,d,e+8|0);break c}gV(g)}gb=e+32|0;d=f+544|0;e=f+32|0;g=w[m|0];d:{while(1){if(g>>>0>=w[e|0]){e=e+1|0;if((d|0)!=(e|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;jh(a,0);n=a+484360|0;Cf(Qb(n),w[i|0]);u[f+30>>1]=0;j=a+484344|0;rg(j,w[i|0]);if(w[i|0]){g=0;while(1){s=sc(Qb(n),g),x=g,u[s>>1]=x;if(Sg(j,g&65535,64)){p=g<<2;h=0;while(1){Rc(b,(w[f+32+(h+p)|0]<<8)+1468|0);e=Wc(Yb(j,g),0,h&65535);d=0;while(1){gv(b,e);e:{f:{l=w[e+3|0];g:{if((l|0)!=14){if(!l){if(w[e+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[e+5|0]<=15){break f}}t[e+3|0]=0;break e}Mf(e)}e=e+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=f,x=Rb(Yb(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){e=d;h:{if(w[v[f+24>>2]+3|0]!=17?w[v[f+24>>2]+3|0]!=16:0){break h}t[v[f+24>>2]+3|0]=16;k=0;if(w[v[f+24>>2]+5|0]<16){break h}if(!(!(w[v[f+24>>2]+5|0]&15)|(w[v[f+24>>2]+5|0]&15)==(w[v[f+24>>2]+5|0]>>>4|0))){q=w[v[f+24>>2]+5|0]>>>4|0;r=w[v[f+24>>2]+5|0]&15;k=1}d=v[f+24>>2];t[d+5|0]=w[d+5|0]>>>4}Oj(f+24|0);d=e+1|0;if((e&65535)>>>0<3){continue}break}t[f+31|0]=r;t[f+30|0]=q;d=k&255;e=0;i:{if(!d){break i}wm(Yb(j,g),Ve(De(f+8|0,16,w[(f+d|0)+29|0]),h));d=k+1|0;e=(d&255)==3?1:d}k=e;h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Rc(b,(w[m|0]<<8)+1468|0);e=1;while(1){c=(B(e,104)+a|0)+484380|0;if(v[c>>2]){ug(Sc(f+8|0,8,1,0,0),c,b)}e=e+1|0;if((e|0)!=32){continue}break}}gb=f+560|0;return o|0}function wma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[$b(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[$b(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=Xm(+(ZV(e,b,c,d)>>>0)*1e-4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[$b(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[$b(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=$b(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[$b(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[$b(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[$b(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[$b(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[$b(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=44;h=a,i=_o(Xc(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b-17&255)>>>0>=223){t[a+3|0]=9;h=a,i=Ki(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){Mf(a);break a}t[a+3|0]=0}gb=f+16|0}function CZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-384|0;gb=e;yc(b);f=gb-32|0;gb=f;j=e+344|0;_D(f+24|0,j);g=xb(f+24|0);d=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=d;v[f>>2]=h;v[f+4>>2]=d;d=b;fc(f+16|0,d,f);h=xb(f+16|0);if((h|0)==(g|0)){Vb(d,xb(f+24|0))}gb=f+32|0;d=(g|0)==(h|0);if(!d){ZD(j)}a:{b:{if(!d){break b}if(!rE(e+344|0)){break b}if(!Nb(b,Xc(qE(e+344|0),jb))){break b}c:{if(!c){break c}Ed(a,2097152);sg(a);i=1;jh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[e+376|0];v[a+480204>>2]=B(w[e+377|0],1e4);u[a+480190>>1]=w[e+378|0];if(w[e+381|0]<w[e+380|0]){ff(Qb(a+484360|0),w[e+381|0])}d=Tb(e+80|0,16546);Eb(a+1300344|0,d);vb(d);d=Tb(e+80|0,16566);Eb(a+1300356|0,d);vb(d);v[a+1300404>>2]=5;dw(b,e+80|0);Sr(Qb(a+484360|0),e+80|0,w[e+380|0],65535,65535);if(x[a+480190>>1]){j=1;while(1){pE(b,e+40|0);h=gb-16|0;gb=h;g=(B(i,104)+a|0)+484380|0;wd(g,0);k=e+40|0;t[g+37|0]=w[k+22|0]<<4;t[h+15|0]=w[k+23|0];t[h+14|0]=64;m=g,n=w[$b(h+15|0,h+14|0)|0]<<2,u[m+30>>1]=n;t[g+36|0]=w[k+24|0];d=k+25|0;v[g>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);f=k+33|0;d:{if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<3){break d}l=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=k+29|0;if(l>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0){break d}u[g+34>>1]=x[g+34>>1]|2;v[g+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[g+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))}gb=h+16|0;Fk(e+8|0,2,e+40|0);Fc(e+24|0,e+8|0);v[23048]=0;Q(354,((i<<5)+a|0)+946300|0,e+24|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break a}vb(e+24|0);j=j+1|0;i=j&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}Vb(b,B(64-w[e+378|0]|0,37));f=a+484344|0;rg(f,w[e+379|0]);if(w[e+379|0]){i=c&1;j=0;while(1){e:{f:{if(i){if(Sg(f,j&65535,64)){break f}}Vb(b,2048);break e}d=Yb(f,j);m=e,n=Rb(d),v[m+40>>2]=n;m=e,n=Ub(d),v[m+24>>2]=n;if(!Fb(e+40|0,e+24|0)){break e}while(1){d=v[e+40>>2];nn(e+8|0,b);g=rd(e+8|0);h=Df(e+8|0);k=Ri(e+8|0);l=w[e+8|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[g|0];t[d+3|0]=w[h|0];t[d+5|0]=w[k|0];Mf(d);Oj(e+40|0);if(Fb(e+40|0,e+24|0)){continue}break}}j=j+1|0;if(j>>>0<w[e+379|0]){continue}break}}if(!(c&2)){break c}i=1;c=Sc(e+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){ug(c,(B(i&65535,104)+a|0)+484380|0,b);i=i+1|0;if(x[a+480190>>1]>=(i&65535)>>>0){continue}break}}i=1}gb=e+384|0;return i|0}a=P()|0;O()|0;vb(e+24|0);R(a|0);L()}function j8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-128|0;gb=e;a:{if(hd(b)){break a}f=w[lL(b)|0];g=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}g=0}d=g;Fs(e+112|0,b,0,Bb(b)-1|0);Eb(b,e+112|0);vb(e+112|0)}Md(e+112|0);f=v[e+112>>2];Md(e+96|0);f=kL(f,v[e+100>>2],b);Md(e+112|0);c:{d:{e:{f:{g:{if((f|0)==v[e+116>>2]){if(te(b,56371)){a=aa(8)|0;v[23048]=0;T(2056,e+112|0,57575,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break f}rc(a,e+112|0);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break d}b=P()|0;O()|0;vb(e+112|0);break e}if(!d){break g}a=aa(8)|0;v[23048]=0;T(2056,e+80|0,57454,b|0);b=v[23048];v[23048]=0;h:{i:{j:{k:{l:{if((b|0)!=1){v[23048]=0;S(2057,e+96|0,e+80|0);b=v[23048];v[23048]=0;if((b|0)==1){break l}v[23048]=0;T(755,e+112|0,e+96|0,c|0);b=v[23048];v[23048]=0;d=1;if((b|0)==1){break k}rc(a,e+112|0);v[23048]=0;T(84,a|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break d}b=P()|0;O()|0;vb(e+112|0);d=0;break j}b=P()|0;O()|0;break h}b=P()|0;d=1;O()|0;break i}b=P()|0;O()|0}vb(e+96|0)}vb(e+80|0);if(!d){break e}}ca(a|0);break e}m:{switch(v[f+4>>2]){case 0:Mh(e+72|0,b);b=(kI(c)|0)!=0;c=v[e+76>>2];v[e>>2]=v[e+72>>2];v[e+4>>2]=c;jL(a,e,b,d);break g;case 1:Mh(e- -64|0,b);b=gb-160|0;gb=b;c=Pn(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[23048]=0;g=fa(131)|0;h=v[23048];v[23048]=0;if((h|0)==1){break c}v[23048]=0;T(132,b+8|0,f+(b+16|0)|0,g|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}Xb(b+8|0);v[23048]=0;f=Q(169,c|0,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}g=v[v[f>>2]-12>>2];v[23048]=0;f=cp(f+g|0);g=v[23048];v[23048]=0;if((g|0)==1){break c}g=v[b>>2];h=v[b+4>>2];ag(c);gb=b+160|0;b=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=b;iL(a,e+8|0,f?0:g,f?0:h,d);break g;case 2:Mh(e+56|0,b);b=gb-160|0;gb=b;c=Pn(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[23048]=0;g=fa(131)|0;h=v[23048];v[23048]=0;if((h|0)==1){break c}v[23048]=0;T(132,b+8|0,f+(b+16|0)|0,g|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}Xb(b+8|0);v[23048]=0;f=Q(170,c|0,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}g=v[v[f>>2]-12>>2];v[23048]=0;f=cp(f+g|0);g=v[23048];v[23048]=0;if((g|0)==1){break c}i=A[b>>3];ag(c);gb=b+160|0;b=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=b;hL(a,e+16|0,f?0:i,d);break g;case 3:break m;default:break g}}Mh(e+48|0,b);Mh(e+40|0,c);b=v[e+52>>2];v[e+32>>2]=v[e+48>>2];v[e+36>>2]=b;b=v[e+44>>2];v[e+24>>2]=v[e+40>>2];v[e+28>>2]=b;gL(a,e+32|0,e+24|0,d)}gb=e+128|0;return}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}a=P()|0;O()|0;ag(c);R(a|0);L()}function g8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-176|0;gb=d;g=d+160|0;fL(g);v[g>>2]=57732;dd(g+4|0);h=a;eo(v[a+24>>2],g);f=w[a+62|0];e=w[a+61|0];i=w[a+60|0];j=v[a+24>>2];b=Me(d+136|0,b);v[23048]=0;i=i?13:15;e=e?i&14:i;f=W(2065,j|0,b|0,(f?e&3:e)|0)|0;e=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((e|0)!=1){yb(b);if(!f){b=aa(8)|0;v[23048]=0;c=Q(91,d+120|0,56777)|0;a=v[23048];v[23048]=0;if((a|0)!=1){rc(b,c);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;ca(b|0);break b}p:{if(w[a+63|0]){break p}v[23048]=0;S(2066,a|0,a+36|0);b=v[23048];v[23048]=0;if((b|0)!=1){break p}a=P()|0;O()|0;break b}t[a+28|0]=1;eo(v[h+24>>2],v[a+4>>2]);v[23048]=0;S(2067,d+120|0,g|0);b=v[23048];v[23048]=0;if((b|0)==1){break o}k=d,l=Rb(d+120|0),v[k+112>>2]=l;k=d,l=Ub(d+120|0),v[k+104>>2]=l;if(Fb(d+112|0,d+104|0)){h=a+68|0;while(1){b=v[d+112>>2];f=v[b>>2];v[23048]=0;e=f;f=b+4|0;T(2068,a|0,e|0,f|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}b=v[b>>2];v[23048]=0;S(2069,d+40|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;T(9,d+56|0,0,d+40|0);b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;b=Q(91,d+24|0,56796)|0;e=v[23048];v[23048]=0;if((e|0)==1){break i}v[23048]=0;T(2062,d+72|0,d+56|0,b|0);e=v[23048];v[23048]=0;if((e|0)==1){break k}v[23048]=0;T(755,d+88|0,d+72|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break m}v[23048]=0;S(1438,h|0,d+88|0);f=v[23048];v[23048]=0;if((f|0)==1){break n}vb(d+88|0);vb(d+72|0);vb(b);vb(d+56|0);vb(d+40|0);Ro(d+112|0);if(Fb(d+112|0,d+104|0)){continue}break}}k=d,l=rr(c),v[k+88>>2]=l;k=d,l=Xg(c),v[k+72>>2]=l;q:{while(1){v[23048]=0;b=Xf(d+88|0,d+72|0);c=v[23048];v[23048]=0;r:{if((c|0)!=1){if(b){break r}Ht(d+120|0);Ft(g);gb=d+176|0;return}a=P()|0;O()|0;break c}v[23048]=0;c=se(d+88|0);b=v[23048];v[23048]=0;s:{if((b|0)==1){break s}v[23048]=0;b=Q(119,d+8|0,c|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break s}v[23048]=0;Y(2009,a|0,b|0,c+12|0,0);c=v[23048];v[23048]=0;if((c|0)==1){break q}vb(b);Fj(d+88|0);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(b);break c}a=P()|0;O()|0;yb(b);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+88|0);break l}a=P()|0;O()|0}vb(d+72|0);break j}a=P()|0;O()|0}vb(b);break h}a=P()|0;O()|0}vb(d+56|0);break f}a=P()|0;O()|0}vb(d+40|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}Ht(d+120|0)}Ft(g);R(a|0)}L()}function c8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=gb-112|0;gb=d;a:{b:{c:{if(!(b<.8)){v[23048]=0;_(2074,d+16|0);e=v[23048];v[23048]=0;d:{e:{f:{g:{h:{if((e|0)!=1){c=v[c>>2];v[23048]=0;S(2075,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break h}eo(v[d+16>>2],v[d>>2]);c=v[d+16>>2];a=Me(d+88|0,a);v[23048]=0;c=W(2065,c|0,a|0,15)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}yb(a);if(c){a=v[d+16>>2];v[23048]=0;U(1313,a|0)|0;a=v[23048];v[23048]=0;f=1;if((a|0)==1){break f}}qi(d);ri(d+16|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;yb(a);break e}c=V(0)|0;O()|0}qi(d)}ri(d+16|0);break c}if(!(b<.6)){v[23048]=0;_(2074,d+16|0);e=v[23048];v[23048]=0;i:{j:{k:{l:{m:{if((e|0)!=1){c=v[c>>2];v[23048]=0;S(2075,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break m}eo(v[d+16>>2],v[d>>2]);c=v[d+16>>2];a=Me(d- -64|0,a);v[23048]=0;c=W(2065,c|0,a|0,2)|0;e=v[23048];v[23048]=0;if((e|0)==1){break l}yb(a);if(c){a=v[d+16>>2];v[23048]=0;U(1313,a|0)|0;a=v[23048];v[23048]=0;f=.8;if((a|0)==1){break k}}qi(d);ri(d+16|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;break i}c=V(0)|0;O()|0;yb(a);break j}c=V(0)|0;O()|0}qi(d)}ri(d+16|0);break c}f=.2;if(!(b<.2)){v[23048]=0;_(2074,d+16|0);e=v[23048];v[23048]=0;n:{o:{p:{q:{r:{if((e|0)!=1){c=v[c>>2];v[23048]=0;S(2075,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break r}eo(v[d+16>>2],v[d>>2]);c=v[d+16>>2];a=Me(d+40|0,a);v[23048]=0;c=W(2065,c|0,a|0,0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}yb(a);f=0;if(c){a=v[d+16>>2];v[23048]=0;U(1313,a|0)|0;a=v[23048];v[23048]=0;f=.6;if((a|0)==1){break p}}qi(d);ri(d+16|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;break n}c=V(0)|0;O()|0;yb(a);break o}c=V(0)|0;O()|0}qi(d)}ri(d+16|0);break c}if(b<.1){break b}v[23048]=0;T(793,d+16|0,a|0,2048);c=v[23048];v[23048]=0;s:{t:{u:{if((c|0)!=1){v[23048]=0;c=Wd(d+16|0);e=v[23048];v[23048]=0;if((e|0)==1){break t}e=v[d+16>>2];v[23048]=0;a=U(247,a|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break t}v[23048]=0;a=wG(2076,3,0,c,e,a,0);c=v[23048];v[23048]=0;if((c|0)==1){break t}a=a+1|0;if(a>>>0>=3){break u}f=A[(a<<3)+59376>>3];Ac(d+16|0);break b}c=V(0)|0;O()|0;break c}a=aa(8)|0;v[23048]=0;e=Q(91,d|0,56371)|0;c=v[23048];v[23048]=0;if((c|0)!=1){rc(a,e);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}c=V(0)|0;O()|0;vb(e);break s}c=V(0)|0;O()|0;ca(a|0);break s}c=V(0)|0;O()|0}Ac(d+16|0)}Z(c|0)|0;$();f=0}gb=d+112|0;return+f}L()}function xG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;g=gb-48|0;gb=g;o(+a);d=j(1)|0;h=j(0)|0;a:{b:{e=d;d=e;f=e&2147483647;c:{if(f>>>0<=1074752122){if((d&1048575)==598523){break c}if(f>>>0<=1073928572){if((e|0)>0?1:(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0?1:(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(f>>>0<=1075594811){if(f>>>0<=1075183036){if((f|0)==1074977148){break c}if((e|0)>0?1:(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((f|0)==1075388923){break c}if((e|0)>0?1:(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(f>>>0>1094263290){break b}}k=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+k*-1.5707963267341256;i=k*6.077100506506192e-11;a=c-i;A[b>>3]=a;o(+a);d=j(1)|0;j(0)|0;h=f>>>20|0;e=(h-(d>>>20&2047)|0)<17;if(D(k)<2147483648){d=~~k}else{d=-2147483648}d:{if(e){break d}i=c;a=k*6.077100506303966e-11;c=c-a;i=k*2.0222662487959506e-21-(i-c-a);a=c-i;A[b>>3]=a;e=h;o(+a);h=j(1)|0;j(0)|0;if((e-(h>>>20&2047)|0)<50){break d}i=c;a=k*2.0222662487111665e-21;c=c-a;i=k*8.4784276603689e-32-(i-c-a);a=c-i;A[b>>3]=a}A[b+8>>3]=c-a-i;break a}if(f>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,h|0);l(1,e&1048575|1096810496);a=+n();d=g+16|0;h=g+16|8;m=1;while(1){if(D(a)<2147483648){p=~~a}else{p=-2147483648}c=+(p|0);A[d>>3]=c;a=(a-c)*16777216;if(m){m=0;d=h;continue}break}A[g+32>>3]=a;p=g+16|0;m=g;f=(f>>>20|0)-1046|0;e:{if(a==0){d=1;while(1){h=d;d=d-1|0;if(A[(g+16|0)+(h<<3)>>3]==0){continue}break}d=h+1|0;break e}d=3}d=$I(p,m,f,d,1);a=A[g>>3];if((e|0)<-1?1:(e|0)<=-1){A[b>>3]=-a;A[b+8>>3]=-A[g+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[g+8>>3]}gb=g+48|0;return d}function ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0;f=gb-32|0;gb=f;p=a+4|0;o=v[p>>2];n=a+20|0;s=v[qe(n,b)>>2];a:{if(s+1>>>0<2){break a}h=(B(b,880)+o|0)+616|0;if(!zi(h)){if(!w[qe(n,b)+4|0]){break a}}i=B(b,880)+o|0;if(!v[i+720>>2]){break a}A=v[(v[i+704>>2]&2?i+700|0:i+692|0)>>2];g=v[i+696>>2];j=v[i+700>>2];Db(f,v[a>>2]+1074308|0,31);u=Cb(f);y=i+1362|0;l=w[y|0];z=i+624|0;e=sw(z,c);k=jb;m=k;v[f+24>>2]=e;v[f+28>>2]=k;if(w[i+704|0]&128){v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+m|0)}k=j-g|0;D=k<<1;e=B(b,880)+o|0;E=e+1316|0;m=e+1469|0;F=(l&17)!=1;b:{while(1){c:{if(d>>>0>q>>>0){g=(w[y|0]&17)==1;break c}t[m|0]=w[m|0]&254;e=Wc(Yb(v[a>>2]+484344|0,x[v[p>>2]+70>>1]),v[v[p>>2]+48>>2],b);j=w[e+3|0];if(w[e+2|0]==11){mA(f,v[a>>2],e,0);l=dc(f);uo(v[a>>2],h,v[f>>2]);g=1;if(w[l|0]){break c}}g=1;d:{switch(j-4|0){case 0:uo(v[a>>2],h,w[e+5|0]);break c;case 2:break d;default:break c}}uo(v[a>>2],h,0)}v[f+20>>2]=v[E>>2];if(u){au(v[a>>2],h)}if(!F){zO(v[a>>2],h,f+20|0);g=1}if(!u){au(v[a>>2],h)}v[f+16>>2]=0;AO(h,f+16|0);e:{f:{if(w[i+705|0]&2){break f}g:{if(!g){if(!w[qe(n,b)+4|0]){break g}}if(w[m|0]&12){KS(h,C(1),0,v[a>>2]);e=w[m|0];t[m|0]=(e&8?-9:-5)&e}Fz(f,v[a>>2],h,v[f+20>>2],0);g=v[f+4>>2];e=z;v[e>>2]=v[f>>2];v[e+4>>2]=g;G=qe(n,b),H=0,t[G+4|0]=H;e=sw(e,c);g=jb;j=g;v[f+24>>2]=e;v[f+28>>2]=g;if(!(w[i+704|0]&128)){break g}v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+j|0)}Sb(h,f+24|0);g=v[h+4>>2];j=g;l=v[h>>2];if(A>>>0>g>>>0){break f}e=v[i+704>>2];if(!(e&2)){break e}if(e&4){r=v[i+696>>2];l=r;e=l;if((e|0)>(j|0)?1:0){v[f>>2]=0;v[f+4>>2]=l<<1;G=h,H=Hg(f,h),v[G>>2]=H;v[h+4>>2]=jb;v[i+704>>2]=v[i+704>>2]^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;r=v[i+696>>2];g=v[h+4>>2]}Db(f,v[a>>2]+1074308|0,33);e=(g-r>>>0)%(D-Cb(f)>>>0)|0;h:{if(e>>>0>=k>>>0){v[h+4>>2]=v[i+700>>2]+(k-e|0);g=v[i+704>>2];if(!(g&128)){break h}break f}v[h+4>>2]=e+v[i+696>>2];g=v[i+704>>2];if(!(g&128)){break f}}v[i+704>>2]=g^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;break f}j=v[i+700>>2];if(j+k>>>0<=g>>>0){g=j+((g-j>>>0)%(k>>>0)|0)|0}while(1){e=g;g=e-k|0;if(e>>>0>=j>>>0){continue}break}v[h>>2]=l;v[h+4>>2]=e}q=q+1|0;if((s|0)!=(q|0)){continue}break b}break}YA(h);v[(B(b,880)+o|0)+1324>>2]=0}G=qe(n,b),H=0,v[G>>2]=H}gb=f+32|0}function Q2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=gb-16|0;gb=k;m=Dx(g);n=kx(g);Mg(k,n);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23048]=0;g=Q(2397,m|0,g<<24>>24)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;h=a+1|0}d:{e:{f:{if(!(w[h|0]!=48|(c-h|0)<2|(w[h+1|0]|32)!=120)){v[23048]=0;g=Q(2397,m|0,48)|0;i=v[23048];v[23048]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;g=t[h+1|0];v[23048]=0;g=Q(2397,m|0,g|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;h=h+2|0;if(h>>>0>=c>>>0){break e}g=h;while(1){g:{i=t[g|0];v[23048]=0;j=fa(2371)|0;l=v[23048];v[23048]=0;if((l|0)==1){break g}v[23048]=0;i=vx(i,j);j=v[23048];v[23048]=0;if((j|0)==1){break g}if(!i){break d}g=g+1|0;if((g|0)!=(c|0)){continue}break f}break}break a}if(c>>>0<=h>>>0){break e}g=h;while(1){i=t[g|0];v[23048]=0;fa(2371)|0;j=v[23048];v[23048]=0;if((j|0)==1){break a}v[23048]=0;i=Lh(i);j=v[23048];v[23048]=0;if((j|0)==1){break a}if(!i){break d}g=g+1|0;if((g|0)!=(c|0)){continue}break}}g=c;break d}g=h}h:{if(hd(k)){i=v[f>>2];v[23048]=0;Y(2387,m|0,h|0,g|0,i|0);i=v[23048];v[23048]=0;if((i|0)==1){break a}v[f>>2]=v[f>>2]+(g-h<<2);break h}fm(h,g);i=0;v[23048]=0;o=U(2385,n|0)|0;j=v[23048];v[23048]=0;p=(h-a<<2)+d|0;i:{j:{if((j|0)!=1){if(g>>>0<=h>>>0){break j}j=0;while(1){k:{if(t[pc(k,i)|0]<1){break k}if(t[pc(k,i)|0]!=(j|0)){break k}j=v[f>>2];v[f>>2]=j+4;v[j>>2]=o;i=(Bb(k)-1>>>0>i>>>0)+i|0;j=0}l=t[h|0];v[23048]=0;q=Q(2397,m|0,l|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break a}l=v[f>>2];v[f>>2]=l+4;v[l>>2]=q;j=j+1|0;h=h+1|0;if((h|0)!=(g|0)){continue}break}h=l+4|0;break i}break a}h=v[f>>2]}Gs(p,h)}l:{if(c>>>0>g>>>0){while(1){h=w[g|0];if((h|0)==46){v[23048]=0;i=U(2388,n|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}j=v[f>>2];h=j+4|0;v[f>>2]=h;v[j>>2]=i;g=g+1|0;break l}v[23048]=0;i=Q(2397,m|0,h<<24>>24)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;if((g|0)!=(c|0)){continue}break}h=h+4|0;g=c;break l}h=v[f>>2]}v[23048]=0;Y(2387,m|0,g|0,c|0,h|0);h=v[23048];v[23048]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g<<2)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;vb(k);gb=k+16|0;return}a=P()|0;O()|0;vb(k);R(a|0);L()}function QU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=pe(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=gb-16|0;gb=b;d=Cj(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<1){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[sd(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}g=c;d=(d|0)/32|0;c=d<<2;kh(g,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<1){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}pe(a,f);gb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=pe(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=gb-16|0;gb=f;d=Cj(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<1){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;b=v[sd(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;d=v[g+4>>2];h=v[v[e+24>>2]>>2];j=v[e+28>>2];v[f+8>>2]=b;k=32-d|0;v[f+4>>2]=k;l=Gb(f+8|0,f+4|0);i=v[g>>2];j=h&(-1<<j&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>=1){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[e+24>>2]=h;v[g>>2]=b}if((d|0)<1){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=sd(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<1){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}pe(a,g);gb=f+16|0}gb=e+80|0}function f7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-160|0;gb=d;a:{if(jk(b)){break a}f=w[jl(b)|0];e=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}e=0}c=e;wl(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}Md(d+128|0);e=v[d+128>>2];Md(d+112|0);e=il(e,v[d+116>>2],b);Md(d+128|0);c:{d:{e:{f:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=wc(d+144|0,56371);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Kc(d+8|0,d)){a=aa(8)|0;v[23048]=0;c=Q(91,d+128|0,57444)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}e=0;f=0;if(!c){break f}c=aa(8)|0;v[23048]=0;e=Q(2061,d+112|0,b|0)|0;a=v[23048];v[23048]=0;g:{h:{i:{if((a|0)!=1){v[23048]=0;T(2045,d+128|0,57454,e|0);a=v[23048];v[23048]=0;if((a|0)==1){break i}rc(c,d+128|0);a=0;v[23048]=0;T(84,c|0,56328,1945);b=v[23048];v[23048]=0;if((b|0)!=1){break c}b=P()|0;O()|0;vb(d+128|0);break h}b=P()|0;O()|0;break g}b=P()|0;a=1;O()|0}vb(e);if(!a){break d}}ca(c|0);break d}if(v[e+4>>2]!=1){a=aa(8)|0;v[23048]=0;c=Q(91,d+128|0,57468)|0;b=v[23048];v[23048]=0;if((b|0)!=1){rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=wc(d+96|0,56371);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Kc(d+56|0,d+48|0)){a=aa(8)|0;v[23048]=0;c=Q(91,d+128|0,57444)|0;b=v[23048];v[23048]=0;if((b|0)!=1){rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}b=P()|0;O()|0;vb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=wc(d+80|0,57289);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Kc(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break f}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=wc(d- -64|0,57437);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Kc(d+24|0,d+16|0)){break f}a=v[v[a+32>>2]+52>>2];e=a;f=a>>31}gb=d+160|0;jb=f;return e|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function WZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=gb-16|0;gb=f;a:{if((d|0)<1){a=0}else{Rp(c,d);v[f+4>>2]=b;v[f>>2]=a;a=zb(v[c>>2]);v[f+12>>2]=d;v[f+8>>2]=a;q=d;a=0;b=0;while(1){b:{e=bh(f,b);m=bh(f,b+4|0)<<8|bh(f,b+5|0);g=bh(f,b+6|0);i=bh(f,b+7|0);t=b+8|0;c:{d:{e:{switch(e|0){case 0:b=0;if(!m){break d}while(1){cs(f,a+b|0,bh(f,b+t|0));b=b+1|0;if((m|0)!=(b|0)){continue}break};break d;case 1:break e;default:break b}}k=bh(f,b+10|0);cs(f,a,k);a=(a>>>0<d>>>0)+a|0;m=m+3&65532;r=i|g<<8;if(r>>>0<2){break c}j=b+11|0;b=r-1|0;g=0;o=0;l=0;p=0;while(1){i=lg(j,g,1,f);f:{g:{h:{i:{j:{if((o|0)<=7){if(i){e=g;break g}g=g+1|0;l=8;break j}e=g+1|0;k:{if(!i){if(!lg(j,e,1,f)){break g}e=2;l:{m:{h=g+2|0;if(!lg(j,h,1,f)){break m}e=3;h=g+3|0;if(!lg(j,h,1,f)){break m}e=lg(j,h,3,f);g=g+6|0;break l}g=h+1|0}h=4;e=((l<<3)+e|0)-17|0;if((e|0)<=-1|e>>>0>=56){break a}l=w[e+16224|0];if((l|0)!=8){break i}break k}h=4;g=e;if((l|0)!=8){break i}}l=8;h=1;if((p|0)>19){break i}}h=0;break h}p=p+8|0}e=b;n:{if((e|0)<1){break n}while(1){i=(g|0)/8|0;e=i+j|0;n=bh(f,e);k=k-((bh(f,e+1|0)<<8|n<<16|bh(f,e+2|0))<<(g-(i<<3)|0)+8>>32-l)|0;cs(f,a,k&255);e=b-1|0;g=g+l|0;a=(a>>>0<d>>>0)+a|0;if((b|0)<2){break n}i=(h|0)>0;b=e;h=h-1|0;if(i){continue}break}}o=(o|0)==31?31:o+1|0;b=e;break f}o:{p:{h=e+1|0;if(!lg(j,h,1,f)){e=2;break p}h=e+2|0;if(!lg(j,h,1,f)){e=4;break p}h=e+3|0;if(!lg(j,h,1,f)){e=6;break p}g=e+5|0;if(!lg(j,e+4|0,1,f)){h=lg(j,g,3,f)+8|0;g=e+8|0;break o}h=lg(j,g,5,f)+16|0;g=e+10|0;break o}g=h+2|0;h=lg(j,h+1|0,1,f)+e|0}q:{if(lg(j,g,1,f)){i=-256;e=12;break q}g=g+1|0;e=lg(j,g,1,f);i=e?-4352:0;e=e?14:8}g=g+1|0;n=lg(j,g,e,f);if((h|0)>=3){s=o-((h|0)!=3)|0;o=(s|0)>0?s-1|0:0}g=e+g|0;if((b|0)<1|(h|0)<1){break f}i=(a+i|0)+(n^-1)|0;e=b;while(1){b=f;k=a;n=f;s=i;if(i>>>0>=y[f+12>>2]){break a}u=k;k=w[s+v[n+8>>2]|0];cs(b,u,k);b=e-1|0;a=(a>>>0<d>>>0)+a|0;if((e|0)<2){break f}i=i+1|0;n=(h|0)>1;e=b;h=h-1|0;if(n){continue}break}}p=p-(p>>3)|0;if((b|0)>0){continue}break}break c}a=a+m|0;r=m}b=m+t|0;q=q-r|0;if((q|0)>0){continue}}break}Rp(c,v[f+12>>2]-q|0);a=cd(c)^1}gb=f+16|0;return a|0}a=aa(8)|0;v[23048]=0;U(336,a|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){b=P()|0;O()|0;ca(a|0);R(b|0);L()}ja(a|0,16160,259);L()}function _2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=gb-16|0;gb=k;m=nD(g);o=px(g);Mg(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23048]=0;g=Q(22,m|0,g<<24>>24)|0;i=v[23048];v[23048]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{e:{f:{if(!(w[i|0]!=48|(c-i|0)<2|(w[i+1|0]|32)!=120)){v[23048]=0;g=Q(22,m|0,48)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[23048]=0;g=Q(22,m|0,g|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;if(i>>>0>=c>>>0){break e}g=i;while(1){g:{h=t[g|0];v[23048]=0;j=fa(2371)|0;l=v[23048];v[23048]=0;if((l|0)==1){break g}v[23048]=0;h=vx(h,j);j=v[23048];v[23048]=0;if((j|0)==1){break g}if(!h){break d}g=g+1|0;if((g|0)!=(c|0)){continue}break f}break}break a}if(c>>>0<=i>>>0){break e}g=i;while(1){h=t[g|0];v[23048]=0;fa(2371)|0;j=v[23048];v[23048]=0;if((j|0)==1){break a}v[23048]=0;h=Lh(h);j=v[23048];v[23048]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;if((g|0)!=(c|0)){continue}break}}g=c;break d}g=i}h:{i:{if(hd(k)){h=v[f>>2];v[23048]=0;Y(2366,m|0,i|0,g|0,h|0);h=v[23048];v[23048]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break i}fm(i,g);j=0;v[23048]=0;q=U(2358,o|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break h}if(g>>>0>i>>>0){h=i;l=0;while(1){j:{if(t[pc(k,j)|0]<1){break j}if(t[pc(k,j)|0]!=(l|0)){break j}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;j=(Bb(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[23048]=0;p=Q(22,m|0,p|0)|0;n=v[23048];v[23048]=0;if((n|0)==1){break h}n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;l=l+1|0;h=h+1|0;if((h|0)!=(g|0)){continue}break}}fm((i-a|0)+d|0,v[f>>2])}k:{if(c>>>0<=g>>>0){break k}while(1){i=w[g|0];if((i|0)==46){v[23048]=0;i=U(2367,o|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;break k}v[23048]=0;i=Q(22,m|0,i<<24>>24)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;if((g|0)!=(c|0)){continue}break}g=c}i=v[f>>2];v[23048]=0;Y(2366,m|0,g|0,c|0,i|0);i=v[23048];v[23048]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;vb(k);gb=k+16|0;return}}a=P()|0;O()|0;vb(k);R(a|0);L()}function cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-1168|0;gb=d;yc(b);a:{if(!bO(b,d+1144|0)){break a}if(!TN(d+1144|0)){break a}e=d+1152|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(Pk(b)|0)){break a}f=d+1160|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))!=(Bf(b)|0)){break a}if(!c){g=1;break a}Pb(d+1088|0,0,56);e=d+1088|0;i=-2;b:{if(!e){break b}v[e+44>>2]=0;v[e+48>>2]=0;v[e+52>>2]=0;v[e+20>>2]=0;v[e+24>>2]=0;v[e+8>>2]=0;h=v[e+32>>2];if(!h){v[e+32>>2]=2209;h=2209}if(!v[e+36>>2]){v[e+36>>2]=2210}h=kb[h|0](v[e+40>>2],1,43784)|0;i=-4;if(!h){break b}v[e+28>>2]=h;v[h+43780>>2]=1;v[h+10992>>2]=0;v[h+10996>>2]=0;v[h>>2]=0;v[h+11008>>2]=15;v[h+11e3>>2]=1;v[h+11004>>2]=0;i=0}if(i){break a}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+1084>>2]=e;g=d+1164|0;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);i=(g|0)!=0;h=$W(d+1072|0,g);c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){f=1;break k}f=1;if(!g){break k}while(1){v[23048]=0;v[d+32>>2]=1024;e=Gb(d+32|0,d+1084|0);f=v[23048];v[23048]=0;if((f|0)==1){break d}e=v[e>>2];f=_d(d+40|0,d+48|0,e);v[23048]=0;i=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=i;T(253,d+32|0,b|0,d+8|0);f=v[23048];v[23048]=0;if((f|0)==1){break i}v[23048]=0;j=GJ(j,d+48|0,e);f=v[23048];v[23048]=0;if((f|0)==1){break j}v[d+1104>>2]=g;v[d+1092>>2]=e;v[d+1088>>2]=d+48;f=v[h>>2];v[23048]=0;v[d+1100>>2]=f+k;l=Q(1484,d+1088|0,0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break j}m=v[d+1084>>2]-e|0;v[d+1084>>2]=m;f=(l|0)!=1;e=v[d+1104>>2];i=(e|0)!=0;if(!e|(l|0)==1){break k}k=(g+k|0)-e|0;g=e;if(m){continue}break}}v[23048]=0;U(1485,d+1088|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break h}g=0;b=d+1156|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(j|0)|i|f)){v[23048]=0;me(d+24|0,h);b=v[23048];v[23048]=0;if((b|0)==1){break g}b=Xd(d+16|0);v[23048]=0;g=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=g;e=W(770,d+48|0,d|0,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break f}Bc(b);v[23048]=0;g=W(1399,a|0,e|0,c|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break e}yb(e)}gc(h);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Bc(b);break c}a=P()|0;O()|0;yb(e);break c}a=P()|0;O()|0}gc(h);R(a|0);L()}gb=d+1168|0;return g|0}function uR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-96|0;gb=f;t[f+95|0]=d;n=FA(a);o=Gi(n);u[b>>1]=0;a:{if(o){while(1){b:{if(!Io(n,j&65535)){break b}j=x[b>>1];if(Gc(a)>>>0<=j>>>0){v[c>>2]=0;a=1;break a}m=Id(a,x[b>>1]);rk(f+72|0,m);Dl(f- -64|0,m);j=v[f+76>>2];v[f+32>>2]=v[f+72>>2];v[f+36>>2]=j;j=v[f+68>>2];v[f+24>>2]=v[f+64>>2];v[f+28>>2]=j;l=f+80|0;e=f+32|0;i=f+24|0;j=gb-32|0;gb=j;c:{if(w[f+95|0]){g=v[e+4>>2];v[j+24>>2]=v[e>>2];v[j+28>>2]=g;e=Cj(i,e);i=v[j+28>>2];v[j+8>>2]=v[j+24>>2];v[j+12>>2]=i;i=gb-16|0;gb=i;v[i+12>>2]=e;h=j+8|0;g=v[h+4>>2];d:{if(g){v[i+8>>2]=32-g;e=Gb(i+8|0,i+12|0);k=v[h>>2];e=v[e>>2];g=v[k>>2]&(-1<<g&-1>>>v[i+8>>2]-e);if(g){_c(l,k,Epa(g));break d}g=v[i+12>>2];if((g|0)==(e|0)){gR(l,h,e);break d}e=g-e|0;v[i+12>>2]=e;v[h>>2]=k+4}if(e>>>0>=32){g=v[h>>2];while(1){k=v[g>>2];if(k){_c(l,g,Epa(k));break d}g=g+4|0;v[h>>2]=g;e=e-32|0;v[i+12>>2]=e;if(e>>>0>31){continue}break}}e:{if(!e){g=v[h>>2];break e}g=v[h>>2];h=v[g>>2]&-1>>>32-e;if(!h){break e}_c(l,g,Epa(h));break d}_c(l,g,e)}gb=i+16|0;break c}g=v[e+4>>2];v[j+16>>2]=v[e>>2];v[j+20>>2]=g;e=Cj(i,e);i=v[j+20>>2];v[j>>2]=v[j+16>>2];v[j+4>>2]=i;g=gb-16|0;gb=g;v[g+12>>2]=e;i=j;h=v[i+4>>2];f:{if(h){v[g+8>>2]=32-h;e=v[Gb(g+8|0,g+12|0)>>2];k=-1<<h&-1>>>v[g+8>>2]-e;h=v[i>>2];k=k&(v[h>>2]^-1);if(k){_c(l,h,Epa(k));break f}k=v[g+12>>2];if((k|0)==(e|0)){gR(l,i,e);break f}e=k-e|0;v[g+12>>2]=e;v[i>>2]=h+4}if(e>>>0>=32){h=v[i>>2];while(1){k=v[h>>2];if((k|0)!=-1){_c(l,h,Epa(k^-1));break f}h=h+4|0;v[i>>2]=h;e=e-32|0;v[g+12>>2]=e;if(e>>>0>31){continue}break}}g:{if(!e){h=v[i>>2];break g}h=v[i>>2];i=(v[h>>2]^-1)&-1>>>32-e;if(!i){break g}_c(l,h,Epa(i));break f}_c(l,h,e)}gb=g+16|0}gb=j+32|0;if(d){Dl(f+56|0,m);if(!tR(f+80|0,f+56|0)){break b}v[c>>2]=0;a=1;break a}Dl(f+56|0,m);if(tR(f+80|0,f+56|0)^1){rk(f+48|0,m);a=v[f+84>>2];b=v[f+80>>2];v[f+40>>2]=b;v[f+44>>2]=a;d=v[f+52>>2];v[f+16>>2]=v[f+48>>2];v[f+20>>2]=d;v[f+8>>2]=b;v[f+12>>2]=a;p=c,q=tU(f+16|0,f+8|0),v[p>>2]=q;a=1;break a}if(y[m+4>>2]>=y[Yb(v[a+24>>2]+484344|0,x[sc(n,x[b>>1])>>1])+12>>2]){break b}v[c>>2]=v[m+4>>2];a=1;break a}j=x[b>>1]+1|0;u[b>>1]=j;if((j&65535)>>>0<o>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}gb=f+96|0;return a|0}function b7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;a:{if(jk(c)){break a}g=w[jl(c)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;wl(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}Md(e+128|0);f=v[e+128>>2];Md(e+112|0);h=il(f,v[e+116>>2],c);Md(e+128|0);f=v[c>>2];g=v[c+4>>2];c:{d:{e:{f:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=wc(e+144|0,56371);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Kc(e+8|0,e)){a=aa(8)|0;v[23048]=0;b=Q(91,e+128|0,57444)|0;c=v[23048];v[23048]=0;if((c|0)==1){break e}rc(a,b);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}c=P()|0;O()|0;vb(b);break d}if(d){a=aa(8)|0;v[23048]=0;b=Q(2061,e+112|0,c|0)|0;c=v[23048];v[23048]=0;g:{h:{i:{if((c|0)!=1){v[23048]=0;T(2045,e+128|0,57454,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}rc(a,e+128|0);d=0;v[23048]=0;T(84,a|0,56328,1945);c=v[23048];v[23048]=0;if((c|0)!=1){break c}c=P()|0;O()|0;vb(e+128|0);break h}c=P()|0;O()|0;break g}c=P()|0;d=1;O()|0}vb(b);if(!d){break d}}ca(a|0);break d}Jb(a);break f}v[e+104>>2]=f;v[e+108>>2]=g;d=wc(e+96|0,56371);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Kc(e+56|0,e+48|0)){a=aa(8)|0;v[23048]=0;b=Q(91,e+128|0,57444)|0;c=v[23048];v[23048]=0;if((c|0)!=1){rc(a,b);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}c=P()|0;O()|0;vb(b);break d}c=P()|0;O()|0;ca(a|0);break d}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=wc(e+80|0,57333);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Kc(e+40|0,e+32|0)){j:{switch(v[b+52>>2]){case 0:Tb(a,57526);break f;case 1:Tb(a,57534);break f;case 2:Tb(a,57543);break f;default:break j}}Jb(a);break f}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=wc(e- -64|0,57376);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Kc(e+24|0,e+16|0)){k:{switch(v[b+56>>2]){case 0:Tb(a,57548);break f;case 1:Tb(a,57553);break f;case 2:Tb(a,57559);break f;case 3:Tb(a,57570);break f;default:break k}}Jb(a);break f}Jb(a)}gb=e+160|0;return}c=P()|0;O()|0;ca(a|0)}R(c|0)}L()}function ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=gb-48|0;gb=l;f=v[a+4>>2];e=pe(l+40|0,b);j=pe(l+32|0,c);d=gb-16|0;gb=d;e=PU(pe(d+8|0,e),pe(d,j));gb=d+16|0;d=e+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^f-1)>>>0<32?f:0)){e=v[a>>2];v[(d>>>0<33?e:e+(d-1>>>3&536870908)|0)>>2]=0}d=pe(l+24|0,b);c=pe(l+16|0,c);zp(l+8|0,a,f);b=l;j=gb-48|0;gb=j;a=l+8|0;a:{if(v[d+4>>2]==v[a+4>>2]){d=pe(j+40|0,d);c=pe(j+32|0,c);f=pe(j+24|0,a);a=gb-16|0;gb=a;c=Cj(c,d);v[a+12>>2]=c;b:{if((c|0)<1){break b}e=v[d+4>>2];if(e){g=32-e|0;v[a+8>>2]=g;c=v[sd(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;e=v[f>>2];g=-1<<v[d+4>>2]&-1>>>g-c;v[e>>2]=v[e>>2]&(g^-1)|g&v[v[d>>2]>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;v[f>>2]=e+(c>>>3&536870908);v[d>>2]=v[d>>2]+4;c=v[a+12>>2]}e=(c|0)/32|0;c=e<<2;kh(v[f>>2],v[d>>2],c);e=v[a+12>>2]-(e<<5)|0;v[a+12>>2]=e;v[f>>2]=c+v[f>>2];if((e|0)<1){break b}c=c+v[d>>2]|0;v[d>>2]=c;d=v[f>>2];i=d;n=v[d>>2];d=-1>>>32-e|0;v[i>>2]=n&(d^-1)|d&v[c>>2];v[f+4>>2]=v[a+12>>2]}pe(b,f);gb=a+16|0;break a}e=pe(j+16|0,d);c=pe(j+8|0,c);d=pe(j,a);f=gb-16|0;gb=f;a=Cj(c,e);v[f+12>>2]=a;c:{if((a|0)<1){break c}c=v[e+4>>2];d:{if(!c){c=v[d+4>>2];break d}c=32-c|0;v[f+8>>2]=c;a=v[sd(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-a;g=v[d+4>>2];k=v[v[e>>2]>>2];i=v[e+4>>2];v[f+8>>2]=a;m=32-g|0;v[f+4>>2]=m;n=Gb(f+8|0,f+4|0);h=v[d>>2];k=k&(-1<<i&-1>>>c-a);c=v[d+4>>2];g=v[e+4>>2];i=c>>>0>g>>>0?k<<c-g:k>>>g-c|0;g=v[n>>2];v[h>>2]=i|v[h>>2]&(-1<<c&-1>>>m-g^-1);i=c+g|0;c=i&31;v[d+4>>2]=c;h=h+(i>>>3&536870908)|0;v[d>>2]=h;a=a-g|0;if((a|0)>=1){v[h>>2]=v[h>>2]&(-1>>>32-a^-1)|k>>>g+v[e+4>>2];v[d+4>>2]=a;c=a}v[e>>2]=v[e>>2]+4;a=v[f+12>>2]}g=32-c|0;if((a|0)>=32){k=-1<<c;i=k^-1;h=v[e>>2];while(1){a=v[d>>2];h=v[h>>2];v[a>>2]=i&v[a>>2]|h<<c;v[d>>2]=a+4;v[a+4>>2]=k&v[a+4>>2]|h>>>g;m=v[f+12>>2];a=m-32|0;v[f+12>>2]=a;h=v[e>>2]+4|0;v[e>>2]=h;if((m|0)>63){continue}break}}if((a|0)<1){break c}k=v[v[e>>2]>>2];v[f+8>>2]=g;c=sd(f+12|0,f+8|0);e=v[d>>2];h=v[d+4>>2];c=v[c>>2];i=v[e>>2]&(-1<<h&-1>>>g-c^-1);g=k&-1>>>32-a;v[e>>2]=i|g<<h;a=c+h|0;v[d+4>>2]=a&31;a=e+(a>>>3&536870908)|0;v[d>>2]=a;e=v[f+12>>2]-c|0;v[f+12>>2]=e;if((e|0)<1){break c}v[a>>2]=v[a>>2]&(-1>>>32-e^-1)|g>>>c;v[d+4>>2]=v[f+12>>2]}pe(b,d);gb=f+16|0}gb=j+48|0;gb=l+48|0}function ZY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0;e=gb-32|0;gb=e;j=Pi(e+24|0);if(v[a+12>>2]){q=j+3|0;r=j+5|0;s=j+4|0;x=j+2|0;z=j+1|0;A=e+16|5;C=e+16|3;while(1){D=Of(a,n);while(1){a:{if(!Nb(c,1)){break a}k=Hd(c);if((k|0)==255){break a}h=k&31;d=wi(a)>>>0>h>>>0;h=B(h,6)+D|0;if(k&64){l=1}else{f=Hd(c);g=f<<24>>24;b:{c:{d:{f=f&127;switch(f|0){case 0:break b;case 1:break d;default:break c}}t[(d?h:e+24|0)|0]=255;break b}if(!(!b|f>>>0>121)){t[(d?h:e+24|0)|0]=f-1;break b}if((f-12&255)>>>0>96|b){break b}t[(d?h:e+24|0)|0]=f+13}E=d?h+1|0:z,F=Hd(c),t[E|0]=F;l=(g|0)<0}if(l){p=d?h:j;g=d?h+3|0:q;f=d?h+5|0:r;o=d?h+4|0:s;m=d?h+2|0:x;h=d?h:e+24|0;while(1){d=h;v[e+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=Hd(c);l=d&128;i=d&63;e:{if(d&64){t[m|0]=1;t[o|0]=i;break e}d=Hd(c);t[f|0]=d;f:{g:{if(i>>>0<=15){t[g|0]=i;Mf(p);h:{i:{j:{d=w[g|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[g|0]=9;t[f|0]=B(w[f|0]&15,17);break f}t[g|0]=0;t[m|0]=1;v[e+12>>2]=w[f|0]+1>>>1;v[e+8>>2]=64;E=o,F=v[sd(e+12|0,e+8|0)>>2],t[E|0]=F;break f}if((d|0)!=19){break f}if(w[f|0]==128){break g}Yt(p);break f}if(i>>>0>44){break f}t[g|0]=w[i+16800|0];k:{switch(i-16|0){case 0:if(d>>>0>1){break g}t[f|0]=d|158;break f;case 1:case 2:t[e+12|0]=15;E=f,F=w[$b(e+12|0,f)|0]|224,t[E|0]=F;break f;case 5:case 6:v[e+12>>2]=16;v[e+8>>2]=d+1;E=f,F=v[sd(e+12|0,e+8|0)>>2]/2|240,t[E|0]=F;break f;case 14:l:{m:{n:{o:{p:{i=d>>>4|0;switch(i-1|0){case 1:break n;case 0:break o;default:break p}}switch(i-10|0){case 1:break l;case 0:break m;default:break g}}t[g|0]=2;t[f|0]=d|240;break f}t[g|0]=3;t[f|0]=d|240;break f}t[g|0]=11;t[f|0]=(d<<3&120)+8|15;break f}t[g|0]=11;t[f|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[e+12>>2]=d+1>>>1;v[e+8>>2]=64;E=f,F=v[sd(e+12|0,e+8|0)>>2],t[E|0]=F;break f}t[g|0]=0}cz(g,f,C,A);if(po(w[e+19|0])>>>0<=po(w[g|0])>>>0){break e}q:{if(w[m|0]){break q}if(!dz(g,f,1)){break q}t[m|0]=w[g|0];t[o|0]=w[f|0]}t[g|0]=w[e+19|0];t[f|0]=w[e+21|0]}if(l){continue}break}}if(!(k&128)){continue}}break}n=n+1|0;if(n>>>0<y[a+12>>2]){continue}break}}gb=e+32|0}function yu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=gb-48|0;gb=f;v[f+32>>2]=c;u[f+38>>1]=b;g=FA(a);a:{if(uc(g)>>>0<=b>>>0){break a}if(BR(a,x[sc(g,b)>>1])>>>0<=c>>>0){break a}b:{if(Gc(a)>>>0>b>>>0){if(y[Id(a,b)+4>>2]>c>>>0){break b}}mk(a,0);if(Gc(a)>>>0<=b>>>0){break a}}c=x[v[a+24>>2]+480188>>1];b=v[d>>2];v[f+16>>2]=b;v[f+20>>2]=b+B(c,880);d=f+24|0;b=d;v[b>>2]=-2078137563;v[b+4>>2]=-873292572;g=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;c=f+16|0;if(DR(c)){while(1){b=w[KT(c,k)+843|0];m=b^Fpa(g^k,e^i,435,256);b=!b;g=(n=g,o=Fpa(m,jb,435,256),p=b,p?n:o);e=b?e:jb;b=k+1|0;i=b>>>0<1?i+1|0:i;k=b;if(!i&DR(c)>>>0>b>>>0){continue}break}}v[d>>2]=g;v[d+4>>2]=e;i=Hm(f+16|0,f+38|0,f+32|0);e=gb-16|0;gb=e;c=e+8|0;j=gb-16|0;gb=j;m=a+12|0;g=m;b=$d(g);l=nR(g,i,b,dc(g));v[j+8>>2]=l;n=j,o=rh(g),v[n>>2]=o;c:{if(Nl(j+8|0,j)){if(!yl(wb(g),i,se(j+8|0))){break c}}l=rh(g)}gb=j+16|0;b=v[Cc(c,l)>>2];gb=e+16|0;v[f+8>>2]=b;n=f,o=Xg(m),v[n+16>>2]=o;b=0;if(Xf(f+8|0,f+16|0)){b=cd(se(f+8|0)+8|0)^1}k=v[d>>2]!=-2078137563|v[d+4>>2]!=-873292572;ve(f+16|0,Id(a,x[f+38>>1]),v[f+32>>2]);j=1;c=b|k;i=Cb(f+16|0)^1;if(i?0:!c){break a}d:{e:{f:{g:{if(b){g=se(f+8|0)+8|0;l=Rb(g);e=Ub(g);c=d;h=gb-16|0;gb=h;v[h>>2]=e;v[h+8>>2]=l;if(Fb(h+8|0,h)){while(1){e=v[h+8>>2];if(v[e>>2]!=v[c>>2]|v[e+4>>2]!=v[c+4>>2]){zu(h+8|0);if(Fb(h+8|0,h)){continue}}break}l=v[h+8>>2]}gb=h+16|0;v[f+16>>2]=l;n=f,o=Ub(g),v[n+40>>2]=o;if(Fb(f+16|0,f+40|0)){break a}if(!k){break e}break g}if(k){break g}if(!c){break d}break f}v[a+28>>2]=v[a+28>>2]+1}if(b|i){break e}e=vR(m,Hm(f+16|0,f+38|0,f+32|0));h:{if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=jR(b,e);wb(e);iR(v[c+4>>2]);v[c+4>>2]=v[c+4>>2]+8;_b(c);gb=b+16|0;break h}c=gb-32|0;gb=c;b=wb(e);b=DA(c+8|0,cv(e,zf(e)+1|0),zf(e),b);iR(v[b+8>>2]);v[b+8>>2]=v[b+8>>2]+8;CA(e,b);BA(b);gb=c+32|0}}e=vR(m,Hm(f+16|0,f+38|0,f+32|0));i:{if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=jR(b,e);wb(e);hR(v[c+4>>2],d);v[c+4>>2]=v[c+4>>2]+8;_b(c);gb=b+16|0;break i}c=gb-32|0;gb=c;b=wb(e);b=DA(c+8|0,cv(e,zf(e)+1|0),zf(e),b);hR(v[b+8>>2],d);v[b+8>>2]=v[b+8>>2]+8;CA(e,b);BA(b);gb=c+32|0}}ve(f+16|0,Id(a,x[f+38>>1]),v[f+32>>2]);Ef(f+16|0,1);j=0}gb=f+48|0;return j|0}function I8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Jb(a);v[23048]=0;X(1324);c=v[23048];v[23048]=0;a:{b:{if((c|0)==1){c=Ra(56328,90496,90472,0)|0;c:{d:{e:{d=O()|0;if((d|0)==(da(56328)|0)){c=Z(c|0)|0;v[23048]=0;Q(1926,a|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;Q(1926,a|0,55680)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;Q(1926,a|0,55739)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}b=kb[v[v[c>>2]+8>>2]](c)|0;v[23048]=0;Q(1926,a|0,(b?b:52181)|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((da(90496)|0)==(d|0)){c=Z(c|0)|0;v[23048]=0;Q(1926,a|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}v[23048]=0;Q(1926,a|0,55680)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}v[23048]=0;Q(1926,a|0,55723)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}b=kb[v[v[c>>2]+8>>2]](c)|0;v[23048]=0;Q(1926,a|0,(b?b:52181)|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=da(90472)|0;c=Z(c|0)|0;g:{if((d|0)==(e|0)){v[23048]=0;Q(1926,a|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;Q(1926,a|0,55680)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;Q(1926,a|0,55706)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}b=kb[v[v[c>>2]+8>>2]](c)|0;v[23048]=0;Q(1926,a|0,(b?b:52181)|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[23048]=0;Q(1926,a|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break d}v[23048]=0;Q(1926,a|0,55680)|0;b=v[23048];v[23048]=0;if((b|0)==1){break d}v[23048]=0;Q(1926,a|0,55683)|0;b=v[23048];v[23048]=0;if((b|0)==1){break d}v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Ab()}L()}return}vb(a);R(b|0);L()}function gK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-48|0;gb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+52>>2]){case 0:b=gb-96|0;gb=b;d=v[c>>2];i=v[d+4>>2];j=v[d+24>>2];v[b+48>>2]=v[d+20>>2];v[b+52>>2]=j;j=v[d+16>>2];v[b+40>>2]=v[d+12>>2];v[b+44>>2]=j;bk(b+72|0,b+40|0,i);d=lf(b+56|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];k=v[v[c+8>>2]>>2];v[b+32>>2]=v[b+88>>2];c=v[b+84>>2];v[b+24>>2]=v[b+80>>2];v[b+28>>2]=c;c=v[b+76>>2];v[b+16>>2]=v[b+72>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;f=b+16|0;c=b;d=gb-16|0;gb=d;if(j){while(1){i=0;if(k){while(1){q=d,r=A[lj(c,i,g)>>3],A[q+8>>3]=r;hg(d+8|0,-1,1);h=A[d+8>>3]*32768;A[d+8>>3]=h;h=fe(h);c:{if(D(h)<2147483648){l=~~h;break c}l=-2147483648}m=Uc(l);q=_n(f,i,g),s=m,u[q>>1]=s;i=i+1|0;if((k|0)!=(i|0)){continue}break}}g=g+1|0;if((j|0)!=(g|0)){continue}break}}gb=d+16|0;gb=b+96|0;break a;case 2:qy(c,ye(b));break a;case 3:j=gk(b);b=gb-96|0;gb=b;d=v[c>>2];g=v[d+4>>2];k=v[d+24>>2];v[b+48>>2]=v[d+20>>2];v[b+52>>2]=k;k=v[d+16>>2];v[b+40>>2]=v[d+12>>2];v[b+44>>2]=k;bk(b+72|0,b+40|0,g);d=lf(b+56|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);k=v[v[c+12>>2]>>2];m=v[v[c+8>>2]>>2];v[b+32>>2]=v[b+88>>2];c=v[b+84>>2];v[b+24>>2]=v[b+80>>2];v[b+28>>2]=c;c=v[b+76>>2];v[b+16>>2]=v[b+72>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;n=b+16|0;c=b;d=gb-16|0;gb=d;if(k){o=j+12|0;while(1){g=0;if(m){while(1){h=fe(A[lj(c,g,i)>>3]*134217728);f=Mb(j,g);l=f;f=Lm(h)+(v[f>>2]>>1)|0;p=f;f=ut(o)+f&-4096;v[l>>2]=p-f;A[d+8>>3]=+(f|0)*7.450580596923828e-9;hg(d+8|0,-1,1);h=A[d+8>>3]*32768;A[d+8>>3]=h;h=fe(h);d:{if(D(h)<2147483648){f=~~h;break d}f=-2147483648}f=Uc(f);q=_n(n,g,i),s=f,u[q>>1]=s;g=g+1|0;if((m|0)!=(g|0)){continue}break}}i=i+1|0;if((k|0)!=(i|0)){continue}break}}gb=d+16|0;gb=b+96|0;break a;case 1:qy(c,ye(b));break a;default:break b}}qy(c,ye(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];gb=e+48|0}function d9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-80|0;gb=k;a:{b:{c:{j=Zp(1,32);d:{e:{if(!j){a=aa(4)|0;cm(a);v[23048]=0;T(84,a|0,90496,1937);a=v[23048];v[23048]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+16>>2]=0;v[j+20>>2]=0;v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j+24>>2]=0;v[j+28>>2]=0;v[j>>2]=c?c:1928;d=vu(k- -64|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[23048]=0;c=Q(91,k+48|0,c|0)|0;f=v[23048];v[23048]=0;i:{if((f|0)!=1){v[23048]=0;f=Q(1938,d|0,c|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break i}v[23048]=0;Q(464,f|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[23048]=0;c=Q(91,k+48|0,c|0)|0;e=v[23048];v[23048]=0;j:{if((e|0)!=1){v[23048]=0;S(1939,d|0,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23048]=0;a=U(1312,96)|0;i=v[23048];v[23048]=0;k:{l:{m:{if((i|0)!=1){v[k+44>>2]=c;v[k+40>>2]=e;v[k+36>>2]=f;v[k+32>>2]=b;v[23048]=0;T(1940,k+48|0,j|0,j+4|0);b=v[23048];v[23048]=0;if((b|0)==1){break m}b=oq(k+24|0,k+48|0);c=v[k+44>>2];v[k+16>>2]=v[k+40>>2];v[k+20>>2]=c;v[23048]=0;c=v[k+36>>2];v[k+8>>2]=v[k+32>>2];v[k+12>>2]=c;ba(2014,a|0,k+8|0,b|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break l}v[j+28>>2]=a;mf(b);oj(k+48|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;xl(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;mf(b);oj(k+48|0)}Zb(a)}xl(d);Z(i|0)|0;v[23048]=0;Y(1920,55229,j|0,g|0,h|0);a=v[23048];v[23048]=0;if((a|0)!=1){v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){a=v[j+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Zb(a);v[j+20>>2]=0}Zb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break b}}Z(i|0)|0;j=0;v[23048]=0;Y(1920,55229,0,g|0,h|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=k+80|0;return j|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break b}R(a|0);L()}V(0)|0;O()|0;Ab()}L()}function Koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=gb-1120|0;gb=d;v[d+1116>>2]=c;k=Ok(d+56|0,b);v[23048]=0;p=jp(k);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){g=nc(a);v[23048]=0;a=U(511,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break h}v[d+16>>2]=a;v[23048]=0;v[d+48>>2]=85899345;a=Gb(d+16|0,d+48|0);c=v[23048];v[23048]=0;if((c|0)==1){break g}a=v[a>>2];v[23048]=0;v[d+32>>2]=B(a,50);a=Gb(d+1116|0,d+32|0);c=v[23048];v[23048]=0;if((c|0)==1){break g}a=v[a>>2];v[23048]=0;S(544,g|0,a|0);a=v[23048];v[23048]=0;if((a|0)==1){break g}v[23048]=0;e=U(553,d+32|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break f}a=0;v[23048]=0;h=Q(41,d+16|0,8192)|0;c=v[23048];v[23048]=0;if((c|0)==1){break e}while(1){s=Mb(e,a),z=8192,u[s>>1]=z;s=Mb(e,a),z=a,t[s+2|0]=z;a=a+1|0;if((a|0)!=256){continue}break}m=9;break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}i:{j:while(1){c=0;n=257;while(1){q=m&255;k:{while(1){j=n&65535;while(1){v[23048]=0;i=Q(252,k|0,q|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break i}l=i&65535;if((l|0)==257|j>>>0<l>>>0){break k}if(qc(g)>>>0>=y[d+1116>>2]){break k}if((l|0)==256){m=9;continue j}f=j>>>0>l>>>0?i:c;a=8191;while(1){f=f&65535;r=w[Mb(e,f)+2|0];o=a&65535;s=oc(h,o),z=r,t[s|0]=z;f=x[Mb(e,f)>>1];if(f>>>0<=8191){a=a-1|0;continue}break}s=d,z=Ub(g),v[s+48>>2]=z;Sd(d+8|0,d+48|0);s=d,z=Rb(h),v[s>>2]=z;a=Ne(d,o);f=Ub(h);v[23048]=0;Y(545,g|0,v[d+8>>2],a|0,f|0);a=v[23048];v[23048]=0;if((a|0)==1){break i}l:{if((j|0)!=(l|0)){break l}a=oc(h,o);v[23048]=0;S(554,g|0,a|0);a=v[23048];v[23048]=0;if((a|0)!=1){break l}break i}if(j>>>0>=8192){c=i;continue}if(qc(g)>>>0>=y[d+1116>>2]){continue}break}a=oc(h,o);s=Mb(e,j),z=w[a|0],t[s+2|0]=z;s=Mb(e,j),z=c,u[s>>1]=z;a=n+1|0;n=8192;c=i;i=a&65535;if((i|0)==8192){continue}break}m=((i|0)==1<<q)+m|0;n=a;continue}break}break}v[23048]=0;a=jp(k);c=v[23048];v[23048]=0;m:{if((c|0)!=1){v[23048]=0;Q(248,b|0,((a-p|0)+3&-4)+p|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break m}}break i}gc(h);VC(e);yb(k);gb=d+1120|0;return}a=P()|0;O()|0;gc(h)}VC(e)}gc(g)}yb(k);R(a|0);L()}function Kga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=d;k=$f(a,c);we(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(nd(a,5)){break a}}f=v[h+24>>2];d=gb-160|0;gb=d;i=bm(d+56|0,v[a+28>>2]);v[23048]=0;g=Q(662,d+40|0,28209)|0;e=v[23048];v[23048]=0;b:{c:{d:{e:{if((e|0)!=1){v[23048]=0;v[d+24>>2]=19922997;v[d+28>>2]=0;T(663,i|0,g|0,d+24|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}Hb(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}t[d+39|0]=0;v[23048]=0;g=Q(662,d+40|0,28216)|0;e=v[23048];v[23048]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[23048]=0;W(664,i|0,d+39|0,g|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break q}Hb(g);g=Jb(d+40|0);v[23048]=0;e=Q(662,d+24|0,28218)|0;j=v[23048];v[23048]=0;if((j|0)==1){break p}v[23048]=0;T(1119,i|0,g|0,e|0);j=v[23048];v[23048]=0;if((j|0)==1){break o}Hb(e);v[23048]=0;T(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[23048];v[23048]=0;if((e|0)==1){break n}v[23048]=0;S(467,b|0,d+24|0);e=v[23048];v[23048]=0;if((e|0)==1){break m}vb(d+24|0);u[d+22>>1]=0;v[23048]=0;e=Q(662,d+24|0,28220)|0;f=v[23048];v[23048]=0;if((f|0)==1){break g}v[23048]=0;W(1120,i|0,d+22|0,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break l}Hb(e);og(d+22|0,4e3);v[23048]=0;e=Q(662,d+24|0,28222)|0;f=v[23048];v[23048]=0;if((f|0)==1){break k}f=v[Cc(d+16|0,x[d+22>>1])>>2];v[23048]=0;Y(1121,i|0,b|0,e|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break j}Hb(e);u[d+14>>1]=65535;v[23048]=0;e=Q(662,d+24|0,28224)|0;f=v[23048];v[23048]=0;if((f|0)==1){break i}v[23048]=0;f=W(1120,i|0,d+14|0,e|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Hb(e);if(!((f|0)==1|j>>>0<=l>>>0)){ff(b,x[d+14>>1])}vb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+24|0);break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0}vb(g)}Yg(i);R(a|0);L()}Yg(i);gb=d+160|0}Rf(a,k,c,h+16|0);gb=h+32|0}function uo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){Db(f+8|0,a+1074308|0,15);if(Cb(f+8|0)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+813|0];t[b+814|0]=c;t[b+813|0]=c}c:{if(wj(b)){e=v[a+1074384>>2];i=v[b+860>>2];d:{if(c){v[b+756>>2]=c;break d}c=v[b+756>>2];if(!c){break c}}d=v[b+708>>2];e:{f:{if((d|0)>=1){if((c|0)<0){break f}break e}if(!d|(c|0)<1){break e}}c=0-c|0;v[b+756>>2]=c}g=b;h=(+(e>>>0)+1)*+(c|0)/+y[a+1074408>>2];g:{if(D(h)<2147483648){c=~~h;break g}c=-2147483648}v[g+860>>2]=c;if(w[b+90|0]&16){c=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,c);v[b+860>>2]=c}a=c-(e?i:0)|0;c=a>>31;e=d>>31;if((e+d^e)>>>0<=(c^a+c)>>>0){if(!d){break c}v[b+708>>2]=0;v[b+856>>2]=d+v[b+856>>2];t[b+853|0]=w[b+853|0]|8;break c}v[b+708>>2]=d-a;v[b+856>>2]=a+v[b+856>>2];t[b+853|0]=w[b+853|0]|8;break c}d=1;h:{if(!(t[b+853|0]&1)|v[a+480180>>2]&524352){break h}if(v[a+1074408>>2]==1){Db(f+8|0,a+1074308|0,6);if(Cb(f+8|0)){break h}}d=0;if(v[a+480180>>2]!=8){break h}d=(w[a+480208|0]&2)>>>1|0}if(!(v[a+480180>>2]!=268435456|c>>>0<240)){d=t[b+853|0]&1;c=c-240|0}if(c){v[b+756>>2]=(v[a+480180>>2]==64?B(c,10):c)<<2}e=v[b+708>>2];c=v[b+700>>2];i:{if(!c){c=0;break i}if(!e|d^1){break i}g=b;j:{if((c|0)<(e|0)){d=v[b+756>>2];k:{if(!(w[a+480208|0]&16)){break k}if(v[a+480180>>2]==4){c=v[b+700>>2];break k}c=v[b+756>>2]/4|0;c=v[((c>>>0<255?c:255)<<2)+38304>>2];d=c;e=c>>31;c=v[b+700>>2];d=Fpa(d,e,c,c>>31)+32768|0;c=jb;d=vc(Gpa(d,d>>>0<32768?c+1|0:c,65536,0),jb);c=v[b+700>>2];d=d-c|0;d=(d|0)>1?d:1}e=v[b+708>>2];c=c+d|0;c=(c|0)>(e|0)?e:c;break j}if((c|0)<=(e|0)){break i}d=0-v[b+756>>2]|0;l:{if(!(w[a+480208|0]&16)){break l}if(v[a+480180>>2]==4){c=v[b+700>>2];break l}c=v[b+756>>2]/4|0;c=v[((c>>>0<255?c:255)<<2)+39328>>2];d=c;e=c>>31;c=v[b+700>>2];d=Fpa(d,e,c,c>>31)+32768|0;c=jb;d=vc(Gpa(d,d>>>0<32768?c+1|0:c,65536,0),jb);c=v[b+700>>2];d=d-c|0;d=(d|0)<-1?d:-1}e=v[b+708>>2];c=c+d|0;c=(c|0)<(e|0)?e:c}v[g+700>>2]=c}if((c|0)!=(e|0)){break c}Db(f+8|0,a+1074308|0,25);if(j=!Cb(f+8|0),k=0,l=v[a+480180>>2]!=1,l?j:k){break c}v[b+708>>2]=0}gb=f+16|0}function eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Xd(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=gg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Kd(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[h+8>>2],4);Sb(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Kd(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=dg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=ac(q,-16777216,16776704);p=v[a+64>>2];g=ac(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=Fpa(l,s,f,f>>31);l=jb;p=Fpa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=Fpa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Iy(a){a=a|0;var b=0,c=0,d=C(0),e=0;Pb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[23048]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}ea(1847,e|0,67,5,c|0,b|0);b=v[23048];v[23048]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[23048]=0;ea(1847,a+4528|0,62,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[23048]=0;ea(1847,a+4552|0,53,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[23048]=0;ea(1847,a+4576|0,43,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[23048]=0;ea(1847,a+4600|0,32,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[23048]=0;ea(1847,a+4624|0,22,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[23048]=0;ea(1847,a+4648|0,75,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[23048]=0;ea(1847,a+4672|0,69,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[23048]=0;ea(1847,a+4696|0,60,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[23048]=0;ea(1847,a+4720|0,48,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[23048]=0;ea(1847,a+4744|0,36,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[23048]=0;ea(1847,a+4768|0,25,5,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}v[23048]=0;ea(1847,a+4792|0,0,0,0,0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[23048]=0;ea(1847,a+4816|0,3,0,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[23048]=0;ea(1847,a+4840|0,3,0,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}v[23048]=0;ea(1847,a+4864|0,407,1,c|0,0);b=v[23048];v[23048]=0;if((b|0)==1){break a}v[23048]=0;ea(1847,a+4888|0,400,1,c|0,0);b=v[23048];v[23048]=0;if((b|0)==1){break a}v[23048]=0;ea(1847,a+4912|0,10,0,c|0,-1);b=v[23048];v[23048]=0;if((b|0)==1){break a}v[23048]=0;ea(1847,a+4936|0,10,0,c|0,-1);c=v[23048];v[23048]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(90496)|0;if((O()|0)==(da(90496)|0)){Z(c|0)|0;t[a+5045|0]=0;$();return}R(c|0);L()}function EL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{d:{e:{f:{k=Zp(1,28);if(!k){a=aa(4)|0;cm(a);v[23048]=0;T(84,a|0,90496,1937);a=v[23048];v[23048]=0;if((a|0)!=1){break a}break f}v[k+24>>2]=0;v[k+16>>2]=0;v[k+20>>2]=0;v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1928;d=vu(j- -64|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[23048]=0;c=Q(91,j+48|0,c|0)|0;f=v[23048];v[23048]=0;j:{if((f|0)!=1){v[23048]=0;f=Q(1938,d|0,c|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break j}v[23048]=0;Q(464,f|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[23048]=0;c=Q(91,j+48|0,c|0)|0;e=v[23048];v[23048]=0;k:{if((e|0)!=1){v[23048]=0;S(1939,d|0,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23048]=0;a=U(1312,80)|0;i=v[23048];v[23048]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[23048]=0;T(1940,j+48|0,k|0,k+4|0);b=v[23048];v[23048]=0;if((b|0)==1){break n}b=oq(j+24|0,j+48|0);c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[23048]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;ba(1941,a|0,j+8|0,b|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break m}v[k+24>>2]=a;mf(b);oj(j+48|0);xl(d);i=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;mf(b);oj(j+48|0)}Zb(a)}xl(d);Z(i|0)|0;v[23048]=0;Y(1920,52722,k|0,g|0,h|0);a=v[23048];v[23048]=0;if((a|0)!=1){v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Zb(Ct(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Zb(a);v[k+20>>2]=0}Zb(k);break d}i=V(0)|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[23048]=0;Y(1920,52722,0,g|0,h|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=j+80|0;return i|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break b}R(a|0);L()}V(0)|0;O()|0;Ab()}L()}function Dna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);c=gb-96|0;gb=c;e=gb-32|0;gb=e;g=b+16|0;wW(e+24|0,g);h=xb(e+24|0);d=v[e+28>>2];f=v[e+24>>2];v[e+8>>2]=f;v[e+12>>2]=d;v[e>>2]=f;v[e+4>>2]=d;d=a;fc(e+16|0,a,e);f=xb(e+16|0);if((f|0)==(h|0)){Vb(d,xb(e+24|0))}gb=e+32|0;if((f|0)!=(h|0)){Pb(g,0,128)}UW(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;td(c+72|0,a,_f(a));v[23048]=0;d=U(511,c+72|0)|0;e=v[23048];v[23048]=0;a:{b:{if((e|0)==1){break b}v[23048]=0;e=b+4|0;S(488,e|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;me(c- -64|0,e);d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;d=v[c+68>>2];v[c+8>>2]=v[c+64>>2];v[c+12>>2]=d;T(675,c+40|0,c+72|0,c+8|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;d=U(376,a|0)|0;e=v[23048];v[23048]=0;c:{if((e|0)==1){break c}v[23048]=0;T(341,c+40|0,a|0,d|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}v[23048]=0;a=U(328,c+40|0)|0;d=v[23048];v[23048]=0;d:{if((d|0)!=1){e:{f:{g:{if(!a){break g}while(1){v[23048]=0;a=Q(250,c+40|0,5)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}if(!a){break g}v[23048]=0;Q(676,c+40|0,c+36|0)|0;a=v[23048];v[23048]=0;h:{if((a|0)!=1){a=4;if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))==1414682436|(w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))==1196380752){break h}v[23048]=0;a=U(376,c+40|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[23048]=0;T(341,c+16|0,c+40|0,a|0);a=v[23048];v[23048]=0;i:{j:{if((a|0)!=1){if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))!=1414682436){break j}v[23048]=0;i=C(Aa(677,c+16|0));a=v[23048];v[23048]=0;if((a|0)==1){break e}z[b+144>>2]=i;break i}a=P()|0;O()|0;break d}if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))!=1196380752){break i}v[23048]=0;a=U(376,c+16|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}v[b+148>>2]=a}yb(c+16|0);continue}}yb(c+40|0);yb(c+72|0);gb=c+96|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(c+16|0);break d}a=P()|0;O()|0}yb(c+40|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(c+72|0);R(a|0);L()}function aK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-48|0;gb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+52>>2]){case 0:b=gb-80|0;gb=b;d=v[c>>2];i=v[d+4>>2];v[b+40>>2]=v[d+20>>2];j=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=j;ak(b- -64|0,b+32|0,i);d=lf(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];k=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;f=b+16|0;c=b;d=gb-16|0;gb=d;if(j){while(1){i=0;if(k){while(1){q=d,r=A[lj(c,i,g)>>3],A[q+8>>3]=r;hg(d+8|0,-1,1);h=A[d+8>>3]*32768;A[d+8>>3]=h;h=fe(h);c:{if(D(h)<2147483648){l=~~h;break c}l=-2147483648}m=Uc(l);q=Zn(f,i,g),s=m,u[q>>1]=s;i=i+1|0;if((k|0)!=(i|0)){continue}break}}g=g+1|0;if((j|0)!=(g|0)){continue}break}}gb=d+16|0;gb=b+80|0;break a;case 2:ny(c,ye(b));break a;case 3:j=gk(b);b=gb-80|0;gb=b;d=v[c>>2];g=v[d+4>>2];v[b+40>>2]=v[d+20>>2];k=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=k;ak(b- -64|0,b+32|0,g);d=lf(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);k=v[v[c+12>>2]>>2];m=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;n=b+16|0;c=b;d=gb-16|0;gb=d;if(k){o=j+12|0;while(1){g=0;if(m){while(1){h=fe(A[lj(c,g,i)>>3]*134217728);f=Mb(j,g);l=f;f=Lm(h)+(v[f>>2]>>1)|0;p=f;f=ut(o)+f&-4096;v[l>>2]=p-f;A[d+8>>3]=+(f|0)*7.450580596923828e-9;hg(d+8|0,-1,1);h=A[d+8>>3]*32768;A[d+8>>3]=h;h=fe(h);d:{if(D(h)<2147483648){f=~~h;break d}f=-2147483648}f=Uc(f);q=Zn(n,g,i),s=f,u[q>>1]=s;g=g+1|0;if((m|0)!=(g|0)){continue}break}}i=i+1|0;if((k|0)!=(i|0)){continue}break}}gb=d+16|0;gb=b+80|0;break a;case 1:ny(c,ye(b));break a;default:break b}}ny(c,ye(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];gb=e+48|0}function Sh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;a:{if(!Od(a)){break a}pk(a);if(c){c=b;n=gb-16|0;gb=n;f=a;if(Od(a)){e=x[f+34>>1];o=v[f+4>>2];h=v[f+8>>2];m=v[f>>2];r=!(e&2)|(o>>>0>=h>>>0|m>>>0<h>>>0);p=v[f+12>>2];g=v[f+16>>2];s=!(e&8)|(p>>>0>=g>>>0|g>>>0>m>>>0);z=c+1300264|0;d=c+1074984|0;l=e&4;A=e&16;while(1){b:{if((f|0)!=v[d+104>>2]){break b}c=v[d+76>>2];if(!c){break b}c:{d:{e:{i=d;f:{g:{if(s){break g}j=v[d+88>>2];if(j&2048){break g}v[d+84>>2]=g;v[d+80>>2]=p;e=A;c=g;break f}if(r){break e}v[d+84>>2]=h;v[d+80>>2]=o;j=v[d+88>>2];e=l;c=h}v[i+76>>2]=c;k=j|2;v[d+88>>2]=k;q=d+88|0;i=1;if(!e){break d}j=j|6;i=1;e=1;break c}k=v[d+88>>2]&-3;v[d+88>>2]=k;q=d+88|0;i=0}j=k&-5;e=0}v[d+88>>2]=j;if(y[d+4>>2]>c>>>0){j=j&-129;v[d+88>>2]=j;k=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=k}if(!e){v[q>>2]=j&-129}if(i){break b}v[d+76>>2]=m}d=d+880|0;if((z|0)!=(d|0)){continue}break}}gb=n+16|0}if((Vi(a)|0)==2){d=0;f=gb+-64|0;gb=f;e=ld(a);h=v[a+20>>2];g=h+(B(e,v[a>>2])<<1)|0;while(1){if(e){i=B(d,e);l=B(e,d^-1);c=0;while(1){u[g+(c+i<<1)>>1]=x[g+(c-e<<1)>>1];u[h+(c+l<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];g=v[a+4>>2];Db(f+32|0,b+1074308|0,33);BS(f+40|0,d,h+(B(e,g)<<1)|0,i-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Db(f+32|0,b+1074308|0,33);BS(f+8|0,d+(e<<7)|0,h+(B(a,e)<<1)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}gb=f- -64|0;return}if((Vi(a)|0)!=1){break a}d=0;f=gb+-64|0;gb=f;e=ld(a);h=v[a+20>>2];g=h+B(e,v[a>>2])|0;while(1){if(e){i=B(d,e);l=B(e,d^-1);c=0;while(1){t[g+(c+i|0)|0]=w[g+(c-e|0)|0];t[h+(c+l|0)|0]=w[c+h|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];g=v[a+4>>2];Db(f+32|0,b+1074308|0,33);AS(f+40|0,d,h+B(e,g)|0,i-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Db(f+32|0,b+1074308|0,33);AS(f+8|0,d+(e<<6)|0,h+B(a,e)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}gb=f- -64|0}}function yO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;e=B(b,880)+a|0;a:{if(w[e+1075074|0]&2){j=1;b:{if(!(w[a+480209|0]&16)){break b}j=0;if(!(v[a+480180>>2]&16777248)){break b}j=!(w[a+480208|0]&4)}if(v[a+480180>>2]==64){a=B(b,880)+a|0;b=a+1075805|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075810|0],167)}t[b|0]=d+1;break a}g=e+1074984|0;c:{if(!j){break c}Db(h+8|0,a+1074308|0,21);if(!Cb(h+8|0)){break c}e=B(b,880)+a|0;f=e+1075805|0;t[f|0]=w[f|0]+(w[e+1075809|0]<<2)}f=B(b,880)+a|0;i=f+1075808|0;k=f+1075805|0;e=Cz(a,w[i|0],w[k|0]);d:{if(wj(g)){z[d>>2]=C(C(B(w[f+1075810|0],e)|0)*C(6510417279059766e-21))+z[d>>2];c=f+1075837|0;d=w[c|0];t[c|0]=d&243|8;if(v[a+1074408>>2]!=(v[a+1074384>>2]+1|0)){break d}t[c|0]=d|12;break d}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}e=v[a+480180>>2]&5?(w[i|0]&3)==1?0-e|0:e:e;g=a+1074308|0;Db(h+8|0,g,21);d=Cb(h+8|0);f=v[a+480208>>2];e:{if(d){d=f&4;e=d?e:0-e|0;d=d?5:6;break e}d=5;f:{if(f&131072){break f}d=8;if(v[a+480180>>2]==1024){break f}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break f}d=6}Db(h+8|0,g,80);if(!Cb(h+8|0)){break e}d=w[(B(b,880)+a|0)+1075777|0]==26?d+2|0:d}d=(B(w[(B(b,880)+a|0)+1075810|0],e)|0)/(1<<d)|0;f=0-d|0;g:{if(!(w[a+480208|0]&16)|v[a+480180>>2]==4){break g}e=v[c>>2];if((d|0)<=-1){d=cA(a,f>>>2|0);d=vc(Gpa(Fpa(d,d>>31,e,e>>31),jb,65536,0),jb);e=v[c>>2];d=d-e|0;g=f&3;if(!g){break g}i=d;d=uP(a,g);d=(i+vc(Gpa(Fpa(d,d>>31,e,e>>31),jb,65536,0),jb)|0)-v[c>>2]|0;break g}g=d&3;d=bA(a,d>>>2|0);d=vc(Gpa(Fpa(d,d>>31,e,e>>31),jb,65536,0),jb);e=v[c>>2];d=d-e|0;if(!g){break g}i=d;d=tP(a,g);d=(i+vc(Gpa(Fpa(d,d>>31,e,e>>31),jb,65536,0),jb)|0)-v[c>>2]|0}v[c>>2]=v[c>>2]+d;c=ku(a,b);if(!c){break d}d=c;e=f<<16>>16;g=v[(B(b,880)+a|0)+1075640>>2];i=2;h:{if(!g){break h}i=w[g+33|0]}kb[v[v[c>>2]+88>>2]](d,e,i<<24>>24,b)}if(!j){break a}Db(h+8|0,a+1074308|0,21);if(Cb(h+8|0)){break a}t[k|0]=w[k|0]+w[(B(b,880)+a|0)+1075809|0];break a}if(!(w[e+1075654|0]&2)){break a}a=ku(a,b);if(!a){break a}kb[v[v[a>>2]+88>>2]](a,0,0,b)}gb=h+16|0}function FE(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=gb-128|0;gb=j;a:{b:{c:{if(!hn(f,g,h,i,0,0,0,0)){break c}k=f;m=g;p=h;n=i&65535;o=i>>>16&32767;d:{e:{if((o|0)!=32767){l=4;if(o){break e}l=k|p|(m|n)?3:2;break d}l=!(k|p|(m|n))}}r=e>>>16|0;n=r&32767;if((n|0)==32767){break c}if(l){break b}}Dd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];$E(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}l=n<<16;o=d;q=l|e&65535;m=q;q=i>>>16&32767;k=i&65535|q<<16;if((hn(b,c,o,m,f,g,h,k)|0)<=0){if(hn(b,c,o,m,f,g,p,k)){h=b;i=c;break a}Dd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(n){i=c;h=b}else{Dd(j+96|0,b,c,o,m,0,0,0,1081540608);h=v[j+108>>2];m=h;o=v[j+104>>2];n=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Dd(j+80|0,f,g,p,k,0,0,0,1081540608);f=v[j+92>>2];k=f;p=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;m=m&65535|65536;if((n|0)>(q|0)){while(1){k=o;l=p;t=k-l|0;l=m-((k>>>0<l>>>0)+s|0)|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;l=l-(k>>>0>t>>>0)|0;k=t-k|0;f:{if((l|0)>0?1:(l|0)>=0){m=h;h=h-f|0;i=i-((f>>>0>m>>>0)+g|0)|0;if(!(h|k|(i|l))){Dd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}l=l<<1|k>>>31;o=k<<1|i>>>31;break f}l=m<<1|o>>>31;o=o<<1|i>>>31}m=l;l=i<<1|h>>>31;h=h<<1;i=l;n=n-1|0;if((q|0)<(n|0)){continue}break}n=q}l=o;q=l-p|0;k=m-((l>>>0<p>>>0)+s|0)|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=k-(l>>>0>q>>>0)|0;p=q-l|0;g:{if((k|0)<0){p=o;k=m;break g}o=h;h=h-f|0;i=i-((f>>>0>o>>>0)+g|0)|0;if(h|p|(i|k)){break g}Dd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;n=n-1|0;m=i<<1|h>>>31;h=h<<1;i=m;c=b;b=p;k=k<<1|b>>>31;p=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((n|0)<=0){Dd(j- -64|0,h,i,p,k&65535|(b|n+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=p;e=k&65535|(b|n)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;gb=j+128|0}function wm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;a:{b:{if(cd(a)|y[a+12>>2]<=y[b+4>>2]){break b}c=x[b+8>>1]>=wi(a)>>>0;g=x[b+8>>1];if((g|0)!=65535?c:0){break b}f=g;if((f&65535)==65535){g=wi(a)-1|0;f=0}e=Wc(a,v[b+4>>2],f&65535);j=w[b+12|0];k=j&4;c:{d:{if(j&2){break d}l=g&65535;if(l>>>0<(f&65535)>>>0){break d}i=w[b+10|0];c=f;d=e;while(1){e:{if(!k){if((i|0)!=w[d+3|0]){break e}break c}if((i|0)==w[d+2|0]){break c}}d=d+6|0;c=c+1|0;if((c&65535)>>>0<=l>>>0){continue}break}}i=g&65535;if(i>>>0>=(f&65535)>>>0){c=f;d=e;while(1){f:{if(!k){if(w[d+3|0]){break f}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break c}if(w[d+2|0]){break f}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break c}d=d+6|0;c=c+1|0;if(i>>>0>=(c&65535)>>>0){continue}break}}g:{if(!(j&1)){break g}d=v[no(a)+480180>>2]&2;i=b;c=w[b+12|0];if(!(c&4|(f&65535)>>>0>(g&65535)>>>0)){while(1){h:{i:{switch(w[e+3|0]-9|0){case 4:if(!hz(v[no(a)+8>>2],1)){break h}d=1;t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+3|0]=w[b+10|0];t[e+5|0]=w[b+11|0];break a;case 0:break i;default:break h}}j:{if(d){c=w[e+5|0];if(c>>>0>128){break h}t[e+2|0]=2;t[e+3|0]=w[b+10|0];a=1;break j}t[e+2|0]=2;t[e+3|0]=w[b+10|0];c=w[e+5|0];a=2}t[e+4|0]=a+(c&255)>>>a;t[e+5|0]=w[b+11|0];break c}e=e+6|0;f=f+1|0;if((f&65535)>>>0<=(g&65535)>>>0){continue}break}c=w[b+12|0]}k:{l:{if(c&4){f=w[b+11|0];e=13;m:{switch(w[b+10|0]-1|0){case 1:f=_o(B(d?2:4,f));c=w[b+12|0];e=9;break;case 0:break m;default:break k}}t[b+11|0]=f;t[b+10|0]=e;c=c&254;break l}e=w[b+11|0];t[h+14|0]=e;f=b;g=!d;d=w[b+10|0];n:{if(!(g|(d|0)!=9)){if(e>>>0>128){break k}d=2;e=(e&254)>>>1|0;break n}t[h+15|0]=d;o:{if(dz(h+15|0,h+14|0,1)){d=w[h+15|0];if(d){break o}}c=w[b+12|0];break k}c=w[b+12|0];e=w[h+14|0]}t[f+11|0]=e;t[b+10|0]=d;c=c&254}t[i+12|0]=c}d=1;if(c&1){break g}t[b+12|0]=c^4;if(wm(a,b)){break a}}p:{q:{c=v[b>>2];if((c|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){break q}c=v[b>>2]}if((c|0)!=2){break b}d=0;c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1;break p}v[b+4>>2]=v[b+4>>2]+1}t[b+12|0]=w[b+12|0]|1;d=wm(a,b);break a}d=1;break a}d=0}gb=h+16|0;return d|0}function Kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;a:{b:{c:{h=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?h>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?h>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?h>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?h>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;m=v[a+48>>2];v[g+36>>2]=m;k=v[a+52>>2];v[g+40>>2]=k;l=v[a+56>>2];v[g+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=e;v[g+16>>2]=h;v[g+20>>2]=f;e:{if(d){while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(j>>>16&65520)+r|0;j=u[e+14>>1];h=u[e+12>>1];l=u[e+10>>1];q=u[e+8>>1];p=u[e+6>>1];t=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];i=0;k=1;f=0;while(1){e=f<<1;v[(g+8|0)+(f<<2)>>2]=(((((((B(u[b+(e|-8)>>1],w)+B(u[b+(e|-12)>>1],x)|0)+B(u[b+(e|-4)>>1],t)|0)+B(u[b+e>>1],p)|0)+B(u[b+(e|4)>>1],q)|0)+B(u[b+(e|8)>>1],l)|0)+B(h,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=k&1;k=0;f=1;if(e){continue}break}while(1){k=(g+8|0)+(i<<2)|0;j=v[k>>2];h=v[a+60>>2];l=h;e=(g+32|0)+(i<<3)|0;q=v[e>>2];b=ac(q,-16777216,16776704);i=v[a+64>>2];f=ac(v[e+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=Fpa(l,p,h,h>>31);l=jb;p=h;h=Fpa(i,i>>31,b,b>>31);i=p+h|0;b=jb+l|0;b=i>>>0<h>>>0?b+1|0:b;h=i;i=v[a+68>>2];i=Fpa(i,i>>31,f,f>>31);f=h+i|0;b=jb+b|0;b=f>>>0<i>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Lc(f,b,24);v[e+4>>2]=q;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[e>>2]=b-(f&j);i=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];e=v[g+28>>2];continue}break}j=v[g+24>>2];e=v[g+28>>2];l=v[g+44>>2];k=v[g+40>>2];m=v[g+36>>2];i=v[g+32>>2];break e}b=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=g+48|0}function Cga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;d=gb-48|0;gb=d;e=NR(d+32|0,1<<v[b+12>>2]);if(zf(a)){while(1){f=A[qe(a,c)>>3];MR(Tc(e,c),f);c=c+1|0;if(zf(a)>>>0>c>>>0){continue}break}}v[23048]=0;qz(b,e);c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}w=d,x=Rb(e),v[w>>2]=x;w=d,x=Ub(e),v[w+24>>2]=x;if(Fb(d,d+24|0)){while(1){c=v[d>>2];t=c;f=A[c+8>>3];i=gb-32|0;gb=i;o(+A[c>>3]);c=j(1)|0;g=j(0)|0;o(+f);k=j(1)|0;p=j(0)|0;q=c&2147483647;h=q;k=k&2147483647;r=(h|0)==(k|0)&g>>>0<p>>>0|h>>>0<k>>>0;c=r?g:p;h=r?h:k;r=h;l(0,c|0);l(1,h|0);f=+n();h=h>>>20|0;b:{if((h|0)==2047){break b}u=g;g=(k|0)==(q|0)&g>>>0>p>>>0|k>>>0<q>>>0;p=g?u:p;q=g?q:k;g=q;l(0,p|0);l(1,g|0);m=+n();c:{if(!(c|r)){break c}c=g>>>20|0;if((c|0)==2047){break c}if((c-h|0)>=65){f=m+f;break b}d:{if(c>>>0>=1534){f=f*1.90109156629516e-211;m=m*1.90109156629516e-211;s=5.260135901548374e210;break d}s=1;if(h>>>0>572){break d}f=f*5.260135901548374e210;m=m*5.260135901548374e210;s=1.90109156629516e-211}cJ(i+24|0,i+16|0,m);cJ(i+8|0,i,f);f=s*K(A[i>>3]+A[i+16>>3]+A[i+8>>3]+A[i+24>>3]);break b}f=m}gb=i+32|0;MR(t,Wp(f));Ro(d);if(Fb(d,d+24|0)){continue}break}}v[23048]=0;oz(b,e);c=v[23048];v[23048]=0;if((c|0)==1){break a}v[23048]=0;nz(e);c=v[23048];v[23048]=0;if((c|0)==1){break a}if(vf(e)>>>0>3){c=1;while(1){HA(Tc(e,c),2);HA(Tc(e,(vf(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<vf(e)>>>1>>>0){continue}break}}v[23048]=0;qz(b,e);c=v[23048];v[23048]=0;if((c|0)==1){break a}w=d,x=Rb(e),v[w+24>>2]=x;w=d,x=Ub(e),v[w+16>>2]=x;e:{if(Fb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[23048]=0;GA(d,c);g=v[23048];v[23048]=0;if((g|0)==1){break e}g=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=g;g=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=g;Ro(d+24|0);if(Fb(d+24|0,d+16|0)){continue}break}}v[23048]=0;oz(b,e);b=v[23048];v[23048]=0;if((b|0)==1){break a}v[23048]=0;nz(e);b=v[23048];v[23048]=0;if((b|0)==1){break a}if(zf(a)){c=0;while(1){f=A[Tc(e,c)>>3];w=qe(a,c),y=f,A[w>>3]=y;c=c+1|0;if(zf(a)>>>0>c>>>0){continue}break}}Wq(e);gb=d+48|0;return}}a=P()|0;O()|0;Wq(e);R(a|0);L()}function fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Xd(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=gg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=(((i&2147483647)<<1|g>>>31)&-2)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Kd(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Jd(v[h+8>>2],4);Sb(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Kd(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Jd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=dg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=ac(q,-16777216,16776704);p=v[a+64>>2];g=ac(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=Fpa(l,s,f,f>>31);l=jb;p=Fpa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=Fpa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];h=v[a+44>>2];v[f+32>>2]=h;m=v[a+48>>2];v[f+36>>2]=m;k=v[a+52>>2];v[f+40>>2]=k;l=v[a+56>>2];v[f+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){i=(((i&2147483647)<<1|j>>>31)&-2)+s|0;b=(j>>>16&65520)+r|0;e=u[b+14>>1];j=u[b+12>>1];g=u[b+10>>1];l=u[b+8>>1];q=u[b+6>>1];p=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];h=0;m=1;k=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[i+(b|-4)|0],w)+B(t[i+(b|-6)|0],x)|0)+B(t[i+(b|-2)|0],p)|0)+B(t[b+i|0],q)|0)+B(t[i+(b|2)|0],l)|0)+B(t[i+(b|4)|0],g)|0)+B(j,t[i+(b|6)|0])|0)+B(e,t[i+(b|8)|0])<<8)/32768;y=k&1;k=0;b=1;if(y){continue}break}while(1){k=(f+8|0)+(h<<2)|0;j=v[k>>2];g=v[a+60>>2];l=g;i=(f+32|0)+(h<<3)|0;q=v[i>>2];b=ac(q,-16777216,16776704);h=v[a+64>>2];e=ac(v[i+4>>2],-16777216,16776704);p=g>>31;j=j<<8;g=j;g=Fpa(l,p,g,g>>31);l=jb;p=g;g=Fpa(h,h>>31,b,b>>31);h=p+g|0;b=jb+l|0;b=h>>>0<g>>>0?b+1|0:b;g=h;h=v[a+68>>2];h=Fpa(h,h>>31,e,e>>31);e=g+h|0;b=jb+b|0;b=e>>>0<h>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Lc(e,b,24);v[i+4>>2]=q;e=v[a+72>>2];v[k>>2]=(b|0)/256;v[i>>2]=b-(e&j);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;e=o>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];i=v[f+28>>2];continue}break}j=v[f+24>>2];i=v[f+28>>2];l=v[f+44>>2];k=v[f+40>>2];m=v[f+36>>2];h=v[f+32>>2];break e}b=n>>12;e=o>>12}v[a+40>>2]=n;v[a+20>>2]=e;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=i;gb=f+48|0}function c9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{j=Zp(1,32);d:{e:{if(!j){a=aa(4)|0;cm(a);v[23048]=0;T(84,a|0,90496,1937);a=v[23048];v[23048]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+16>>2]=0;v[j+20>>2]=0;v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j+24>>2]=0;v[j+28>>2]=0;v[j>>2]=c?c:1928;d=vu(k+32|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[23048]=0;c=Q(91,k+16|0,c|0)|0;f=v[23048];v[23048]=0;i:{if((f|0)!=1){v[23048]=0;f=Q(1938,d|0,c|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break i}v[23048]=0;Q(464,f|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[23048]=0;c=Q(91,k+16|0,c|0)|0;e=v[23048];v[23048]=0;j:{if((e|0)!=1){v[23048]=0;S(1939,d|0,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[23048]=0;c=U(1312,96)|0;e=v[23048];v[23048]=0;k:{l:{m:{if((e|0)!=1){v[23048]=0;T(1940,k+16|0,j|0,j+4|0);e=v[23048];v[23048]=0;if((e|0)==1){break m}e=oq(k+8|0,k+16|0);v[23048]=0;ga(2015,c|0,a|0,b|0,e|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break l}v[j+28>>2]=c;mf(e);oj(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;xl(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;mf(e);oj(k+16|0)}Zb(c)}xl(d);Z(i|0)|0;v[23048]=0;Y(1920,55255,j|0,g|0,h|0);a=v[23048];v[23048]=0;if((a|0)!=1){v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){a=v[j+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Zb(a);v[j+20>>2]=0}Zb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break b}}Z(i|0)|0;j=0;v[23048]=0;Y(1920,55255,0,g|0,h|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=k+48|0;return j|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break b}R(a|0);L()}V(0)|0;O()|0;Ab()}L()}function rx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[22953]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[f|0];if(d){v[a>>2]=d&57343;a=a+4|0;f=f+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Lf(f)|0}e=1;break g}e=0;break h}e=1}while(1){if(!e){e=w[f|0]>>>3|0;if((e-16|e+(g>>26))>>>0>7){break f}h=f+1|0;e=h;n:{if(!(g&33554432)){break n}if((w[h|0]&192)!=128){break f}h=f+2|0;e=h;if(!(g&524288)){break n}if((w[h|0]&192)!=128){break f}e=f+3|0}f=e;d=d-1|0;e=1;continue}while(1){g=w[f|0];o:{if(f&3|g-1>>>0>126){break o}g=v[f>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[f+4>>2];e=f+4|0;f=e;if(!((g-16843009|g)&-2139062144)){continue}break}f=e}e=g&255;if(e-1>>>0<=126){d=d-1|0;f=f+1|0;continue}break}e=e-194|0;if(e>>>0>50){break e}f=f+1|0;g=v[(e<<2)+77696>>2];e=0;continue}}while(1){if(!e){if(!d){break a}while(1){p:{e=w[f|0];h=e-1|0;q:{r:{if(h>>>0>126){g=e;break r}if(f&3|d>>>0<5){break q}s:{while(1){g=v[f>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[f+1|0];v[a+8>>2]=w[f+2|0];v[a+12>>2]=w[f+3|0];a=a+16|0;f=f+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[f|0]}e=g&255;h=e-1|0}if(h>>>0>126){break p}}v[a>>2]=e;a=a+4|0;f=f+1|0;d=d-1|0;if(d){continue}break a}break}e=e-194|0;if(e>>>0>50){break e}f=f+1|0;g=v[(e<<2)+77696>>2];e=1;continue}h=w[f|0];e=h>>>3|0;if((e-16|e+(g>>26))>>>0>7){break f}t:{u:{i=f+1|0;e=h-128|g<<6;h=i;v:{if((e|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}i=f+2|0;e=h|e<<6;h=i;if((e|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}e=h|e<<6;h=f+3|0}f=h;v[a>>2]=e;d=d-1|0;a=a+4|0;break t}v[115529]=25;f=f-1|0;break c}e=0;continue}}f=f-1|0;if(g){break d}g=w[f|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[115529]=25;if(!a){break b}}v[b>>2]=f}return-1}v[b>>2]=f;return c|0}function oz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=gb-208|0;gb=c;f=1;e=v[a+12>>2];k=1<<e;n=2;if(e>>>0>=2){j=k;while(1){j=j>>>2|0;if(j){p=B(f,3);q=f<<1;l=0;while(1){hO(c+192|0,Tc(a,l<<1));hO(c+176|0,Tc(a,l));yi(c+160|0,c+176|0,c+192|0);e=l<<n;o=f+e|0;if(e>>>0<o>>>0){while(1){d=Tc(b,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=e+f|0;d=Tc(b,g);h=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=h;h=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=h;h=e+q|0;d=Tc(b,h);m=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=m;m=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=m;m=e+p|0;d=Tc(b,m);i=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=i;i=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=i;rl(c+80|0,c+144|0,c+128|0);qj(c- -64|0,c+144|0,c+128|0);rl(c+48|0,c+112|0,c+96|0);qj(c+16|0,c+112|0,c+96|0);yi(c+32|0,43920,c+16|0);rl(c+16|0,c+80|0,c+48|0);d=Tc(b,e);i=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=i;i=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=i;rl(c,c- -64|0,c+32|0);yi(c+16|0,c+192|0,c);d=Tc(b,g);i=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=i;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;qj(c,c+80|0,c+48|0);yi(c+16|0,c+176|0,c);d=Tc(b,h);h=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=h;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;qj(c,c- -64|0,c+32|0);yi(c+16|0,c+160|0,c);d=Tc(b,m);h=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=h;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;e=e+1|0;if((o|0)!=(e|0)){continue}break}}l=l+1|0;if((l|0)!=(j|0)){continue}break}e=v[a+12>>2]}f=f<<2;n=n+2|0;if(n>>>0<=e>>>0){continue}break}}a:{if(!(e&1)){break a}j=k>>>1|0;if(!j){break a}e=0;while(1){k=e+j|0;a=Tc(b,k);f=v[a+12>>2];v[c+200>>2]=v[a+8>>2];v[c+204>>2]=f;f=v[a+4>>2];v[c+192>>2]=v[a>>2];v[c+196>>2]=f;qj(c+176|0,Tc(b,e),c+192|0);a=Tc(b,k);f=v[c+188>>2];v[a+8>>2]=v[c+184>>2];v[a+12>>2]=f;k=v[c+180>>2];v[a>>2]=v[c+176>>2];v[a+4>>2]=k;pz(Tc(b,e),c+192|0);e=e+1|0;if((j|0)!=(e|0)){continue}break}}gb=c+208|0}function c2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-1072|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;v[a+956>>2]=a+960;j=Lx(a+960|0,100,84351,a+16|0);v[a+48>>2]=2350;o=ge(a+536|0,0,a+48|0);v[a+48>>2]=2350;m=ge(a+528|0,0,a+48|0);l=a+544|0;a:{b:{c:{if(j>>>0>=100){v[23048]=0;j=fa(2371)|0;l=v[23048];v[23048]=0;if((l|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[23048]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=ba(2390,a+956|0,j|0,84351,a|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}f=v[a+956>>2];if(!f){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break b}Ge(o,f);Ge(m,Ad(j<<2));if(ok(m)){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)==1){break b}break c}l=v[m>>2]}v[23048]=0;Ic(a+520|0,d);f=v[23048];v[23048]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[23048]=0;q=U(2375,a+520|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break j}v[23048]=0;f=v[a+956>>2];Y(2387,q|0,f|0,f+j|0,l|0);f=v[23048];v[23048]=0;if((f|0)==1){break j}p=j?w[v[a+956>>2]]==45:p;h=Jb(a+488|0);g=Jb(a+472|0);f=Jb(a+456|0);v[23048]=0;na(2419,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,g|0,f|0,a+452|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}v[a+36>>2]=2350;c=ge(a+40|0,0,a+36|0);i=v[a+452>>2];k:{if((i|0)<(j|0)){k=Bb(f)+(j-i<<1|1)|0;break k}k=Bb(f)+2|0}n=a+48|0;k=(Bb(g)+k|0)+i|0;if(k>>>0<101){break h}Ge(c,Ad(k<<2));n=v[c>>2];if(n){break h}v[23048]=0;X(2351);b=v[23048];v[23048]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}k=v[d+4>>2];v[23048]=0;qa(2420,n|0,a+36|0,a+32|0,k|0,l|0,(j<<2)+l|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],h|0,g|0,f|0,i|0);i=v[23048];v[23048]=0;if((i|0)!=1){v[23048]=0;b=la(2400,b|0,n|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Hc(c)}Pc(f);Pc(g);vb(h)}Xb(a+520|0);break a}Hc(c);Pc(f);Pc(g);vb(h);Xb(a+520|0);Hc(m);Hc(o);gb=a+1072|0;return b|0}L()}j=P()|0;O()|0}Hc(m);Hc(o);R(j|0);L()}function nca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{switch(b|0){case 0:e=gb-16|0;gb=e;f=Jb(a);d=c;c:{d:{if(Bb(c)){while(1){a=v[ck(d,h)>>2];e:{if(a>>>0>=2097152){v[23048]=0;S(110,f|0,63);a=v[23048];v[23048]=0;if((a|0)!=1){break e}break d}c=0;f:{g:{h:{while(1){g=a&63;t[(e+10|0)+c|0]=g;b=c+1|0;a=a>>>6|0;if(!a){break h}c=b;if((c|0)!=6){continue}break}b=7;a=1;break g}if(!c){v[23048]=0;S(110,f|0,t[e+10|0]);a=v[23048];v[23048]=0;if((a|0)!=1){break e}break d}a=7-c|0;if((b|0)!=2){break g}if((g|0)==1){break f}b=2;a=6}g=(-1<<b^-1)<<a;c=b-1|0;j=c+(e+10|0)|0;a=b;while(1){i:{if((a|0)==(b|0)){a=w[j|0];v[23048]=0;S(110,f|0,(a|g)<<24>>24);i=v[23048];v[23048]=0;a=c;if((i|0)!=1){break i}break d}v[23048]=0;a=a-1|0;S(110,f|0,t[a+(e+10|0)|0]|-128);i=v[23048];v[23048]=0;if((i|0)==1){break d}}if(a){continue}break}break e}v[23048]=0;S(110,f|0,t[e+10|0]|64);a=v[23048];v[23048]=0;if((a|0)==1){break d}}h=h+1|0;if(Bb(d)>>>0>h>>>0){continue}break}}gb=e+16|0;break c}a=P()|0;O()|0;vb(f);R(a|0);L()}return;case 1:b=0;a=Jb(a);d=Bb(c);v[23048]=0;S(111,a|0,d|0);d=v[23048];v[23048]=0;j:{if((d|0)!=1){k:{if(Bb(c)){while(1){d=v[ck(c,b)>>2];l:{if(d>>>0<=127){v[23048]=0;S(110,a|0,d<<24>>24);d=v[23048];v[23048]=0;if((d|0)!=1){break l}break k}v[23048]=0;S(110,a|0,63);d=v[23048];v[23048]=0;if((d|0)==1){break k}}b=b+1|0;if(Bb(c)>>>0>b>>>0){continue}break}}break j}}break a}return;case 2:b=0;a=Jb(a);d=Bb(c);v[23048]=0;S(111,a|0,d|0);d=v[23048];v[23048]=0;m:{if((d|0)!=1){n:{if(Bb(c)){while(1){d=v[ck(c,b)>>2];o:{if(d>>>0<=255){v[23048]=0;S(110,a|0,d<<24>>24);d=v[23048];v[23048]=0;if((d|0)!=1){break o}break n}v[23048]=0;S(110,a|0,63);d=v[23048];v[23048]=0;if((d|0)==1){break n}}b=b+1|0;if(Bb(c)>>>0>b>>>0){continue}break}}break m}}break a}return;case 3:ko(a,c,4128);return;case 4:ko(a,c,5152);return;case 5:ko(a,c,6176);return;case 6:ko(a,c,7200);return;case 7:ko(a,c,8224);return;case 8:ko(a,c,9248);return;default:break b}}Jb(a);return}b=P()|0;O()|0;vb(a);R(b|0);L()}function iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Xd(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=gg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Kd(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[h+8>>2],4);Sb(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Kd(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=dg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=ac(o,-16777216,16776704);n=v[a+64>>2];g=ac(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=Fpa(m,s,f,f>>31);m=jb;n=Fpa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=Fpa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Sb(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function i2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-464|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;v[a+348>>2]=a+352;j=Lx(a+352|0,100,84351,a+16|0);v[a+48>>2]=2350;o=ge(a+232|0,0,a+48|0);v[a+48>>2]=2350;m=ge(a+224|0,0,a+48|0);l=a+240|0;a:{b:{c:{if(j>>>0>=100){v[23048]=0;j=fa(2371)|0;l=v[23048];v[23048]=0;if((l|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[23048]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=ba(2390,a+348|0,j|0,84351,a|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}f=v[a+348>>2];if(!f){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break b}Ge(o,f);Ge(m,Ad(j));if(ok(m)){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)==1){break b}break c}l=v[m>>2]}v[23048]=0;Ic(a+216|0,d);f=v[23048];v[23048]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[23048]=0;q=U(21,a+216|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break j}v[23048]=0;f=v[a+348>>2];Y(2366,q|0,f|0,f+j|0,l|0);f=v[23048];v[23048]=0;if((f|0)==1){break j}p=j?w[v[a+348>>2]]==45:p;h=Jb(a+192|0);g=Jb(a+176|0);f=Jb(a+160|0);v[23048]=0;na(2417,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,h|0,g|0,f|0,a+156|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}v[a+36>>2]=2350;c=ge(a+40|0,0,a+36|0);i=v[a+156>>2];k:{if((i|0)<(j|0)){k=Bb(f)+(j-i<<1|1)|0;break k}k=Bb(f)+2|0}n=a+48|0;k=(Bb(g)+k|0)+i|0;if(k>>>0<101){break h}Ge(c,Ad(k));n=v[c>>2];if(n){break h}v[23048]=0;X(2351);b=v[23048];v[23048]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}k=v[d+4>>2];v[23048]=0;qa(2418,n|0,a+36|0,a+32|0,k|0,l|0,j+l|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],h|0,g|0,f|0,i|0);i=v[23048];v[23048]=0;if((i|0)!=1){v[23048]=0;b=la(17,b|0,n|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Hc(c)}vb(f);vb(g);vb(h)}Xb(a+216|0);break a}Hc(c);vb(f);vb(g);vb(h);Xb(a+216|0);Hc(m);Hc(o);gb=a+464|0;return b|0}L()}j=P()|0;O()|0}Hc(m);Hc(o);R(j|0);L()}function ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb+-64|0;gb=d;u[d+62>>1]=c;og(d+62|0,32);f=nc(a);v[23048]=0;S(750,f|0,x[d+62>>1]);a=v[23048];v[23048]=0;a:{if((a|0)!=1){b:{if(!x[d+62>>1]){break b}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;c:{d:{if((a&65535)>>>0<4e3){break d}u[d+24>>1]=1;e:{if(!x[b+480190>>1]){break e}while(1){f:{if(Od(El(b,x[d+24>>1]))){break f}i=d,j=VB(Rb(f),Ub(f),d+24|0),v[i+48>>2]=j;i=d,j=Ub(f),v[i+40>>2]=j;if(Fb(d+48|0,d+40|0)){break f}u[d+60>>1]=x[d+24>>1];c=1;if(!x[b+480192>>1]){break e}while(1){a=v[(((c&65535)<<2)+b|0)+900380>>2];g:{if(!a){break g}a=a+236|0;e=Ku(a);if((a|0)==(e|0)){break g}while(1){if(x[a>>1]==x[d+60>>1]){u[a>>1]=0}a=a+2|0;if((e|0)!=(a|0)){continue}break}}c=c+1|0;if(x[b+480192>>1]>=(c&65535)>>>0){continue}break}break e}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break d}c=av(d+48|0);v[23048]=0;a=Q(1004,b|0,c|0)|0;e=v[23048];v[23048]=0;h:{i:{if((e|0)==1){break i}j:{if(a){v[23048]=0;Q(1005,b|0,c|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break i}e=1;if(!x[b+480192>>1]){break j}while(1){a=v[(((e&65535)<<2)+b|0)+900380>>2];k:{if(!a){break k}a=a+236|0;g=Ku(a);if((a|0)==(g|0)){break k}while(1){l:{if(y[c+4>>2]<=x[a>>1]){break l}ve(d+40|0,c,x[a>>1]);if(Cb(d+40|0)){break l}u[a>>1]=0}a=a+2|0;if((g|0)!=(a|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break j}Ee(c);break b}rk(d+24|0,c);hB(d+32|0,d+24|0,1);Dl(d+16|0,c);v[23048]=0;t[d+15|0]=0;dT(d+40|0,d+32|0,d+16|0,d+15|0);a=v[23048];v[23048]=0;if((a|0)!=1){break h}}a=P()|0;O()|0;Ee(c);break a}rk(d,c);i=d,j=Cj(d+40|0,d),u[i+60>>1]=j;Ee(c);if(x[d+60>>1]>=4e3){break c}}v[23048]=0;S(442,f|0,d+60|0);a=v[23048];v[23048]=0;if((a|0)!=1){if(x[b+480190>>1]>=x[d+60>>1]){break c}u[b+480190>>1]=x[d+60>>1];break c}a=P()|0;O()|0;break a}h=h+1|0;if(x[d+62>>1]>(h&65535)>>>0){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0}Ze(f);R(a|0);L()}function Gla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=a;d=w[b+2|0];a:{b:{if((d-16&255)>>>0<=128){t[a+2|0]=1;d=(d-16|0)/2|0;break b}c:{switch((d+96&240)>>>4|0){case 0:t[a+2|0]=4;d=d&15;break b;case 1:t[a+2|0]=3;d=d&15;break b;case 2:t[a+2|0]=6;d=d&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;d=d&15}t[c+4|0]=d}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{c=w[b+4|0];if(c>>>0<=28){switch(c|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(c-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((c|0)==128){break e}if((c|0)!=157){break d}t[a+2|0]=15;c=w[b+6|0];t[a+3|0]=20;t[a+4|0]=c>>>3;t[e+15|0]=15;g=a,h=w[$b(b+5|0,e+15|0)|0]|208,t[g+5|0]=h;break d}c=w[b+6|0];d=w[b+5|0];if(!(c|d)){break d}t[a+5|0]=d;t[a+3|0]=c;Mf(a);f=w[b+6|0]==15;break d}t[a+3|0]=2;g=a,h=Ki(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=3;g=a,h=Ki(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=4;g=a,h=Ki(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=5;t[a+5|0]=w[b+6|0]&240|w[b+5|0]>>>4;break d}c=w[b+5|0];if(c){t[a+5|0]=c;t[a+3|0]=9;break d}if((w[b+6|0]-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=w[b+6|0]>>>1;break d}c=w[b+6|0];if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=w[b+5|0]&15;break d}t[a+3|0]=w[b+6|0];t[a+5|0]=w[b+5|0];Wu(a,1);f=(w[a+3|0]&254)==16;break d}t[a+3|0]=18;t[a+5|0]=w[b+5|0];break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1;break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=w[b+6|0]>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}gb=e+16|0;return f|0}function U7(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=C(0),g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=0;e=gb-16|0;gb=e;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if(!((a|0)>-1?a>>>0>=8388608:0)){g=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}g=C(C(c-c)/C(0));if((a|0)<=-1){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;n=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));i=C(c*C(c*C(.5)));k=C(c/C(c+C(2)));f=C(k*k);m=C(f*f);g=c;c=(l(2,(p(C(c-i)),j(2))&-4096),q());f=C(C(C(g-c)-i)+C(k*C(i+C(C(f*C(C(m*C(.2849878668785095))+C(.6666666269302368)))+C(m*C(C(m*C(.24279078841209412))+C(.40000972151756287)))))));c=C(C(n*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(f*C(.434326171875))+C(C(n*C(7.903415166765626e-7))+C(C(f+c)*C(-3168997136526741e-20))))))}g=c}f=C(g*C(2e3));if(!(C(D(f))<C(2147483648))){break c}a=~~f;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=gb-16|0;gb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){e=aa(8)|0;v[23048]=0;b=Q(91,b|0,58332)|0;a=v[23048];v[23048]=0;if((a|0)==1){break k}rc(e,b);v[23048]=0;T(84,e|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break i}a=P()|0;O()|0;vb(b);break j}gb=b+16|0;a=v[(a<<24>>24<<2)+59400>>2];break h}a=P()|0;O()|0;ca(e|0)}R(a|0)}L()}break b;case 3:v[e>>2]=0;d=gb-80|0;gb=d;a=v[a+24>>2]+24604|0;v[d+40>>2]=v[a+32>>2];v[d>>2]=v[a+36>>2];b=v[Wf(d+40|0,d)>>2];o=e;l:{if(v[a+32>>2]==v[dr(d+40|0)+32>>2]){h=-1;if(v[a+36>>2]==v[dr(d)+36>>2]){break l}}h=0;if((b|0)<1){break l}h=(b+500|0)/1e3|0}v[o>>2]=h;gb=d+80|0;a=v[e>>2];break b;default:break d}}d=aa(8)|0;v[23048]=0;b=Q(91,e|0,56835)|0;a=v[23048];v[23048]=0;m:{if((a|0)!=1){rc(d,b);v[23048]=0;T(84,d|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break m}a=P()|0;O()|0;ca(d|0)}R(a|0);L()}a=-2147483648}gb=e+16|0;return a|0}L()}function hK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+52>>2]){case 0:d=0;b=gb-96|0;gb=b;f=v[c>>2];j=v[f+4>>2];i=v[f+24>>2];v[b+48>>2]=v[f+20>>2];v[b+52>>2]=i;i=v[f+16>>2];v[b+40>>2]=v[f+12>>2];v[b+44>>2]=i;bk(b+72|0,b+40|0,j);f=lf(b+56|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];v[b+32>>2]=v[b+88>>2];c=v[b+84>>2];v[b+24>>2]=v[b+80>>2];v[b+28>>2]=c;c=v[b+76>>2];v[b+16>>2]=v[b+72>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;g=b+16|0;c=b;if(j){while(1){f=0;if(i){while(1){h=jd(v[xj(c,f,d)>>2]+2048|0,12);h=(h|0)>-32768?h:-32768;o=_n(g,f,d),p=(h|0)<32767?h:32767,u[o>>1]=p;f=f+1|0;if((i|0)!=(f|0)){continue}break}}d=d+1|0;if((j|0)!=(d|0)){continue}break}}gb=b+96|0;break a;case 2:ry(c,ye(b));break a;case 3:j=gk(b);b=gb-96|0;gb=b;d=v[c>>2];i=v[d+4>>2];h=v[d+24>>2];v[b+48>>2]=v[d+20>>2];v[b+52>>2]=h;h=v[d+16>>2];v[b+40>>2]=v[d+12>>2];v[b+44>>2]=h;bk(b+72|0,b+40|0,i);d=lf(b+56|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);i=v[v[c+12>>2]>>2];h=v[v[c+8>>2]>>2];v[b+32>>2]=v[b+88>>2];c=v[b+84>>2];v[b+24>>2]=v[b+80>>2];v[b+28>>2]=c;c=v[b+76>>2];v[b+16>>2]=v[b+72>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;l=b+16|0;c=b;if(i){m=j+12|0;while(1){d=0;if(h){while(1){g=xj(c,d,f);k=Mb(j,d);g=v[g>>2]+(v[k>>2]>>1)|0;n=g;g=ut(m)+g&-4096;v[k>>2]=n-g;g=jd(g|2048,12);g=(g|0)>-32768?g:-32768;o=_n(l,d,f),p=(g|0)<32767?g:32767,u[o>>1]=p;d=d+1|0;if((h|0)!=(d|0)){continue}break}}f=f+1|0;if((i|0)!=(f|0)){continue}break}}gb=b+96|0;break a;case 1:ry(c,ye(b));break a;default:break b}}ry(c,ye(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];gb=e+48|0}function Oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;a:{b:{c:{i=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?i>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?i>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?i>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;v[f+16>>2]=i;v[f+20>>2]=e;if(d){while(1){m=1;e=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];i=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];t=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];k=0;b=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((((B(u[e+(h|-8)>>1],w)+B(u[e+(h|-12)>>1],x)|0)+B(u[e+(h|-4)>>1],t)|0)+B(u[e+h>>1],o)|0)+B(u[e+(h|4)>>1],l)|0)+B(u[e+(h|8)>>1],n)|0)+B(u[e+(h|12)>>1],i)|0)+B(j,u[e+(h|16)>>1])|0)/32768;h=b;b=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];i=v[a+60>>2];n=i;h=(f+32|0)+(k<<3)|0;k=v[h>>2];b=ac(k,-16777216,16776704);l=v[a+64>>2];e=ac(v[h+4>>2],-16777216,16776704);o=i>>31;i=g<<8;g=i;g=Fpa(n,o,g,g>>31);n=jb;l=Fpa(l,l>>31,b,b>>31);g=l+g|0;b=jb+n|0;b=g>>>0<l>>>0?b+1|0:b;o=g;g=v[a+68>>2];g=Fpa(g,g>>31,e,e>>31);e=o+g|0;b=jb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Lc(e,b,24);v[h+4>>2]=k;e=v[a+72>>2];v[j>>2]=(b|0)/256;v[h>>2]=b-(e&i);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function DL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{d:{e:{f:{j=Zp(1,28);if(!j){a=aa(4)|0;cm(a);v[23048]=0;T(84,a|0,90496,1937);a=v[23048];v[23048]=0;if((a|0)!=1){break a}break f}v[j+24>>2]=0;v[j+16>>2]=0;v[j+20>>2]=0;v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1928;d=vu(k+32|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[23048]=0;c=Q(91,k+16|0,c|0)|0;f=v[23048];v[23048]=0;j:{if((f|0)!=1){v[23048]=0;f=Q(1938,d|0,c|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break j}v[23048]=0;Q(464,f|0,e|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[23048]=0;c=Q(91,k+16|0,c|0)|0;e=v[23048];v[23048]=0;k:{if((e|0)!=1){v[23048]=0;S(1939,d|0,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[23048]=0;c=U(1312,80)|0;e=v[23048];v[23048]=0;l:{m:{n:{if((e|0)!=1){v[23048]=0;T(1940,k+16|0,j|0,j+4|0);e=v[23048];v[23048]=0;if((e|0)==1){break n}e=oq(k+8|0,k+16|0);v[23048]=0;ga(1942,c|0,a|0,b|0,e|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break m}v[j+24>>2]=c;mf(e);oj(k+16|0);xl(d);i=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;mf(e);oj(k+16|0)}Zb(c)}xl(d);Z(i|0)|0;v[23048]=0;Y(1920,52745,j|0,g|0,h|0);a=v[23048];v[23048]=0;if((a|0)!=1){v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Zb(Ct(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Zb(a);v[j+20>>2]=0}Zb(j);break d}i=V(0)|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[23048]=0;Y(1920,52745,0,g|0,h|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=k+48|0;return i|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break b}R(a|0);L()}V(0)|0;O()|0;Ab()}L()}function jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Xd(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=gg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=(((i&2147483647)<<1|g>>>31)&-2)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Kd(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Jd(v[h+8>>2],4);Sb(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Kd(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Jd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=dg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=ac(o,-16777216,16776704);n=v[a+64>>2];g=ac(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=Fpa(m,s,f,f>>31);m=jb;n=Fpa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=Fpa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Sb(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function si(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=C(0),n=0,o=C(0),p=0;if(!(kb[v[v[a>>2]+136>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(kb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((kb[v[v[a>>2]+152>>2]](a)|0)<1){break a}if(!IM(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}m=z[a+4196>>2];k=C(m*k);j=C(m*j);l=a+44|0;n=Pd(l,0);l=Pd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;k=z[g+n>>2];h=b+g|0;m=z[h>>2];p=h;h=c+g|0;z[p>>2]=C(z[d+g>>2]*j)-C(z[h>>2]+z[g+l>>2]);z[h>>2]=C(z[e+g>>2]*j)-C(k+m);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+n>>2]*j)-z[d+g>>2])+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*j)-z[e+g>>2])+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[d+g>>2])-C(z[g+n>>2]*k);h=c+g|0;z[h>>2]=C(z[h>>2]+z[e+g>>2])-C(z[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[g+n>>2])-C(z[d+g>>2]*j);h=c+g|0;z[h>>2]=C(z[h>>2]+z[g+l>>2])-C(z[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+n>>2]*k)+C(z[d+g>>2]*j))+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*k)+C(z[e+g>>2]*j))+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=IM(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;m=C(z[d+g>>2]-z[g+n>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=C(z[h>>2]+C(m*j))+C(o*k);g=c+g|0;z[g>>2]=C(C(o*j)+C(m*k))+z[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(kb[v[v[a>>2]+136>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[d>>2]+z[a+n>>2];d=a+c|0;z[d>>2]=z[d>>2]+z[a+l>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function Raa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0),u=0,w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(ei(m)){A=Pd(m,0);B=Pd(m,1);D=qd(m,0);E=qd(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){j=a+4304|0;i=q+1|0;u=i+v[a+4272>>2]&4095;l=j+(u<<4)|0;w=i+v[a+4276>>2]&4095;g=((w<<4)+j|0)+4|0;x=i+v[a+4280>>2]&4095;n=((x<<4)+j|0)+8|0;y=i+v[a+4284>>2]&4095;h=((y<<4)+j|0)+12|0;r=v[a+4288>>2]+o|0;s=v[a+4292>>2]+o|0;G=a+69840|0;H=a+78032|0;F=d;while(1){u=u-1&4095;i=(u<<4)+j|0;e=z[i>>2];r=r&1023;I=(r<<3)+G|0;p=z[I+4>>2];J=z[h>>2];K=z[n>>2];L=z[g>>2];M=z[l>>2];N=z[B>>2];O=z[A>>2];t=z[a+4232>>2];w=w-1&4095;l=(w<<4)+j|0;k=z[l+4>>2];f=C(C(t*z[I>>2])+C(k*C(.6180340051651001)));h=o<<3;g=h+G|0;z[g+4>>2]=k-C(f*C(.6180340051651001));k=e;e=C(C(p*t)-C(e*C(.6180340051651001)));z[g>>2]=k+C(e*C(.6180340051651001));z[i>>2]=f;z[l+4>>2]=e;s=s&1023;g=(s<<3)+H|0;p=z[g+4>>2];x=x-1&4095;n=(x<<4)+j|0;f=z[n+8>>2];t=z[a+4236>>2];e=C(t*z[g>>2]);y=y-1&4095;g=(y<<4)+j|0;k=z[g+12>>2];e=C(e+C(k*C(.6180340051651001)));h=h+H|0;z[h+4>>2]=k-C(e*C(.6180340051651001));k=f;f=C(C(p*t)-C(f*C(.6180340051651001)));z[h>>2]=k+C(f*C(.6180340051651001));z[n+8>>2]=e;z[g+12>>2]=f;f=C(z[i>>2]+e);e=C(O+C(1.0000000031710769e-30));z[D>>2]=f+C(z[a+4224>>2]*e);f=C(N+C(1.0000000031710769e-30));z[E>>2]=C(C(z[a+4224>>2]*f)+z[l+4>>2])+z[g+12>>2];h=(q<<4)+j|0;p=z[a+4228>>2];e=C(p*e);z[h>>2]=C(C(z[a+4240>>2]*z[i>>2])+e)+C(M*z[a+4244>>2]);f=C(p*f);z[h+4>>2]=C(C(z[a+4248>>2]*z[l+4>>2])+f)+C(L*z[a+4252>>2]);z[h+8>>2]=C(C(z[a+4256>>2]*z[n+8>>2])-f)+C(K*z[a+4260>>2]);z[h+12>>2]=C(C(z[a+4264>>2]*z[g+12>>2])+e)+C(J*z[a+4268>>2]);h=g+12|0;n=n+8|0;g=l+4|0;E=E+4|0;D=D+4|0;B=B+4|0;A=A+4|0;s=s-1|0;r=r-1|0;o=o-1&1023;q=q-1&4095;l=i;F=F-1|0;if(F){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;si(a,b,c,qd(m,0),qd(m,1),d)}}function Yp(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Ad(b)}if(b>>>0>=4294967232){v[115529]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[116975]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;ws(c,b);return a}if(v[116861]==(f|0)){c=c+v[116858]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[116858]=c;v[116861]=b;return a}if(v[116860]==(f|0)){c=c+v[116857]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[116860]=d;v[116857]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=467420,o=v[116855]&Jpa(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+467724|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=467424,o=v[116856]&Jpa(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;ws(b,l);return a}c=Ad(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;hc(c,a,b>>>0>d>>>0?d:b);Zb(a);a=c}return a}function Pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;i=v[a+48>>2];v[f+36>>2]=i;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;v[f+16>>2]=h;v[f+20>>2]=e;if(d){while(1){e=(((g&2147483647)<<1|j>>>31)&-2)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];h=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];k=0;m=1;i=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[e+(b|-4)|0],x)+B(t[e+(b|-6)|0],y)|0)+B(t[e+(b|-2)|0],w)|0)+B(t[b+e|0],o)|0)+B(t[e+(b|2)|0],l)|0)+B(t[e+(b|4)|0],n)|0)+B(t[e+(b|6)|0],h)|0)+B(j,t[e+(b|8)|0])<<8)/32768;g=i;i=0;b=1;if(g){continue}break}while(1){j=(f+8|0)+(k<<2)|0;e=v[j>>2];h=v[a+60>>2];n=h;i=(f+32|0)+(k<<3)|0;k=v[i>>2];b=ac(k,-16777216,16776704);l=v[a+64>>2];g=ac(v[i+4>>2],-16777216,16776704);o=h>>31;h=e<<8;e=h;e=Fpa(n,o,e,e>>31);n=jb;l=Fpa(l,l>>31,b,b>>31);e=l+e|0;b=jb+n|0;b=e>>>0<l>>>0?b+1|0:b;o=e;e=v[a+68>>2];e=Fpa(e,e>>31,g,g>>31);g=o+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);v[i+4>>2]=k;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&h);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];i=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function XS(a){a=a|0;var b=0,c=0,d=0,e=0;Pb(a,0,288);dB(a+288|0);er(a+800|0);t[a+2|0]=w[27441];b=w[27439]|w[27440]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[27444];b=w[27442]|w[27443]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[27448]|w[27449]<<8|(w[27450]<<16|w[27451]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[27445]|w[27446]<<8|(w[27447]<<16|w[27448]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[27452]|w[27453]<<8|(w[27454]<<16|w[27455]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[27455]|w[27456]<<8|(w[27457]<<16|w[27458]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[27463];b=w[27459]|w[27460]<<8|(w[27461]<<16|w[27462]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;b=gb-32|0;gb=b;c=Tb(b+16|0,27422);v[23048]=0;Ye(b+8|0,a+288|0);d=v[23048];v[23048]=0;a:{b:{if((d|0)==1){break b}v[23048]=0;Q(450,b+8|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}vb(c);gb=b+32|0;break a}a=P()|0;O()|0;vb(c);R(a|0);L()}d=a+800|0;b=0;a=gb+-64|0;gb=a;c:{d:{e:{while(1){v[a+60>>2]=b<<3;f:{if(b>>>0<=15){of(a+32|0,27430);v[23048]=0;S(490,a+16|0,a+60|0);c=v[23048];v[23048]=0;g:{h:{i:{j:{if((c|0)!=1){v[23048]=0;T(491,a+48|0,a+32|0,a+16|0);c=v[23048];v[23048]=0;if((c|0)==1){break j}v[23048]=0;Ye(a+8|0,d+(b<<5)|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}v[23048]=0;Q(450,a+8|0,a+48|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break i}vb(a+48|0);vb(a+16|0);Hb(a+32|0);break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a+48|0)}vb(a+16|0)}Hb(a+32|0);break d}c=Tb(a+48|0,27421);v[23048]=0;Ye(a+32|0,d+(b<<5)|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}v[23048]=0;Q(450,a+32|0,c|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}vb(c)}b=b+1|0;if((b|0)!=128){continue}break}gb=a- -64|0;break c}b=P()|0;O()|0;vb(c)}R(b|0);L()}}function qz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=gb-208|0;gb=c;f=1;e=v[a+12>>2];h=1<<e;if(e&1){i=h>>>1|0;if(i){e=0;while(1){j=e+i|0;f=Tc(b,j);d=v[f+12>>2];v[c+200>>2]=v[f+8>>2];v[c+204>>2]=d;d=v[f+4>>2];v[c+192>>2]=v[f>>2];v[c+196>>2]=d;qj(c+176|0,Tc(b,e),c+192|0);f=Tc(b,j);d=v[c+188>>2];v[f+8>>2]=v[c+184>>2];v[f+12>>2]=d;j=v[c+180>>2];v[f>>2]=v[c+176>>2];v[f+4>>2]=j;pz(Tc(b,e),c+192|0);e=e+1|0;if((i|0)!=(e|0)){continue}break}e=v[a+12>>2]}f=2;h=h>>>3|0}else{h=h>>>2|0}j=e&-2;if(j){while(1){if(f){o=B(h,3);p=h<<1;i=0;while(1){e=Tc(a,i<<1);d=v[e+12>>2];v[c+200>>2]=v[e+8>>2];v[c+204>>2]=d;d=v[e+4>>2];v[c+192>>2]=v[e>>2];v[c+196>>2]=d;e=Tc(a,i);d=v[e+12>>2];v[c+184>>2]=v[e+8>>2];v[c+188>>2]=d;d=v[e+4>>2];v[c+176>>2]=v[e>>2];v[c+180>>2]=d;yi(c+160|0,c+176|0,c+192|0);e=i<<j;m=h+e|0;if(e>>>0<m>>>0){while(1){d=Tc(b,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=e+h|0;yi(c+128|0,c+192|0,Tc(b,g));k=e+p|0;yi(c+112|0,c+176|0,Tc(b,k));n=e+o|0;yi(c+96|0,c+160|0,Tc(b,n));rl(c+80|0,c+144|0,c+112|0);qj(c- -64|0,c+144|0,c+112|0);rl(c+48|0,c+128|0,c+96|0);Im(c+16|0,-A[5490],-A[5491]);qj(c,c+128|0,c+96|0);yi(c+32|0,c+16|0,c);rl(c+16|0,c+80|0,c+48|0);d=Tc(b,e);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;l=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=l;qj(c+16|0,c+80|0,c+48|0);d=Tc(b,g);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;rl(c+16|0,c- -64|0,c+32|0);d=Tc(b,k);k=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=k;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;qj(c+16|0,c- -64|0,c+32|0);d=Tc(b,n);k=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=k;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;e=e+1|0;if((m|0)!=(e|0)){continue}break}}i=i+1|0;if((f|0)!=(i|0)){continue}break}}h=h>>>2|0;f=f<<2;j=j-2|0;if(j){continue}break}}gb=c+208|0}function bK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+52>>2]){case 0:d=0;b=gb-80|0;gb=b;f=v[c>>2];j=v[f+4>>2];v[b+40>>2]=v[f+20>>2];i=v[f+16>>2];v[b+32>>2]=v[f+12>>2];v[b+36>>2]=i;ak(b- -64|0,b+32|0,j);f=lf(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;g=b+16|0;c=b;if(j){while(1){f=0;if(i){while(1){h=jd(v[xj(c,f,d)>>2]+2048|0,12);h=(h|0)>-32768?h:-32768;o=Zn(g,f,d),p=(h|0)<32767?h:32767,u[o>>1]=p;f=f+1|0;if((i|0)!=(f|0)){continue}break}}d=d+1|0;if((j|0)!=(d|0)){continue}break}}gb=b+80|0;break a;case 2:oy(c,ye(b));break a;case 3:j=gk(b);b=gb-80|0;gb=b;d=v[c>>2];i=v[d+4>>2];v[b+40>>2]=v[d+20>>2];h=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=h;ak(b- -64|0,b+32|0,i);d=lf(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);i=v[v[c+12>>2]>>2];h=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;l=b+16|0;c=b;if(i){m=j+12|0;while(1){d=0;if(h){while(1){g=xj(c,d,f);k=Mb(j,d);g=v[g>>2]+(v[k>>2]>>1)|0;n=g;g=ut(m)+g&-4096;v[k>>2]=n-g;g=jd(g|2048,12);g=(g|0)>-32768?g:-32768;o=Zn(l,d,f),p=(g|0)<32767?g:32767,u[o>>1]=p;d=d+1|0;if((h|0)!=(d|0)){continue}break}}f=f+1|0;if((i|0)!=(f|0)){continue}break}}gb=b+80|0;break a;case 1:oy(c,ye(b));break a;default:break b}}oy(c,ye(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];gb=e+48|0}function i7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-96|0;gb=e;a:{if(hd(c)){break a}g=w[lL(c)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Fs(e+80|0,c,0,Bb(c)-1|0);Eb(c,e+80|0);vb(e+80|0)}Md(e+80|0);f=v[e+80>>2];Md(e+72|0);g=kL(f,v[e+76>>2],c);Md(e+80|0);c:{d:{e:{f:{g:{if(v[e+84>>2]==(g|0)){if(te(c,56371)){a=aa(8)|0;v[23048]=0;b=Q(91,e+80|0,57444)|0;c=v[23048];v[23048]=0;if((c|0)==1){break e}rc(a,b);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}c=P()|0;O()|0;vb(b);break d}if(!d){break g}a=aa(8)|0;v[23048]=0;T(2056,e+80|0,57454,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){rc(a,e+80|0);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break c}c=P()|0;O()|0;vb(e+80|0);break d}c=P()|0;O()|0;ca(a|0);break d}f=Jb(e+80|0);h:{i:{j:{k:{switch(v[g+4>>2]){case 0:Mh(e- -64|0,c);v[23048]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(2005,b|0,e+8|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;t[e+72|0]=b;S(2060,a|0,e+72|0);a=v[23048];v[23048]=0;if((a|0)!=1){break h}}break j;case 1:Mh(e+56|0,c);v[23048]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=vG(b,e+16|0,d);c=jb;d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;v[e+72>>2]=b;v[e+76>>2]=c;S(2063,a|0,e+72|0);a=v[23048];v[23048]=0;if((a|0)!=1){break h}}break j;case 2:Mh(e+48|0,c);v[23048]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(2007,b|0,e+24|0,d|0);b=v[23048];v[23048]=0;if((b|0)!=1){v[23048]=0;A[e+72>>3]=h;S(2064,a|0,e+72|0);a=v[23048];v[23048]=0;if((a|0)!=1){break h}}break j;case 3:break k;default:break i}}Mh(e+40|0,c);v[23048]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;Y(2008,a|0,b|0,e+32|0,d|0);a=v[23048];v[23048]=0;if((a|0)!=1){break h}}c=P()|0;O()|0;vb(f);break d}Dc(a,f)}vb(f);break f}Jb(a)}gb=e+96|0;return}c=P()|0;O()|0;ca(a|0)}R(c|0)}L()}function Sz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-160|0;gb=g;a:{b:{c:{d:{e:{if(!c){break e}d=v[c+4>>2];if(!d&y[c>>2]>=xb(b)>>>0|d){break e}b=aa(8)|0;v[23048]=0;Q(203,b|0,32397)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break d}a=P()|0;O()|0;ca(b|0);break a}if(!v[b>>2]){b=aa(8)|0;v[23048]=0;U(1314,b|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break c}a=P()|0;O()|0;ca(b|0);break a}d=v[b+4>>2];e=v[b>>2];v[g>>2]=e;v[g+4>>2]=d;v[g+128>>2]=e;v[g+132>>2]=d;d=gb-32|0;gb=d;e=v[g+4>>2];f=v[g>>2];v[d+8>>2]=f;v[d+12>>2]=e;v[d+16>>2]=f;v[d+20>>2]=e;Ch(d+24|0,d+8|0);e=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=e;e=gb-16|0;gb=e;f=v[d+4>>2];h=v[d>>2];v[e>>2]=h;v[e+4>>2]=f;v[e+8>>2]=h;v[e+12>>2]=f;f=gb-16|0;gb=f;h=v[e+4>>2];j=v[e>>2];v[f>>2]=j;v[f+4>>2]=h;v[f+8>>2]=j;v[f+12>>2]=h;h=g+136|0;GF(h,f);gb=f+16|0;gb=e+16|0;v[h+12>>2]=0;gb=d+32|0;f:{g:{if(a&2){d=xn(g+104|0,h);v[23048]=0;e=Q(1315,d|0,c|0)|0;f=v[23048];v[23048]=0;d=1;if((f|0)==1){break f}if((e|0)==1){break g}f=xn(g+80|0,h);v[23048]=0;f=Q(1316,f|0,c|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break b}k=(f|0)==1;if(k){break g}i=xn(g+56|0,h);v[23048]=0;i=Q(1317,i|0,c|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break b}l=(i|0)==1;if(l){break g}j=xn(g+32|0,h);v[23048]=0;j=Q(1318,j|0,c|0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break b}if((j|0)==1){break g}d=(e|0)==-1?-1:0;d=k?d:(f|0)==-1?-1:d;i=(j|0)==-1?-1:l?d:(i|0)==-1?-1:d}if(a&1){a=32400;while(1){d=v[a>>2];if(d){e=xn(g+8|0,h);v[23048]=0;e=Q(d|0,e|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break g}i=(e|0)==-1?-1:i}a=a+12|0;if((a|0)!=32904){continue}break}}if(c){d=0;if((i|0)!=-1){break g}d=Xc(v[c>>2],v[c+4>>2])>>>0>xb(b)>>>0?-1:0;break g}d=0;if((i|0)!=-1){break g}d=xb(b)>>>0>2047?1:-1}gb=g+160|0;return d}break b}ja(b|0,90776,24);L()}ja(b|0,90672,24);L()}a=P()|0;O()|0}R(a|0);L()}function uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;t=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){n=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+t|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){s=(g+8|0)+(f<<2)|0;f=f<<1;v[s>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],q)|0)+B(j,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],w)+B(u[e+(f|-12)>>1],x)|0)+B(u[e+(f|-4)>>1],r)|0)+B(u[e+f>>1],m)|0)/2|0)|0)/16384;s=h&1;h=0;f=1;if(s){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=ac(q,-16777216,16776704);m=v[a+64>>2];i=ac(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=Fpa(l,r,h,h>>31);l=jb;m=Fpa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=Fpa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Lc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);o=e+o|0;l=o>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}l=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=l;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function Zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb+-64|0;gb=c;u[c+62>>1]=b;e=Gi(a);b=e;f=c+48|0;g=Bg(f);a:{if(!b){break a}v[23048]=0;S(850,f|0,b|0);h=v[23048];v[23048]=0;if((h|0)!=1){v[23048]=0;S(1113,f|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;_r(g);R(a|0);L()}b:{c:{if(!e){break c}b=0;while(1){i=sc(f,b),j=b-d|0,u[i>>1]=j;v[23048]=0;g=Q(1112,a|0,b|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break b}d=(x[g>>1]==x[c+62>>1])+d|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}if(!(d&65535)){break c}e=Rb(a);d=Ub(a);b=gb-32|0;gb=b;v[b+16>>2]=d;i=b,j=VB(e,d,c+62|0),v[i+24>>2]=j;d:{if(!Fb(b+24|0,b+16|0)){break d}v[b+8>>2]=v[b+24>>2];if(!Fb(sf(b+8|0),b+16|0)){break d}while(1){if(x[v[b+8>>2]>>1]!=x[c+62>>1]){u[v[b+24>>2]>>1]=x[v[b+8>>2]>>1];sf(b+24|0)}if(Fb(sf(b+8|0),b+16|0)){continue}break}}gb=b+32|0;v[c+32>>2]=v[b+24>>2];b=Sd(c+40|0,c+32|0);i=c,j=Ub(a),v[i+16>>2]=j;e=Sd(c+24|0,c+16|0);b=v[b>>2];d=gb-32|0;gb=d;v[d+16>>2]=v[e>>2];v[d+24>>2]=b;b=a;e=v[b>>2];i=d,j=Rb(b),v[i+8>>2]=j;e=e+(sp(d+24|0,d+8|0)<<1)|0;if(Fb(d+24|0,d+16|0)){pn(b,vg(e+(sp(d+16|0,d+24|0)<<1)|0,v[b+4>>2],e))}Uh(e);gb=d+32|0;i=c,j=Rb(a),v[i+32>>2]=j;i=c,j=Ub(a),v[i+16>>2]=j;if(Fb(c+32|0,c+16|0)){while(1){b=x[v[c+32>>2]>>1];d=v[a+24>>2];v[23048]=0;d=oe(d+484344|0,b);e=v[23048];v[23048]=0;if((e|0)==1){break b}e:{if(!d){break e}b=Yb(v[a+24>>2]+484344|0,b);i=c,j=Rb(b),v[i+8>>2]=j;i=c,j=Ub(b),v[i>>2]=j;if(!Fb(c+8|0,c)){break e}while(1){b=v[c+8>>2];f:{if(w[b+3|0]!=12){break f}d=w[b+5|0];if(uc(f)>>>0<=d>>>0){break f}i=b,j=w[sc(f,w[b+5|0])|0],t[i+5|0]=j}Oj(c+8|0);if(Fb(c+8|0,c)){continue}break}}sf(c+32|0);if(Fb(c+32|0,c+16|0)){continue}break}}b=x[a+28>>1];if(uc(f)>>>0<=b>>>0){break c}i=a,j=x[sc(f,x[a+28>>1])>>1],u[i+28>>1]=j}Ze(f);gb=c- -64|0;return}a=P()|0;O()|0;Ze(f);R(a|0);L()}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=C(0),x=0,y=0,A=C(0),B=0,E=0,F=0,G=C(0);a:{if(!v[a+4276>>2]){break a}j=a+44|0;if(!ei(j)){break a}o=Pd(j,0);p=Pd(j,1);q=qd(j,0);r=qd(j,1);y=kb[v[v[a>>2]+192>>2]](a)|0;e=C(kb[v[v[a>>2]+200>>2]](a));w=C(kb[v[v[a>>2]+188>>2]](a));s=kb[v[v[a>>2]+212>>2]](a)|0;if(d){k=a+4260|0;A=C(e*C(.009999999776482582));B=s&1;n=v[a+4256>>2];f=v[a+4272>>2];E=s>>>0>1;t=d;while(1){i=z[o>>2];l=z[p>>2];h=jo(a,f+n|0);f=jo(a,f);e=z[Mb(k,h)>>2];F=Mb(k,f),G=C(C(A*e)+C(C(l+i)*C(.5))),z[F>>2]=G;b:{if(y){g=z[a+4244>>2];e=C(z[a+4236>>2]+g);z[a+4236>>2]=e;g=C(g+z[a+4240>>2]);z[a+4240>>2]=g;if(!(e<=C(1))){e=C(e+C(-2));z[a+4236>>2]=e}if(!(g<=C(1))){z[a+4240>>2]=g+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));g=C(D(z[a+4240>>2]));g=C(C(g+g)+C(-1));break b}g=z[a+4244>>2];m=z[a+4240>>2];e=C(C(g*m)+z[a+4236>>2]);z[a+4236>>2]=e;g=C(m-C(e*g));z[a+4240>>2]=g}m=z[Mb(k,jo(a,v[a+4280>>2]+v[a+4272>>2]|0))>>2];F=q,G=C(C(C(C(m-i)+C(C(C(z[Mb(k,jo(a,v[a+4284>>2]+v[a+4272>>2]|0))>>2]-m)*C(.000244140625))*C(v[a+4280>>2]&4095)))*w)+i),z[F>>2]=G;i=z[Mb(k,jo(a,v[a+4288>>2]+v[a+4272>>2]|0))>>2];F=r,G=C(C(C(C(i-l)+C(C(C(z[Mb(k,jo(a,v[a+4292>>2]+v[a+4272>>2]|0))>>2]-i)*C(.000244140625))*C(v[a+4288>>2]&4095)))*w)+l),z[F>>2]=G;u=a;n=v[a+4256>>2];f=n;i=z[a+4248>>2];l=C(i*(B?g:e));c:{if(C(D(l))<C(2147483648)){h=~~l;break c}h=-2147483648}x=f+(E?h:0-h|0)|0;v[u+4288>>2]=x;f=s>>>0<4;u=a;e=C(i*e);d:{if(C(D(e))<C(2147483648)){h=~~e;break d}h=-2147483648}f=(f?h:0-h|0)+n|0;v[u+4280>>2]=f;v[a+4292>>2]=x+4096;v[a+4284>>2]=f+4096;p=p+4|0;o=o+4|0;r=r+4|0;q=q+4|0;h=a;f=v[a+4272>>2];if((f|0)<=0){f=f+(v[a+4276>>2]<<12)|0}f=f-4096|0;v[h+4272>>2]=f;t=t-1|0;if(t){continue}break}}si(a,b,c,qd(j,0),qd(j,1),d)}}function vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+s|0;n=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){v[(g+8|0)+(f<<2)>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],q)|0)+B(j,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],w)+B(t[e+(f|-6)|0],x)|0)+B(t[e+(f|-2)|0],r)|0)+B(t[e+f|0],m)<<8)/2|0)|0)/16384;y=h&1;h=0;f=1;if(y){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=ac(q,-16777216,16776704);m=v[a+64>>2];i=ac(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=Fpa(l,r,h,h>>31);l=jb;m=Fpa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=Fpa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Lc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;l=p>>12;v[c>>2]=v[c>>2]+B(l,v[g+8>>2]);o=e+o|0;f=o>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}f=o>>12;l=p>>12}v[a+40>>2]=o;v[a+20>>2]=l;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=f;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=gb-16|0;gb=j;f=EA(a,c);v[j+8>>2]=f;q=j,r=Xg(a),v[q>>2]=r;a:{b:{if(!Xf(j+8|0,j)){break b}if(xR(c,se(j+8|0))){break b}b=se(j+8|0)+8|0;a=b;if(v[b>>2]){zf(a);mR(a);mg(a);zf(a);AA(wb(a),v[a>>2],mg(a));q=wb(a),r=0,v[q>>2]=r;v[a>>2]=0;v[a+4>>2]=0}gp(b,d);v[b>>2]=v[d>>2];v[b+4>>2]=v[d+4>>2];a=wb(d);q=wb(b),r=v[a>>2],v[q>>2]=r;v[a>>2]=0;v[d>>2]=0;v[d+4>>2]=0;break a}m=gb-16|0;gb=m;n=c;h=gb-32|0;gb=h;l=h+20|0;f=h+16|0;i=c;e=gb-32|0;gb=e;v[e+24>>2]=b;g=a;c:{d:{e:{f:{if(!Ck(e+24|0,Cc(e+16|0,rh(a)))){k=wb(g);if(!yl(k,i,se(e+24|0))){break f}}v[e+16>>2]=b;if(!Ck(e+16|0,Cc(e+8|0,lC(g)))){o=wb(g);k=e+16|0;p=k;c=v[k>>2];f=v[c>>2];g:{if(f){c=f;while(1){f=c;c=v[c+4>>2];if(c){continue}break}break g}if(ig(c)){while(1){c=v[c+8>>2];if(ig(c)){continue}break}}f=v[c+8>>2]}v[p>>2]=f;if(!yl(o,se(k),i)){break e}}if(!v[b>>2]){v[l>>2]=b;break c}b=v[e+16>>2];v[l>>2]=b;b=b+4|0;break c}if(!yl(k,se(e+24|0),i)){break d}c=gb-16|0;gb=c;v[c+8>>2]=b;Fj(c+8|0);gb=c+16|0;c=v[c+8>>2];v[e+16>>2]=c;if(!Ck(e+16|0,Cc(e+8|0,rh(g)))){if(!yl(k,i,se(e+16|0))){break e}}if(!v[v[e+24>>2]+4>>2]){v[l>>2]=b;b=b+4|0;break c}v[l>>2]=c;b=c;break c}b=lR(g,l,i);break c}v[l>>2]=b;v[f>>2]=b;b=f}gb=e+32|0;c=b;b=v[b>>2];if(!b){f=gb-16|0;gb=f;b=dc(a);i=Wh(h,kR(),Ij(f+8|0,b));b=v[i>>2];v[23048]=0;b=b+16|0;g=v[23048];v[23048]=0;h:{if((g|0)!=1){g=v[n+4>>2];v[b>>2]=v[n>>2];v[b+4>>2]=g;wb(d);g=Jg(b+8|0);v[b+8>>2]=v[d>>2];v[b+12>>2]=v[d+4>>2];b=wb(d);q=wb(g),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0;q=dc(i),r=1,t[q+4|0]=r;gb=f+16|0;break h}a=P()|0;O()|0;zA(i);R(a|0);L()}tk(a,v[h+20>>2],c,v[h>>2]);b=Bd(h);zA(h)}a=v[Cc(h+24|0,b)>>2];gb=h+32|0;f=v[Cc(m+8|0,a)>>2];gb=m+16|0}gb=j+16|0;return f|0}function P2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=gb-432|0;gb=i;v[i+424>>2]=37;v[i+428>>2]=0;j=Is(i+424|1,84106,v[c+4>>2]);v[i+380>>2]=i+384;a=Be();a:{if(j){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;l=i- -64|0;v[l>>2]=e;v[l+4>>2]=f;v[i+48>>2]=k;a=If(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=If(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2350;k=ge(i+368|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(j){v[23048]=0;a=fa(2371)|0;j=v[23048];v[23048]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[23048]=0;a=ba(2390,i+380|0,a|0,i+424|0,i|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break e}break c}v[23048]=0;a=fa(2371)|0;j=v[23048];v[23048]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[23048]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=ba(2390,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}}e=v[i+380>>2];if(!e){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)==1){break c}break d}Ge(k,e)}e=v[i+380>>2];g=e+a|0;h=Lg(e,g,c);v[i+116>>2]=2350;f=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;e=i+384|0;break g}a=Ad(a<<3);if(!a){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ge(f,a);e=v[i+380>>2]}v[23048]=0;Ic(i+104|0,c);j=v[23048];v[23048]=0;h:{i:{if((j|0)!=1){v[23048]=0;ia(2399,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=v[23048];v[23048]=0;if((e|0)==1){break i}Xb(i+104|0);v[23048]=0;a=la(2400,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break h}Hc(f);Hc(k);gb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Xb(i+104|0);break f}c=P()|0;O()|0}Hc(f);break b}L()}c=P()|0;O()|0}Hc(k);R(c|0);L()}function Z2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=gb-256|0;gb=i;v[i+248>>2]=37;v[i+252>>2]=0;j=Is(i+248|1,84106,v[c+4>>2]);v[i+204>>2]=i+208;a=Be();a:{if(j){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;l=i- -64|0;v[l>>2]=e;v[l+4>>2]=f;v[i+48>>2]=k;a=If(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=If(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2350;k=ge(i+192|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(j){v[23048]=0;a=fa(2371)|0;j=v[23048];v[23048]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[23048]=0;a=ba(2390,i+204|0,a|0,i+248|0,i|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break e}break c}v[23048]=0;a=fa(2371)|0;j=v[23048];v[23048]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[23048]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=ba(2390,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}}e=v[i+204>>2];if(!e){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)==1){break c}break d}Ge(k,e)}e=v[i+204>>2];g=e+a|0;h=Lg(e,g,c);v[i+116>>2]=2350;f=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;e=i+208|0;break g}a=Ad(a<<1);if(!a){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ge(f,a);e=v[i+204>>2]}v[23048]=0;Ic(i+104|0,c);j=v[23048];v[23048]=0;h:{i:{if((j|0)!=1){v[23048]=0;ia(2391,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=v[23048];v[23048]=0;if((e|0)==1){break i}Xb(i+104|0);v[23048]=0;a=la(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break h}Hc(f);Hc(k);gb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Xb(i+104|0);break f}c=P()|0;O()|0}Hc(f);break b}L()}c=P()|0;O()|0}Hc(k);R(c|0);L()}function X5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;d=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}b=(b|0)==1?2:b;if(b>>>0>4|!(1<<b&21)){break a}f=v[c+11e3>>2];j=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}h=(b|0)==4;g=v[c+11004>>2];if(g?!h:0){break a}d=v[c+11008>>2]>0?9:8;v[c+11004>>2]=h|g;if(!(!f|(b|0)!=4)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];b=FJ(c,v[a>>2],e+12|0,b,b,e+8|0,d|4);v[c+43780>>2]=b;d=v[e+12>>2];v[a>>2]=d+v[a>>2];v[a+4>>2]=v[a+4>>2]-d;v[a+8>>2]=d+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];d=-3;if((b|0)<0){break a}if(!b){d=1;break a}v[c+43780>>2]=-1;d=-5;break a}f=v[c+10996>>2];if(!f){i=(b|0)!=4;k=i?d|2:d;h=c+11012|0;b=v[c+10992>>2];while(1){d=v[a+4>>2];v[e+8>>2]=32768-b;v[e+12>>2]=d;f=FJ(c,v[a>>2],e+12|0,h,b+h|0,e+8|0,k);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[c+10996>>2]=b;d=v[a+16>>2];b=b>>>0<d>>>0?b:d;hc(v[a+12>>2],h+v[c+10992>>2]|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];g=v[c+10996>>2]-b|0;v[c+10996>>2]=g;b=b+v[c+10992>>2]&32767;v[c+10992>>2]=b;if((f|0)<0){break b}d=-5;if(j?0:(f|0)==1){break a}if(!i){if(!f){d=g?-5:1;break a}if(v[a+16>>2]){continue}break a}if(f){d=0;if(g|!v[a+4>>2]){break a}if(v[a+16>>2]){continue}break a}break}d=!g;break a}b=v[a+16>>2];b=b>>>0>f>>>0?f:b;hc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2]-b|0;v[c+10996>>2]=a;v[c+10992>>2]=b+v[c+10992>>2]&32767;d=0;if(v[c+43780>>2]){break a}d=!a;break a}d=-3}gb=e+16|0;return d|0}function fg(a,b,c,d,e){var f=0,g=0,h=0;h=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=h;f=x[a+20>>1];b=x[a+70>>1]+(f+x[a+22>>1]|0)|0;b=w[a+79|0]?x[v[a>>2]+3836>>1]+b|0:b;a:{b:{c:{switch(v[a+16>>2]){case 0:c=x[v[a>>2]+3832>>1];c=f+(c&x[a+34>>1]?0:x[a+24>>1]?B((f^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((c>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;u[a+20>>1]=c;if(c<<16>>16>0){break b}v[a+16>>2]=1;u[a+20>>1]=0;break b;case 1:c=x[v[a>>2]+3832>>1];c=f+(c&x[a+46>>1]?0:x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0)|0;u[a+20>>1]=c;g=c<<16>>16;c=x[a+28>>1];if((g|0)<(c|0)){break b}v[a+16>>2]=2;u[a+20>>1]=c;break b;case 2:if(w[a+78|0]){break b}case 3:c=0;g=f;f=x[v[a>>2]+3832>>1];f=g+(f&x[a+58>>1]?0:x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:break c}}c=0;v[a+72>>2]=0;break a}f=b<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(h>>>10|0)+d|0;c=d&255;b=d&65535;d:{e:{switch(x[a+12>>1]){case 0:e=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+28880>>1];break d;case 1:e=0;b=x[((b&512?0:b&256?c^255:c)<<1)+28880>>1];break d;case 2:e=0;b=x[((b&256?c^255:c)<<1)+28880>>1];break d;case 3:e=0;b=x[((b&256?0:c)<<1)+28880>>1];break d;case 4:f:{if(b&512){e=0;b=28880;break f}e=(b&256)>>>8|0;b=(((c<<1^b<<24>>31)&254)<<1)+28880|0}b=x[b>>1];break d;case 5:e=0;if(b&512){b=28880}else{c=c<<1&254;b=((b&128?c^255:c)<<1)+28880|0}b=x[b>>1];break d;case 6:e=(d&512)>>>9|0;b=0;break d;default:break e}}c=d<<3&4088;e=(b&512)>>>9|0;b=e?c^4088:c}u[a+74>>1]=x[a+72>>1];d=a;a=b+f|0;a=(a&65535)>>>0<8191?a:8191;c=0-e^x[((a&255)<<1)+28368>>1]+1024>>>((a&65280)>>>8)<<1;u[d+72>>1]=c}return c<<16>>16}function Oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-32|0;gb=h;l=h,m=qk(b),v[l+16>>2]=m;e=gb-32|0;gb=e;c=b;d=a;b=$d(d);g=dc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+14|0;e:{if(Mu(c,d)){if(!v[b>>2]){break b}g=b;break e}if(!Mu(d,c)){break c}g=b+4|0;if(!v[b+4>>2]){break d}b=g;g=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=g;break a}v[e+28>>2]=b;b=g;break a}b=dc(d)}v[e+28>>2]=b}g=b;b=v[b>>2];t[e+27|0]=0;if(!b){j=gb-16|0;gb=j;b=dc(a);k=Wh(e+8|0,jc(48,4),Ij(j+8|0,b));b=v[k>>2];i=gb-16|0;gb=i;v[i+8>>2]=v[h+16>>2];c=v[i+8>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+14|0]=f;t[b+15|0]=f>>>8;t[b+16|0]=f>>>16;t[b+17|0]=f>>>24;t[b+18|0]=d;t[b+19|0]=d>>>8;t[b+20|0]=d>>>16;t[b+21|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);f=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+38|0]=f;t[b+39|0]=f>>>8;t[b+40|0]=f>>>16;t[b+41|0]=f>>>24;t[b+42|0]=d;t[b+43|0]=d>>>8;t[b+44|0]=d>>>16;t[b+45|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);f=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+30|0]=f;t[b+31|0]=f>>>8;t[b+32|0]=f>>>16;t[b+33|0]=f>>>24;t[b+34|0]=d;t[b+35|0]=d>>>8;t[b+36|0]=d>>>16;t[b+37|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);c=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b+22|0]=c;t[b+23|0]=c>>>8;t[b+24|0]=c>>>16;t[b+25|0]=c>>>24;t[b+26|0]=d;t[b+27|0]=d>>>8;t[b+28|0]=d>>>16;t[b+29|0]=d>>>24;u[b+46>>1]=0;gb=i+16|0;l=dc(k),m=1,t[l+4|0]=m;gb=j+16|0;tk(a,v[e+28>>2],g,v[e+8>>2]);b=Bd(e+8|0);t[e+27|0]=1;g=e+8|0;c=g;a=v[c>>2];v[c>>2]=0;if(a){dc(g);if(a){rT(a)}}}Xh(h+24|0,Cc(e+8|0,b),e+27|0);gb=e+32|0;a=Kl(h+24|0);gb=h+32|0;return a+32|0}function kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;j=c+484344|0;rg(j,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){f=v[a+8>>2];g=_f(a);Vb(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Hd(a)+1|0;break b}c=Fg(a)}d=Fg(a);Rc(a,f+g|0);td(e+24|0,a,d);v[23048]=0;c=W(386,j|0,i&65535,(c?c>>>0<1024?c:1024:64)|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break a}c:{if(!c|!d){break c}c=Yb(j,i);k=e,l=Rb(c),v[k+16>>2]=l;k=e,l=Ub(c),v[k+8>>2]=l;if(!Fb(e+16|0,e+8|0)){break c}while(1){d=v[e+16>>2];v[23048]=0;c=U(373,e+24|0)|0;f=v[23048];v[23048]=0;d:{e:{f:{if((f|0)!=1){if(!(c&128)){break f}if(c&1){v[23048]=0;f=U(373,e+24|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break a}t[d|0]=f}if(c&2){break e}break d}break a}t[d|0]=c;c=255}v[23048]=0;f=U(373,e+24|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break a}t[d+1|0]=f}f=0;if(c&4){v[23048]=0;f=U(373,e+24|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break a}}if(c&8){v[23048]=0;g=U(373,e+24|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}t[d+3|0]=g}if(c&16){v[23048]=0;c=U(373,e+24|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break a}t[d+5|0]=c}c=d;g:{h:{g=w[d|0];if(!g){break h}h=255;if((g|0)==97){break g}if(g>>>0>96){break h}h=g+12|0;break g}h=0}t[c|0]=h;i:{if(w[d+5|0]|w[d+3|0]){v[23048]=0;Mf(d);c=v[23048];v[23048]=0;if((c|0)!=1){break i}break a}t[d+3|0]=0}if(w[d+1|0]==255){t[d+1|0]=0}c=f-16|0;j:{if((c&255)>>>0<=64){t[d+4|0]=c;t[d+2|0]=1;break j}if(f>>>0<96){break j}c=f&15;t[d+4|0]=c;f=f-96>>4;t[d+2|0]=w[f+27343|0];if((f|0)!=6){break j}t[d+4|0]=c<<2}Oj(e+16|0);if(Fb(e+16|0,e+8|0)){continue}break}}yb(e+24|0);i=i+1|0;if(i>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}gb=e+48|0;return}a=P()|0;O()|0;yb(e+24|0);R(a|0);L()}function JS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-32|0;gb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;if(!(b&2)){break a}b=w[a+14|0];if(b>>>0<=w[a+13|0]){break a}if(Lb(a)>>>0<=b>>>0){break a}while(1){d=Ec(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Lb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Lb(a)>>>0<=b>>>0){break a}d=x[Ec(a,w[a+14|0])>>1];e=Ec(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Ec(a,b)>>1]-1&65535;d=cr(a,b,64,64);q=f,r=Rb(a),v[q+8>>2]=r;q=f,r=So(f+8|0,w[a+14|0]),v[q+16>>2]=r;e=Sd(f+24|0,f+16|0);k=tr(f,b,d&255);g=gb-32|0;gb=g;v[g+24>>2]=v[e>>2];b=a;d=v[b>>2];q=g,r=Rb(b),v[q>>2]=r;d=d+(lv(g+24|0,g)<<2)|0;c:{d:{if(y[b+4>>2]<y[wb(b)>>2]){l=v[b+4>>2];if((l|0)!=(d|0)){break d}iW(b,k);break c}e=wb(b);e=Ap(g,Tg(b,Lb(b)+1|0),d-v[b>>2]>>2,e);v[23048]=0;S(1107,e|0,k|0);i=v[23048];v[23048]=0;if((i|0)!=1){ik(b);i=v[e+4>>2];j=e+4|0;Ym(wb(b),v[b>>2],d,j);wb(b);h=d;d=e+8|0;Pl(h,v[b+4>>2],d);mc(b,j);mc(b+4|0,d);mc(wb(b),bc(e));v[e>>2]=v[e+4>>2];ol(b,Lb(b));d=i;Ti(e);break c}a=P()|0;O()|0;Ti(e);R(a|0);L()}m=gb-16|0;gb=m;i=d;j=b;o=v[b+4>>2];b=(o-(d+4|0)|0)+d|0;h=Ug(m,j,l-b>>2);e:{f:{if(b>>>0<l>>>0){e=b;while(1){n=wb(j);p=v[h+4>>2];v[23048]=0;$o(n,p,e);n=v[23048];v[23048]=0;if((n|0)==1){break f}v[h+4>>2]=v[h+4>>2]+4;e=e+4|0;if(l>>>0>e>>>0){continue}break}}_b(h);Sm(i,b,o);gb=m+16|0;break e}a=P()|0;O()|0;_b(h);R(a|0);L()}u[d>>1]=x[k>>1];t[d+2|0]=w[k+2|0]}Uh(d);gb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}gb=f+32|0}function Wda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=gb-144|0;gb=c;e=bm(c+40|0,a);v[23048]=0;d=Q(662,c+24|0,45917)|0;a=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[23048]=0;v[c>>2]=19922997;v[c+4>>2]=0;T(663,e|0,d|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break n}Hb(d);if(v[e>>2]&1073741824){break e}v[23048]=0;d=Q(662,c+24|0,45922)|0;a=v[23048];v[23048]=0;if((a|0)==1){break m}v[23048]=0;ba(1490,e|0,b|0,d|0,1491)|0;a=v[23048];v[23048]=0;if((a|0)==1){break l}Hb(d);v[c+20>>2]=0;v[c+16>>2]=0;v[23048]=0;d=Q(662,c+24|0,45927)|0;a=v[23048];v[23048]=0;if((a|0)==1){break k}v[23048]=0;W(1492,e|0,c+20|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break j}Hb(d);v[23048]=0;d=Q(662,c+24|0,45932)|0;a=v[23048];v[23048]=0;if((a|0)==1){break i}v[23048]=0;W(1492,e|0,c+16|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break h}Hb(d);a=b;d=v[c+16>>2];f=v[c+20>>2];o:{if(!f){break o}if(d>>>0<f>>>0|f>>>0>y[v[no(a)+8>>2]+40>>2]){break o}if(d>>>0>y[v[no(a)+8>>2]+40>>2]){break o}v[a+20>>2]=d;v[a+16>>2]=f}d=Co(c+24|0);v[23048]=0;f=Q(662,c|0,45937)|0;a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;T(1493,e|0,d|0,f|0);a=v[23048];v[23048]=0;if((a|0)==1){break g}Hb(f);if(cd(d)){break f}v[23048]=0;T(1494,d|0,v[c+20>>2],16777216);a=v[23048];v[23048]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;Hb(f);break b}v[23048]=0;S(1495,b|0,d|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}Qc(d)}Yg(e);gb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Qc(d)}Yg(e);R(a|0);L()}function q2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-624|0;gb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2402;b=ge(a+200|0,a+208|0,a+16|0);v[23048]=0;Ic(a+192|0,e);h=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[23048]=0;h=U(2375,a+192|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break k}t[a+191|0]=0;e=v[e+4>>2];v[23048]=0;c=ra(2410,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}if(!c){break e}c=w[84347]|w[84348]<<8|(w[84349]<<16|w[84350]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[84344]|w[84345]<<8|(w[84346]<<16|w[84347]<<24);v[a+176>>2]=w[84340]|w[84341]<<8|(w[84342]<<16|w[84343]<<24);v[a+180>>2]=c;v[23048]=0;Y(2387,h|0,a+176|0,a+186|0,a+128|0);c=v[23048];v[23048]=0;if((c|0)==1){break j}v[a+4>>2]=2350;d=ge(a+8|0,0,a+4|0);h=v[a+196>>2];c=h-v[b>>2]|0;e=a+16|0;if((c|0)<393){break h}Ge(d,Ad((c>>>2|0)+2|0));if(v[d>>2]){break i}v[23048]=0;X(2351);c=v[23048];v[23048]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+191|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+168|0;while(1){j=e,k=w[(a+176|0)+(hx(a+128|0,h,c)-(a+128|0)>>2)|0],t[j|0]=k;e=e+1|0;c=c+4|0;if(c>>>0<y[a+196>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((IH(a+16|0,a)|0)==1){break f}v[23048]=0;_(2404,84324);c=v[23048];v[23048]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Hc(d);break c}Hc(d)}v[23048]=0;c=Q(2381,a+616|0,a+608|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Xb(a+192|0);Hc(b);gb=a+624|0;return c|0}e=P()|0;O()|0}Xb(a+192|0)}Hc(b);R(e|0);L()}L()}function rna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;v[g+24>>2]=d;k=$f(a,c);we(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!k){if(nd(a,5)){break a}}j=v[g+24>>2];d=gb-160|0;gb=d;h=bm(d+56|0,v[a+28>>2]);v[23048]=0;e=Q(662,d+8|0,28226)|0;f=v[23048];v[23048]=0;b:{c:{d:{e:{if((f|0)!=1){v[23048]=0;v[d+48>>2]=19922997;v[d+52>>2]=0;T(663,h|0,e|0,d+48|0);f=v[23048];v[23048]=0;if((f|0)==1){break e}Hb(e);if(!(v[h>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}t[d+48|0]=0;t[d+47|0]=0;v[23048]=0;e=Q(662,d+8|0,28218)|0;f=v[23048];v[23048]=0;f:{if((f|0)!=1){v[23048]=0;T(1123,h|0,d+48|0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break f}Hb(e);if(!w[d+48|0]){break b}Af(d+48|0,50);v[23048]=0;e=Q(662,d+8|0,28234)|0;f=v[23048];v[23048]=0;g:{h:{i:{j:{if((f|0)!=1){v[23048]=0;T(1123,h|0,d+47|0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break j}Hb(e);e=Ei(b);f=w[d+48|0];if(e>>>0<f>>>0){e=UA(d+8|0,v[b+12>>2]);v[23048]=0;T(1124,b|0,f|0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break i}Km(e)}e=0;f=x[Ej(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){while(1){i=e&255;ff(Ej(b,i),f);i=Ej(b,i);v[23048]=0;S(1125,d+8|0,d+7|0);l=v[23048];v[23048]=0;if((l|0)==1){break h}v[23048]=0;Y(1126,h|0,i|0,d+8|0,j|0);i=v[23048];v[23048]=0;if((i|0)==1){break g}Hb(d+8|0);e=e+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];j=Ei(b);t[b+16|0]=e>>>0<j>>>0?w[d+47|0]:0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}a=P()|0;O()|0;Km(e);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(d+8|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e)}Yg(h);R(a|0);L()}Yg(h);gb=d+160|0}Rf(a,k,c,g+16|0);gb=g+32|0}function Rq(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;v[e+12>>2]=u[b+782>>1]+w[b+839|0];v[e+8>>2]=u[b+784>>1]+(w[b+840|0]&127);Vd(e+12|0,0,127);Vd(e+8|0,0,127);m=a+1074308|0;Db(e,m,1);j=Cb(e);i=v[e+12>>2];if(!j){u[b+782>>1]=0;t[b+839|0]=i;j=v[e+8>>2];u[b+784>>1]=0;t[b+840|0]=j}Db(e,m,36);i=B(i,d+256|0);n=(i|0)/256|0;j=Cb(e);l=v[e+8>>2];a:{if(!(l|!j|(i|0)<65024)){n=-1;a=b+790|0;if(!ne(a)){break a}if(ru(a)|x[b+788>>1]|(v[b>>2]|v[b+4>>2])){break a}a=v[b+88>>2];if(a&8192){break a}v[b+88>>2]=a&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;f=re(C(10),C(C(0-l|0)*C(.00937500037252903)));i=gb-16|0;gb=i;h=C(B(v[e+12>>2],d+256|0)>>>0);l=i;d=a;b:{if(v[a+480180>>2]!=33554432){g=C(110);k=C(C(h/(w[d+480209|0]&128?C(10240):C(12288)))+C(.25));break b}g=C(125);k=C(h*C(9227362170349807e-20))}o=l,p=Bi(C(re(C(2),k)*g)),v[o+12>>2]=p;Vd(i+12|0,120,2e4);j=v[i+12>>2];d=v[d+24620>>2];gb=i+16|0;Db(e,m,36);h=C(C(((d|0)<j<<1?d>>>1|0:j)>>>0)*C(6.2831854820251465));c:{if(!(!Cb(e)|v[a+480208>>2]&32768)){g=C(C(y[a+24620>>2])/h);h=C(C(f+C(-1))+C(g*f));z[e>>2]=h;f=C(g*g);break c}g=C(h/C(y[a+24620>>2]));f=C(f+f);z[e>>2]=g*C(C(1)-f);aQ(e,C(2));h=C(C(f-z[e>>2])/g);z[e>>2]=h;f=C(C(1)/C(g*g))}g=C(C(h+C(1))+f);h=C(C(C(f+f)+h)/g);k=C(C(16777216)/g);f=C(C(-f)/g);d:{if(w[b+847|0]==1){o=b,p=Bi(C(C(16777216)-k)),v[o+60>>2]=p;o=b,p=Bi(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Bi(C(f*C(16777216))),v[o+68>>2]=p;a=-1;break d}o=b,p=Bi(k),v[o+60>>2]=p;o=b,p=Bi(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Bi(C(f*C(16777216))),v[o+68>>2]=p;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}gb=e+16|0;return n}function Wma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=gb-48|0;gb=j;a:{if(!Nb(a,1)){break a}d=b;c=nv(d);b:{if(c>>>0<=63){k=gb-32|0;gb=k;c:{h=64-c|0;d:{if(h>>>0<=(v[wb(d)>>2]-v[d+4>>2]|0)/33>>>0){e=gb-16|0;gb=e;c=e;v[c>>2]=d;d=v[d+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+B(h,33);d=v[c+4>>2];if((d|0)!=v[c+8>>2]){while(1){lW(d);d=v[c+4>>2]+33|0;v[c+4>>2]=d;if(v[c+8>>2]!=(d|0)){continue}break}}_b(c);gb=e+16|0;break d}l=wb(d);e=k+8|0;c=d;i=nv(c)+h|0;f=gb-16|0;gb=f;v[f+12>>2]=i;g=gb-16|0;gb=g;v[g+12>>2]=130150524;v[23048]=0;v[g+8>>2]=2147483647;m=Gb(g+12|0,g+8|0);n=v[23048];v[23048]=0;e:{if((n|0)!=1){gb=g+16|0;g=v[m>>2];break e}V(0)|0;O()|0;Ab();L()}f:{if(g>>>0>=i>>>0){c=kW(c);if(c>>>0<g>>>1>>>0){v[f+8>>2]=c<<1;g=v[Jc(f+8|0,f+12|0)>>2]}gb=f+16|0;break f}Mc();L()}i=nv(d);f=0;c=gb-16|0;gb=c;v[c+12>>2]=0;vd(e+12|0,l);if(g){if(g>>>0>=130150525){xc(19375);L()}f=jc(B(g,33),1)}v[e>>2]=f;i=B(i,33)+f|0;v[e+8>>2]=i;v[e+4>>2]=i;o=bc(e),p=B(g,33)+f|0,v[o>>2]=p;gb=c+16|0;v[23048]=0;oW(e,h);c=v[23048];v[23048]=0;if((c|0)==1){break c}c=e+4|0;h=v[d>>2];f=v[d+4>>2]-h|0;g=v[c>>2]+B((f|0)/-33|0,33)|0;v[c>>2]=g;if((f|0)>=1){hc(g,h,f)}zc(d,c);zc(d+4|0,e+8|0);zc(wb(d),bc(e));v[e>>2]=v[e+4>>2];nW(e)}gb=k+32|0;break b}a=P()|0;O()|0;nW(e);R(a|0);L()}if((c|0)!=64){Hj(d,v[d>>2]+2112|0)}}f=Hd(a);if(!f){break a}while(1){f=f-1|0;c=gb-32|0;gb=c;g=j+8|0;qC(c+24|0,g);e=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=a;fc(c+16|0,d,c);h=xb(c+16|0);if((h|0)==(e|0)){Vb(d,xb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){lW(g)}g:{if(!d){break g}d=w[j+8|0];if(d>>>0>63){break g}hc(qW(b,d),j+8|0,33)}if(f&255){continue}break}}gb=j+48|0}function y2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2402;b=ge(a+152|0,a+160|0,a+16|0);v[23048]=0;Ic(a+144|0,e);h=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[23048]=0;h=U(21,a+144|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break k}t[a+143|0]=0;e=v[e+4>>2];v[23048]=0;c=ra(2403,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}if(!c){break e}c=w[84347]|w[84348]<<8|(w[84349]<<16|w[84350]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[84344]|w[84345]<<8|(w[84346]<<16|w[84347]<<24);v[a+128>>2]=w[84340]|w[84341]<<8|(w[84342]<<16|w[84343]<<24);v[a+132>>2]=c;v[23048]=0;Y(2366,h|0,a+128|0,a+138|0,a+118|0);c=v[23048];v[23048]=0;if((c|0)==1){break j}v[a+4>>2]=2350;d=ge(a+8|0,0,a+4|0);h=v[a+148>>2];e=a+16|0;if((h-v[b>>2]|0)<99){break h}Ge(d,Ad((h-v[b>>2]|0)+2|0));if(v[d>>2]){break i}v[23048]=0;X(2351);c=v[23048];v[23048]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+143|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+128|0;while(1){j=e,k=w[((ho(a+118|0,h,c)-a|0)+a|0)+10|0],t[j|0]=k;e=e+1|0;c=c+1|0;if(c>>>0<y[a+148>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((IH(a+16|0,a)|0)==1){break f}v[23048]=0;_(2404,84324);c=v[23048];v[23048]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Hc(d);break c}Hc(d)}v[23048]=0;c=Q(2353,a+280|0,a+272|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Xb(a+144|0);Hc(b);gb=a+288|0;return c|0}e=P()|0;O()|0}Xb(a+144|0)}Hc(b);R(e|0);L()}L()}function yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;q=v[a+16>>2];e=v[a+44>>2];v[f+32>>2]=e;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;n=v[a+56>>2];v[f+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;if(d){while(1){n=1;i=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];t=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];k=0;e=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[i+(h|8)>>1],o)+B(u[i+(h|4)>>1],l)|0)+B(u[i+(h|12)>>1],m)|0)+B(j,u[i+(h|16)>>1])|0)/2|0)+((((B(u[i+(h|-8)>>1],w)+B(u[i+(h|-12)>>1],x)|0)+B(u[i+(h|-4)>>1],t)|0)+B(u[i+h>>1],p)|0)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];m=v[a+60>>2];o=m;h=(f+32|0)+(k<<3)|0;k=v[h>>2];e=ac(k,-16777216,16776704);l=v[a+64>>2];i=ac(v[h+4>>2],-16777216,16776704);p=m>>31;m=g<<8;g=m;g=Fpa(o,p,g,g>>31);o=jb;l=Fpa(l,l>>31,e,e>>31);g=l+g|0;e=jb+o|0;e=g>>>0<l>>>0?e+1|0:e;p=g;g=v[a+68>>2];g=Fpa(g,g>>31,i,i>>31);i=p+g|0;e=jb+e|0;e=i>>>0<g>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Lc(i,e,24);v[h+4>>2]=k;i=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(i&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];n=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];e=v[f+32>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function iN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){if(!ig(d)){while(1){d=v[d+8>>2];if(!ig(d)){continue}break}}d=v[d+8>>2];break c}d=PV(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(ig(d)){v[v[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=v[d+8>>2]+4|0;break e}v[v[d+8>>2]+4>>2]=e;c=v[d+8>>2]}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){v[d+8>>2]=v[b+8>>2];f:{if(ig(b)){f=v[d+8>>2];break f}f=v[d+8>>2]+4|0}v[f>>2]=d;f=v[b>>2];v[d>>2]=f;tm(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){tm(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=ig(c);d=w[c+12|0];g:{h:{if(!b){if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;yr(v[c+8>>2]);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];i:{if(!(w[b+12|0]?0:b)){b=v[c+4>>2];if(w[b+12|0]?0:b){break i}t[c+12|0]=0;j:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break j}a=b}t[a+12|0]=1;return}if(!ig(b)){break h}b=v[b+8>>2]+4|0;break g}a=v[c+4>>2];if(w[a+12|0]?0:a){break i}t[b+12|0]=1;t[c+12|0]=0;xr(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;yr(v[c+8>>2]);return}if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;xr(v[c+8>>2]);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];k:{if(w[d+12|0]?0:d){break k}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(ig(b)){b=v[b+8>>2]+4|0;break g}b=v[b+8>>2];break g}if(w[d+12|0]?0:d){break k}t[b+12|0]=1;t[c+12|0]=0;yr(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;xr(v[c+8>>2]);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function s7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;g=nc(a);a=b+24|0;f=Qb(v[a>>2]+484360|0);v[23048]=0;h=Gi(f);f=v[23048];v[23048]=0;a:{b:{c:{if((f|0)==1){break c}v[23048]=0;S(1436,g|0,h|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}d:{e:{if(h){f=0;while(1){c=x[sc(Qb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[23048]=0;d=Ul(d+484344|0,c);i=v[23048];v[23048]=0;if((i|0)==1){break b}f:{if(d){c=Yb(v[a>>2]+484344|0,x[sc(Qb(v[a>>2]+484360|0),f)>>1]);v[23048]=0;S(2101,e|0,c|0);c=v[23048];v[23048]=0;g:{h:{i:{if((c|0)!=1){v[23048]=0;T(2095,e+16|0,b|0,e|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}v[23048]=0;S(1438,g|0,e+16|0);c=v[23048];v[23048]=0;if((c|0)==1){break h}vb(e+16|0);vb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(e+16|0)}vb(e);break a}v[23048]=0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if((c|0)==65534){v[23048]=0;c=Q(91,e+16|0,57013)|0;d=v[23048];v[23048]=0;j:{if((d|0)!=1){v[23048]=0;S(1438,g|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break j}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[23048]=0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if((c|0)==65535){v[23048]=0;c=Q(91,e+16|0,57022)|0;d=v[23048];v[23048]=0;k:{if((d|0)!=1){v[23048]=0;S(1438,g|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break k}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[23048]=0;c=Q(91,e+16|0,57031)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}v[23048]=0;S(1438,g|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}vb(c)}f=f+1|0;if((h|0)!=(f|0)){continue}break}}gb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(g);R(a|0);L()}function Eea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=gb-48|0;gb=g;h=xi(b)^-1;a:{if(Lb(d)>>>0<=h>>>0){_t(a);break a}xi(b);if((w[c+4|0]|w[c+5|0]<<8)>>>0>=60){Vb(b,4)}k=g,l=xi(b),v[k+44>>2]=l;Vb(b,4);i=xi(b);j=xi(b);if(!((j|0)>36?(i|0)>=1:0)){_t(a);break a}b:{if(!f){break b}if(!Br(Id(e,v[Mb(d,h)>>2]),f)){break b}_t(a);break a}Bw(g+24|0,b,j,i);v[23048]=0;b=U(328,g+24|0)|0;d=v[23048];v[23048]=0;c:{if((d|0)==1){break c}d:{e:{if(!b){v[23048]=0;U(1442,a|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break e}break c}if((w[c+4|0]|w[c+5|0]<<8)>>>0<=39){v[23048]=0;Q(370,g+24|0,8)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}}if((w[c+4|0]|w[c+5|0]<<8)>>>0<=59){v[23048]=0;Q(370,g+24|0,16)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}}v[23048]=0;U(1434,g+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}f:{if((w[c+4|0]|w[c+5|0]<<8)>>>0>=120){v[23048]=0;U(1434,g+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;Q(370,g+24|0,8)|0;break f}if((w[c+4|0]|w[c+5|0]<<8)>>>0>=100){v[23048]=0;Q(370,g+24|0,4)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;U(1434,g+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;Q(370,g+24|0,4)|0;break f}if((w[c+4|0]|w[c+5|0]<<8)>>>0>=62){v[23048]=0;U(1434,g+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;Q(370,g+24|0,4)|0;break f}v[23048]=0;U(1434,g+24|0)|0}b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;b=U(1434,g+24|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break d}v[23048]=0;T(341,g|0,g+24|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}Lk(a,g);v[a+20>>2]=v[g+44>>2];yb(g)}yb(g+24|0);break a}}a=P()|0;O()|0;yb(g+24|0);R(a|0);L()}gb=g+48|0}function dz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}t[a|0]=1;t[f+15|0]=64;i=b,j=w[$b(b,f+15|0)|0],t[i|0]=j;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=12;e=1;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=13;e=1;break a}g=w[b|0];if(g>>>0<240){d=0;while(1){h=w[d+33824|0];m:{n:{if(c){if(g>>>0<=h>>>0){break n}break m}if((g|0)!=(h|0)){break m}}t[a|0]=11;t[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;e=1;break a}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;e=1;break a}e=0;c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;e=1;break a}g=c&240;if(!g){t[a|0]=4;e=1;break a}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;e=1;break a}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;e=1;break a}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break a}r:{if(c){t[b|0]=0;break r}e=0;if(w[b|0]){break a}}t[a|0]=8;e=1;break a}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;d=w[$b(f+14|0,f+13|0)|0];break s}e=0;d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8;e=1}gb=f+16|0;return e}function Rx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:while(1){g=b-4|0;b:while(1){d=a;c:while(1){d:{e:{f:{g:{h:{i:{j:{k:{a=b-d|0;e=a>>2;switch(e|0){case 4:break j;case 2:break k;case 0:case 1:break d;case 3:break g;case 5:break i;default:break h}}if(!Nd(g,d)){break d}mc(d,g);return}Qx(d,d+4|0,d+8|0,g);return}Px(d,d+4|0,d+8|0,d+12|0,g);return}if((a|0)<=123){f=gb-16|0;gb=f;e=d;c=d+8|0;Un(d,d+4|0,c);a=d+12|0;g=b;if((a|0)!=(g|0)){while(1){b=a;if(Nd(a,c)){v[f+12>>2]=v[b>>2];d=b;while(1){l:{a=c;v[d>>2]=v[a>>2];if((a|0)==(e|0)){a=e;break l}d=a;c=d-4|0;if(Nd(f+12|0,c)){continue}}break}v[a>>2]=v[f+12>>2]}c=b;a=b+4|0;if((g|0)!=(a|0)){continue}break}}gb=f+16|0;return}h=((e|0)/2<<2)+d|0;m:{if((a|0)>=3997){a=(e|0)/4<<2;i=Px(d,a+d|0,h,a+h|0,g);break m}i=Un(d,h,g)}a=g;if(!Nd(d,h)){while(1){a=a-4|0;if((d|0)==(a|0)){f=d+4|0;if(Nd(d,g)){break e}if((f|0)==(g|0)){break d}while(1){if(Nd(d,f)){mc(f,g);f=f+4|0;break e}f=f+4|0;if((g|0)!=(f|0)){continue}break}break d}if(!Nd(a,h)){continue}break}mc(d,a);i=i+1|0}e=d+4|0;if(e>>>0>=a>>>0){break f}while(1){f=e;e=e+4|0;if(Nd(f,h)){continue}while(1){a=a-4|0;if(!Nd(a,h)){continue}break}if(a>>>0<f>>>0){e=f;break f}else{mc(f,a);h=(f|0)==(h|0)?a:h;i=i+1|0;continue}}}Un(d,d+4|0,g);break d}n:{if((e|0)==(h|0)){break n}if(!Nd(h,e)){break n}mc(e,h);i=i+1|0}if(!i){f=WI(d,e);a=e+4|0;if(WI(a,b)){b=e;a=d;if(!f){continue a}break d}if(f){continue b}}if((e-d|0)<(b-e|0)){Rx(d,e,c);a=e+4|0;continue b}Rx(e+4|0,b,c);b=e;a=d;continue a}a=g;if((f|0)==(a|0)){break d}while(1){e=f;f=e+4|0;if(!Nd(d,e)){continue}while(1){a=a-4|0;if(Nd(d,a)){continue}break}if(a>>>0<=e>>>0){d=e;continue c}else{mc(e,a);continue}}}break}break}break}}
function g2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=gb-16|0;gb=x;v[c>>2]=a;A=d&512;while(1){a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];p=gn(g,32);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 3:if(hd(n)){break a}p=w[pc(n,0)|0];q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 2:if(hd(m)|!A){break a}C=c,D=Hi(Ld(m),hf(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=h?e+1|0:e;r=e;c:{if(e>>>0>=f>>>0){break c}while(1){if(!fh(g,2048,t[r|0])){break c}r=r+1|0;if((r|0)!=(f|0)){continue}break}r=f}if((o|0)>=1){p=o;q=p;d:{if(e>>>0<r>>>0){while(1){e:{r=r-1|0;q=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=q;q=p-1|0;s=(p|0)<2;if(s){break e}p=q;if(e>>>0<r>>>0){continue}}break}u=0;p=0;if(s){break d}}u=gn(g,48);p=q}if((p|0)>=1){while(1){q=v[c>>2];v[c>>2]=q+1;t[q|0]=u;q=(p|0)>1;p=p-1|0;if(q){continue}break}}p=v[c>>2];v[c>>2]=p+1;t[p|0]=j}f:{if((e|0)==(r|0)){p=gn(g,48);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break f}q=-1;g:{if(hd(l)){break g}q=t[pc(l,0)|0]}u=0;p=0;while(1){s=p+1|0;h:{if((p|0)!=(q|0)){break h}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;u=u+1|0;if(Bb(l)>>>0>u>>>0){if(w[pc(l,u)|0]==127){q=-1;s=1;break h}q=t[pc(l,u)|0]}s=1}p=s;r=r-1|0;s=w[r|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=s;if((e|0)!=(r|0)){continue}break}}fm(B,v[c>>2])}y=y+1|0;if((y|0)!=4){continue}break}if(Bb(n)>>>0>1){C=x,D=Ld(n),v[C+8>>2]=D;e=gb-16|0;gb=e;v[e+8>>2]=v[x+8>>2];v[e+8>>2]=v[e+8>>2]+1;gb=e+16|0;C=c,D=Hi(v[e+8>>2],hf(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=x+16|0}function a2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;x=gb-16|0;gb=x;v[c>>2]=a;A=d&512;while(1){a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=Ss(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 3:if(hd(n)){break a}q=v[ck(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 2:if(hd(m)|!A){break a}D=c,E=Hi(Ld(m),mi(m),v[c>>2]),v[D>>2]=E;break a;case 4:break b;default:break a}}B=v[c>>2];e=h?e+4|0:e;s=e;c:{if(e>>>0>=f>>>0){break c}while(1){if(!bl(g,2048,v[s>>2])){break c}s=s+4|0;if(s>>>0<f>>>0){continue}break}}if((o|0)>=1){d:{e:{if(e>>>0>=s>>>0){q=o;break e}r=v[c>>2];q=o;while(1){f:{s=s-4|0;v[r>>2]=v[s>>2];p=q;q=p-1|0;r=r+4|0;if((p|0)<2){break f}if(e>>>0<s>>>0){continue}}break}v[c>>2]=r;if((p|0)>1){break e}r=v[c>>2];break d}p=Ss(g,48);r=v[c>>2];while(1){v[r>>2]=p;r=r+4|0;u=(q|0)>1;q=q-1|0;if(u){continue}break}}v[c>>2]=r+4;v[r>>2]=j}g:{if((e|0)==(s|0)){q=Ss(g,48);p=v[c>>2];u=p+4|0;v[c>>2]=u;v[p>>2]=q;break g}p=-1;h:{if(hd(l)){break h}p=t[pc(l,0)|0]}r=0;q=0;while(1){u=q+1|0;i:{if((q|0)!=(p|0)){break i}q=v[c>>2];v[c>>2]=q+4;v[q>>2]=k;r=r+1|0;if(Bb(l)>>>0>r>>>0){if(w[pc(l,r)|0]==127){p=-1;u=1;break i}p=t[pc(l,r)|0]}u=1}q=u;s=s-4|0;C=v[s>>2];z=v[c>>2];u=z+4|0;v[c>>2]=u;v[z>>2]=C;if((e|0)!=(s|0)){continue}break}}Gs(B,u)}y=y+1|0;if((y|0)!=4){continue}break}if(Bb(n)>>>0>1){D=x,E=Ld(n),v[D+8>>2]=E;e=gb-16|0;gb=e;v[e+8>>2]=v[x+8>>2];Ag(e+8|0);gb=e+16|0;D=c,E=Hi(v[e+8>>2],mi(n),v[c>>2]),v[D>>2]=E}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=x+16|0}function Mha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}s=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=(j>>>16&65520)+p|0;f=u[b>>1];e=(e<<1)+s|0;j=u[e-6>>1];i=u[b+2>>1];n=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];r=v[a+60>>2];b=ac(m,-16777216,16776704);o=v[a+64>>2];g=ac(g,-16777216,16776704);b=Fpa(o,o>>31,b,b>>31);o=jb;q=b;j=(((((((B(i,n)+B(f,j)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=j;f=Fpa(r,r>>31,b,b>>31);e=q+f|0;b=jb+o|0;b=e>>>0<f>>>0?b+1|0:b;q=e;e=v[a+68>>2];e=Fpa(e,e>>31,g,g>>31);g=q+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);g=v[a+72>>2];e=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;n=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,n);k=e+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,i);b=b-(g&j)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;q=v[a+16>>2];h=v[a+44>>2];v[g+32>>2]=h;e=v[a+48>>2];v[g+36>>2]=e;k=v[a+52>>2];v[g+40>>2]=k;n=v[a+56>>2];v[g+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];i=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=i;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;if(d){while(1){f=(((i&2147483647)<<1|j>>>31)&-2)+q|0;n=1;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];w=u[e+28>>1];x=u[e+26>>1];y=u[e+24>>1];k=0;e=1;h=0;while(1){v[(g+8|0)+(h<<2)>>2]=(((((B(t[f+(h|4)|0],o)+B(t[f+(h|2)|0],l)|0)+B(t[f+(h|6)|0],m)|0)+B(j,t[f+(h|8)|0])<<8)/2|0)+((((B(t[f+(h|-4)|0],x)+B(t[f+(h|-6)|0],y)|0)+B(t[f+(h|-2)|0],w)|0)+B(t[h+f|0],p)<<8)/2|0)|0)/16384;i=e;e=0;h=1;if(i){continue}break}while(1){j=(g+8|0)+(k<<2)|0;f=v[j>>2];m=v[a+60>>2];o=m;i=(g+32|0)+(k<<3)|0;k=v[i>>2];e=ac(k,-16777216,16776704);l=v[a+64>>2];h=ac(v[i+4>>2],-16777216,16776704);p=m>>31;m=f<<8;f=m;f=Fpa(o,p,f,f>>31);o=jb;l=Fpa(l,l>>31,e,e>>31);f=l+f|0;e=jb+o|0;e=f>>>0<l>>>0?e+1|0:e;l=f;f=v[a+68>>2];f=Fpa(f,f>>31,h,h>>31);h=l+f|0;e=jb+e|0;e=h>>>0<f>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Lc(h,e,24);v[i+4>>2]=k;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[i>>2]=e-(h&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],r);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];i=v[g+28>>2];continue}break}j=v[g+24>>2];i=v[g+28>>2];n=v[g+44>>2];k=v[g+40>>2];h=v[g+32>>2];e=v[g+36>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=e;v[a+44>>2]=h;v[a>>2]=j;v[a+4>>2]=i;gb=g+48|0}
function a_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-80|0;gb=d;yc(b);ps(a);a:{if(!dh(b,d+72|0)){break a}if(!lF(d+72|0)){break a}b:{if(!c){break b}if(!Nb(b,4)){break a}Hw(a);Gw(d+48|0);Fw(Yi(a)+32|0,d+48|0);os(d+48|0);i=v[Yi(a)+32>>2];c=Pk(b);if(c&1){break a}g=c-4|0;Rc(b,g);c=Hd(b);h=Hd(b)<<8|c<<16|Hd(b);if(!h){break a}v[23048]=0;S(324,i|0,h|0);c=v[23048];v[23048]=0;c:{if((c|0)==1){a=V(90496)|0;if((O()|0)!=(da(90496)|0)){break c}Z(a|0)|0;$();break a}Rc(b,4);kF(d+48|0,b);b=v[d+48>>2];j=zb(v[i>>2]);f=gb-32|0;gb=f;t[f+24|0]=w[b|0];t[f+25|0]=w[b+1|0];t[f+26|0]=w[b+2|0];t[f+27|0]=w[b+3|0];c=jF(f+8|0);e=b+g|0;v[c+12>>2]=e-4;v[c+8>>2]=b;Rj(c,w[e-1|0]);b=h;while(1){d:{if(!Rj(c,1)){v[f+4>>2]=1;while(1){e=Rj(c,2);v[f+4>>2]=e+v[f+4>>2];if((e|0)==3){continue}break}tc(f+4|0,b);e:{if(!v[f+4>>2]){break e}e=1;while(1){b=b-1|0;n=j+b|0,o=Rj(c,8),t[n|0]=o;if(y[f+4>>2]<=e>>>0){break e}e=e+1|0;continue}}if(!b){break d}}e=Rj(c,2);v[f+4>>2]=e+2;f:{if((e|0)==3){e=c;g=7;g:{if(!Rj(c,1)){break g}g=w[lc(f+24|0,3)|0]}g=Rj(e,g);while(1){e=Rj(c,3);v[f+4>>2]=e+v[f+4>>2];if((e|0)==7){continue}break}break f}g=Rj(c,w[lc(f+24|0,e)|0])}tc(f+4|0,b);k=0;l=v[f+4>>2];if(l){while(1){e=0;m=b+g|0;if(h>>>0>m>>>0){e=w[j+m|0]}b=b-1|0;t[j+b|0]=e;k=k+1|0;if((l|0)!=(k|0)){continue}break}}if(b){continue}}break}gb=f+32|0;me(d+32|0,i);b=v[d+36>>2];v[d+16>>2]=v[d+32>>2];v[d+20>>2]=b;Ch(d+40|0,d+16|0);b=Xd(d+24|0);v[23048]=0;c=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=c;c=W(254,d+48|0,d+8|0,b|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){id(Yi(a)+12|0,c);yb(c);Bc(b);break b}a=P()|0;O()|0;Bc(b)}R(a|0);L()}e=1}gb=d+80|0;return e|0}function Nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}r=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=e+r|0;f=t[b+4|0];e=(j>>>16&65520)+p|0;j=u[e+14>>1];i=t[b+3|0];o=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=ac(m,-16777216,16776704);n=v[a+64>>2];g=ac(g,-16777216,16776704);b=Fpa(n,n>>31,b,b>>31);n=jb;J=b;b=v[a+68>>2];q=Fpa(b,b>>31,g,g>>31);g=J+q|0;b=jb+n|0;b=g>>>0<q>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,o)|0)+B(f,j)<<8)/32768<<8;f=Fpa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);g=v[a+72>>2];j=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;o=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,o);k=j+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,i);b=b-(g&e)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function tZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;yc(c);a:{if(!Nb(c,3)){break a}while(1){wp(f+8|0,c);i=rd(f+8|0);d=Df(f+8|0);g=f+8|0;if(y[a+12>>2]<=w[g|0]){break a}e=Wc(a,w[g|0],b);h=w[i|0];b:{if(h>>>0<=126){if(!(h|w[d|0])){t[e|0]=254;break b}t[e|0]=h+1;if(w[d|0]==255){break b}if(!w[e+1|0]){t[e+1|0]=j}t[e+2|0]=1;t[e+4|0]=w[d|0];break b}c:{switch(h-127|0){case 0:d=w[g|0]+t[d|0]|0;if((d|0)<0|(d|0)>=v[a+12>>2]<<16>>16){break b}d=Wc(a,d,b);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[e|0]=g;t[e+1|0]=g>>>8;t[e+2|0]=g>>>16;t[e+3|0]=g>>>24;d=w[d+4|0]|w[d+5|0]<<8;t[e+4|0]=d;t[e+5|0]=d>>>8;break b;case 1:j=w[d|0]+1|0;t[e+1|0]=j;break b;default:break c}}d=t[d|0];t[f+7|0]=d;g=0;h=h&127;if(h>>>0<=23){g=w[h+16688|0]}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{h=w[i|0];switch((h&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break e}}if((d|0)>-1){break f}d=0-d&15;break e}t[f+6|0]=64;d=w[$b(f+7|0,f+6|0)|0];if(w[e+2|0]>1){break e}t[e+4|0]=d;t[e+2|0]=1;break b}if((d|0)>-1){g=3;break d}d=0-d&127;t[f+7|0]=d;break e}if(!d){break b}if((d|0)<=-1){d=0-d|-16;t[f+7|0]=d;break e}d=d<<4|15;t[f+7|0]=d;break e}if(!d){break b}g=(d|0)>-1;if(!g){d=0-d&15;t[f+7|0]=d;h=w[i|0]}g=g?3:2;d=((h|0)==22?-32:-16)|d;t[f+7|0]=d;break d}d=d&15|-48;t[f+7|0]=d;break e}d=d&15|-64;t[f+7|0]=d;break e}d=d- -64&127;if(!w[e+3|0]){break e}o:{switch(w[e+2|0]){case 0:case 2:break o;default:break b}}t[e+2|0]=2;t[e+4|0]=d>>>1;break b}d=d<<4}if(!(g&255)){break b}}t[e+5|0]=d;t[e+3|0]=g}if(Nb(c,3)){continue}break}}gb=f+16|0}function lpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Jb(a);j=Bb(b);v[23048]=0;S(499,f|0,j|0);a=v[23048];v[23048]=0;a:{b:{c:{d:{if((a|0)!=1){if(!j){break d}a=0;e:{while(1){d=t[pc(b,e)|0];h=d&255;f:{g:{switch(a+1|0){case 1:a=1;h:{switch(h-123|0){case 2:a=3;break f;case 0:break f;default:break h}}a=0;v[23048]=0;W(500,f|0,1,d|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break f}break e;case 2:i:{switch(h-123|0){case 0:a=0;v[23048]=0;W(500,f|0,1,123)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}break f;case 2:l=1;d=g+1|0;a=0;if(wu(c)>>>0<=g>>>0){g=d;break f}v[23048]=0;g=Eo(c,g);a=v[23048];v[23048]=0;if((a|0)!=1){a=0;v[23048]=0;Q(502,f|0,g|0)|0;h=v[23048];v[23048]=0;g=d;if((h|0)!=1){break f}}e=P()|0;O()|0;break b;default:break i}}a=-1;d=d-48|0;if((d&255)>>>0>9){break f}k=1;a=2;i=d;break f;case 3:a=-1;j:{switch(h-123|0){case 2:a=0;if(wu(c)>>>0<=i>>>0){break f}v[23048]=0;d=Eo(c,i);a=v[23048];v[23048]=0;if((a|0)!=1){a=0;v[23048]=0;Q(502,f|0,d|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break f}}e=P()|0;O()|0;break b;case 0:break f;default:break j}}if((d-48&255)>>>0>9){break f}i=(d+B(i,10)|0)-48|0;k=1;a=2;break f;case 4:a=-1;if((d|0)!=125){break f}a=0;v[23048]=0;W(500,f|0,1,125)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}break f;case 0:break g;default:break f}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break}e=k&l;a=(a|0)!=0;break c}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}a=0}if(!(a|e&1)){return}a=aa(8)|0;v[23048]=0;U(83,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){v[23048]=0;T(84,a|0,1932,24);a=v[23048];v[23048]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;ca(a|0)}vb(f);R(e|0)}L()}function Dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Jb(a);j=Bb(b);v[23048]=0;S(79,f|0,j|0);a=v[23048];v[23048]=0;a:{b:{c:{d:{if((a|0)!=1){if(!j){break d}a=0;e:{while(1){d=t[pc(b,e)|0];h=d&255;f:{g:{switch(a+1|0){case 1:a=1;h:{switch(h-123|0){case 2:a=3;break f;case 0:break f;default:break h}}a=0;v[23048]=0;W(80,f|0,1,d|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break f}break e;case 2:i:{switch(h-123|0){case 0:a=0;v[23048]=0;W(80,f|0,1,123)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}break f;case 2:l=1;d=g+1|0;a=0;if(wu(c)>>>0<=g>>>0){g=d;break f}v[23048]=0;g=Eo(c,g);a=v[23048];v[23048]=0;if((a|0)!=1){a=0;v[23048]=0;Q(82,f|0,g|0)|0;h=v[23048];v[23048]=0;g=d;if((h|0)!=1){break f}}e=P()|0;O()|0;break b;default:break i}}a=-1;d=d-48|0;if((d&255)>>>0>9){break f}k=1;a=2;i=d;break f;case 3:a=-1;j:{switch(h-123|0){case 2:a=0;if(wu(c)>>>0<=i>>>0){break f}v[23048]=0;d=Eo(c,i);a=v[23048];v[23048]=0;if((a|0)!=1){a=0;v[23048]=0;Q(82,f|0,d|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break f}}e=P()|0;O()|0;break b;case 0:break f;default:break j}}if((d-48&255)>>>0>9){break f}i=(d+B(i,10)|0)-48|0;k=1;a=2;break f;case 4:a=-1;if((d|0)!=125){break f}a=0;v[23048]=0;W(80,f|0,1,125)|0;d=v[23048];v[23048]=0;if((d|0)==1){break e}break f;case 0:break g;default:break f}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break}e=k&l;a=(a|0)!=0;break c}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}a=0}if(!(a|e&1)){return}a=aa(8)|0;v[23048]=0;U(83,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){v[23048]=0;T(84,a|0,1932,24);a=v[23048];v[23048]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;ca(a|0)}vb(f);R(e|0)}L()}function Ls(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Tq(c,d);v[i+4>>2]=2350;n=yH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ad(k);if(!j){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)!=1){break a}break b}Ge(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!hd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[23048]=0;h=Q(2352,a|0,i+120|0)|0;b=v[23048];v[23048]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[23048]=0;b=Q(2353,a|0,i+120|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Hc(n);gb=i+128|0;return d|0}break b}v[23048]=0;p=U(2354,a|0)|0;b=v[23048];v[23048]=0;f:{if((b|0)!=1){if(g){break f}v[23048]=0;p=Q(2355,e|0,p|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=t[pc(h,r)|0];h:{if(g){break h}v[23048]=0;q=Q(2355,e|0,q<<24>>24)|0;u=v[23048];v[23048]=0;if((u|0)!=1){break h}break b}i:{if((p&255)==(q&255)){s=1;if((Bb(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[23048]=0;U(2356,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Bb(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Hc(n);R(a|0)}L()}function _ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;g=v[a+52>>2];v[b+40>>2]=g;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){m=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+r|0;h=j>>>21&2040;j=u[h+40886>>1];i=u[h+40884>>1];k=u[h+40882>>1];p=u[h+40880>>1];h=0;g=1;f=0;while(1){q=(b+8|0)+(f<<2)|0;f=f<<1;v[q>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],p)|0)+B(i,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;l=g&1;g=0;f=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;g=v[j>>2];i=v[a+60>>2];k=i;h=(b+32|0)+(h<<3)|0;p=v[h>>2];e=ac(p,-16777216,16776704);l=v[a+64>>2];f=ac(v[h+4>>2],-16777216,16776704);q=i>>31;i=g<<8;g=i;g=Fpa(k,q,g,g>>31);k=jb;l=Fpa(l,l>>31,e,e>>31);g=l+g|0;e=jb+k|0;e=g>>>0<l>>>0?e+1|0:e;k=g;g=v[a+68>>2];g=Fpa(g,g>>31,f,f>>31);f=k+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Lc(f,e,24);v[h+4>>2]=p;f=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(f&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);n=e+n|0;k=n>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];g=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}k=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=g;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function Ks(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Tq(c,d);v[i+4>>2]=2350;n=yH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ad(k);if(!j){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)!=1){break a}break b}Ge(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!hd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[23048]=0;h=Q(2380,a|0,i+120|0)|0;b=v[23048];v[23048]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[23048]=0;b=Q(2381,a|0,i+120|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Hc(n);gb=i+128|0;return d|0}break b}v[23048]=0;p=U(2382,a|0)|0;b=v[23048];v[23048]=0;f:{if((b|0)!=1){if(g){break f}v[23048]=0;p=Q(2383,e|0,p|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=v[ck(h,r)>>2];h:{if(g){break h}v[23048]=0;q=Q(2383,e|0,q|0)|0;u=v[23048];v[23048]=0;if((u|0)!=1){break h}break b}i:{if((p|0)==(q|0)){s=1;if((Bb(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[23048]=0;U(2384,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Bb(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Hc(n);R(a|0)}L()}function v7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;f=nc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(mj(b)){lh(c+56|0);break n}v[23048]=0;S(2099,c+40|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break m}v[23048]=0;S(2087,c+56|0,c+40|0);a=v[23048];v[23048]=0;if((a|0)==1){break l}Tf(c+40|0)}a=b+36|0;o:{if(mj(b)){break o}a=v[c+56>>2]}e=bo(a);v[23048]=0;S(1436,f|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break k}h=c,i=Rb(a),v[h+32>>2]=i;h=c,i=Ub(a),v[h+24>>2]=i;if(Fb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=Ej(v[a>>2]+484360|0,w[e+16|0]);v[23048]=0;S(2100,c+8|0,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break j}v[23048]=0;T(9,c+40|0,0,c+8|0);d=v[23048];v[23048]=0;if((d|0)==1){break i}v[23048]=0;S(1438,f|0,c+40|0);d=v[23048];v[23048]=0;if((d|0)==1){break h}vb(c+40|0);vb(c+8|0);p:{if(!hd(CK(f))){break p}d=w[e+12|0];v[23048]=0;d=Q(516,b|0,d|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}if(!d){break p}d=v[a>>2];v[23048]=0;d=wk(d);g=v[23048];v[23048]=0;if((g|0)==1){break f}b=Yb(v[a>>2]+484344|0,x[sc(b,v[e+12>>2])>>1]);v[23048]=0;S(2101,c+8|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;Y(421,c+40|0,0,d|0,c+8|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}Eb(CK(f),c+40|0);vb(c+40|0);vb(c+8|0)}ZK(c+32|0);if(Fb(c+32|0,c+24|0)){continue}break}}ll(c+56|0);gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Tf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(c+40|0)}vb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(c+8|0);break b}b=P()|0;O()|0}ll(c+56|0)}yd(f);R(b|0);L()}function ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-16|0;gb=d;a:{if(!Nb(a,2)){Sg(c+484344|0,b,64);break a}j=c+484344|0;h=Gd(Kr(a),1,1024);if(!Sg(j,b,h)|!h){break a}k=x[c+480188>>1];while(1){n=Of(Yb(j,b),i);g=0;if(k){while(1){nn(d+8|0,a);e=rd(d+8|0);o=Df(d+8|0);c=B(g,6)+n|0;f=w[Ri(d+8|0)|0];t[c+5|0]=f;l=0;m=w[d+8|0];if((m-1&255)>>>0<=35){t[c|0]=m+48;l=w[e|0]+1|0}e=c+5|0;t[c+1|0]=l;b:{c:{d:{switch(w[o|0]){case 1:t[c+3|0]=2;t[e|0]=f&15;break b;case 2:t[c+3|0]=3;t[e|0]=f&15;break b;case 12:if(!f){break b}t[c+3|0]=1;break b;case 13:if(!f){break b}t[c+3|0]=39;t[d+7|0]=15;p=e,q=w[$b(d+7|0,e)|0]|16,t[p|0]=q;break b;case 30:if(!f){break b}t[c+3|0]=38;t[d+6|0]=15;p=e,q=w[$b(d+6|0,e)|0]|16,t[p|0]=q;break b;case 21:if(!f){break b}t[c+3|0]=39;t[d+5|0]=15;p=e,q=w[$b(d+5|0,e)|0]|80,t[p|0]=q;break b;case 17:if(!f){break b}t[c+3|0]=38;t[d+4|0]=15;p=e,q=w[$b(d+4|0,e)|0]|80,t[p|0]=q;break b;case 15:t[c+3|0]=19;t[e|0]=(f|0)!=0;break b;case 25:t[c+3|0]=12;break b;case 27:Vm(c);t[c|0]=255;break b;case 28:t[c+3|0]=16;break b;case 31:t[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}t[e|0]=f&15;break b;case 5:t[e|0]=f<<4;break b;case 6:t[d+3|0]=f&15;t[d+2|0]=14;p=e,q=w[$b(d+3|0,d+2|0)|0]|240,t[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}t[d+1|0]=f&15;t[d|0]=14;p=e,q=w[$b(d+1|0,d)|0]<<4|15,t[p|0]=q;break b}t[c+4|0]=f;t[c+2|0]=1}t[c+3|0]=0;break c;case 0:break c;default:break d}}t[c+3|0]=0}t[e|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+16|0}function aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;f=v[a+52>>2];v[b+40>>2]=f;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+q|0;g=j>>>21&2040;j=u[g+40886>>1];i=u[g+40884>>1];k=u[g+40882>>1];p=u[g+40880>>1];h=0;m=1;f=1;g=0;while(1){v[(b+8|0)+(g<<2)>>2]=(((B(t[e+g|0],k)+B(t[e+(g|-2)|0],p)|0)+B(i,t[e+(g|2)|0])|0)+B(j,t[e+(g|4)|0])<<8)/16384;l=f&1;f=0;g=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;f=v[j>>2];i=v[a+60>>2];k=i;g=(b+32|0)+(h<<3)|0;p=v[g>>2];e=ac(p,-16777216,16776704);l=v[a+64>>2];h=ac(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=Fpa(k,r,f,f>>31);k=jb;l=Fpa(l,l>>31,e,e>>31);f=l+f|0;e=jb+k|0;e=f>>>0<l>>>0?e+1|0:e;k=f;f=v[a+68>>2];f=Fpa(f,f>>31,h,h>>31);h=k+f|0;e=jb+e|0;e=f>>>0>h>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Lc(h,e,24);v[g+4>>2]=p;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[g>>2]=e-(h&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;k=o>>12;v[c>>2]=v[c>>2]+B(k,v[b+8>>2]);n=e+n|0;g=n>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];f=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}g=n>>12;k=o>>12}v[a+40>>2]=n;v[a+20>>2]=k;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=f;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=g;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function i3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Jb(a+208|0);v[23048]=0;Ic(a+16|0,d);b=v[23048];v[23048]=0;a:{b:{c:{d:{if((b|0)!=1){v[23048]=0;b=U(2375,a+16|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break d}v[23048]=0;Y(2387,b|0,84064,84090,a+224|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}Xb(a+16|0);c=Jb(a+192|0);b=Nc(c);v[23048]=0;S(124,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23048]=0;d=Q(2380,a+344|0,a+336|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Bb(c)+b|0)){d=Bb(c);b=Bb(c);v[23048]=0;S(124,c|0,b<<1);b=v[23048];v[23048]=0;if((b|0)==1){break b}b=Nc(c);v[23048]=0;S(124,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=d+b}v[23048]=0;d=U(2382,a+344|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}if(gm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23048]=0;U(2384,a+344|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xb(a+16|0);break a}v[23048]=0;S(124,c|0,v[a+188>>2]-b|0);b=v[23048];v[23048]=0;f:{if((b|0)==1){break f}b=Ob(c);v[23048]=0;d=fa(2371)|0;g=v[23048];v[23048]=0;if((g|0)==1){break f}v[a>>2]=f;v[23048]=0;b=ba(2372,b|0,d|0,a|0,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[23048]=0;b=Q(2381,a+344|0,a+336|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(c);vb(h);gb=a+352|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);R(b|0);L()}function Ala(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0;g=gb-48|0;gb=g;a:{if(w[b+8|0]){b=b+12|0;z=g,A=qc(b)-c|0,v[z+40>>2]=A;z=g,A=xb(d),v[z+32>>2]=A;e=v[Gb(g+40|0,g+32|0)>>2];z=g,A=Rb(b),v[z+40>>2]=A;l=Ne(g+40|0,c);z=g,A=Rb(b),v[z+24>>2]=A;z=g,A=Ne(g+24|0,c),v[z+32>>2]=A;Hi(l,Ne(g+32|0,e),v[d>>2]);Gj(a,d,e);break a}e=v[d+4>>2];d=v[d>>2];v[g+8>>2]=d;v[g+12>>2]=e;v[g+16>>2]=d;v[g+20>>2]=e;n=g+8|0;d=gb-48|0;gb=d;b:{if(!w[b+24|0]){e=v[n+4>>2];l=v[n>>2];v[d+40>>2]=l;v[d+44>>2]=e;i=v[v[b>>2]+40>>2];v[d>>2]=l;v[d+4>>2]=e;kb[i|0](a,b,c,d);break b}p=v[n>>2];e=xb(n);v[d+36>>2]=e;c:{if(!e){break c}l=b+40|0;while(1){i=d;m=c;x=l;j=0;h=gb-32|0;gb=h;e=b;o=e+40|0;f=e+232|0;q=c&-4096;d:{while(1){r=Dj(f,j);k=v[r>>2];s=Um(o,k);if(!(!w[s+8|0]|v[s>>2]!=(q|0))){v[h+24>>2]=v[r>>2];e=f+(j<<2)|0;Sm(f,e,e+4|0);z=Dj(f,0),A=v[h+24>>2],v[z>>2]=A;break d}j=j+1|0;if((j|0)!=16){continue}break}z=h,A=v[Dj(f,15)>>2],v[z+24>>2]=A;Sm(f,f+60|0,f- -64|0);f=Dj(f,0);v[f>>2]=v[h+24>>2];k=v[f>>2];f=Um(o,k);v[f>>2]=q;WB(h+16|0,e,k);j=v[v[e>>2]+40>>2];o=v[h+20>>2];v[h+8>>2]=v[h+16>>2];v[h+12>>2]=o;kb[j|0](h+24|0,e,q,h+8|0);z=f,A=xb(h+24|0),v[z+4>>2]=A;t[f+8|0]=1}gb=h+32|0;f=i;e=Um(x,k);i=m-v[e>>2]|0;v[f+16>>2]=4096-i;z=d,A=v[Gb(d+16|0,d+36|0)>>2],v[z+32>>2]=A;e=v[e+4>>2];m=e-i|0;v[d+28>>2]=e>>>0<m>>>0?0:m;e=v[Gb(d+32|0,d+28|0)>>2];WB(d+16|0,b,k);m=v[d+16>>2];WB(d+8|0,b,k);vg(i+m|0,e+(i+v[d+8>>2]|0)|0,p);i=v[d+36>>2]-e|0;v[d+36>>2]=i;u=e+u|0;if(e>>>0<y[d+32>>2]){break c}c=c+e|0;p=e+p|0;if(i){continue}break}}Gj(a,n,u)}gb=d+48|0}gb=g+48|0}function w3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Jb(a+208|0);v[23048]=0;Ic(a+16|0,d);b=v[23048];v[23048]=0;a:{b:{c:{d:{if((b|0)!=1){v[23048]=0;b=U(21,a+16|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break d}v[23048]=0;Y(2366,b|0,84064,84090,a+224|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}Xb(a+16|0);c=Jb(a+192|0);b=Nc(c);v[23048]=0;S(124,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23048]=0;d=Q(2352,a+264|0,a+256|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Bb(c)+b|0)){d=Bb(c);b=Bb(c);v[23048]=0;S(124,c|0,b<<1);b=v[23048];v[23048]=0;if((b|0)==1){break b}b=Nc(c);v[23048]=0;S(124,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=d+b}v[23048]=0;d=U(2354,a+264|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}if(hm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23048]=0;U(2356,a+264|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xb(a+16|0);break a}v[23048]=0;S(124,c|0,v[a+188>>2]-b|0);b=v[23048];v[23048]=0;f:{if((b|0)==1){break f}b=Ob(c);v[23048]=0;d=fa(2371)|0;g=v[23048];v[23048]=0;if((g|0)==1){break f}v[a>>2]=f;v[23048]=0;b=ba(2372,b|0,d|0,a|0,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[23048]=0;b=Q(2353,a+264|0,a+256|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(c);vb(h);gb=a+272|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);R(b|0);L()}function kM(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=gb-16|0;gb=d;k=d,l=C(Jy(z[a+4216>>2])/C(yf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(K(C(C(Tp(C(z[um(d+12|0,d+8|0)>>2]*C(6.2831854820251465)))*C(.4000000059604645))+C(.6000000238418579))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));f=a;b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[f+4272|0]=c;f=a;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[f+4273|0]=e;h=re(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))*C(.05000000074505806)));k=d,l=C(Jy(z[a+4220>>2])/C(yf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[um(d+12|0,d+8|0)>>2];k=d,l=C(Jy(z[a+4224>>2])/C(yf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(z[um(d+12|0,d+8|0)>>2]*C(3.1415927410125732));e=gb-16|0;gb=e;f=(p(b),j(2));c=f&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=Vn(+b,0);break c}if(c>>>0<=1081824209){g=+b;if(c>>>0<=1075235811){b=Vn(((f|0)>-1?-1.5707963267948966:1.5707963267948966)+g,1);break c}b=Vn(((f|0)>-1?-3.141592653589793:3.141592653589793)+g,0);break c}if(c>>>0<=1088565717){g=+b;if(c>>>0<=1085271519){b=Vn(((f|0)>-1?-4.71238898038469:4.71238898038469)+g,1);break c}b=Vn(((f|0)>-1?-6.283185307179586:6.283185307179586)+g,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=Ux(b,e+8|0);b=Vn(A[e+8>>3],c&1)}gb=e+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=Tp(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+48800>>2];gb=d+16|0}function gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Xd(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=gg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=(h<<1)+p|0;b:{if((b|0)<=0){break b}while(1){Kd(v[i+8>>2],u[(e<<1)+h>>1]/4<<16>>16);Jd(v[i+8>>2],4);Sb(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Kd(b,u[h+(v[f+44>>2]<<1)>>1]/4<<16>>16);Jd(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=dg(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=ac(o,-16777216,16776704);k=v[a+64>>2];g=ac(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=Fpa(j,l,e,e>>31);j=jb;k=Fpa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=Fpa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Lc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Sb(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function FH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-272|0;gb=h;g=v[b>>2];v[h+12>>2]=g;m=a?a:h+16|0;e=0;a:{b:{c:{d=a?d:256;if(!d|!g){break c}f=c>>>0>=d>>>0;if(!(c>>>0>32|c>>>0>=d>>>0)){break b}while(1){k=f?d:c;c=c-k|0;l=0;n=gb-16|0;gb=n;d:{e:{f:{g:{f=m;if(f){if(k>>>0>=4){break g}g=k;break f}f=0;j=v[h+12>>2];g=v[j>>2];if(!g){break d}while(1){if(g>>>0<=127){f=f+1|0}else{l=-1;k=gl(n+12|0,g,0);if((k|0)==-1){break d}f=f+k|0}g=v[j+4>>2];j=j+4|0;l=f;if(g){continue}break}break d}j=v[h+12>>2];g=k;while(1){i=v[j>>2];h:{if(i-1>>>0>=127){if(!i){t[f|0]=0;v[h+12>>2]=0;break e}l=-1;i=gl(f,i,0);if((i|0)==-1){break d}g=g-i|0;f=f+i|0;break h}t[f|0]=i;g=g-1|0;j=v[h+12>>2];f=f+1|0}j=j+4|0;v[h+12>>2]=j;if(g>>>0>3){continue}break}}if(g){j=v[h+12>>2];while(1){i=v[j>>2];i:{if(i-1>>>0>=127){if(!i){t[f|0]=0;v[h+12>>2]=0;break e}l=-1;i=gl(n+12|0,i,0);if((i|0)==-1){break d}if(g>>>0<i>>>0){break e}gl(f,v[j>>2],0);g=g-i|0;f=f+i|0;break i}t[f|0]=i;g=g-1|0;j=v[h+12>>2];f=f+1|0}j=j+4|0;v[h+12>>2]=j;if(g){continue}break}}l=k;break d}l=k-g|0}gb=n+16|0;if((l|0)==-1){d=0;g=v[h+12>>2];e=-1;break c}f=(h+16|0)==(m|0);m=f?m:l+m|0;e=e+l|0;d=d-(f?0:l)|0;g=v[h+12>>2];if(!d|!g){break c}f=c>>>0>=d>>>0;if(c>>>0>32|c>>>0>=d>>>0){continue}break}break b}if(!g){break a}}if(!c|!d){break a}f=e;while(1){j:{k=gl(m,v[g>>2],0);k:{if(k+1>>>0<=1){e=-1;if(k){break a}v[h+12>>2]=0;break k}g=v[h+12>>2]+4|0;v[h+12>>2]=g;f=f+k|0;c=c-1|0;if(c){break j}}e=f;break a}m=k+m|0;e=f;d=d-k|0;if(d){continue}break}}if(a){v[b>>2]=v[h+12>>2]}gb=h+272|0;return e|0}function R2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-384|0;gb=f;v[f+376>>2]=37;v[f+380>>2]=0;g=Is(f+376|1,84105,v[c+4>>2]);v[f+332>>2]=f+336;a=Be();a:{if(g){h=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=h;a=If(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=If(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2350;h=ge(f+320|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){v[23048]=0;a=fa(2371)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[23048]=0;A[f+8>>3]=e;a=ba(2390,f+332|0,a|0,f+376|0,f|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){break e}break c}v[23048]=0;a=fa(2371)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[23048]=0;a=ba(2390,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}}g=v[f+332>>2];if(!g){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)==1){break c}break d}Ge(h,g)}g=v[f+332>>2];j=g+a|0;k=Lg(g,j,c);v[f+68>>2]=2350;i=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;g=f+336|0;break g}a=Ad(a<<3);if(!a){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ge(i,a);g=v[f+332>>2]}v[23048]=0;Ic(f+56|0,c);l=v[23048];v[23048]=0;h:{i:{if((l|0)!=1){v[23048]=0;ia(2399,g|0,k|0,j|0,a|0,f+68|0,f- -64|0,f+56|0);g=v[23048];v[23048]=0;if((g|0)==1){break i}Xb(f+56|0);v[23048]=0;a=la(2400,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break h}Hc(i);Hc(h);gb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Xb(f+56|0);break f}c=P()|0;O()|0}Hc(i);break b}L()}c=P()|0;O()|0}Hc(h);R(c|0);L()}function b3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-208|0;gb=f;v[f+200>>2]=37;v[f+204>>2]=0;g=Is(f+200|1,84105,v[c+4>>2]);v[f+156>>2]=f+160;a=Be();a:{if(g){h=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=h;a=If(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=If(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2350;h=ge(f+144|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){v[23048]=0;a=fa(2371)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[23048]=0;A[f+8>>3]=e;a=ba(2390,f+156|0,a|0,f+200|0,f|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){break e}break c}v[23048]=0;a=fa(2371)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[23048]=0;a=ba(2390,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}}g=v[f+156>>2];if(!g){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)==1){break c}break d}Ge(h,g)}g=v[f+156>>2];j=g+a|0;k=Lg(g,j,c);v[f+68>>2]=2350;i=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;g=f+160|0;break g}a=Ad(a<<1);if(!a){v[23048]=0;X(2351);a=v[23048];v[23048]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ge(i,a);g=v[f+156>>2]}v[23048]=0;Ic(f+56|0,c);l=v[23048];v[23048]=0;h:{i:{if((l|0)!=1){v[23048]=0;ia(2391,g|0,k|0,j|0,a|0,f+68|0,f- -64|0,f+56|0);g=v[23048];v[23048]=0;if((g|0)==1){break i}Xb(f+56|0);v[23048]=0;a=la(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break h}Hc(i);Hc(h);gb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Xb(f+56|0);break f}c=P()|0;O()|0}Hc(i);break b}L()}c=P()|0;O()|0}Hc(h);R(c|0);L()}function uL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0);d=gb-48|0;gb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}hc(d+8|0,v[a>>2]+24604|0,40);v[d+8>>2]=b;Iz(v[a>>2],d+8|0);break d;case 2:f=a+24|0;a=v[f>>2];b=a+24664|0;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=a+24656|0;e=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=e;b=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=b;e=d;g=gb-16|0;gb=g;b=3;f:{g:{h:{a=c;if(!a|(a|0)>7){break h}b=2;if((a|0)>2){break h}b=1;if((a|0)==2){break h}b=0;if((a|0)>0){break h}a=aa(8)|0;v[23048]=0;c=Q(91,g|0,58383)|0;b=v[23048];v[23048]=0;i:{if((b|0)!=1){rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break g}b=P()|0;O()|0;vb(c);break i}b=P()|0;O()|0;ca(a|0)}R(b|0);L()}gb=g+16|0;break f}L()}t[e+8|0]=b;if(!By(d+8|0,v[f>>2]+24648|0)){break d}Hz(v[f>>2],d+8|0);break d;case 3:b=a+24|0;hc(d+8|0,v[b>>2]+24604|0,40);a=d+8|0;e=gb-48|0;gb=e;j:{if((c|0)==-1){Gt(a,v[dr(e+8|0)+32>>2]);Go(a,v[dr(e+8|0)+36>>2]);break j}if((c|0)<=0){Gt(a,0);Go(a,0);break j}c=B(c,1e3);Gt(a,c);Go(a,c)}gb=e+48|0;if(v[v[b>>2]+24640>>2]==v[d+44>>2]?v[v[b>>2]+24636>>2]==v[d+40>>2]:0){break d}Iz(v[b>>2],d+8|0);break d;default:a=aa(8)|0;v[23048]=0;b=Q(91,d+8|0,56835)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}rc(a,b);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b;case 0:break e}}h=a,i=re(C(10),C(C(c|0)*C(.0005000000237487257))),z[h+48>>2]=i}gb=d+48|0;return}c=P()|0;O()|0;ca(a|0)}R(c|0)}L()}function hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Xd(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=gg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=h+p|0;b:{if((b|0)<=0){break b}while(1){Kd(v[i+8>>2],t[e+h|0]<<6);Jd(v[i+8>>2],4);Sb(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Kd(b,t[h+v[f+44>>2]|0]<<6);Jd(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=dg(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=ac(o,-16777216,16776704);k=v[a+64>>2];g=ac(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=Fpa(j,l,e,e>>31);j=jb;k=Fpa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=Fpa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Lc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Sb(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function $ga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}i=a,j=Fu(t[a+36|0],t[a+37|0]),v[i+24>>2]=j;u[a+36>>1]=0;if((b|0)!=1){break a}e=Fpa(v[a+24>>2],0,8272,0)+4181|0;d=jb;i=a,j=Xc(Ipa(e,e>>>0<4181?d+1|0:d,8363,0),jb),v[i+24>>2]=j;break a}if(d){break a}if((c|0)==1){e=Fpa(v[a+24>>2],0,8363,0)+4136|0;d=jb;i=a,j=Xc(Ipa(e,e>>>0<4136?d+1|0:d,8272,0),jb),v[i+24>>2]=j}d=gb-16|0;gb=d;h=d+8|0;e=v[a+24>>2];g=0;b:{if(!e){break b}g=Ko(Wp(+(e>>>0)*.00011957431543704412)*2215.9795828054475)}it(h,ac(g,-16384,16383),128);t[a+36|0]=v[d+8>>2];t[a+37|0]=v[d+12>>2];gb=d+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}d=c&4;if(d){e=x[a+34>>1];if(!(e&32)){u[a+28>>1]=128;u[a+34>>1]=e|32}Af(a+40|0,15);Af(a+41|0,63)}c:{if(!w[a+41|0]|(!(b&16777248)|!d?!(c&16777248?b&4:0):0)){break c}d=w[a+40|0];if(!d){break c}b=w[a+39|0];if(b){i=a,j=_o(Xc(((d<<8|b>>>1)>>>0)/(b>>>0)|0,0)),t[i+39|0]=j;break c}t[a+39|0]=255}d:{e:{if((c|0)!=4){if((c|0)==16777216){break d}if((c|0)!=32|w[a+38|0]!=2){break e}t[a+38|0]=3;break e}if(w[a+38|0]!=4){break e}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}f:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;Lo(a,0,f);break f}if(!(w[a+35|0]&2)|(c|0)!=2){break f}a=a+68|0;b=lc(a,8);t[b|0]=w[b|0]&3;a=lc(a,9);t[a|0]=w[a|0]&3}gb=f+32|0}function Qha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{j=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?j>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?j>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?j>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?j>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];g=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=(i>>>16&65520)+m|0;f=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=ac(k,-16777216,16776704);l=v[a+64>>2];g=ac(g,-16777216,16776704);b=Fpa(l,l>>31,b,b>>31);l=jb;n=b;i=(((((((B(j,s)+B(f,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;f=Fpa(o,o>>31,b,b>>31);e=n+f|0;b=jb+l|0;b=e>>>0<f>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=Fpa(e,e>>31,g,g>>31);g=n+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);g=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,r);v[c+4>>2]=v[c+4>>2]+B(e,q);b=b-(g&i)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function Rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}o=v[a+16>>2];g=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=e+o|0;f=t[b+4|0];e=(j>>>16&65520)+m|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=ac(k,-16777216,16776704);l=v[a+64>>2];g=ac(g,-16777216,16776704);b=Fpa(l,l>>31,b,b>>31);l=jb;J=b;b=v[a+68>>2];n=Fpa(b,b>>31,g,g>>31);g=J+n|0;b=jb+l|0;b=g>>>0<n>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(f,j)<<8)/32768<<8;f=Fpa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);g=v[a+72>>2];f=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,q);v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(g&e)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function Fz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=gb-16|0;gb=j;k=j;a:{if(!wj(c)){h=b;i=v[c+704>>2];g=gb-16|0;gb=g;v[g+12>>2]=d;f=0;b:{if(!d){break b}if(v[h+480180>>2]&20){d=h+1074308|0;Db(g,d,73);if(Cb(g)){v[g+12>>2]=x[g+12>>1]}if(w[h+480208|0]&16){Db(g,d,73);e=Cb(g);d=v[g+12>>2];f=v[((d>>>0)%768<<2)+35104>>2]<<6>>>(e?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0)|0;break b}d=v[g+12>>2];if(!d){v[g+12>>2]=1;d=1}f=229079296/(d>>>0)|0;break b}f=227001280/(d>>>0)|0;if(ep(h)){break b}f=(d+i<<4)-133808|0;if(v[h+480180>>2]==64){break b}d=v[h+480180>>2];tc(g+12|0,16777215);if(d&17408){f=Xc(Ipa(Fpa(i?i:8363,0,3506176,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}if(w[h+480208|0]&16){Db(g,h+1074308|0,7);if(Cb(g)){f=e>>31;d=v[g+12>>2];h=d>>>24|0;i=d<<8;e=i+e|0;d=h+f|0;d=e>>>0<i>>>0?d+1|0:d;f=(d&15)<<28|e>>>4;break b}f=Xc(Ipa(Fpa(i?i:8363,0,7012352,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}f=Xc(Ipa(-1485242368,13,(v[g+12>>2]<<8)+e|0,0),jb)}gb=g+16|0;e=f;break a}e=v[c+700>>2]}v[k+12>>2]=e;d=v[c+656>>2];c=u[c+776>>1];c:{if(!c){break c}c=d?B(t[d+33|0],c):c;if(!c){break c}e=oh(wg(+(c|0)*25431315104166665e-22)*+(e>>>0));v[j+12>>2]=e}d:{if(!d){break d}c=v[d+40>>2];if(!c){break d}d=(c|0)/2|0;f=v[b+1074412>>2];f=Fpa(f,f>>31,e,e>>31);e=d+f|0;d=jb+(d>>31)|0;l=j,m=vc(Gpa(e,e>>>0<f>>>0?d+1|0:d,c,c>>31),jb),v[l+12>>2]=m}tc(j+12|0,2147483647);c=j;l=c,m=Gpa(0,v[c+12>>2],v[b+24620>>2]<<4,0),v[l>>2]=m;v[c+4>>2]=jb;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;v[a+8>>2]=v[c+12>>2];gb=c+16|0}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];l=v[a+44>>2];v[b+32>>2]=l;j=v[a+48>>2];v[b+36>>2]=j;k=v[a+52>>2];v[b+40>>2]=k;i=v[a+56>>2];v[b+44>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){j=h>>>18|0;l=1;e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+q|0;g=0;k=1;f=0;while(1){i=f<<1;h=u[i+e>>1];v[(b+8|0)+(f<<2)>>2]=h+((B(j,u[e+(i|4)>>1]-h|0)|0)/16384|0);h=k&1;k=0;f=1;if(h){continue}break}while(1){k=(b+8|0)+(g<<2)|0;f=v[k>>2];j=v[a+60>>2];i=j;h=(b+32|0)+(g<<3)|0;p=v[h>>2];e=ac(p,-16777216,16776704);o=v[a+64>>2];g=ac(v[h+4>>2],-16777216,16776704);r=j>>31;j=f<<8;f=j;f=Fpa(i,r,f,f>>31);i=jb;o=Fpa(o,o>>31,e,e>>31);f=o+f|0;e=jb+i|0;e=f>>>0<o>>>0?e+1|0:e;i=f;f=v[a+68>>2];f=Fpa(f,f>>31,g,g>>31);g=i+f|0;e=jb+e|0;e=f>>>0>g>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=Lc(g,e,24);v[h+4>>2]=p;g=v[a+72>>2];v[k>>2]=(e|0)/256;v[h>>2]=e-(g&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];k=v[b+40>>2];j=v[b+36>>2];l=v[b+32>>2];break a}g=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=l;v[a+24>>2]=g;v[a>>2]=h;v[a+4>>2]=e;gb=b+48|0}function oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-48|0;gb=e;wd(b,2);zk(e+16|0,2,a+1|0);Fc(e+32|0,e+16|0);v[23048]=0;Q(355,b+43|0,e+32|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){vb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;g=b,h=v[Gb(e+32|0,e+16|0)>>2],v[g+4>>2]=h;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);g=b,h=v[Gb(e+32|0,b)>>2],v[g+8>>2]=h;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>y[b+4>>2]?d>>>0>=2:0){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}ii(e+16|0,a+16|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;ii(e+16|0,a+20|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+4|0]=f;t[d+5|0]=f>>>8;t[d+6|0]=f>>>16;t[d+7|0]=f>>>24;ii(e+16|0,a+24|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Lo(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[$b(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;a=a+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=c?a&65535:a;v[b+24>>2]=a;b:{c:{if(!a){c=8363;break c}c=1024;if(a>>>0>1023){break b}}v[b+24>>2]=c}gb=e+48|0;return}a=P()|0;O()|0;vb(e+32|0);R(a|0);L()}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;k=v[a+52>>2];v[b+40>>2]=k;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){j=i>>>10&4194048;e=(((e&2147483647)<<1|i>>>31)&-2)+r|0;g=0;l=1;k=1;f=0;while(1){i=t[e+f|0];v[(b+8|0)+(f<<2)>>2]=((B(j,t[e+(f|2)|0]-i|0)|0)/16384|0)+(i<<8);i=k&1;k=0;f=1;if(i){continue}break}while(1){k=(b+8|0)+(g<<2)|0;j=v[k>>2];h=v[a+60>>2];o=h;i=(b+32|0)+(g<<3)|0;q=v[i>>2];e=ac(q,-16777216,16776704);g=v[a+64>>2];f=ac(v[i+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=Fpa(o,p,h,h>>31);o=jb;p=h;h=Fpa(g,g>>31,e,e>>31);g=p+h|0;e=jb+o|0;e=g>>>0<h>>>0?e+1|0:e;h=g;g=v[a+68>>2];g=Fpa(g,g>>31,f,f>>31);f=h+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Lc(f,e,24);v[i+4>>2]=q;f=v[a+72>>2];v[k>>2]=(e|0)/256;v[i>>2]=e-(f&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;g=n>>12;v[c>>2]=v[c>>2]+B(g,v[b+8>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];k=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}f=m>>12;g=n>>12}v[a+40>>2]=m;v[a+20>>2]=g;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=k;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=f;v[a>>2]=i;v[a+4>>2]=e;gb=b+48|0}function Bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-112|0;gb=c;Fm(c+88|0,b,1413829443);v[23048]=0;b=U(328,c+88|0)|0;d=v[23048];v[23048]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[23048]=0;T(1445,c- -64|0,a+140|0,1413894985);a=v[23048];v[23048]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[23048]=0;a=Q(1451,c- -64|0,44805)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}b=28591;if(a){b=Jb(c+48|0);v[23048]=0;a=U(511,c- -64|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break m}v[23048]=0;W(462,c- -64|0,b|0,a|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break m}v[23048]=0;d=Q(119,c+16|0,b|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break l}v[23048]=0;e=Q(91,c|0,44829)|0;a=v[23048];v[23048]=0;if((a|0)==1){break k}v[23048]=0;T(1452,c+32|0,d|0,e|0);a=v[23048];v[23048]=0;if((a|0)==1){break j}Eb(b,c+32|0);vb(c+32|0);vb(e);vb(d);v[23048]=0;T(13,c+32|0,2,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break h}v[23048]=0;a=U(999,c+32|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break g}vb(c+32|0);vb(b);b=a-1>>>0<19398657?1252:28591}yb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(e)}vb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+32|0)}vb(b);break d}a=P()|0;O()|0}yb(c- -64|0);break b}v[23048]=0;a=Q(250,c+88|0,2)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[23048]=0;b=U(340,c+88|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}yb(c+88|0);R(a|0);L()}yb(c+88|0);gb=c+112|0;return b|0}function dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=h;i=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=i;if(d){while(1){l=1;i=((((h&2147483647)<<1|k>>>31)&2147483646)<<1)+o|0;b=k>>>21&2040;k=u[b+40886>>1];j=u[b+40884>>1];m=u[b+40882>>1];n=u[b+40880>>1];f=0;b=1;g=0;while(1){h=g<<1;v[(e+8|0)+(g<<2)>>2]=(((B(u[h+i>>1],m)+B(u[i+(h|-4)>>1],n)|0)+B(u[i+(h|4)>>1],j)|0)+B(k,u[i+(h|8)>>1])|0)/16384;h=b;b=0;g=1;if(h){continue}break}while(1){k=(e+8|0)+(f<<2)|0;i=v[k>>2];j=v[a+60>>2];m=j;h=(e+32|0)+(f<<3)|0;n=v[h>>2];b=ac(n,-16777216,16776704);f=v[a+64>>2];g=ac(v[h+4>>2],-16777216,16776704);j=j>>31;i=i<<8;j=Fpa(m,j,i,i>>31);m=jb;r=j;j=Fpa(f,f>>31,b,b>>31);f=r+j|0;b=jb+m|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=v[a+68>>2];f=Fpa(f,f>>31,g,g>>31);g=j+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);v[h+4>>2]=n;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&i);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];h=v[e+28>>2];continue}break}k=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=k;v[a+4>>2]=h;gb=e+48|0}function j3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-384|0;gb=a;v[a+368>>2]=c;v[a+376>>2]=b;jx(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Jb(a+200|0);b=Nc(d);v[23048]=0;S(124,d|0,b|0);b=v[23048];v[23048]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=v[a+232>>2];h=v[a+236>>2];while(1){d:{v[23048]=0;g=Q(2380,a+376|0,a+368|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+196>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+196>>2]=g+c}v[23048]=0;g=U(2382,a+376|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(ix(g,a+23|0,a+22|0,c,a+196|0,h,b,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23048]=0;U(2384,a+376|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[23048]=0;Y(2369,a|0,c|0,v[a+196>>2],e|0);b=v[23048];v[23048]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;kf(a+216|0,a+32|0,v[a+28>>2],e);v[23048]=0;b=Q(2381,a+376|0,a+368|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];vb(d);vb(a+216|0);gb=a+384|0;break a}}b=P()|0;O()|0;vb(d);vb(a+216|0);R(b|0);L()}return b|0}function z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;mx(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Jb(a+208|0);b=Nc(d);v[23048]=0;S(124,d|0,b|0);b=v[23048];v[23048]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=t[a+238|0];h=t[a+239|0];while(1){d:{v[23048]=0;g=Q(2352,a+280|0,a+272|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+204>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+204>>2]=g+c}v[23048]=0;g=U(2354,a+280|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(lx(g,a+23|0,a+22|0,c,a+204|0,h,b,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23048]=0;U(2356,a+280|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[23048]=0;Y(2369,a|0,c|0,v[a+204>>2],e|0);b=v[23048];v[23048]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;kf(a+224|0,a+32|0,v[a+28>>2],e);v[23048]=0;b=Q(2353,a+280|0,a+272|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];vb(d);vb(a+224|0);gb=a+288|0;break a}}b=P()|0;O()|0;vb(d);vb(a+224|0);R(b|0);L()}return b|0}function vca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;c=b+1300304|0;if(!Fd(c)){f=i+8|0;d=wf(12);v[23048]=0;e=U(1655,d|0)|0;g=v[23048];v[23048]=0;a:{if((g|0)!=1){d=gb-16|0;gb=d;v[d+12>>2]=e;Eq(f,d+12|0);gb=d+16|0;break a}a=P()|0;O()|0;Zb(d);R(a|0);L()}cP(c,Bd(i+8|0));gu(i+8|0)}d=v[c>>2];c=gb+-64|0;gb=c;ZO(c+16|0,a);v[23048]=0;T(9,c+32|0,0,c+16|0);f=v[23048];v[23048]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){v[23048]=0;Hy(c+48|0,c+32|0);f=v[23048];v[23048]=0;if((f|0)!=1){vb(c+32|0);vb(c+16|0);k=c,l=Rb(d),v[k+8>>2]=l;k=c,l=Ub(d),v[k>>2]=l;h:{if(Fb(c+8|0,c)){f=0;d=0;while(1){g=0;e=v[c+8>>2];if(v[v[e>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){g=v[v[e>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}h=v[e>>2];v[23048]=0;S(1656,c+16|0,h+8|0);h=v[23048];v[23048]=0;if((h|0)==1){break h}v[23048]=0;h=LL(c+16|0,c+48|0);j=v[23048];v[23048]=0;i:{j:{if((j|0)!=1){vb(c+16|0);g=!g;if(g|h){break j}f=v[e>>2];d=3;break i}d=P()|0;O()|0;vb(c+16|0);break d}if(!(g|(d|0)>1)){f=v[e>>2];d=2;break i}g=v[e>>2];e=!h&(d|0)<1;f=e?g:f;d=e?1:d}Ag(c+8|0);if(Fb(c+8|0,c)){continue}break}break f}d=0;break e}d=P()|0;O()|0;break d}d=P()|0;O()|0;vb(c+32|0);break g}d=P()|0;O()|0}vb(c+16|0);break c}d=0;if(!f){break e}e=v[f+4>>2];if(!e){break e}v[23048]=0;a=W(e|0,f|0,b|0,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){d=(a|0)!=0;break e}d=P()|0;O()|0;break d}vb(c+48|0);gb=c- -64|0;break b}vb(c+48|0)}R(d|0);L()}gb=i+16|0;return d|0}function eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;b=v[a+48>>2];v[e+36>>2]=b;g=v[a+52>>2];v[e+40>>2]=g;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];j=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=j;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;if(d){while(1){h=(((j&2147483647)<<1|k>>>31)&-2)+o|0;b=k>>>21&2040;k=u[b+40886>>1];i=u[b+40884>>1];m=u[b+40882>>1];n=u[b+40880>>1];g=0;l=1;b=1;f=0;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+h|0],m)+B(t[h+(f|-2)|0],n)|0)+B(t[h+(f|2)|0],i)|0)+B(k,t[h+(f|4)|0])<<8)/16384;j=b;b=0;f=1;if(j){continue}break}while(1){k=(e+8|0)+(g<<2)|0;h=v[k>>2];i=v[a+60>>2];m=i;j=(e+32|0)+(g<<3)|0;n=v[j>>2];b=ac(n,-16777216,16776704);g=v[a+64>>2];f=ac(v[j+4>>2],-16777216,16776704);i=i>>31;h=h<<8;i=Fpa(m,i,h,h>>31);m=jb;r=i;i=Fpa(g,g>>31,b,b>>31);g=r+i|0;b=jb+m|0;b=g>>>0<i>>>0?b+1|0:b;i=g;g=v[a+68>>2];g=Fpa(g,g>>31,f,f>>31);f=i+g|0;b=jb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Lc(f,b,24);v[j+4>>2]=n;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[j>>2]=b-(f&h);g=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];j=v[e+28>>2];continue}break}k=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];g=v[e+40>>2];f=v[e+32>>2];b=v[e+36>>2]}v[a+56>>2]=l;v[a+52>>2]=g;v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=k;v[a+4>>2]=j;gb=e+48|0}function efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb-48|0;gb=c;d=x[a+480190>>1];t[c+32|0]=0;AR(b,d+1|0,c+32|0);if(x[a+480192>>1]){g=nc(c+32|0);d=a+484344|0;k=c,l=Rb(d),v[k+24>>2]=l;k=c,l=Ub(d),v[k+16>>2]=l;if(Fb(c+24|0,c+16|0)){while(1){a:{i=v[c+24>>2];if(!ai(i)){break a}d=x[a+480188>>1];v[23048]=0;t[c|0]=0;T(1156,g|0,d|0,c|0);d=v[23048];v[23048]=0;if((d|0)!=1){b:{k=c,l=Rb(i),v[k+8>>2]=l;j=0;if(!v[i+12>>2]){break a}while(1){f=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{d=v[c+8>>2];v[23048]=0;d=ne(d);e=v[23048];v[23048]=0;if((e|0)==1){break d}e:{if(!d){break e}d=w[v[c+8>>2]+1|0];if(!w[v[c+8>>2]+1|0]){d=w[oc(g,f)|0]}if(d&255){e=v[((w[v[c+8>>2]+1|0]<<2)+a|0)+900380>>2];f:{if(!e){break f}e=x[ud(e+236|0,w[v[c+8>>2]]-1|0)>>1];if(e>>>0>x[a+480190>>1]){break f}ve(c,b,e);Ef(c,1)}k=oc(g,f),l=d,t[k|0]=l;break e}d=x[a+480192>>1];if(!d){break e}e=d;while(1){h=v[((d<<2)+a|0)+900380>>2];g:{if(!h){break g}h=x[ud(h+236|0,w[v[c+8>>2]]-1|0)>>1];if(h>>>0>x[a+480190>>1]){break g}ve(c,b,h);Ef(c,1)}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}Oj(c+8|0);f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[i+12>>2]){continue}break}break a}}a=P()|0;O()|0;gc(g);R(a|0);L()}_O(c+24|0);if(Fb(c+24|0,c+16|0)){continue}break}}d=x[a+480190>>1];h:{if(!d){f=0;break h}f=0;e=d;while(1){ve(c,b,d);if(!Cb(c)){f=Od((B(d,104)+a|0)+484380|0)+f|0}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}gc(g)}gb=c+48|0;return f&65535}function kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Xd(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=gg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Kd(v[h+8>>2],u[(e<<1)+g>>1]/4<<16>>16);Jd(v[h+8>>2],4);Sb(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Kd(b,u[g+(v[f+44>>2]<<1)>>1]/4<<16>>16);Jd(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=dg(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=ac(k,-16777216,16776704);l=v[a+64>>2];i=ac(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=Fpa(j,p,e,e>>31);j=jb;l=Fpa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Fpa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Lc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Sb(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function tO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=gb-16|0;gb=c;d=B(b,880)+a|0;a:{if(v[d+1075072>>2]&134218752){break a}if(!kk(d+1074984|0)){break a}h=v[(B(b,880)+a|0)+1075640>>2];if(w[h+15|0]&2){break a}d=ym(a,b,2,1);if(d-251>>>0<5|!d){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}e=B(b,880)+a|0;d=w[e+1075774|0];b:{if(w[e+1075776|0]==1){t[c+8|0]=64;f=w[$b(e+1075778|0,c+8|0)|0];break b}f=255;if(w[e+1075777|0]!=13){break b}t[c+8|0]=64;f=w[$b((B(b,880)+a|0)+1075779|0,c+8|0)|0]}j=a+1074308|0;Db(c+8|0,j,2);if(Cb(c+8|0)){if(d){e=a;f=b;if(ue(d)){d=w[lc(h+108|0,d-1|0)|0]}tl(e,f,d,x[(B(b,880)+a|0)+1075672>>1]);break a}if((f|0)==255){break a}kb[v[v[g>>2]+76>>2]](g,39,f,b);break a}k=v[h+4>>2];if(d){e=k<<2;v[c+4>>2]=e;if(!w[h+35|0]){e=v[(B(b,880)+a|0)+1075672>>2];v[c+4>>2]=e}i=u[(B(b,880)+a|0)+1075762>>1];Db(c+8|0,j,28);l=c,m=(Cb(c+8|0)?i<<2:i)+e|0,v[l+4>>2]=m;Vd(c+4|0,0,256);e=d;i=b;if(ue(d)){e=w[lc(h+108|0,d-1|0)|0]}tl(a,i,e&255,x[c+4>>1])}e=w[h+35|0];Db(c+8|0,j,101);a=(d|0)!=0;c:{if(Cb(c+8|0)){break c}a=ue(d)}if(a|(f|0)==255?!(a&(e|0)==1):0){break a}d:{switch(w[h+36|0]){case 1:if((f|0)!=255){JM(g,f<<1);break a}JM(g,k<<1);break a;case 0:break d;default:break a}}if((f|0)!=255){t[c+8|0]=127;t[c+4|0]=f<<1;m=g,n=7,o=w[$b(c+8|0,c+4|0)|0],p=b,l=v[v[g>>2]+76>>2],kb[l](m|0,n|0,o|0,p|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;p=g,o=7,n=w[Gb(c+8|0,c+4|0)|0],m=b,l=v[v[g>>2]+76>>2],kb[l](p|0,o|0,n|0,m|0)}gb=c+16|0}function Tz(a,b){var c=0,d=0,e=0,f=0,g=0;c=10;d=8;e=7;a=$z(a);a:{b:{c:{switch(b-1|0){default:g=(b|0)==16777216;if((b|0)!=32?!g:0){break b}Kb(a,0,1);Kb(a,7,1);Kb(a,8,1);Kb(a,9,1);Kb(a,10,1);Kb(a,11,1);Kb(a,12,1);Kb(a,13,1);Kb(a,14,1);Kb(a,15,1);Kb(a,16,1);Kb(a,17,1);Kb(a,18,1);Kb(a,19,1);Kb(a,20,1);Kb(a,21,1);Kb(a,22,1);Kb(a,23,1);Kb(a,24,1);Kb(a,25,1);Kb(a,26,1);Kb(a,27,1);Kb(a,28,1);Kb(a,29,1);Kb(a,30,1);Kb(a,31,1);Kb(a,32,1);Kb(a,33,1);Kb(a,34,1);Kb(a,35,1);Kb(a,36,1);Kb(a,37,1);Kb(a,38,1);Kb(a,39,1);Kb(a,40,1);Kb(a,41,1);Kb(a,42,1);Kb(a,43,1);Kb(a,44,1);Kb(a,45,1);Kb(a,46,1);Kb(a,47,1);Kb(a,48,1);Kb(a,103,1);Kb(a,50,1);Kb(a,87,1);Kb(a,88,1);Kb(a,100,1);Kb(a,102,1);Kb(a,104,1);if(!g){break a}c=111;d=108;e=105;f=99;break b;case 3:Kb(a,0,1);Kb(a,4,1);Kb(a,8,1);Kb(a,9,1);Kb(a,10,1);Kb(a,17,1);Kb(a,40,1);Kb(a,51,1);Kb(a,52,1);Kb(a,53,1);Kb(a,54,1);Kb(a,55,1);Kb(a,56,1);Kb(a,57,1);Kb(a,58,1);Kb(a,59,1);Kb(a,60,1);Kb(a,61,1);Kb(a,62,1);Kb(a,63,1);Kb(a,64,1);Kb(a,65,1);Kb(a,66,1);Kb(a,67,1);Kb(a,68,1);Kb(a,69,1);Kb(a,70,1);Kb(a,71,1);Kb(a,72,1);Kb(a,73,1);Kb(a,74,1);Kb(a,75,1);Kb(a,76,1);Kb(a,86,1);Kb(a,88,1);c=98;d=93;e=90;f=89;break b;case 1:Kb(a,0,1);Kb(a,8,1);Kb(a,10,1);Kb(a,47,1);Kb(a,57,1);Kb(a,77,1);Kb(a,79,1);Kb(a,78,1);Kb(a,80,1);Kb(a,82,1);Kb(a,88,1);c=111;d=107;e=106;f=96;break b;case 2:break b;case 0:break c}}Kb(a,5,1);Kb(a,83,1);Kb(a,84,1);Kb(a,85,1);c=89;d=88;e=92;f=91}Kb(a,f,1);Kb(a,e,1);Kb(a,d,1);Kb(a,c,1)}}function qM(a){var b=C(0),c=0,d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),k=C(0),m=0,n=C(0),o=0,r=C(0);e=gb-16|0;gb=e;c=yf(v[a+16>>2]);o=a,r=re(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))*C(.05000000074505806))),z[o+4232>>2]=r;f=C(C(c>>>0)*C(.0010000000474974513));o=a,r=re(C(10),C(C(-1)/C(C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))*f))),z[o+4236>>2]=r;o=a,r=re(C(10),C(C(-1)/C(C(C(z[a+4216>>2]*C(2950))+C(50))*f))),z[o+4240>>2]=r;v[e+12>>2]=1325400064;g=e;b=C(re(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))*C(.05000000074505806)))*C(2147483648));c=(p(b),j(2));a:{b:{c:{if(!((c|0)>-1?c>>>0>=8388608:0)){d=C(C(-1)/C(b*b));if(!(c&2147483647)){break a}d=C(C(b-b)/C(0));if((c|0)<=-1){break a}c=(p(C(b*C(33554432))),j(2));m=-152;break c}if(c>>>0>2139095039){break b}m=-127;b=C(0);if((c|0)==1065353216){break b}}c=c+4913933|0;n=C((c>>>23|0)+m|0);b=C((l(2,(c&8388607)+1060439283|0),q())+C(-1));h=C(b/C(b+C(2)));i=C(h*h);k=C(i*i);d=b;b=C(b*C(b*C(.5)));b=C(C(n*C(.6931381225585938))+C(d+C(C(C(n*C(905800061445916e-20))+C(h*C(b+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287)))))))-b)))}d=b}z[g+8>>2]=C(d*C(96817624))+C(67108864);o=a,r=C(z[um(e+12|0,e+8|0)>>2]*C(4.656612873077393e-10)),z[o+4244>>2]=r;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);g=a;b=C(C(C(z[a+4228>>2]*C(4))*f)+C(2));d:{if(C(D(b))<C(2147483648)){a=~~b;break d}a=-2147483648}v[g+4252>>2]=a;gb=e+16|0}function Nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=c;d=v[a+4>>2];v[23048]=0;S(904,d|0,b|0);b=v[23048];v[23048]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+56;_b(a);gb=c+16|0;break a}b=P()|0;O()|0;_b(a);R(b|0);L()}return}l=gb-32|0;gb=l;j=a;e=wb(a);f=l+8|0;g=a;d=hr(a)+1|0;h=gb-16|0;gb=h;v[h+12>>2]=d;i=gb-16|0;gb=i;v[i+12>>2]=76695844;v[23048]=0;v[i+8>>2]=2147483647;k=Gb(i+12|0,i+8|0);c=v[23048];v[23048]=0;b:{if((c|0)!=1){gb=i+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Ab();L()}c:{if(c>>>0>=d>>>0){d=yU(g);if(d>>>0<c>>>1>>>0){v[h+8>>2]=d<<1;c=v[Jc(h+8|0,h+12|0)>>2]}gb=h+16|0;break c}Mc();L()}d=hr(a);a=0;g=gb-16|0;gb=g;v[g+12>>2]=0;vd(f+12|0,e);if(c){a=c;if(a>>>0>=76695845){xc(25852);L()}a=jc(B(a,56),4)}v[f>>2]=a;d=B(d,56)+a|0;v[f+8>>2]=d;v[f+4>>2]=d;m=bc(f),n=B(c,56)+a|0,v[m>>2]=n;gb=g+16|0;a=f;c=v[a+8>>2];v[23048]=0;S(904,c|0,b|0);b=v[23048];v[23048]=0;d:{if((b|0)!=1){v[a+8>>2]=v[a+8>>2]+56;b=a;f=a+4|0;k=f;c=v[j+4>>2];g=v[j>>2];if((c|0)!=(g|0)){d=v[k>>2];while(1){e=d-56|0;c=c-56|0;GB(e,c);GB(e+12|0,c+12|0);FB(e+24|0,c+24|0);u[e+52>>1]=x[c+52>>1];d=v[c+48>>2];v[e+44>>2]=v[c+44>>2];v[e+48>>2]=d;d=v[c+40>>2];v[e+36>>2]=v[c+36>>2];v[e+40>>2]=d;d=v[k>>2]-56|0;v[k>>2]=d;if((c|0)!=(g|0)){continue}break}}zc(j,f);zc(j+4|0,b+8|0);zc(wb(j),bc(b));v[b>>2]=v[b+4>>2];wU(a);gb=l+32|0;break d}b=P()|0;O()|0;wU(a);R(b|0);L()}}function nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=gb-16|0;gb=f;a:{if(vr(a)){break a}l=d+484344|0;i=Gd(Hd(a)+1|0,1,1024);if(!Sg(l,b,i)){break a}d=x[d+480188>>1];if(!d|!i){break a}m=d-1|0;while(1){if(!Nb(a,1)){break a}g=Hd(a);b:{if(!g){j=j+1|0;break b}d=Yb(l,b);u[f+14>>1]=g&31;u[f+12>>1]=m;d=Wc(d,j,x[Vc(f+14|0,f+12|0)>>1]);if(!(g&224)){break b}c:{if(!(g&128)){break c}o=d,p=Hd(a),t[o+5|0]=p;d:{e=Hd(a);if(e>>>0>=26){break d}e=w[e+44912|0];t[d+3|0]=e;e:{switch(e-1|0){case 0:if(!w[d+5|0]){break d}break c;case 12:if(w[d+2|0]){break c}t[d+2|0]=1;e=Gd(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break c;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break c}t[d+5|0]=e;break c;case 8:e=w[d+5|0];if(e>>>0<=128){o=d,p=Ki(e<<1),t[o+5|0]=p;break c}if((e|0)!=164){break c}t[d+5|0]=145;t[d+3|0]=20;break c;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break c;case 18:Yt(d);break c;case 16:if(w[d+5|0]>31){break c}t[d+3|0]=16;break c;case 27:break e;default:break c}}n=d;e=w[d+5|0];h=e&240;k=2;f:{g:{if((h|0)==16){break g}if((h|0)!=32){break f}k=3}t[n+3|0]=k}t[d+5|0]=e&15|224;break c}t[d+3|0]=0}h:{if(!(g&64)){break h}Rr(f+8|0,a);e=rd(f+8|0);t[d+1|0]=w[f+8|0];e=w[e|0];t[d|0]=e;h=255;if((e|0)!=128){h=253;if(e>>>0<129){break h}}t[d|0]=h}if(!(g&32)){break b}t[d+2|0]=1;e=Hd(a);t[d+4|0]=e;if(!c){break b}t[d+4|0]=(e<<6>>>0)/127}if(j>>>0<i>>>0){continue}break}}gb=f+16|0}function jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=lc(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=ud(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=ud(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}$B(a+484|0,b+48|0,0);$B(a+590|0,b+68|0,0);$B(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<=-1){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[$b(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[Vc(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[Vc(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;Zl(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;Yl(b,w[a|0]&127,w[a|0]>>>7|0);gb=e+16|0}function YM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=gb-16|0;gb=j;a:{if((b|0)==(c|0)){break a}v[j+12>>2]=-1953789045;Qy(b,c,j+12|0);c=c-b>>2;v[j+8>>2]=c;f=1;e=Lb(a);h=e+1|0;v[j+4>>2]=h;i=v[Jc(j+4|0,j+8|0)>>2];m=b;k=c;d=11;b:{if(c>>>0>622){break b}d=7;if(c>>>0>67){break b}d=5;if(c>>>0>38){break b}d=3;if(c>>>0>6){break b}d=c-1>>>1|0}c=v[j+8>>2];l=m;m=k-d>>>1|0;k=l+(m<<2)|0;l=v[k>>2];g=B(Pt(v[((c<<2)+b|0)-4>>2]^(l^v[b>>2])),1664525);v[k>>2]=g+l;k=d+m|0;d=(k<<2)+b|0;l=d;n=v[d>>2];d=e+g|0;v[l>>2]=n+d;v[b>>2]=d;if(e){while(1){g=f-1|0;d=v[((g>>>0)%(c>>>0)<<2)+b>>2];l=(f>>>0)%(c>>>0)|0;o=(l<<2)+b|0;c=((f+m>>>0)%(c>>>0)<<2)+b|0;n=v[c>>2];d=B(Pt(d^(v[o>>2]^n)),1664525);v[c>>2]=d+n;g=Mb(a,g);c=v[j+8>>2];n=((f+k>>>0)%(c>>>0)<<2)+b|0;d=v[g>>2]+(d+l|0)|0;v[n>>2]=d+v[n>>2];v[o>>2]=d;f=f+1|0;if(e>>>0>=f>>>0){continue}break}}if(i>>>0>h>>>0){while(1){e=((h+m>>>0)%(c>>>0)<<2)+b|0;g=v[e>>2];f=(h>>>0)%(c>>>0)|0;d=(f<<2)+b|0;a=B(Pt(v[((h-1>>>0)%(c>>>0)<<2)+b>>2]^(g^v[d>>2])),1664525);v[e>>2]=a+g;e=((h+k>>>0)%(c>>>0)<<2)+b|0;a=a+f|0;v[e>>2]=a+v[e>>2];v[d>>2]=a;h=h+1|0;if((i|0)!=(h|0)){continue}break}}h=c+i|0;if(h>>>0<=i>>>0){break a}while(1){e=((i+m>>>0)%(c>>>0)<<2)+b|0;g=v[e>>2];f=(i>>>0)%(c>>>0)|0;d=(f<<2)+b|0;a=B(Pt(v[((i-1>>>0)%(c>>>0)<<2)+b>>2]+(g+v[d>>2]|0)|0),1566083941);v[e>>2]=a^g;e=((i+k>>>0)%(c>>>0)<<2)+b|0;a=a-f|0;v[e>>2]=a^v[e>>2];v[d>>2]=a;i=i+1|0;if(h>>>0>i>>>0){continue}break}}gb=j+16|0}function lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Xd(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=gg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Kd(v[h+8>>2],t[e+g|0]<<6);Jd(v[h+8>>2],4);Sb(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Kd(b,t[g+v[f+44>>2]|0]<<6);Jd(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=dg(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=ac(k,-16777216,16776704);l=v[a+64>>2];i=ac(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=Fpa(j,p,e,e>>31);j=jb;l=Fpa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Fpa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Lc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Sb(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function _da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=gb-32|0;gb=i;v[i+24>>2]=b;b=v[a>>2];q=i,r=Rb(a),v[q>>2]=r;b=b+B(Wt(i+24|0,i),6)|0;a:{b:{if(!c){break b}h=v[wb(a)>>2];e=v[a+4>>2];if((h-e|0)/6>>>0>=c>>>0){f=c;h=e-b|0;g=(h|0)/6|0;if(c>>>0>g>>>0){FC(a,c-g|0,d);f=g;if(!h){break b}}m=gb-16|0;gb=m;o=a;p=e;h=b;n=v[a+4>>2];g=B((n-(B(c,6)+b|0)|0)/6|0,6)+b|0;l=Er(m,a,(e-g|0)/6|0);if(e>>>0>g>>>0){e=g;while(1){wb(o);k=v[l+4>>2];j=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[k|0]=j;t[k+1|0]=j>>>8;t[k+2|0]=j>>>16;t[k+3|0]=j>>>24;j=w[e+4|0]|w[e+5|0]<<8;t[k+4|0]=j;t[k+5|0]=j>>>8;v[l+4>>2]=v[l+4>>2]+6;e=e+6|0;if(p>>>0>e>>>0){continue}break}}_b(l);e=g-h|0;if(e){kh(B((e|0)/-6|0,6)+n|0,h,e)}gb=m+16|0;d=b>>>0<=d>>>0?y[a+4>>2]>d>>>0?B(c,6)+d|0:d:d;a=b;if(f){while(1){c=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;c=w[d+4|0]|w[d+5|0]<<8;t[a+4|0]=c;t[a+5|0]=c>>>8;a=a+6|0;f=f-1|0;if(f){continue}break}}break b}f=wb(a);f=AW(i,rC(a,zg(a)+c|0),(b-v[a>>2]|0)/6|0,f);v[23048]=0;T(684,f|0,c|0,d|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}DC(a);c=v[f+4>>2];g=f+4|0;yW(wb(a),v[a>>2],b,g);wb(a);h=f+8|0;d=h;e=v[a+4>>2]-b|0;if((e|0)>=1){hc(v[d>>2],b,e);v[d>>2]=v[d>>2]+B((e>>>0)/6|0,6)}mc(a,g);mc(a+4|0,h);mc(wb(a),bc(f));v[f>>2]=v[f+4>>2];tC(a,zg(a));b=c;ov(f)}Uh(b);gb=i+32|0;return}a=P()|0;O()|0;ov(f);R(a|0);L()}function wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+r|0;n=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=u[e-4>>1];p=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=ac(m,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);e=Fpa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];q=Fpa(e,e>>31,f,f>>31);e=I+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=Fpa(G,H,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function vJ(a){var b=0,c=0,d=0,e=0;he(a,v[a+20>>2]);if(v[a+24>>2]>=1){while(1){he(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}he(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<1){break a}while(1){c=B(e,24)+b|0;b=v[c+16>>2];if(b){d=a;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=1){he(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){he(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}he(d,b)}he(a,v[c+20>>2]);e=e+1|0;if((e|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){d=a;if(v[a+120>>2]>=1){c=0;while(1){b=B(c,2096)+b|0;he(a,v[b+8>>2]);he(a,v[b+28>>2]);he(a,v[b+32>>2]);he(a,v[b+2084>>2]);b=v[b+2088>>2];he(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}he(d,b)}he(a,v[a+260>>2]);he(a,v[a+396>>2]);d=v[a+404>>2];if(d){b=1;c=a;if(v[a+400>>2]>=1){he(a,v[d+4>>2]);if(v[a+400>>2]>=2){while(1){he(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}d=v[a+404>>2]}he(c,d)}c=1;b:{if(v[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;he(a,v[d+800>>2]);he(a,v[d+928>>2]);he(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;he(a,v[b+1068>>2]);he(a,v[b+1076>>2]);he(a,v[b+1084>>2]);he(a,v[b+1092>>2]);he(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function IJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{b:{c:{g=(b|0)>=0;f=a+8|0;d:{if(kl(f)){f=kl(f);break d}f=kq(f)}if(!((f|0)>(b|0)?g:0)){c=aa(8)|0;v[23048]=0;b=Q(91,i|0,59705)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}rc(c,b);v[23048]=0;T(84,c|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}if(c>>>0>=120){c=aa(8)|0;v[23048]=0;b=Q(91,i|0,59724)|0;a=v[23048];v[23048]=0;if((a|0)!=1){rc(c,b);v[23048]=0;T(84,c|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}a=P()|0;O()|0;ca(c|0);break b}h=a+32|0;a=gA(v[h>>2],65535);j=(a|0)==65535?255:a;u[i>>1]=j;f=v[h>>2]+B(j,880)|0;g=f+1074984|0;No(g,v[h>>2],65535);a=c+1|0;t[f+1075788|0]=a;t[f+1075785|0]=a;u[f+1075772>>1]=0;zm(g);yo(v[h>>2],g,b+1|0,0,1,1);v[f+1075680>>2]=65536;ou(v[h>>2],g,a,0,1,1,65535);m=f+1075676|0,n=Ko(pA(e*128,-128,128)+128),v[m>>2]=n;m=f+1075672|0,n=Ko(pA(d*256,0,256)),v[m>>2]=n;a=v[h>>2]+1074470|0;k=a;f=(x[v[h>>2]+480212>>1]<<1)+a|0;l=f;g=i;c=i;b=f;e:{if((b|0)==(a|0)){break e}c=x[c>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((l|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[g>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=hp(k,b);u[v[h>>2]+480212>>1]=a;gb=i+16|0;return j|0}a=P()|0;O()|0;ca(c|0)}R(a|0)}L()}function Q0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;i=c;j=(c|0)==(d|0);a:{if(j){break a}while(1){if(!v[i>>2]){break a}i=i+4|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}m=1;while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];n=ni(l+8|0,l+12|0);v[23048]=0;j=FH(f,e,i-c>>2,g-f|0,b);o=v[23048];v[23048]=0;d:{if((o|0)!=1){jf(n);gb=l+16|0;break d}a=P()|0;O()|0;jf(n);R(a|0);L()}e:{f:{g:{h:{i:{j:{switch(j+1|0){case 0:v[h>>2]=f;k:{if(v[e>>2]==(c|0)){break k}while(1){b=cx(f,v[c>>2],k+8|0,v[a+8>>2]);if((b|0)==-1){break k}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break i;case 1:break b;default:break j}}f=j+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break g}if((d|0)==(i|0)){c=v[e>>2];i=d;break e}j=cx(k+4|0,0,b,v[a+8>>2]);if((j|0)!=-1){break h}}m=2;break b}f=v[h>>2];if(j>>>0>g-f>>>0){break b}if(!j){break f}c=w[k+4|0];v[h>>2]=f+1;t[f|0]=c;i=k+4|0;c=j-1|0;if(!c){break f}while(1){j=w[i+1|0];f=v[h>>2];v[h>>2]=f+1;t[f|0]=j;i=i+1|0;c=c-1|0;if(c){continue}break}break f}c=v[e>>2];break c}c=v[e>>2]+4|0;v[e>>2]=c;f=c;i=d;l:{if((d|0)==(f|0)){break l}while(1){i=f;if(!v[f>>2]){break l}f=f+4|0;if((f|0)!=(d|0)){continue}break}i=d}f=v[h>>2]}if((f|0)==(g|0)){break c}if((c|0)!=(d|0)){continue}break}}m=(c|0)!=(d|0)}gb=k+16|0;return m|0}function xha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+r|0;n=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=t[e-2|0];p=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=ac(m,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);e=Fpa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];q=Fpa(e,e>>31,f,f>>31);e=J+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=Fpa(H,I,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+q|0;f=u[e>>1];v[b+8>>2]=f;v[b+12>>2]=u[e+2>>1];j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=ac(p,-16777216,16776704);o=v[a+64>>2];h=ac(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=Fpa(k,r,f,f>>31);k=jb;o=Fpa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=Fpa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Lc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function m3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;jx(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Jb(a+184|0);b=Nc(d);v[23048]=0;S(124,d|0,b|0);b=v[23048];v[23048]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23048]=0;g=Q(2380,a+360|0,a+352|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+180>>2]=g+c}v[23048]=0;g=U(2382,a+360|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(ix(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23048]=0;U(2384,a+360|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[23048]=0;j=C(xa(2365,c|0,v[a+180>>2],e|0));b=v[23048];v[23048]=0;f:{if((b|0)==1){break f}z[f>>2]=j;kf(a+200|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2381,a+360|0,a+352|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);R(b|0);L()}return b|0}function D3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;mx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Jb(a+192|0);b=Nc(d);v[23048]=0;S(124,d|0,b|0);b=v[23048];v[23048]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[23048]=0;g=Q(2352,a+264|0,a+256|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2354,a+264|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(lx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23048]=0;U(2356,a+264|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[23048]=0;j=C(xa(2365,c|0,v[a+188>>2],e|0));b=v[23048];v[23048]=0;f:{if((b|0)==1){break f}z[f>>2]=j;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2353,a+264|0,a+256|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function jga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=gb+-64|0;gb=f;a:{b:{c:{d:{if(!a){break d}j=e<<2;if(j>>>0>d>>>0){break d}m=B(b,e);if(!m|!Nb(c,j)){break d}s=j-4|0;o=m-8|0;while(1){td(f+40|0,c,d);v[23048]=0;S(795,f+16|0,f+40|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}v[23048]=0;x=Wd(f+16|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}p=v[f+16>>2];if(e){q=p-4|0;k=0;while(1){v[23048]=0;b=U(784,f+40|0)|0;h=v[23048];v[23048]=0;e:{if((h|0)!=1){v[f+12>>2]=b;v[23048]=0;b=U(373,f+40|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break c}v[f+8>>2]=b;Vd(f+8|0,0,89);v[23048]=0;Q(370,f+40|0,1)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}h=k+n|0;if(o>>>0<h>>>0){break e}l=0;b=e+k<<2;if(q>>>0<b>>>0){break e}while(1){i=zb(w[b+x|0]);r=l&1;i=r?i>>>4|0:i&15;g=v[f+8>>2];v[f+8>>2]=t[(i&7)+30985|0]+g;g=u[(g<<1)+31008>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=v[f+12>>2]+(i&8?0-g|0:g);Vd(f+8|0,0,88);Vd(f+12|0,-32768,32767);u[(h<<1)+a>>1]=v[f+12>>2];h=e+h|0;b=b+r|0;l=l+1|0;if((l|0)!=8){continue}if(h>>>0>o>>>0){break e}l=0;b=b+s|0;if(q>>>0>=b>>>0){continue}break}break e}break c}k=k+1|0;if((k|0)!=(e|0)){continue}break}}Ac(f+16|0);yb(f+40|0);b=Nb(c,j);n=(p-j<<1)+n|0;if(n>>>0>=m>>>0){break d}if(b){continue}break}}gb=f- -64|0;return}b=P()|0;O()|0;Ac(f+16|0);break a}b=P()|0;O()|0}yb(f+40|0);R(b|0);L()}function sna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;j=$f(a,c);we(g+8|0,v[a+28>>2]);d=v[g+20>>2];v[g+24>>2]=v[g+16>>2];v[g+28>>2]=d;a:{if(!j){if(nd(a,5)){break a}}d=gb-144|0;gb=d;h=bm(d+40|0,v[a+28>>2]);v[23048]=0;f=Q(662,d+24|0,45943)|0;e=v[23048];v[23048]=0;b:{c:{d:{e:{if((e|0)!=1){v[23048]=0;v[d+16>>2]=19922997;v[d+20>>2]=0;T(663,h|0,f|0,d+16|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}Hb(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f);break c}k=d,l=Te(b),u[k+16>>1]=l;u[d+14>>1]=65535;v[23048]=0;f=Q(662,d+24|0,45949)|0;e=v[23048];v[23048]=0;f:{if((e|0)!=1){v[23048]=0;e=W(1120,h|0,d+14|0,f|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break f}Hb(f);if((e|0)!=1){u[d+16>>1]=x[d+14>>1]}og(d+16|0,4e3);g:{if(x[d+16>>1]<=Te(b)>>>0){break g}v[23048]=0;S(385,b|0,x[d+16>>1]);e=v[23048];v[23048]=0;if((e|0)!=1){break g}e=P()|0;O()|0;break c}e=0;u[d+12>>1]=0;if(!x[d+16>>1]){break b}h:{while(1){i:{f=Yb(b,e&65535);v[23048]=0;S(1507,d+24|0,d+12|0);i=v[23048];v[23048]=0;if((i|0)==1){break i}v[23048]=0;ba(1490,h|0,f|0,d+24|0,1508)|0;f=v[23048];v[23048]=0;if((f|0)==1){break h}Hb(d+24|0);e=e+1|0;u[d+12>>1]=e;if(x[d+16>>1]>(e&65535)>>>0){continue}break b}break}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(d+24|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f)}Yg(h);R(e|0);L()}Yg(h);gb=d+144|0}Rf(a,j,c,g+24|0);gb=g+32|0}function gG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-96|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{b=v[b>>2];j:{if(!b){Tb(a,11188);break j}if(!(b&65535)){d=gb-16|0;gb=d;e=Tb(d,11196);Dc(c+80|0,e);vb(e);gb=d+16|0;v[23048]=0;v[c+24>>2]=b>>>24;S(207,c- -64|0,c+24|0);d=v[23048];v[23048]=0;k:{l:{m:{n:{if((d|0)!=1){v[23048]=0;v[c+8>>2]=b>>>16&255;S(208,c+48|0,c+8|0);b=v[23048];v[23048]=0;if((b|0)==1){break n}v[23048]=0;Y(209,a|0,c+80|0,c- -64|0,c+48|0);a=v[23048];v[23048]=0;if((a|0)==1){break m}vb(c+48|0);vb(c- -64|0);Hb(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(c+48|0)}vb(c- -64|0)}break a}d=gb-16|0;gb=d;e=Tb(d,11202);Dc(c+80|0,e);vb(e);gb=d+16|0;v[23048]=0;v[c+44>>2]=b>>>24;S(207,c- -64|0,c+44|0);d=v[23048];v[23048]=0;if((d|0)==1){break i}v[23048]=0;v[c+40>>2]=b>>>16&255;S(208,c+48|0,c+40|0);d=v[23048];v[23048]=0;if((d|0)==1){break h}v[23048]=0;v[c+20>>2]=b>>>8&255;S(208,c+24|0,c+20|0);d=v[23048];v[23048]=0;if((d|0)==1){break g}v[23048]=0;v[c+4>>2]=b&255;S(208,c+8|0,c+4|0);b=v[23048];v[23048]=0;if((b|0)==1){break f}v[23048]=0;ka(210,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break e}vb(c+8|0);vb(c+24|0);vb(c+48|0);vb(c- -64|0);Hb(c+80|0)}gb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+8|0)}vb(c+24|0)}vb(c+48|0)}vb(c- -64|0)}Hb(c+80|0);R(b|0);L()}function k3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;jx(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Jb(a+184|0);b=Nc(d);v[23048]=0;S(124,d|0,b|0);b=v[23048];v[23048]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23048]=0;g=Q(2380,a+360|0,a+352|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+180>>2]=g+c}v[23048]=0;g=U(2382,a+360|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(ix(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23048]=0;U(2384,a+360|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[23048]=0;j=+oa(2368,c|0,v[a+180>>2],e|0);b=v[23048];v[23048]=0;f:{if((b|0)==1){break f}A[f>>3]=j;kf(a+200|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2381,a+360|0,a+352|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);R(b|0);L()}return b|0}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=(((e&2147483647)<<1|g>>>31)&-2)+q|0;f=t[e|0]<<8;v[b+8>>2]=f;v[b+12>>2]=t[e+1|0]<<8;j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=ac(p,-16777216,16776704);o=v[a+64>>2];h=ac(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=Fpa(k,r,f,f>>31);k=jb;o=Fpa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=Fpa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Lc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function B3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;mx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Jb(a+192|0);b=Nc(d);v[23048]=0;S(124,d|0,b|0);b=v[23048];v[23048]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[23048]=0;g=Q(2352,a+264|0,a+256|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2354,a+264|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break d}if(lx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23048]=0;U(2356,a+264|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[23048]=0;j=+oa(2368,c|0,v[a+188>>2],e|0);b=v[23048];v[23048]=0;f:{if((b|0)==1){break f}A[f>>3]=j;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2353,a+264|0,a+256|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-48|0;gb=e;p=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;j=v[a+48>>2];v[e+36>>2]=j;k=v[a+52>>2];v[e+40>>2]=k;g=v[a+56>>2];v[e+44>>2]=g;q=v[a+24>>2];r=v[a+20>>2];b=v[a+4>>2];i=v[a>>2];v[e+24>>2]=i;v[e+28>>2]=b;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;s=a;if(d){while(1){l=i>>>18|0;k=1;g=((((b&2147483647)<<1|i>>>31)&2147483646)<<1)+p|0;f=0;b=1;j=0;while(1){h=j<<1;i=u[h+g>>1];v[(e+8|0)+(j<<2)>>2]=i+((B(l,u[g+(h|4)>>1]-i|0)|0)/16384|0);i=b;b=0;j=1;if(i){continue}break}while(1){j=(e+8|0)+(f<<2)|0;l=v[j>>2];h=v[a+60>>2];m=h;i=(e+32|0)+(f<<3)|0;o=v[i>>2];b=ac(o,-16777216,16776704);f=v[a+64>>2];g=ac(v[i+4>>2],-16777216,16776704);n=h>>31;l=l<<8;h=l;h=Fpa(m,n,h,h>>31);m=jb;n=h;h=Fpa(f,f>>31,b,b>>31);f=n+h|0;b=jb+m|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=v[a+68>>2];f=Fpa(f,f>>31,g,g>>31);g=h+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&l);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;i=v[e+24>>2];b=v[e+28>>2];continue}break}i=v[e+24>>2];b=v[e+28>>2];k=v[e+40>>2];j=v[e+36>>2];f=v[e+32>>2];g=v[e+44>>2]}v[s+56>>2]=g;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=b;gb=e+48|0}function H0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];c=d>>>0>b>>>0;a:{if(f>>>0>=g>>>0|b>>>0>=d>>>0){break a}b:{c:{while(1){c=t[b|0];i=c&255;l=a;d:{if((c|0)>=0){u[f>>1]=i;b=b+1|0;break d}c=2;if(i>>>0<194){break b}if(i>>>0<=223){if((d-b|0)<2){break c}j=w[b+1|0];if((j&192)!=128){break a}u[f>>1]=j&63|i<<6&1984;b=b+2|0;break d}if(i>>>0<=239){if((d-b|0)<3){break c}k=w[b+2|0];j=w[b+1|0];e:{f:{if((i|0)!=237){if((i|0)!=224){break f}if((j&224)==160){break e}break a}if((j&224)==128){break e}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((j&63)<<6|i<<12);b=b+3|0;break d}if(i>>>0>244){break b}c=1;if((d-b|0)<4){break a}k=w[b+3|0];j=w[b+2|0];b=w[b+1|0];g:{h:{switch(i-240|0){case 0:if((b+112&255)>>>0>=48){break b}break g;case 4:if((b&240)!=128){break b}break g;default:break h}}if((b&192)!=128){break b}}if((j&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}c=2;i=i&7;if((b<<12&196608|i<<18)>>>0>1114111){break a}b=b<<2;u[f>>1]=(j>>>4&3|(b&192|i<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=j<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[l+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;b=v[a+12>>2];c=d>>>0>b>>>0;if(f>>>0>=g>>>0){break a}if(b>>>0<d>>>0){continue}break}break a}c=1;break a}c=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return c|0}function pJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0);d=(b<<2)+a|0;g=d+1068|0;m=c<<1&-4;r=g,s=ce(a,m),v[r>>2]=s;j=d+1076|0;r=j,s=ce(a,m),v[r>>2]=s;k=ce(a,c&-4);v[d+1084>>2]=k;a:{g=v[g>>2];if(!g){break a}j=v[j>>2];if(!j|!k){break a}b:{d=c;if((d|0)<4){break b}l=d>>>2|0;l=l>>>0>1?l:1;n=C(d|0);i=C(C(1)/n);while(1){o=e<<2;f=+C(C(C(h<<2)*C(3.1415927410125732))*i);r=o+g|0,t=C(Oe(f)),z[r>>2]=t;p=e|1;q=p<<2;r=q+g|0,t=C(-C(ji(f))),z[r>>2]=t;f=+C(C(C(p|0)*C(1.5707963705062866))*i);r=j+o|0,t=C(C(Oe(f))*C(.5)),z[r>>2]=t;r=j+q|0,t=C(C(ji(f))*C(.5)),z[r>>2]=t;e=e+2|0;h=h+1|0;if((l|0)!=(h|0)){continue}break}if((d|0)<8){break b}d=d>>3;d=(d|0)>1?d:1;i=C(C(1)/n);e=0;h=1;while(1){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))*i);r=k+(e<<2)|0,t=C(Oe(f)),z[r>>2]=t;r=k+(g<<2)|0,t=C(-C(ji(f))),z[r>>2]=t;if((d|0)==(h|0)){break b}e=e+2|0;h=h+1|0;continue}}e=(b<<2)+a|0;d=ce(a,m);v[e+1092>>2]=d;if(!d){break a}b=c;if((b|0)>=2){b=b>>1;h=(b|0)>1?b:1;f=1/+(b|0);b=0;while(1){i=C(ji((+(b|0)*1.5707963705062866+.7853981852531433)*f));r=d+(b<<2)|0,t=C(ji(+C(i*i)*1.5707963705062866)),z[r>>2]=t;b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=ce(a,c>>2&-2);v[e+1100>>2]=b;if(!b){break a}a=c;d=sm(a);if((a|0)>=8){c=36-d|0;a=a>>>3|0;d=a>>>0>1?a:1;a=0;while(1){r=b+(a<<1)|0,s=qm(a)>>>c<<2,u[r>>1]=s;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}ec(a,3);return 0}function E7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-176|0;gb=b;d=Tb(b+8|0,56885);v[23048]=0;Q(91,b+20|0,56890)|0;e=v[23048];v[23048]=0;c=1;a:{b:{if((e|0)==1){break b}v[23048]=0;Q(91,b+32|0,56900)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=2;break b}v[23048]=0;Q(91,b+44|0,56913)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=3;break b}v[23048]=0;Q(91,b+56|0,56931)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=4;break b}v[23048]=0;Q(91,b+68|0,56941)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=5;break b}v[23048]=0;Q(91,b+80|0,56956)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=6;break b}v[23048]=0;Q(91,b+92|0,56964)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=7;break b}v[23048]=0;Q(91,b+104|0,56971)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=8;break b}v[23048]=0;Q(91,b+116|0,56977)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=9;break b}v[23048]=0;Q(91,b+128|0,56982)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=10;break b}v[23048]=0;Q(91,b+140|0,56990)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=11;break b}v[23048]=0;Q(91,b+152|0,57002)|0;c=v[23048];v[23048]=0;if((c|0)==1){c=12;break b}v[b+172>>2]=13;v[b+168>>2]=d;v[23048]=0;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2089,a|0,b|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){a=b+164|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}gb=b+176|0;return}a=b+164|0;break a}a=(b+8|0)+B(c,12)|0}b=P()|0;O()|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}R(b|0);L()}function Rh(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;return}d=b&224;a:{if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;g=c&d;b:{if(g){Go(e,f);break b}Go(e,0)}t[f+40|0]=!g;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){OA((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}a=(B(b&256?d+9|0:d,44)+a|0)+16|0;d=v[a+36>>2];c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}b=c&32;bS(a,b>>>5|0);f=c>>>2&7;aS(a,f);e=a;a=c&3;$R(e,a);if(!d){break a}bS(d,(b|0)!=0);aS(d,f);$R(d,a);return}_R(a,c);if(!d){break a}_R(d,c);return}t[a+42|0]=(c&32)>>>5;t[a+41|0]=(c&16)>>>4;b=c>>>1&7;u[a+30>>1]=b?9-b|0:0;u[a+32>>1]=c&1;return}if((d|0)!=224?d>>>0>=129:0){break a}f=b&31;if(-4144960>>>f&1){break a}e=a;a=t[f+29472|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;Ho(a);u[a+14>>1]=x[((c&15)<<1)+29504>>1];return;case 1:u[a+68>>1]=w[(c>>>6|0)+29536|0];ZR(a);u[a+22>>1]=(c&63)<<2;return;case 2:u[a+24>>1]=c>>>4;Ho(a);u[a+26>>1]=c&15;Ho(a);return;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;Ho(a);return;case 6:break d;default:break a}}u[a+12>>1]=c&7}}function I4(){var a=0,b=0;a=gb-16|0;gb=a;Ys(464960);v[116250]=465016;v[116248]=91872;v[116240]=79096;v[116252]=-1;t[465012]=0;Ps(a+8|0,464960);b=v[v[116240]+8>>2];v[23048]=0;S(b|0,464960,a+8|0);b=v[23048];v[23048]=0;a:{if((b|0)!=1){Xb(a+8|0);gb=a+16|0;break a}b=P()|0;O()|0;Xb(a+8|0);nm(464960);R(b|0);L()}rt(464288);v[116072]=78144;v[116070]=78124;v[116071]=0;v[23048]=0;S(2299,464288,464960);a=v[23048];v[23048]=0;if((a|0)==1){a=P()|0;O()|0;gh(464288);R(a|0);L()}a=gb-16|0;gb=a;uI(465024);v[116266]=465080;v[116264]=91872;v[116256]=79236;v[116268]=-1;t[465076]=0;Ps(a+8|0,465024);b=v[v[116256]+8>>2];v[23048]=0;S(b|0,465024,a+8|0);b=v[23048];v[23048]=0;b:{if((b|0)!=1){Xb(a+8|0);gb=a+16|0;break b}b=P()|0;O()|0;Xb(a+8|0);eq(465024);R(b|0);L()}YH(464376);v[116094]=78192;v[116092]=78172;v[116093]=0;v[23048]=0;S(2300,464376,465024);a=v[23048];v[23048]=0;if((a|0)==1){a=P()|0;O()|0;gh(464376);R(a|0);L()}aI(465088,92016,465136);Bx(464456,465088);$H(465144,92016,465192);Ax(464540,465144);aI(465200,91496,465248);Bx(464624,465200);Bx(464792,v[(v[v[116156]-12>>2]+464624|0)+24>>2]);$H(465256,91496,465304);Ax(464708,465256);Ax(464876,v[(v[v[116177]-12>>2]+464708|0)+24>>2]);_H(v[v[116070]-12>>2]+464280|0);ZH(v[v[116092]-12>>2]+464368|0);pI(v[v[116156]-12>>2]+464624|0);pI(v[v[116177]-12>>2]+464708|0);_H(v[v[116156]-12>>2]+464624|0);ZH(v[v[116177]-12>>2]+464708|0)}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;i=v[a+48>>2];v[e+36>>2]=i;b=v[a+52>>2];v[e+40>>2]=b;j=v[a+56>>2];v[e+44>>2]=j;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){k=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+o|0;i=0;j=1;b=1;f=0;while(1){h=t[f+g|0];v[(e+8|0)+(f<<2)>>2]=((B(k,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){k=(e+8|0)+(i<<2)|0;f=v[k>>2];l=v[a+60>>2];m=l;h=(e+32|0)+(i<<3)|0;i=v[h>>2];b=ac(i,-16777216,16776704);n=v[a+64>>2];g=ac(v[h+4>>2],-16777216,16776704);r=l>>31;l=f<<8;f=l;f=Fpa(m,r,f,f>>31);m=jb;n=Fpa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=Fpa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Lc(g,b,24);v[h+4>>2]=i;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&l);i=1;b=j&1;j=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];j=v[e+44>>2];i=v[e+36>>2];f=v[e+32>>2];b=v[e+40>>2]}v[a+56>>2]=j;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=gb-16|0;gb=e;f=Tb(e,18062);Dc(d- -64|0,f);vb(f);gb=e+16|0;v[23048]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=Fpa(e,e>>31,1e4,0)+14780|0;b=jb;b=Gpa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;S(182,d+48|0,d+44|0);g=v[23048];v[23048]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[23048]=0;v[d+28>>2]=(e-B(f,12)|0)+1;S(184,d+32|0,d+28|0);e=v[23048];v[23048]=0;if((e|0)==1){break j}v[23048]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;S(184,d+16|0,d+12|0);b=v[23048];v[23048]=0;if((b|0)==1){break i}v[23048]=0;ea(597,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[23048];v[23048]=0;if((a|0)==1){break h}vb(d+16|0);vb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}break a}of(d- -64|0,18086);v[23048]=0;S(598,d+48|0,d+78|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;T(237,a|0,d- -64|0,d+48|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}}vb(d+48|0);Hb(d- -64|0);gb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(d+48|0)}Hb(d- -64|0);R(b|0);L()}
function r3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Gh(d);g=Mn(d,a+224|0);Ln(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23048]=0;h=Q(2380,a+344|0,a+336|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Bb(d)+c|0)){h=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[23048]=0;h=U(2382,a+344|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(gm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[23048]=0;U(2384,a+344|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[23048]=0;b=vs(2360,c,v[a+188>>2],e,b);c=jb;g=v[23048];v[23048]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2381,a+344|0,a+336|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function n3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Gh(d);g=Mn(d,a+224|0);Ln(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23048]=0;h=Q(2380,a+344|0,a+336|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Bb(d)+c|0)){h=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[23048]=0;h=U(2382,a+344|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(gm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[23048]=0;U(2384,a+344|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[23048]=0;b=vs(2364,c,v[a+188>>2],e,b);c=jb;g=v[23048];v[23048]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2381,a+344|0,a+336|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function Xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-32|0;gb=e;u[e+28>>1]=c;u[e+30>>1]=b;u[e+26>>1]=d;d=0;k=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(k>>>0<=b>>>0){break a}if(!c|Gi(a)>>>0>=k>>>0){break a}og(e+28|0,k-b&65535);r=e,s=Ol(a),u[r+8>>1]=s;b=Le(e+30|0,e+8|0);_V(a,x[e+28>>1]+x[b>>1]|0);b=x[e+30>>1];if(uc(a)>>>0<b>>>0){Cf(a,x[e+30>>1])}r=e,s=Rb(a),v[r>>2]=s;c=x[e+30>>1];b=gb-16|0;gb=b;v[b+8>>2]=v[e>>2];v[b+8>>2]=v[b+8>>2]+(c<<1);gb=b+16|0;v[e+8>>2]=v[b+8>>2];b=v[Sd(e+16|0,e+8|0)>>2];g=x[e+28>>1];h=e+26|0;j=gb-32|0;gb=j;v[j+24>>2]=b;c=a;b=v[c>>2];r=j,s=Rb(c),v[r>>2]=s;d=b+(sp(j+24|0,j)<<1)|0;b:{c:{d:{if(!g){break d}b=v[wb(c)>>2];f=v[c+4>>2];if(b-f>>1>>>0>=g>>>0){b=g;l=f-d|0;i=l>>1;if(b>>>0>i>>>0){up(c,g-i|0,h);b=i;if(!l){break d}}n=gb-16|0;gb=n;l=c;p=f;o=v[c+4>>2];q=d;i=d+(o-(d+(g<<1)|0)|0)|0;m=di(n,c,f-i>>1);if(f>>>0>i>>>0){f=i;while(1){wb(l);Gu(v[m+4>>2],f);v[m+4>>2]=v[m+4>>2]+2;f=f+2|0;if(p>>>0>f>>>0){continue}break}}_b(m);Sm(q,i,o);gb=n+16|0;f=d;if(d>>>0<=h>>>0){h=y[c+4>>2]>h>>>0?(g<<1)+h|0:h}kv(f,b,h);break d}b=wb(c);b=tp(j,Jk(c,uc(c)+g|0),d-v[c>>2]>>1,b);v[23048]=0;T(364,b|0,g|0,h|0);g=v[23048];v[23048]=0;if((g|0)==1){break c}d=tS(c,b,d);zh(b)}Uh(d);gb=j+32|0;break b}a=P()|0;O()|0;zh(b);R(a|0);L()}if(uc(a)>>>0>k>>>0){Cf(a,k)}d=x[e+28>>1]}gb=e+32|0;return d&65535}function Az(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;h=xO(b,c);a:{if(!v[b+656>>2]|!(t[h+6|0]&1)){break a}e=v[h>>2];i=a+1074308|0;Db(f+8|0,i,31);g=Cb(f+8|0);d=gw(v[b+656>>2],c);if(cd(d)){break a}g=e+(g^1)|0;Db(f+8|0,i,31);j=Cb(f+8|0);e=w[d+12|0];b:{c:{if(!j){d:{if(!(e&2)){break d}e=x[Mb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){Db(f+8|0,i,70);k=Cb(f+8|0)}if((e|0)!=(g|0)|k){break d}g=x[Mb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Mb(d,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Mb(d,w[d+15|0])>>1];Db(f+8|0,i,93);if(!Cb(f+8|0)|(c|0)!=1|v[b+88>>2]&2048){break b}t[h+6|0]=w[h+6|0]&254;break b}k=1;e=x[qo(d)>>1];if(g>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|w[b+669|0]&8)){if(x[h+4>>1]==65535){break f}Db(f+8|0,i,97);if(Cb(f+8|0)){break f}e=w[d+12|0]}if(e&2){e=x[Mb(d,w[d+13|0])>>1];j=x[Mb(d,w[d+14|0])>>1]+1|0;break e}e=x[qo(d)>>1];k=g>>>0>e>>>0;j=e;break e}e=x[Mb(d,w[d+15|0])>>1];j=x[Mb(d,w[d+16|0])>>1]+1|0}e=g>>>0<j>>>0?g:e}g:{if(!k|c){break g}if(!(!(w[b+89|0]&8)|v[a+480180>>2]==16384?!(v[a+480180>>2]&16777248):0)){v[b+88>>2]=v[b+88>>2]|4096}if(w[qo(d)+2|0]|(v[a+480180>>2]&16777248?0:!x[b+788>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}g=e}Db(f+8|0,i,31);l=h,m=Cb(f+8|0)+g|0,v[l>>2]=m}gb=f+16|0}function pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=0;g=gb-16|0;gb=g;m=a+44|0;if(ei(m)){j=Pd(m,0);k=Pd(m,1);h=qd(m,0);i=qd(m,1);r=z[a+4212>>2];v[g+12>>2]=d;if(d){e=v[a+4224>>2];while(1){s=a;f=v[a+4220>>2];a:{if(f>>>0>e>>>0){v[g+8>>2]=f-e;f=v[Gb(g+12|0,g+8|0)>>2];b:{if(!(r<C(1))){if(!f){break b}e=1;while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;if((e|0)==(f|0)){break b}e=e+1|0;continue}}e=v[a+4224>>2];l=f+e|0;if(e>>>0>=l>>>0){break b}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=n*z[j>>2];z[i>>2]=z[k>>2]*n;i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+v[a+4224>>2]|0;break a}v[g+4>>2]=v[a+4216>>2]-e;f=v[Gb(g+12|0,g+4|0)>>2];c:{d:{if(!(r<C(1))){if(!f){break d}e=1;while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;if((e|0)==(f|0)){break d}e=e+1|0;continue}}p=v[a+4216>>2];q=v[a+4224>>2];e=p-q|0;l=e-f|0;if(e>>>0<=l>>>0){break c}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=z[j>>2]*n;z[i>>2]=z[k>>2]*n;i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(l>>>0<e>>>0){continue}break}break c}e=f<<2;k=e+k|0;j=e+j|0;p=v[a+4216>>2];q=v[a+4224>>2]}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+q|0;e=e>>>0<p>>>0?e:0}v[s+4224>>2]=e;if(l){continue}break}}si(a,b,c,qd(m,0),qd(m,1),d)}gb=g+16|0}function t3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Gh(d);h=Mn(d,a+224|0);Ln(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23048]=0;g=Q(2380,a+344|0,a+336|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2382,a+344|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(gm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[23048]=0;U(2384,a+344|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[23048]=0;b=ba(2357,c|0,v[a+188>>2],e|0,b|0)|0;c=v[23048];v[23048]=0;f:{if((c|0)==1){break f}v[f>>2]=b;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2381,a+344|0,a+336|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function q3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Gh(d);h=Mn(d,a+224|0);Ln(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23048]=0;g=Q(2380,a+344|0,a+336|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2382,a+344|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(gm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[23048]=0;U(2384,a+344|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[23048]=0;b=ba(2361,c|0,v[a+188>>2],e|0,b|0)|0;c=v[23048];v[23048]=0;f:{if((c|0)==1){break f}u[f>>1]=b;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2381,a+344|0,a+336|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function p3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Gh(d);h=Mn(d,a+224|0);Ln(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23048]=0;g=Q(2380,a+344|0,a+336|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2382,a+344|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(gm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[23048]=0;U(2384,a+344|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[23048]=0;b=ba(2362,c|0,v[a+188>>2],e|0,b|0)|0;c=v[23048];v[23048]=0;f:{if((c|0)==1){break f}v[f>>2]=b;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2381,a+344|0,a+336|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function o3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Gh(d);h=Mn(d,a+224|0);Ln(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23048]=0;g=Q(2380,a+344|0,a+336|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2382,a+344|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(gm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[23048]=0;U(2384,a+344|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[23048]=0;b=ba(2363,c|0,v[a+188>>2],e|0,b|0)|0;c=v[23048];v[23048]=0;f:{if((c|0)==1){break f}v[f>>2]=b;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2381,a+344|0,a+336|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function M3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Gh(d);Nn(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[23048]=0;h=Q(2352,a+232|0,a+224|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Bb(d)+c|0)){h=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[23048]=0;h=U(2354,a+232|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(hm(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,84064)){break c}v[23048]=0;U(2356,a+232|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[23048]=0;b=vs(2360,c,v[a+188>>2],e,b);c=jb;g=v[23048];v[23048]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2353,a+232|0,a+224|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function F3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Gh(d);Nn(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[23048]=0;h=Q(2352,a+232|0,a+224|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Bb(d)+c|0)){h=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[23048]=0;h=U(2354,a+232|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(hm(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,84064)){break c}v[23048]=0;U(2356,a+232|0)|0;h=v[23048];v[23048]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[23048]=0;b=vs(2364,c,v[a+188>>2],e,b);c=jb;g=v[23048];v[23048]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2353,a+232|0,a+224|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function Sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(d){while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2];break e}b=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=i;v[a+4>>2]=f;gb=g+32|0}function mha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Xd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=gg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Kd(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Kd(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function O3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Gh(d);Nn(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[23048]=0;g=Q(2352,a+232|0,a+224|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2354,a+232|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(hm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,84064)){break c}v[23048]=0;U(2356,a+232|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[23048]=0;b=ba(2357,c|0,v[a+188>>2],e|0,b|0)|0;c=v[23048];v[23048]=0;f:{if((c|0)==1){break f}v[f>>2]=b;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2353,a+232|0,a+224|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Gh(d);Nn(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[23048]=0;g=Q(2352,a+232|0,a+224|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2354,a+232|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(hm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,84064)){break c}v[23048]=0;U(2356,a+232|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[23048]=0;b=ba(2361,c|0,v[a+188>>2],e|0,b|0)|0;c=v[23048];v[23048]=0;f:{if((c|0)==1){break f}u[f>>1]=b;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2353,a+232|0,a+224|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function I3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Gh(d);Nn(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[23048]=0;g=Q(2352,a+232|0,a+224|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2354,a+232|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(hm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,84064)){break c}v[23048]=0;U(2356,a+232|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[23048]=0;b=ba(2362,c|0,v[a+188>>2],e|0,b|0)|0;c=v[23048];v[23048]=0;f:{if((c|0)==1){break f}v[f>>2]=b;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2353,a+232|0,a+224|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function H3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Gh(d);Nn(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[23048]=0;g=Q(2352,a+232|0,a+224|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);v[23048]=0;S(124,d|0,c<<1);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=Nc(d);v[23048]=0;S(124,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[23048]=0;g=U(2354,a+232|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break d}if(hm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,84064)){break c}v[23048]=0;U(2356,a+232|0)|0;g=v[23048];v[23048]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[23048]=0;b=ba(2363,c|0,v[a+188>>2],e|0,b|0)|0;c=v[23048];v[23048]=0;f:{if((c|0)==1){break f}v[f>>2]=b;kf(a+208|0,a+16|0,v[a+12>>2],e);v[23048]=0;b=Q(2353,a+232|0,a+224|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);R(b|0);L()}return b|0}function uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;l=gb-144|0;gb=l;EB(a);a:{b:{if(!Qf(a,64)){break b}c:{d:{if(!Gl(a,60)){break d}if(!jU(a,26140)){break d}i=15;d=450;break c}EB(a);if(!Qf(a,128)){break b}b=0;if(!Gl(a,124)){break a}if(!jU(a,26145)){break a}i=31;d=930}EB(a);e=1;while(1){b=0;h=0;g=gb-16|0;gb=g;c=gb-32|0;gb=c;ii(c+24|0,g+8|0);j=xb(c+24|0);f=v[c+28>>2];k=v[c+24>>2];v[c+8>>2]=k;v[c+12>>2]=f;v[c>>2]=k;v[c+4>>2]=f;f=a;md(c+16|0,a,c);k=xb(c+16|0);if((k|0)==(j|0)){bd(f,xb(c+24|0))}gb=c+32|0;if((j|0)==(k|0)){c=g+8|0;h=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}gb=g+16|0;if(h>>>0>131072){break a}if((e&65535)>>>0<i>>>0){e=e+1|0;continue}break}bd(a,4);if(!Qf(a,2)){break b}g=0;e=gb-16|0;gb=e;c=gb-32|0;gb=c;rn(c+24|0,e+8|0);i=xb(c+24|0);h=v[c+28>>2];j=v[c+24>>2];v[c+8>>2]=j;v[c+12>>2]=h;v[c>>2]=j;v[c+4>>2]=h;md(c+16|0,a,c);h=xb(c+16|0);if((h|0)==(i|0)){bd(f,xb(c+24|0))}gb=c+32|0;if((h|0)==(i|0)){f=e+8|0;g=Ib(w[f|0]|w[f+1|0]<<8)}gb=e+16|0;if(g>>>0<178){break a}b=-1;if(!Qf(a,d)){break a}bd(a,d);d=gb-32|0;gb=d;e=l+8|0;kV(d+24|0,e);f=xb(d+24|0);c=v[d+28>>2];g=v[d+24>>2];v[d+8>>2]=g;v[d+12>>2]=c;v[d>>2]=g;v[d+4>>2]=c;md(d+16|0,a,d);c=xb(d+16|0);if((c|0)==(f|0)){bd(a,xb(d+24|0))}gb=d+32|0;a=(c|0)==(f|0);if(!a){QB(e)}if(!a){break a}b=iU(l+8|0);break a}b=-1}gb=l+144|0;return b|0}function OZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){wd(b,32);Pj(d,1,a+4|0);Fc(d+16|0,d);v[23048]=0;Q(355,b+43|0,d+16|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}vb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;og(b+30|0,256);u[b+32>>1]=w[a+17|0];og(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;og(b+28|0,256);if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);pk(b);t[b+38|0]=w[(w[a+79|0]&7)+40864|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=d+32|0;return c|0}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}function V2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;m=Dx(g);g=kx(g);Mg(k,g);a:{b:{c:{if(hd(k)){v[23048]=0;Y(2387,m|0,a|0,c|0,d|0);g=v[23048];v[23048]=0;if((g|0)==1){break c}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;d:{e:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break e;default:break d}}v[23048]=0;j=Q(2397,m|0,h<<24>>24)|0;h=v[23048];v[23048]=0;if((h|0)==1){break c}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23048]=0;h=Q(2397,m|0,48)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[23048]=0;h=Q(2397,m|0,h|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break c}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}fm(j,c);h=0;v[23048]=0;n=U(2385,g|0)|0;g=v[23048];v[23048]=0;f:{if((g|0)!=1){if(c>>>0<=j>>>0){break f}g=j;i=0;while(1){g:{if(!w[pc(k,h)|0]){break g}if(t[pc(k,h)|0]!=(i|0)){break g}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=n;h=(Bb(k)-1>>>0>h>>>0)+h|0;i=0}l=t[g|0];v[23048]=0;o=Q(2397,m|0,l|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break c}l=v[f>>2];v[f>>2]=l+4;v[l>>2]=o;i=i+1|0;g=g+1|0;if((g|0)!=(c|0)){continue}break}g=l+4|0;break b}break c}g=v[f>>2];break b}a=P()|0;O()|0;vb(k);R(a|0);L()}Gs((j-a<<2)+d|0,g);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;vb(k);gb=k+16|0}function Vg(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;v[f+12>>2]=d;e=b-1|0;g=0;a:{if(e>>>0>249){break a}h=ep(a);g=v[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;g=x[((e-B(a,12)&255)<<1)+34416>>1]<<4>>>a|0;break a}if(!(v[a+480180>>2]!=64?!(w[a+480208|0]&16):0)){Db(f,a+1074308|0,7);if(!(i=!Cb(f),j=0,k=v[a+480180>>2]!=64,k?i:j)){a=((e&255)>>>0)/12|0;b=Fpa(v[f+12>>2],0,v[(e-B(a,12)<<6&960)+38304>>2]<<a,0);a=jb;c=a>>>21|0;g=Xc((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;g=x[((e-B(a,12)&255)<<1)+34416>>1]<<5>>>a|0;break a}if(!d){v[f+12>>2]=8363}a=((e&255)>>>0)/12|0;tc(f+12|0,-1>>>a|0);g=Xc(Ipa(Fpa(x[((e-B(a,12)&255)<<1)+34416>>1],0,267616,0),jb,v[f+12>>2]<<a,0),jb);break a}if(g&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Db(f,a+1074308|0,76);b=Cb(f)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;g=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;c=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[f>>2]=c+8;Vd(f,0,103);c=c+((b|0)<0?-1:1)|0;c=(c|0)>-8?c:-8;d=b;b=b>>31;b=(d+b^b)&15;g=B(x[(((c|0)<95?c:95)<<1)+34912>>1],b)+B(x[(v[f>>2]<<1)+34896>>1],16-b|0)<<1>>>a|0;break a}a=c>>>4&15;if(!(e>>>0<108?!(a|e>>>0<24):0)){b=B(a,12);a=((e&255)>>>0)/12|0;g=x[(b+(e-B(a,12)&255)<<1)+34016>>1]<<5>>>a|0;break a}g=x[(b<<1)+33790>>1]<<2}gb=f+16|0;return g}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2];break e}b=j>>12;e=k>>12}v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=h;v[a+4>>2]=i;gb=f+32|0}function XR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(ok(a)){i=e+8|0;f=wf(3848);j=v[e+12>>2];c=f+808|0;b=f+16|0;while(1){v[b+16>>2]=0;v[b+20>>2]=0;v[b+36>>2]=0;t[b+40|0]=1;v[b+24>>2]=0;v[b+28>>2]=0;u[b+32>>1]=0;b=b+44|0;if((c|0)!=(b|0)){continue}break}c=f+3832|0;b=f+808|0;while(1){v[b>>2]=0;v[b+4>>2]=0;v[b+68>>2]=0;v[b+72>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;u[b+20>>1]=511;v[b+16>>2]=-1;u[b+14>>1]=1;u[b+6>>1]=0;u[b+8>>1]=0;u[b+10>>1]=0;u[b+12>>1]=0;t[b+73|0]=0;t[b+74|0]=0;t[b+75|0]=0;t[b+76|0]=0;t[b+77|0]=0;t[b+78|0]=0;t[b+79|0]=0;t[b+80|0]=0;b=b+84|0;if((c|0)!=(b|0)){continue}break}b=f;v[b+3832>>2]=0;v[b+3836>>2]=0;c=b+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){_e((b+B(g,84)|0)+808|0,b);g=g+1|0;if((g|0)!=36){continue}break}while(1){v[(b+B(d,44)|0)+32>>2]=b;d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){c=(b+B(d,44)|0)+16|0;g=v[(d<<2)+29392>>2];b:{if(!(!(1<<d&3591)|d>>>0>11)){h=c;c=b+B(g,84)|0;dS(h,c+808|0,c+1060|0,c+1312|0,c+1564|0);break b}h=c;c=b+B(g,84)|0;dS(h,c+808|0,c+1060|0,0,0)}d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){Ho((b+B(d,84)|0)+808|0);d=d+1|0;if((d|0)!=36){continue}break}cS(b,j);Ai(i,f);_z(a,Bd(e+8|0));Dm(e+8|0);break a}cS(v[a>>2],b)}LA(a);gb=e+16|0}function k2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=gb-448|0;gb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2402;h=ge(a+24|0,a+32|0,a+20|0);v[23048]=0;Ic(a+16|0,e);b=v[23048];v[23048]=0;a:{b:{c:{d:{if((b|0)!=1){v[23048]=0;i=U(2375,a+16|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[23048]=0;b=ra(2410,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break b}if(!b){break c}c=gb-16|0;gb=c;b=g;e:{if($e(b)){d=v[b>>2];v[c+12>>2]=0;je(d,c+12|0);Ae(b,0);break e}v[c+8>>2]=0;je(b,c+8|0);Gf(b,0)}gb=c+16|0;if(!w[a+15|0]){break d}v[23048]=0;b=Q(2397,i|0,45)|0;c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(112,g|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[23048]=0;b=Q(2397,i|0,48)|0;c=v[23048];v[23048]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;f:{if(e>>>0>=d>>>0){break f}while(1){if((b|0)!=v[e>>2]){break f}e=e+4|0;if(d>>>0>e>>>0){continue}break}}v[23048]=0;T(2415,g|0,e|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){break c}break b}v[23048]=0;b=Q(2381,a+440|0,a+432|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Xb(a+16|0);Hc(h);gb=a+448|0;return b|0}e=P()|0;O()|0;Xb(a+16|0)}Hc(h);R(e|0);L()}function Aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=ac(k,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);e=Fpa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];l=Fpa(e,e>>31,f,f>>31);e=I+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;h=Fpa(G,H,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Sb(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function Hoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-1072|0;gb=e;v[e+1068>>2]=c;l=Hd(b);g=Ok(e+8|0,b);v[23048]=0;m=jp(g);c=v[23048];v[23048]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23048]=0;c=U(511,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}v[e+4>>2]=c;v[23048]=0;v[e>>2]=536870911;c=Gb(e+4|0,e);d=v[23048];v[23048]=0;if((d|0)==1){break c}tc(e+1068|0,v[c>>2]<<3);v[23048]=0;k=Q(41,a|0,v[e+1068>>2])|0;a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;a=8;f=Q(252,g|0,8)|0;d=v[23048];v[23048]=0;c=1;e:{f:{if((d|0)==1){break f}d=zb(f&255);n=oc(k,0),o=d,t[n|0]=o;g:{if(y[e+1068>>2]<2){break g}while(1){v[23048]=0;j=a&255;d=Q(252,g|0,j|0)|0;h=v[23048];v[23048]=0;h:{i:{j:{k:{if((h|0)!=1){if(d){break k}if(j>>>0>8){break g}a=a+1|0;break j}break f}h=f;f=d>>>1|0;f=h+(d&1?0-f|0:f)|0;h=zb(f&255);n=oc(k,c),o=h,t[n|0]=o;c=c+1|0;if(!(d<<1>>>j|0)){break i}}i=0;break h}i=i+1|0;d=i&255;a=a-(j>>>0>1&d>>>0>=l>>>0)|0;i=d>>>0<l>>>0?i:0}if(y[e+1068>>2]>c>>>0){continue}break}}v[23048]=0;a=jp(g);c=v[23048];v[23048]=0;if((c|0)==1){break f}v[23048]=0;Q(248,b|0,((a-m|0)+3&-4)+m|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break e}}a=P()|0;O()|0;gc(k);break a}yb(g);gb=e+1072|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(g);R(a|0);L()}function I0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c=v[a+12>>2];if(d>>>0>c>>>0){while(1){b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<1){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;if(c>>>0<d>>>0){continue}break}}f=0;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return f|0}function Zq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{f=a;d=b;b:{c:{i=a+58|0;h=lc(i,b);b=t[h|0];if((b|0)==-1){break c}if((b|0)>-1){break b}b=b&127;e=ud(f+22|0,b);g=x[e>>1];if((d|0)!=(g|0)?(g|0)!=65535:0){break c}u[e>>1]=d;t[h|0]=b;break b}m=f+4|0;j=f+22|0;g=255;b=0;e=255;while(1){k=ud(j,b);l=x[k>>1];if((l|0)==65535){u[k>>1]=d;t[h|0]=b;break b}if(!(w[lc(m,b)|0]&32)){g=t[lc(i,l)|0]>-1?g:b;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(g&255)==255?e:g;e=ud(j,b&255);n=lc(i,x[e>>1]),o=255,t[n|0]=o;u[e>>1]=d;t[h|0]=b}b=zl(f,d)}e=b&255;if((e|0)==255){break a}if(ok(a)){break a}d=Um(a+314|0,e);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=b;t[d+9|0]=b>>>8;t[d+10|0]=b>>>16;t[d+11|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=b;t[d+5|0]=b>>>8;t[d+6|0]=b>>>16;t[d+7|0]=b>>>24;g=WR(e);h=g+3|0;b=0;d=1;while(1){f=d;d=d?g:h;Rh(v[a>>2],(d|32)&65535,w[lc(c,b)|0]);Rh(v[a>>2],(d|64)&65535,w[lc(c,b|2)|0]);Rh(v[a>>2],(d|96)&65535,w[lc(c,b|4)|0]);Rh(v[a>>2],(d|128)&65535,w[lc(c,b|6)|0]);Rh(v[a>>2],(d|224)&65535,w[lc(c,b|8)|0]);d=0;b=1;if(f){continue}break}Rh(v[a>>2],Bu(e)|192,w[lc(c,10)|0])}}function Bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=ac(k,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);e=Fpa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];l=Fpa(e,e>>31,f,f>>31);e=J+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;h=Fpa(H,I,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Sb(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function P0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;i=c;j=(c|0)==(d|0);a:{if(j){break a}while(1){if(!w[i|0]){break a}i=i+1|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];m=ni(l+8|0,l+12|0);v[23048]=0;j=EH(f,e,i-c|0,g-f>>2,b);n=v[23048];v[23048]=0;d:{if((n|0)!=1){jf(m);gb=l+16|0;break d}a=P()|0;O()|0;jf(m);R(a|0);L()}e:{f:{g:{h:{i:{j:{if((j|0)==-1){v[h>>2]=f;if(v[e>>2]!=(c|0)){while(1){k:{l:{m:{n:{b=TG(f,c,i-c|0,k+8|0,v[a+8>>2]);switch(b+2|0){case 1:break m;case 2:break n;case 0:break h;default:break l}}c=c+1|0;break k}v[e>>2]=c;break j}c=b+c|0}f=v[h>>2]+4|0;v[h>>2]=f;if(v[e>>2]!=(c|0)){continue}break}}v[e>>2]=c;break c}f=v[h>>2]+(j<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break g}c=v[e>>2];if((d|0)==(i|0)){i=d;break e}if(!TG(f,c,1,b,v[a+8>>2])){break i}}a=2;break b}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;f=c;i=d;if((c|0)==(d|0)){break f}while(1){if(!w[f|0]){i=f;break f}f=f+1|0;if((f|0)!=(d|0)){continue}break}break f}v[e>>2]=c;a=1;break b}c=v[e>>2];break c}f=v[h>>2]}if((f|0)==(g|0)){break c}if((c|0)!=(d|0)){continue}break}}a=(c|0)!=(d|0)}gb=k+16|0;return a|0}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;e=u[f>>1];v[b+8>>2]=e;v[b+12>>2]=u[f+2>>1];i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=ac(n,-16777216,16776704);m=v[a+64>>2];h=ac(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=Fpa(l,r,e,e>>31);l=jb;m=Fpa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=Fpa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function pW(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a:{d=w[a|0];b:{if(d>>>0>21){break b}t[a|0]=w[d+19456|0];c:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break b;case 4:t[b|0]=w[b|0]+1>>>1;break b;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break b;case 6:d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{d=w[b|0];switch((d>>>4|0)-1|0){case 10:break e;case 9:break f;case 8:break g;case 6:break h;case 5:break i;case 4:break j;case 3:break k;case 1:break l;case 0:break m;case 11:case 12:case 13:break b;case 14:break d;default:break n}}t[a|0]=0;break b}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[$b(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break b}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[$b(c+13|0,c+12|0)|0]|240,t[e|0]=f;break b}t[b|0]=d&15|48;break b}t[a|0]=35;t[b|0]=w[b|0]<<4^128;break b}t[b|0]=d&15|176;break b}t[b|0]=d&15|64;break b}t[a|0]=15;t[b|0]=w[b|0]&15;break b}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break b}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break b}t[a|0]=10;break b;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break b}if(a>>>0<=239){t[b|0]=a<<2&48|15;break b}t[b|0]=a<<4|15;break b;case 9:break c;default:break b}}a=w[b|0];if(a>>>0<=223){break a}if(a>>>0>239){break b}t[b|0]=a>>>2&3|240}gb=c+16|0;return}t[b|0]=a>>>0>63?15:a>>>2|0;gb=c+16|0}function f3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;l=nD(g);g=px(g);Mg(k,g);a:{b:{if(hd(k)){v[23048]=0;Y(2366,l|0,a|0,c|0,d|0);g=v[23048];v[23048]=0;if((g|0)==1){break a}g=(c-a|0)+d|0;v[f>>2]=g;break b}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23048]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23048]=0;h=Q(22,l|0,48)|0;i=v[23048];v[23048]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[23048]=0;h=Q(22,l|0,h|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}fm(j,c);h=0;v[23048]=0;o=U(2358,g|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break a}if(c>>>0>j>>>0){g=j;i=0;while(1){e:{if(!w[pc(k,h)|0]){break e}if(t[pc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Bb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23048]=0;n=Q(22,l|0,n|0)|0;m=v[23048];v[23048]=0;if((m|0)==1){break a}m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;i=i+1|0;g=g+1|0;if((g|0)!=(c|0)){continue}break}}fm((j-a|0)+d|0,v[f>>2]);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;vb(k);gb=k+16|0;return}a=P()|0;O()|0;vb(k);R(a|0);L()}function Mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+o|0;e=t[f|0]<<8;v[b+8>>2]=e;v[b+12>>2]=t[f+1|0]<<8;i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=ac(n,-16777216,16776704);m=v[a+64>>2];h=ac(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=Fpa(l,r,e,e>>31);l=jb;m=Fpa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=Fpa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Xd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=gg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Kd(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Jd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Kd(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Hda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0);i=gb-16|0;gb=i;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Lb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}h=u[d+2>>1];if((h|0)<(g|0)){break a}if((Lb(b)-1&65535)>>>0>(h-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Lb(b)){break b}while(1){if(!(z[Mb(b,f)>>2]<C(0))){f=f+1|0;if(Lb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=wN(Lb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;pl(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=Rb(b);f=Ub(b);l=i,m=Rb(g),v[l+8>>2]=m;h=So(i+8|0,u[e>>1]-u[d>>1]|0);b=gb-16|0;gb=b;Cc(b+8|0,To(Fl(c),Fl(f),Fl(h)));gb=b+16|0;c=u[a+28>>1];f=u[e>>1];c:{if((c|0)>=(f|0)){break c}b=f;while(1){b=b-1|0;j=z[Mb(g,u[a+30>>1]+(b-c|0)|0)>>2];k=z[a+32>>2];l=Mb(g,b-u[a+28>>1]|0),n=C(j/k),z[l>>2]=n;f=u[e>>1];c=u[a+28>>1];if((c|0)>=(b|0)){break c}if((f|0)!=-32768){continue}break}}d:{h=u[a+30>>1];b=h+f|0;if((b|0)>u[d+2>>1]|(32767-h|0)<(f|0)){break d}while(1){j=z[a+32>>2];k=z[Mb(g,b-((c<<16>>16)+h|0)|0)>>2];l=Mb(g,b-u[a+28>>1]|0),n=C(k*j),z[l>>2]=n;if(u[d+2>>1]<=(b|0)){break d}h=u[a+30>>1];if(u[e>>1]>(32767-h|0)){break d}b=b+1|0;c=x[a+28>>1];continue}}sq(a);f=1}gb=i+16|0;return f|0}function $1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-496|0;gb=a;Ic(a+488|0,d);v[23048]=0;m=U(2375,a+488|0)|0;g=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Bb(f)){g=v[ck(f,0)>>2];v[23048]=0;i=Q(2397,m|0,45)|0;k=v[23048];v[23048]=0;if((k|0)==1){break g}n=(g|0)==(i|0)}k=Jb(a+456|0);i=Jb(a+440|0);g=Jb(a+424|0);v[23048]=0;na(2419,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,i|0,g|0,a+420|0);c=v[23048];v[23048]=0;if((c|0)==1){break f}v[a+4>>2]=2350;c=ge(a+8|0,0,a+4|0);h=Bb(f);l=v[a+420>>2];h:{if((h|0)>(l|0)){h=Bb(f);j=(Bb(g)+(h-l<<1)|0)+1|0;break h}j=Bb(g)+2|0}h=a+16|0;j=(Bb(i)+j|0)+l|0;if(j>>>0<101){break e}Ge(c,Ad(j<<2));h=v[c>>2];if(h){break e}v[23048]=0;X(2351);b=v[23048];v[23048]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Ob(f);p=Ob(f);f=Bb(f);v[23048]=0;qa(2420,h|0,a+4|0,a|0,j|0,o|0,(f<<2)+p|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,i|0,g|0,l|0);f=v[23048];v[23048]=0;if((f|0)!=1){v[23048]=0;b=la(2400,b|0,h|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Hc(c)}Pc(g);Pc(i);vb(k)}Xb(a+488|0);R(f|0);L()}Hc(c);Pc(g);Pc(i);vb(k);Xb(a+488|0);gb=a+496|0;return b|0}function xx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;g=gb-1040|0;gb=g;s=v[115529];m=g+16|0;a:{b:{c:{n=g+16|0;e=b;h=v[22953];d:{e:{while(1){if((e|0)!=w[d+75792|0]){c=87;d=d+1|0;if((d|0)!=87){continue}break e}break}c=d;if(c){break e}e=75888;break d}d=75888;while(1){i=w[d|0];e=d+1|0;d=e;if(i){continue}d=e;c=c-1|0;if(c){continue}break}}c=v[h+20>>2];if(c){k=v[c+4>>2];d=e;f=v[c>>2];j=v[f>>2]+1794895138|0;l=im(v[f+8>>2],j);h=im(v[f+12>>2],j);i=im(v[f+16>>2],j);f:{if(k>>>2>>>0<=l>>>0){break f}c=k-(l<<2)|0;if((h|i)&3|(c>>>0<=h>>>0|c>>>0<=i>>>0)){break f}u=i>>>2|0;x=h>>>2|0;while(1){o=l>>>1|0;h=o+p|0;i=h<<1;c=(i+x<<2)+f|0;q=im(v[c>>2],j);c=im(v[c+4>>2],j);if(c>>>0>=k>>>0|k-c>>>0<=q>>>0|w[(c+q|0)+f|0]){break f}c=hj(d,c+f|0);if(!c){d=(i+u<<2)+f|0;c=im(v[d>>2],j);d=im(v[d+4>>2],j);if(d>>>0>=k>>>0|c>>>0>=k-d>>>0){break f}r=w[(c+d|0)+f|0]?0:d+f|0;break f}if((l|0)==1){break f}c=(c|0)<0;l=c?o:l-o|0;p=c?p:h;continue}}}d=r?r:e;e=Lf(d);g:{if(e>>>0>=1024){hc(n,d,1023);t[n+1023|0]=0;e=68;break g}hc(n,d,e+1|0);e=0}switch(e+1|0){case 1:break a;case 0:break c;default:break b}}e=v[115529]}m=79860;if((e|0)==28){break a}cb();L()}if(!w[m|0]){v[g>>2]=b;Lx(g+16|0,1024,80064,g);m=g+16|0}v[115529]=s;Tb(a,m);gb=g+1040|0}function Dpa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=E(f)-E(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;hb=a-B(b,c)|0;ib=0;jb=0;return b}e=d;if(!a){break g}if(!e){break f}f=e-1|0;if(f&e){break f}hb=a;ib=f&g;a=g>>>Epa(e)|0;jb=0;return a}f=e-1|0;if(!(f&e)){break e}j=(E(e)+33|0)-E(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}hb=0;a=(g>>>0)/(e>>>0)|0;ib=g-B(a,e)|0;jb=0;return a}f=E(e)-E(g)|0;if(f>>>0<31){break d}break b}hb=a&f;ib=0;if((e|0)==1){break a}c=a;a=Epa(e);d=a&31;if((a&63)>>>0>=32){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}jb=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if((f&63)>>>0>=32){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if((a&63)>>>0>=32){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d-1|0;e=c-1|0;g=(e|0)!=-1?g+1|0:g;h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((f>>>0>h>>>0)+e|0)|0;e=i>>31;i=i>>31;f=c&i;l=k-f|0;f=m-((d&e)+(f>>>0>k>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j-1|0;if(j){continue}break}}hb=l;ib=f;e=b<<1|a>>>31;a=k|a<<1;jb=e|m;return a}hb=a;ib=b;a=0;b=0}jb=b;return a}function wfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;b=a+8|0;iu(b,$d(b));l=wb(b),m=0,v[l>>2]=m;l=b,m=dc(b),v[l>>2]=m;l=dc(b),m=0,v[l>>2]=m;v[a+32>>2]=0;v[a+36>>2]=0;d=a+4|0;v[v[d>>2]>>2]=0;b=v[a>>2];v[v[d>>2]+40>>2]=v[b+480196>>2];v[v[d>>2]+44>>2]=v[b+480204>>2];v[v[d>>2]+80>>2]=v[b+480200>>2];j=x[b+480188>>1];v[h+8>>2]=0;v[h+12>>2]=0;i=h+8|0;u[i+4>>1]=65280;v[i>>2]=0;g=gb-16|0;gb=g;v[g+12>>2]=j;f=a+20|0;a:{if(mg(f)>>>0>=j>>>0){l=g,m=zf(f),v[l+8>>2]=m;c=v[f>>2];b=i;e=v[Gb(g+12|0,g+8|0)>>2];if(e){while(1){v[c>>2]=v[b>>2];u[c+4>>1]=x[b+4>>1];c=c+8|0;e=e-1|0;if(e){continue}break}}b=v[g+12>>2];c=v[g+8>>2];if(b>>>0>c>>>0){mP(f,b-c|0,i);break a}Hj(f,v[f>>2]+(b<<3)|0);break a}b=f;if(v[b>>2]){Rd(b);nP(v[b>>2],mg(b));l=wb(b),m=0,v[l>>2]=m;v[b>>2]=0;v[b+4>>2]=0}c=cv(f,j);if(hs()>>>0<c>>>0){Mc();L()}e=c;if(c>>>0>=536870912){xc(32256);L()}e=jc(e<<3,4);v[b>>2]=e;v[b+4>>2]=e;l=wb(b),m=e+(c<<3)|0,v[l>>2]=m;mP(f,j,i)}gb=g+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(k,880);No((b+v[d>>2]|0)+616|0,v[a>>2],k&65535);t[(b+v[d>>2]|0)+1435|0]=0;t[(b+v[d>>2]|0)+1434|0]=0;t[(b+v[d>>2]|0)+1417|0]=0;t[(b+v[d>>2]|0)+1420|0]=0;t[(b+v[d>>2]|0)+1415|0]=0;k=k+1|0;if(k>>>0<x[v[a>>2]+480188>>1]){continue}break}}gb=h+16|0}function NM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=gb-96|0;gb=c;d=v[b+4>>2];v[c+64>>2]=v[b>>2];v[c+68>>2]=d;b=Xd(c+56|0);v[23048]=0;d=v[c+68>>2];v[c+8>>2]=v[c+64>>2];v[c+12>>2]=d;d=W(254,c+72|0,c+8|0,b|0)|0;e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){Bc(b);v[23048]=0;b=U(511,d|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}v[23048]=0;b=W(1608,d|0,c+16|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}c:{if(!b|v[c+16>>2]!=542066252){break c}b=c+16|4;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break c}b=c+24|0;f=a,g=Ao((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4220>>2]=g;b=c+28|0;f=a,g=Ao((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4224>>2]=g;b=c+32|0;f=a,g=Ao((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4228>>2]=g;b=c+36|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=5){v[a+4232>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}b=c+40|0;v[a+4236>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+4240|0]=w[c+44|0]!=0;t[a+4241|0]=w[c+45|0]!=0;t[a+4242|0]=w[c+46|0]!=0;t[a+4243|0]=w[c+47|0]!=0;t[a+4244|0]=w[c+48|0]!=0;Rt(a)}yb(d);gb=c+96|0;return}a=P()|0;O()|0;Bc(b);break a}a=P()|0;O()|0;yb(d)}R(a|0);L()}function E0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];k=d>>>0>b>>>0;a:{if(f>>>0>=g>>>0|b>>>0>=d>>>0){break a}b:{while(1){i=t[b|0];c=i&255;j=b+1|0;c:{if((i|0)>=0){break c}k=2;if(c>>>0<194){break a}if(c>>>0<=223){if((d-b|0)<2){break b}i=w[b+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;j=b+2|0;break c}if(c>>>0<=239){if((d-b|0)<3){break b}j=w[b+2|0];i=w[b+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((j&192)!=128){break a}c=j&63|(c<<12&61440|(i&63)<<6);j=b+3|0;break c}if(c>>>0>244){break a}if((d-b|0)<4){break b}j=w[b+3|0];l=w[b+2|0];i=w[b+1|0];f:{g:{switch(c-240|0){case 0:if((i+112&255)>>>0<48){break f}break a;case 4:if((i&240)==128){break f}break a;default:break g}}if((i&192)!=128){break a}}if((l&192)!=128|(j&192)!=128){break a}c=j&63|(l<<6&4032|(c<<18&1835008|(i&63)<<12));if(c>>>0>1114111){break a}j=b+4|0}v[f>>2]=c;v[a+12>>2]=j;f=v[a+8>>2]+4|0;v[a+8>>2]=f;b=v[a+12>>2];k=d>>>0>b>>>0;if(f>>>0>=g>>>0){break a}if(b>>>0<d>>>0){continue}break}break a}k=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return k|0}function d2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-192|0;gb=a;Ic(a+184|0,d);v[23048]=0;m=U(21,a+184|0)|0;g=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Bb(f)){g=w[pc(f,0)|0];v[23048]=0;i=Q(22,m|0,45)|0;k=v[23048];v[23048]=0;if((k|0)==1){break g}n=(g|0)==(i&255)}k=Jb(a+160|0);i=Jb(a+144|0);g=Jb(a+128|0);v[23048]=0;na(2417,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,i|0,g|0,a+124|0);c=v[23048];v[23048]=0;if((c|0)==1){break f}v[a+4>>2]=2350;c=ge(a+8|0,0,a+4|0);h=Bb(f);l=v[a+124>>2];h:{if((h|0)>(l|0)){h=Bb(f);j=(Bb(g)+(h-l<<1)|0)+1|0;break h}j=Bb(g)+2|0}h=a+16|0;j=(Bb(i)+j|0)+l|0;if(j>>>0<101){break e}Ge(c,Ad(j));h=v[c>>2];if(h){break e}v[23048]=0;X(2351);b=v[23048];v[23048]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Ob(f);p=Ob(f);f=Bb(f);v[23048]=0;qa(2418,h|0,a+4|0,a|0,j|0,o|0,f+p|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,i|0,g|0,l|0);f=v[23048];v[23048]=0;if((f|0)!=1){v[23048]=0;b=la(17,b|0,h|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Hc(c)}vb(g);vb(i);vb(k)}Xb(a+184|0);R(f|0);L()}Hc(c);vb(g);vb(i);vb(k);Xb(a+184|0);gb=a+192|0;return b|0}function Tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{b:{if(!Nb(b,9)){break b}h=a+484344|0;i=a+480280|0;while(1){dp(b,c+28|0);d=_f(b);c:{if(!((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1229999433|(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1397771593|((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1297110104|(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1297110099))){if(Nb(b,d)){break c}}kg(b,8);break b}td(c+8|0,b,d);d=i;d:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1481001027){while(1){v[23048]=0;e=U(376,c+8|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break a}t[d+8|0]=e;d=d+32|0;if((h|0)!=(d|0)){continue}break d}}e:{if(w[c+28|0]!=70){break e}d=w[c+29|0];e=(d|0)==88;if((d-48&255)>>>0>9?!e:0){break e}f=w[c+30|0];if((f-48&255)>>>0>9){break e}g=w[c+31|0];if((g-48&255)>>>0>9){break e}d=(B(f,10)+(e?-16:B(d,100)+48|0)|0)+g&255;if(d>>>0>249){break d}v[23048]=0;S(646,c+8|0,(B(d,160)+a|0)+906300|0);d=v[23048];v[23048]=0;if((d|0)!=1){break d}break a}if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))!=1430540109){break d}v[a+1074304>>2]=0;j=1}yb(c+8|0);if(Nb(b,9)){continue}break}}gb=c+32|0;return j|0}a=P()|0;O()|0;yb(c+8|0);R(a|0);L()}function Z7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb-2160|0;gb=b;Pb(b+112|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=aa(8)|0;v[23048]=0;b=Q(91,b+96|0,56814)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}rc(a,b);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}g=v[c>>2];d=v[c+12>>2];h=v[c+8>>2];v[b+88>>2]=h;v[b+92>>2]=d;c=v[b+92>>2];v[b+40>>2]=v[b+88>>2];v[b+44>>2]=c;v[b+84>>2]=f;v[b+80>>2]=g;c=v[b+84>>2];v[b+32>>2]=v[b+80>>2];v[b+36>>2]=c;c=b;j=b;i=GT(b+32|0);if(i){e=b- -64|0;v[e>>2]=h;v[b+68>>2]=d;d=v[e+4>>2];v[b+24>>2]=v[e>>2];v[b+28>>2]=d;v[b+60>>2]=f;v[b+56>>2]=g;d=v[b+60>>2];v[b+16>>2]=v[b+56>>2];v[b+20>>2]=d;d=BT(b+16|0)}else{d=0}v[j+72>>2]=d;v[c+76>>2]=0;c=0;d=2048;while(1){d:{e=kb[f|0](g,(b+112|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}c=_d(b+48|0,zb(b+112|0),c);f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;a=Sz(a,b+8|0,i?b+72|0:0);if(a+1>>>0>=3){a=aa(8)|0;v[23048]=0;b=Q(91,b+96|0,56799)|0;c=v[23048];v[23048]=0;if((c|0)!=1){rc(a,b);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;ca(a|0);break b}gb=b+2160|0;return a|0}c=P()|0;O()|0;ca(a|0)}R(c|0)}L()}function foa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;c=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=w[a+3|0];switch(b-14|0){case 8:break j;case 6:case 7:break k;case 1:break l;case 0:break m;case 2:case 3:case 4:case 5:break b;default:break n}}switch(b-31|0){case 2:break h;case 0:break i;default:break b}}o:{p:{b=w[a+5|0];if((b|0)!=240){if((b|0)==15){break p}if(b){break o}a=18030;break g}t[a+5|0]=239;break c}t[a+5|0]=254;break c}if(b>>>0>=16){t[a+5|0]=b|15;break c}t[a+5|0]=b|240;break c}t[a+5|0]=w[a+5|0]^128;break c}c=w[a+5|0];if(c>>>0>=16){t[d+15|0]=c>>>4;t[d+14|0]=15;f=a,g=w[$b(d+15|0,d+14|0)|0]|240,t[f+5|0]=g;break c}t[a+5|0]=c|224;break c}t[a+5|0]=((w[a+5|0]^-1)&254)>>>1;break c}f=a,g=Ki(w[a+5|0]<<1),t[f+5|0]=g;break c}b=32;q:{r:{s:{t:{u:{e=w[a+5|0];switch(e>>>4|0){case 12:case 13:break r;case 11:break s;case 10:break t;case 8:break u;case 0:break c;case 3:break d;case 5:break e;case 14:break f;default:break q}}b=64;break d}b=176;break d}b=224;break d}if(e){break c}}a=18016}t[c+3|0]=w[a|0];break a}t[a+5|0]=119;break c}b=48}t[a+5|0]=e&15|b}b=w[a+3|0]}if(b>>>0>=36){t[a+3|0]=0;break a}t[a+3|0]=w[b+18016|0];if(w[a+2|0]|(b|0)!=12){break a}t[a+2|0]=1;t[a+3|0]=0;c=w[a+5|0];t[a+5|0]=0;t[a+4|0]=c}gb=d+16|0}function TZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-1088|0;gb=f;e=Ah(f+24|0);h=Ok(a,e);yb(e);v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;e=a+1072|0;v[e>>2]=0;v[e+4>>2]=0;e=0;v[a+1080>>2]=0;t[a+1084|0]=d;a:{b:{if(ld(c)){i=a+1064|0;while(1){v[a+1064>>2]=0;v[a+1068>>2]=0;c:{if(!v[c>>2]){break c}while(1){v[23048]=0;d=Q(250,b|0,2)|0;g=v[23048];v[23048]=0;d:{e:{f:{g:{if((g|0)!=1){if(!d){break c}v[23048]=0;d=U(340,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break g}if(!d){break d}v[23048]=0;T(341,f|0,b|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break f}d=Ok(f+24|0,f);id(h,d);hc(h+20|0,d+20|0,1040);yb(f+24|0);yb(f);v[a+1076>>2]=0;v[a+1080>>2]=0;g=Vi(v[a+1060>>2]);d=v[a+1060>>2];if(g>>>0>=2){d=v[d+20>>2];v[23048]=0;S(342,a|0,d+(e<<1)|0);d=v[23048];v[23048]=0;if((d|0)!=1){break d}break e}d=v[d+20>>2];v[23048]=0;S(343,a|0,d+e|0);d=v[23048];v[23048]=0;if((d|0)==1){break e}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(15256)|0;if((O()|0)!=(da(15256)|0)){break a}Z(d|0)|0;v[23048]=0;X(20);d=v[23048];v[23048]=0;if((d|0)==1){break b}}if(y[i>>2]<y[c>>2]){continue}break}}e=e+1|0;if(ld(v[a+1060>>2])>>>0>e>>>0){continue}break}}gb=f+1088|0;return a|0}d=P()|0;O()|0}yb(a);R(d|0);L()}function QI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;k=gb-16|0;gb=k;a:{b:{c:{if((c|0)<=36){h=w[a|0];if(h){break c}f=a;break b}v[115529]=28;d=0;e=0;break a}f=a;d:{while(1){if(!pm(h<<24>>24)){break d}h=w[f+1|0];g=f+1|0;f=g;if(h){continue}break}f=g;break b}e:{g=w[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}m=(g|0)==45?-1:0;f=f+1|0}f:{if(!(c&-17|w[f|0]!=48)){o=1;if((w[f+1|0]&223)==88){f=f+2|0;l=16;break f}f=f+1|0;l=c?c:8;break f}l=c?c:10}p=l;q=l>>31;c=0;while(1){g:{g=t[f|0];h=g-48|0;h:{if((h&255)>>>0<=9){break h}if((g-97&255)>>>0<=25){h=g-87|0;break h}if((g-65&255)>>>0>25){break g}h=g-55|0}if((h|0)>=(l|0)){break g}Bh(k,p,q,j,i);g=1;i:{if(v[k+8>>2]|v[k+12>>2]){break i}r=Fpa(j,i,p,q);n=jb;s=h>>31;u=s^-1;if((n|0)==(u|0)&(h^-1)>>>0<r>>>0|n>>>0>u>>>0){break i}i=n+s|0;g=h+r|0;i=g>>>0<h>>>0?i+1|0:i;j=g;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){v[b>>2]=o?f:a}j:{k:{if(c){v[115529]=68;a=d&1;m=a?0:m;j=d;i=e;break k}if((e|0)==(i|0)&d>>>0>j>>>0|e>>>0>i>>>0){break j}a=d&1}if(!(a|m)){v[115529]=68;a=d;d=a-1|0;e=e-(a>>>0<1)|0;break a}if((e|0)==(i|0)&d>>>0>=j>>>0|e>>>0>i>>>0){break j}v[115529]=68;break a}a=m;c=a^j;d=c-a|0;b=a>>31;e=(b^i)-((a>>>0>c>>>0)+b|0)|0}gb=k+16|0;jb=e;return d}function zV(a,b){var c=0;a:{b:{c:{d:{if(ke(a,24397)){break d}if(ke(a,24424)){break d}if(ke(a,24429)){break d}if(ke(a,24921)){break d}if(!ke(a,24926)){break c}}u[b+8>>1]=4;v[b>>2]=24931;break b}e:{f:{if(ke(a,24402)){break f}if(ke(a,24407)){break f}if(!ke(a,24964)){break e}}t[b+10|0]=1;v[b>>2]=24969;u[b+8>>1]=4;return 1}g:{if(!ke(a,24982)){if(!ke(a,24987)){break g}}u[b+8>>1]=8;v[b>>2]=24992;break b}h:{if(!ke(a,25002)){if(!ke(a,25007)){break h}}v[b>>2]=25012;u[b+8>>1]=t[a+2|0]-48;break b}i:{if(!ke(a,24387)){if(!ke(a,24392)){break i}}v[b+4>>2]=1;v[b>>2]=25030;u[b+8>>1]=w[a|0]==56?8:4;return 1}if(!(zd(a,25061,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=25065;u[b+8>>1]=t[a+3|0]-48;break b}j:{if(zd(a,25081,3)){if(zd(a,25085,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+13|0]=1;t[b+11|0]=1;v[b>>2]=25089;u[b+8>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!zd(a+1|0,25101,3)){t[b+12|0]=1;v[b>>2]=25105;u[b+8>>1]=t[a|0]-48;return 1}if((w[a+1|0]-48&255)>>>0>9|((w[a+2|0]|w[a+3|0]<<8)!=20035?(w[a+2|0]|w[a+3|0]<<8)!=18499:0)){break k}t[b+12|0]=1;v[b>>2]=25105;u[b+8>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}if(zd(a,25136,3)|(w[a+3|0]-52&255)>>>0>5){break a}v[b>>2]=25140;u[b+8>>1]=t[a+3|0]-48}c=1}return c}function SP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;d=v[b+64>>2];a:{b:{f=x[b+68>>1];g=v[b+60>>2];if(!((g|0)==-1?(f|0)==65535:0)){c:{if((d|0)==-1){break c}d=a+1074308|0;Db(e+24|0,d,68);if(Cb(e+24|0)){break c}Db(e+16|0,d,103);if(Cb(e+16|0)?(f|0)!=65535:0){break c}Db(e+8|0,d,49);if(h=Cb(e+8|0),i=0,j=(f|0)!=65535,j?h:i){break c}d=v[b+64>>2];break b}if((f|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((g|0)==-1){v[b+60>>2]=0}d=x[b+68>>1];f=a+484360|0;d:{if(uc(Qb(f))>>>0>d>>>0){d=x[b+68>>1];break d}d=x[Qb(f)+28>>1];u[b+68>>1]=d}e:{if(x[b+72>>1]==(d&65535)){break e}d=a+1074308|0;Db(e+24|0,d,26);if(Cb(e+24|0)){break e}Db(e+16|0,d,68);if(Cb(e+16|0)|v[a+480180>>2]==1|!x[a+480188>>1]){break e}d=0;while(1){t[(B(d,880)+b|0)+1459|0]=0;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[b+52>>2]=v[b+60>>2];if(c){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((d|0)!=-1){break b}c=0;break a}v[b+52>>2]=d;u[b+74>>1]=x[b+72>>1];f:{if(!v[b+20>>2]){break f}if(v[a+480180>>2]==32){Db(e+24|0,a+1074308|0,103);if(Cb(e+24|0)){break f}}if(v[a+480180>>2]==2){break f}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[Yb(a+484344|0,x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}gb=e+32|0;return c}function Mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=gb-48|0;gb=j;m=-1;d=gb-32|0;gb=d;g=j+8|0;fF(d+24|0,g);i=xb(d+24|0);f=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=f;v[d>>2]=e;v[d+4>>2]=f;f=a;md(d+16|0,f,d);e=xb(d+16|0);if((e|0)==(i|0)){bd(f,xb(d+24|0))}gb=d+32|0;f=(e|0)==(i|0);if(!f){gF(g)}a:{if(!f){break a}m=0;if(!gO(j+8|0)){break a}if(c){f=a;e=j+8|0;b:{if(!c){break b}k=Lf(c);if(!k){break b}q=v[f+12>>2];if(Gl(f,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))){c:{if(!(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))){break c}while(1){if(!Qf(f,5)){break c}d:{if((w[e+4|0]|w[e+5|0]<<8)>>>0>=64){d=f;i=Nr(d);h=i&63;e:{if(!(i&64)){break e}g=6;while(1){l=Nr(d);h=(l&127)<<g|h;if(g>>>0>24){break e}g=g+7|0;if(l&128){continue}break}}if(((i&128?0-h|0:h)|0)<1){break d}}g=Nr(f);f:{if(g){i=1;h=0;while(1){l=pq(g<<24>>24);n=h>>>0>=k>>>0;g=n&i;d=g;g:{if(n){break g}d=g;if(!(i&1)){break g}d=w[c+h|0]==(l&255)}i=d;h=h+1|0;g=Nr(f);if(g){continue}break}d=(h|0)==(k|0)&i;break f}d=!k}bd(f,4);o=d?1:o}p=p+1|0;if(p>>>0<(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){continue}break}}h=o&1}Gl(f,q)}if(!h){break a}}m=Qe(a,b,fO(j+8|0),0)}gb=j+48|0;return m|0}function Hq(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=Rb(a),v[f+8>>2]=g;f=c,g=Ub(a),v[f>>2]=g;a=1;j:{if(!Fb(c+8|0,c)){break j}while(1){b=v[c+8>>2];if(!(!ai(b)|v[b+12>>2]==64)){a=4;break j}_O(c+8|0);if(Fb(c+8|0,c)){continue}break}}gb=c+16|0;return a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}gb=c+16|0;return d}function Wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=g+32|0}function VO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b:{d=a+484360|0;if(uc(Qb(d))>>>0<=b>>>0){break b}if(Io(Qb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(uc(Qb(d))>>>0<=c>>>0){break a}if(!Io(Qb(d),b&65535)){continue}break}break a}c=b}if(uc(Qb(d))>>>0>c>>>0){d=a+1074308|0;f=a+1300264|0;c=a+1074984|0;while(1){t[c+799|0]=0;v[c+700>>2]=0;t[c+843|0]=0;t[c+807|0]=0;v[c+708>>2]=0;t[c+823|0]=0;v[c+768>>2]=0;t[c+821|0]=0;t[c+822|0]=0;Db(e+8|0,d,23);if(Cb(e+8|0)){t[c+809|0]=1;t[c+810|0]=0}t[c+841|0]=0;c=c+880|0;if((f|0)!=(c|0)){continue}break}UO(a);c:{if(!(b&65535)){b=a;c=0;while(1){No((b+B(c,880)|0)+1074984|0,b,c&65535);c=c+1|0;if((c|0)!=256){continue}break}mk(b+1300264|0,1);v[b+1074448>>2]=v[b+480200>>2];v[b+1074408>>2]=v[b+480196>>2];v[b+1074412>>2]=v[b+480204>>2];v[b+480208>>2]=v[b+480208>>2]&-769;iA(b+1074368|0);u[b+1074442>>1]=0;v[b+1074384>>2]=-2;c=b+1074420|0;v[c>>2]=0;v[c+4>>2]=0;c=b+1074388|0;v[c>>2]=0;v[c+4>>2]=0;v[b+1074368>>2]=0;v[b+1074372>>2]=0;break c}u[a+1074442>>1]=b;u[a+1074438>>1]=0;b=a+1074416|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074384>>2]=-2;v[a+1074424>>2]=0;b=a+1074388|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074372>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}gb=e+16|0}function Pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=Nf(a);if(f>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{d=b-f|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/52>>>0){_y(a,d,c);break c}h=wb(a);e=GN(a,Nf(a)+d|0);g=Nf(a);f=0;i=gb-16|0;gb=i;v[i+12>>2]=0;b=j+8|0;vd(b+12|0,h);if(e){f=BN(e)}v[b>>2]=f;h=B(g,52)+f|0;v[b+8>>2]=h;v[b+4>>2]=h;m=bc(b),n=B(e,52)+f|0,v[m>>2]=n;gb=i+16|0;v[23048]=0;T(1506,b|0,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=a;JO(a);wb(a);f=b;k=b+4|0;i=k;h=v[a>>2];a=v[a+4>>2];if((h|0)!=(a|0)){d=v[i>>2];while(1){d=d-52|0;a=a-52|0;e=zN(d,wb(a));v[d>>2]=v[a>>2];v[d+4>>2]=v[a+4>>2];g=v[wb(a)>>2];m=wb(e),n=g,v[m>>2]=n;m=wb(a),n=0,v[m>>2]=n;v[a>>2]=0;v[a+4>>2]=0;v[d+20>>2]=v[a+20>>2];e=v[a+16>>2];v[d+12>>2]=v[a+12>>2];v[d+16>>2]=e;g=d+24|0;e=a+24|0;l=bE(g,wb(e));v[g>>2]=v[e>>2];v[g+4>>2]=v[e+4>>2];g=v[wb(e)>>2];m=wb(l),n=g,v[m>>2]=n;m=wb(e),n=0,v[m>>2]=n;v[e>>2]=0;v[e+4>>2]=0;Dc(d+36|0,a+36|0);v[d+48>>2]=v[a+48>>2];d=v[i>>2]-52|0;v[i>>2]=d;if((a|0)!=(h|0)){continue}break}}zc(c,k);zc(c+4|0,f+8|0);zc(wb(c),bc(f));v[f>>2]=v[f+4>>2];AN(c,Nf(c));yN(b)}gb=j+32|0;break a}a=P()|0;O()|0;yN(b);R(a|0);L()}return}if(b>>>0<f>>>0){HN(a,v[a>>2]+B(b,52)|0)}}function A$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(Kg(a,v[b+8>>2],e)){Tw(b,c,d);return}a:{if(Kg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}d=v[a+12>>2];if((d|0)<=0){v[b+44>>2]=4;break b}i=((d<<3)+a|0)+16|0;f=a+16|0;j=b;c:{d:{while(1){e:{u[b+52>>1]=0;Sw(f,b,c,c,1,e);if(w[b+54|0]){break e}f:{if(!w[b+53|0]){break f}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break d}h=1;g=1;if(w[a+8|0]&2){break f}break d}h=1;d=g;if(!(t[a+8|0]&1)){break d}}f=f+8|0;if(i>>>0>f>>>0){continue}}break}d=g;a=4;if(!h){break c}}a=3}v[j+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];f=a+16|0;xs(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=v[a+8>>2];if(!(v[b+36>>2]!=1?!(a&2):0)){while(1){if(w[b+54|0]){break a}xs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}xs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|(v[b+24>>2]==1?v[b+36>>2]==1:0)){break a}xs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function s2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=gb-160|0;gb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=2402;b=ge(a+24|0,a+32|0,a+20|0);v[23048]=0;Ic(a+16|0,e);h=v[23048];v[23048]=0;a:{b:{c:{d:{if((h|0)!=1){v[23048]=0;h=U(21,a+16|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break b}t[a+15|0]=0;e=v[e+4>>2];v[23048]=0;c=ra(2403,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(!c){break c}bf(g);if(!w[a+15|0]){break d}v[23048]=0;c=Q(22,h|0,45)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;S(110,g|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[23048]=0;h=Q(22,h|0,48)|0;c=v[23048];v[23048]=0;if((c|0)==1){break b}e=v[b>>2];i=v[a+20>>2];c=i-1|0;d=c>>>0<e>>>0?e:c;e:{if(c>>>0<=e>>>0){break e}h=h&255;while(1){if((h|0)!=w[e|0]){d=e;break e}e=e+1|0;if((c|0)!=(e|0)){continue}break}}v[23048]=0;T(2409,g|0,d|0,i|0);c=v[23048];v[23048]=0;if((c|0)!=1){break c}break b}v[23048]=0;c=Q(2353,a+152|0,a+144|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Xb(a+16|0);Hc(b);gb=a+160|0;return c|0}e=P()|0;O()|0;Xb(a+16|0)}Hc(b);R(e|0);L()}function qha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Xd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=gg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Kd(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Kd(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Sb(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function SY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;t[g+12|0]=0;l=BD(g+16|0,d,g+12|0);h=v[l>>2];v[g+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){m=g;k=b-1|0;f=w[a|0];b:{c:{if(!(!k|(f|0)!=(e&255))){f=w[a+1|0];v[23048]=0;v[g+8>>2]=f;f=Gb(g+8|0,g+12|0);j=v[23048];v[23048]=0;d:{if((j|0)!=1){j=a+2|0;k=b-2|0;if(!k){break d}i=v[f>>2];if(!(i&255)){break d}j=w[j|0];while(1){t[h|0]=j;f=v[g+12>>2]-1|0;v[g+12>>2]=f;h=h+1|0;i=i-1|0;if(i&255){continue}break}k=b-3|0;j=a+3|0;break b}a=P()|0;O()|0;gc(l);R(a|0);L()}t[h|0]=e;f=v[g+12>>2]-1|0;break c}j=a+1|0;t[h|0]=f;f=v[g+12>>2]-1|0}v[m+12>>2]=f;h=h+1|0}if(!f){break a}a=j;b=k;if(b){continue}break}}j=v[l>>2];e=d-f|0;if(e){h=128;k=0;while(1){b=w[j|0];i=0;f=0;while(1){a=c+k|0;t[a|0]=w[a|0]|(B(b&h,257)&65535)>>>(f-i&7);a=k+1|0;k=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;h=(h<<8|h)>>>1&255;a=i&65535;i=i+1|0;if(a>>>0<7){continue}break}h=(B(h,257)&65535)>>>f&255;j=j+1|0;n=n+1|0;if((n|0)!=(e|0)){continue}break}i=0;while(1){d=c;f=d;m=i<<24>>24;b=t[d|0];d=128;e:{if((b|0)==-128){break e}a=b;d=a;if((a|0)>-1){break e}d=0-(b&127)|0}i=m-(d&255)|0;t[f|0]=i;c=c+1|0;e=e-1|0;if(e){continue}break}}gc(l);gb=g+32|0}function F7(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-80|0;gb=d;a:{b:{c:{d:{e:{f:{g:{if(mj(a)){lh(d+72|0);break g}fo(d+32|0,a);v[23048]=0;S(2087,d+72|0,d+32|0);c=v[23048];v[23048]=0;if((c|0)==1){break f}Tf(d+32|0)}f=a+36|0;h:{if(mj(a)){break h}f=v[d+72>>2]}c=v[a+8>>2];if((c|0)!=-1){break c}c=v[f+4>>2]-24|0;h=bo(f);if(h){break e}break d}g=P()|0;O()|0;Tf(d+32|0);break a}j=A[c>>3];while(1){e=Il(f,g);if(A[e>>3]+i>b){c=e;break d}i=j+i;g=g+1|0;if((h|0)!=(g|0)){continue}break}}b=b-i;break b}c=Il(f,c)}f=a+24|0;e=v[f>>2];g=x[c+12>>1];v[23048]=0;S(2088,e|0,g|0);e=v[23048];v[23048]=0;if((e|0)!=1){i:{e=v[f>>2];g=w[a+64|0];c=sL(tV(d+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[23048]=0;h=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=h;h=v[c+20>>2];v[d+24>>2]=v[c+16>>2];v[d+28>>2]=h;h=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=h;Y(2052,d+56|0,e|0,(g?7:1)|0,d+8|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}c=PO(d+56|0);e=t[c+26|0]&1;g=v[(e?c+8|0:c+12|0)>>2];e=x[(e?c+20|0:c+22|0)>>1];b=A[c>>3];Rm(d+56|0);u[v[f>>2]+1074440>>1]=e;u[v[f>>2]+1074442>>1]=e;v[v[f>>2]+1074420>>2]=g;v[v[f>>2]+1074384>>2]=-2;b=b+i;A[a+16>>3]=b;ll(d+72|0);gb=d+80|0;return+b}}g=P()|0;O()|0;ll(d+72|0)}R(g|0);L()}function dT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=gb-16|0;gb=g;a:{if(w[d|0]){e=pe(g+8|0,b);b=Cj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Gb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){_c(a,c,Epa(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){hB(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){_c(a,c,Epa(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}_c(a,c,Epa(e));break b}_c(a,c,b)}break a}e=pe(g,b);b=Cj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Gb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){_c(a,c,Epa(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){hB(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){_c(a,c,Epa(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}_c(a,c,Epa(e));break d}_c(a,c,b)}}gb=d+16|0;gb=g+16|0}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=e;h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=e;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(d){while(1){e=i+q|0;i=t[e+2|0];m=t[e+1|0];n=t[e|0];o=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=ac(b,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);e=Fpa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];p=Fpa(e,e>>31,f,f>>31);e=w+p|0;f=jb+j|0;f=e>>>0<p>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(n,u[e+40882>>1])+B(o,u[e+40880>>1])|0)+B(m,u[e+40884>>1])|0)+B(i,u[e+40886>>1])<<8)/16384<<8;e=i;h=Fpa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);e=v[a+72>>2];h=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=h+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&i)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function Am(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;f=a+1074308|0;Db(e+8|0,f,96);d=Cb(e+8|0);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[a+480180>>2]==16384?v[b+88>>2]&1:0)|0;b:{if(ne(b+790|0)){d=v[b+656>>2];if(d){d=x[ud(d+236|0,w[b+790|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if(!(w[b+88|0]&2)|y[b+84>>2]>c>>>0?y[b+76>>2]>c>>>0:0){break b}Db(e+8|0,f,57);if(!(h=!Cb(e+8|0),i=0,j=v[a+480180>>2]!=16,j?h:i)){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){Db(e+8|0,f,27);if(Cb(e+8|0)){if(w[a+480208|0]&4){d=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=d;break b}v[b>>2]=0;v[b+4>>2]=0;break b}d=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=d;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}gb=e+16|0}function Uma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&63;if(nv(c)>>>0>d>>>0){g=qW(c,d);h=gb-16|0;gb=h;c=a;t[c+12|0]=0;xg(c);f=gb-32|0;gb=f;a:{b:{d=c;if(Ce(d)>>>0<=14){e=wb(d);e=Ap(f+8|0,15,Lb(d),e);v[23048]=0;S(353,d|0,e|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}Ti(e)}gb=f+32|0;break a}a=P()|0;O()|0;Ti(e);R(a|0);L()}d=w[g+1|0];c:{if(!d){break c}f=0-d|0;while(1){t[h+7|0]=64;f=(f<<16>>16)+d|0;j=tr(h+8|0,f&65535,w[$b(((i<<1)+g|0)+2|0,h+7|0)|0]);d=c;d:{if(y[d+4>>2]<y[wb(d)>>2]){iW(d,j);break d}k=gb-32|0;gb=k;e=d;l=wb(d);d=Ap(k+8|0,Tg(d,Lb(d)+1|0),Lb(d),l);m=v[d+8>>2];v[23048]=0;$o(l,m,j);j=v[23048];v[23048]=0;e:{f:{if((j|0)==1){break f}v[d+8>>2]=v[d+8>>2]+4;v[23048]=0;S(353,e|0,d|0);e=v[23048];v[23048]=0;if((e|0)==1){break f}Ti(d);gb=k+32|0;break e}a=P()|0;O()|0;Ti(d);R(a|0);L()}}i=i+1|0;if((i|0)==15){break c}d=w[((i<<1)+g|0)+1|0];if(d){continue}break}}d=w[g+32|0];t[c+14|0]=d>>>4;t[c+13|0]=d&15;d=w[g+31|0];e=d&15;t[c+15|0]=e;t[c+16|0]=e;if(d&16){t[c+12|0]=w[c+12|0]|4}if(d&32){t[c+12|0]=w[c+12|0]|2}gb=h+16|0}g:{h:{if(b<<24>>24>=0){b=a+12|0;break h}c=a;b=c+12|0;if(cd(c)){break h}a=w[c+12|0]|1;break g}a=w[a+12|0]&-2}t[b|0]=a}function Ed(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb+-64|0;gb=d;v[a+480180>>2]=b;b=Hq(a);Vz(d,b);e=v[d+12>>2];c=a+1074316|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074308>>2]=v[d>>2];v[a+1074312>>2]=c;du(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Zb(mv(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074300>>2]=0;v[a+1074304>>2]=0;u[a+480192>>1]=0;Uz(a,4);e=gb+-64|0;gb=e;b=a+484344|0;IN(b);f=Nf(b);c=$y(e+8|0,b);v[23048]=0;T(1501,b|0,f|0,c|0);b=v[23048];v[23048]=0;a:{if((b|0)!=1){xm(c);gb=e- -64|0;break a}a=P()|0;O()|0;xm(c);R(a|0);L()}rS(a+484360|0);bf(a+1300308|0);bf(a+1300320|0);bf(a+1300332|0);c=a+1300344|0;d=Pb(d,0,64);b=gP(d);Eb(c,b);Eb(c+12|0,b+12|0);Eb(c+24|0,b+24|0);Eb(c+36|0,b+36|0);Eb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];hu(b);dD(a+1300408|0);xg(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}gb=d- -64|0}function yca(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-32|0;gb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=kb[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[sd(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[23048]=0;S(488,d+4|0,b+4|0);b=v[23048];v[23048]=0;c:{if((b|0)!=1){b=v[a+20>>2];v[23048]=0;me(c+8|0,b+4|0);b=v[23048];v[23048]=0;if((b|0)!=1){v[c>>2]=0;v[c+4>>2]=0;b=v[c+12>>2];v[c+16>>2]=v[c+8>>2];v[c+20>>2]=b;b=v[c+4>>2];v[c+24>>2]=v[c>>2];v[c+28>>2]=b;v[23048]=0;_(1645,c+16|0);b=v[23048];v[23048]=0;d:{e:{if((b|0)==1){break e}b=v[v[a>>2]+180>>2];v[23048]=0;S(b|0,a|0,-1);b=v[23048];v[23048]=0;if((b|0)==1){break e}b=0;if((e|0)>0){while(1){d=v[v[a>>2]+48>>2];v[23048]=0;f=C(Ya(d|0,a|0,b|0));d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;z[c+8>>2]=f;S(1646,c+16|0,c+8|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+184>>2];v[23048]=0;_(b|0,a|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(90496)|0;break c}b=V(90496)|0;break c}b=V(90496)|0;break c}b=V(90496)|0}if((O()|0)!=(da(90496)|0)){break a}Z(b|0)|0;Cr(v[a+20>>2]+4|0);$()}gb=c+32|0;return}R(b|0);L()}function Xha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=gb-32|0;gb=e;a:{b:{c:{f=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?f>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?f>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?f>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?f>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;gb=e+32|0}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){f=(g<<1)+q|0;i=u[f>>1];m=u[f-2>>1];n=u[f+2>>1];r=u[f+4>>1];p=v[a+60>>2];f=ac(b,-16777216,16776704);o=v[a+64>>2];g=ac(e,-16777216,16776704);e=Fpa(o,o>>31,f,f>>31);o=jb;f=e;e=j>>>21&2040;j=(((B(i,u[e+40882>>1])+B(m,u[e+40880>>1])|0)+B(n,u[e+40884>>1])|0)+B(r,u[e+40886>>1])|0)/16384<<8;e=j;i=Fpa(p,p>>31,e,e>>31);f=f+i|0;e=jb+o|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=Fpa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Lc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);k=g+k|0;m=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,m);f=e-(f&j)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}m=k>>12;i=l>>12;f=b}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=m;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;wd(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=oh(wg(+(f+1408|0)*.0006510416666666666)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[$b(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+40864|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[$b(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);gb=e+16|0}function LI(a,b){var c=0,d=0,e=0,f=0;a:{b:{c:{c=v[a+4>>2];d:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break d}c=pd(a)}switch(c-43|0){case 0:case 2:break b;default:break c}}b=c-48|0;break a}f=(c|0)==45;d=!b;b=v[a+4>>2];e:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break e}c=pd(a)}b=c-48|0;if(!(d|b>>>0<10|!v[a+104>>2])){v[a+4>>2]=v[a+4>>2]-1}}f:{if(b>>>0<=9){b=0;while(1){d=(b+c|0)-48|0;e=(d|0)>214748363;b=v[a+4>>2];g:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break g}c=pd(a)}b=c-48|0;if(!(e|b>>>0>9)){b=B(d,10);continue}break}e=d;d=d>>31;h:{if(b>>>0>=10){break h}while(1){e=Fpa(e,d,10,0);c=e+c|0;b=jb;b=c>>>0<e>>>0?b+1|0:b;e=c-48|0;d=b-(c>>>0<48)|0;b=v[a+4>>2];i:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break i}c=pd(a)}b=c-48|0;if((d|0)>21474836?1:(d|0)>=21474836?e>>>0>2061584301:0){break h}if(b>>>0<10){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];j:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break j}b=pd(a)}if(b-48>>>0<10){continue}break}}if(v[a+104>>2]){v[a+4>>2]=v[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break f}d=-2147483648;if(!v[a+104>>2]){break f}v[a+4>>2]=v[a+4>>2]-1;jb=-2147483648;return 0}jb=d;return e}function Mu(a,b){var c=0,d=0,e=0,f=0;f=gb-48|0;gb=f;qT(f+24|0,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);qT(f,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=1;e=f+24|0;a=v[e>>2];d=Ib(w[a|0]|w[a+1|0]<<8);a=f;c=v[a>>2];a:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=0;c=v[a>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=1;c=v[e+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+4>>2];b:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=0;c=v[a+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+4>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=1;c=v[e+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+8>>2];c:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=0;c=v[a+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+8>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=1;c=v[e+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[a+12>>2];d:{if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=0;c=v[a+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[e+12>>2];if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=v[e+16>>2];c=Ib(w[b|0]|w[b+1|0]<<8);b=v[a+16>>2];b=c>>>0<Ib(w[b|0]|w[b+1|0]<<8)>>>0;if(!b){a=v[a+16>>2];Ib(w[a|0]|w[a+1|0]<<8);a=v[e+16>>2];Ib(w[a|0]|w[a+1|0]<<8)}}}}}gb=f+48|0;return b}function fo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;g=dd(a);e=b+24|0;a:{b:{if(Ei(v[e>>2]+484360|0)){if(Ei(v[e>>2]+484360|0)){b=0;while(1){f=v[e>>2];a=sL(uV(c+40|0,1),b&255,0,0);v[23048]=0;d=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=d;d=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=d;d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;Y(2052,c- -64|0,f|0,0,c|0);a=v[23048];v[23048]=0;c:{d:{if((a|0)!=1){i=c,j=Rb(c- -64|0),v[i+32>>2]=j;i=c,j=Ub(c- -64|0),v[i+24>>2]=j;if(Fb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{a=v[c+32>>2];h=A[a>>3];f=v[a+16>>2];d=x[a+24>>1];a=c+40|0;v[a+16>>2]=b;v[a+12>>2]=d;v[a+8>>2]=f;A[a>>3]=h;v[23048]=0;S(2053,g|0,a|0);a=v[23048];v[23048]=0;if((a|0)==1){break e}v[c+32>>2]=v[c+32>>2]+32;if(Fb(c+32|0,c+24|0)){continue}break c}break}a=P()|0;O()|0;Rm(c- -64|0);break b}Rm(c- -64|0);b=b+1|0;if(Ei(v[e>>2]+484360|0)>>>0>b>>>0){continue}break}}gb=c+80|0;return}b=aa(8)|0;v[23048]=0;c=Q(91,c+40|0,56752)|0;a=v[23048];v[23048]=0;if((a|0)!=1){rc(b,c);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;ca(b|0)}Tf(g);R(a|0)}L()}function gO(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}d=a+16|0;b=d;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}e=a+24|0;b=e;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}f=a+32|0;b=f;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}c=a+12|0;b=c;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=c;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>858993459){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>536870911){break a}a=a+28|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>1073741823|B(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24),-5)-1>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<<3^-1)>>>0){break a}g=(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<=((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))<<2^-1)>>>0}return g}function aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=gb-16|0;gb=k;a:{b:{if(!Od(a)){break b}if((b|0)==(c|0)|(ld(a)|0)!=2){break b}e=(a|0)==(b|0);if(Od(b)?!e:0){break b}g=(a|0)==(c|0);if(Od(c)?!g:0){break b}if((a|0)==(b|0)){j=v[b+20>>2]}else{j=$q(v[a>>2],Vi(a))}h=j;if((a|0)==(c|0)){i=v[c+20>>2]}else{i=$q(v[a>>2],Vi(a))}if(!(i?h:0)){if(!e){ar(j)}if(g){break b}ar(i);break b}c:{if((Vi(a)|0)==2){g=j;h=i;f=v[a+20>>2];e=v[a>>2];if(e){while(1){u[g>>1]=x[f>>1];u[h>>1]=x[f+2>>1];f=f+4|0;h=h+2|0;g=g+2|0;e=e-1|0;if(e){continue}break}}break c}if((Vi(a)|0)!=1){break c}g=j;h=i;f=v[a+20>>2];e=v[a>>2];if(e){while(1){t[g|0]=w[f|0];t[h|0]=w[f+1|0];f=f+2|0;h=h+1|0;g=g+1|0;e=e-1|0;if(e){continue}break}}}Uo(b,a);v[b+20>>2]=j;u[b+34>>1]=x[b+34>>1]&65471;Uo(c,a);v[c+20>>2]=i;u[c+34>>1]=x[c+34>>1]&65471;j=d+1300264|0;a=d+1074984|0;while(1){i=v[a+104>>2];if(!((c|0)!=(i|0)?(i|0)!=(b|0):0)){v[a+88>>2]=v[a+88>>2]&-65}a=a+880|0;if((j|0)!=(a|0)){continue}break}v[23048]=0;Sh(b,d,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}v[23048]=0;Sh(c,d,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}f=1}gb=k+16|0;return f|0}a=P()|0;O()|0;R(a|0);L()}function Xfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(y[a+4>>2]<y[wb(a)>>2]){h=gb-16|0;gb=h;c=h;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+28;a=wb(a);d=v[c+4>>2];v[23048]=0;tu(a,d,b);a=v[23048];v[23048]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+28;_b(c);gb=h+16|0;break a}a=P()|0;O()|0;_b(c);R(a|0);L()}return}i=gb-32|0;gb=i;h=a;j=wb(a);e=i+8|0;c=Je(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=c;d=c;c=gb-16|0;gb=c;g=a;wb(a);v[c+12>>2]=153391689;v[23048]=0;v[c+8>>2]=2147483647;k=Gb(c+12|0,c+8|0);l=v[23048];v[23048]=0;b:{if((l|0)!=1){gb=c+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Ab();L()}c:{if(c>>>0>=d>>>0){d=Mi(g);if(d>>>0<c>>>1>>>0){v[f+8>>2]=d<<1;c=v[Jc(f+8|0,f+12|0)>>2]}gb=f+16|0;break c}Mc();L()}g=Je(a);a=0;d=gb-16|0;gb=d;v[d+12>>2]=0;Zf(e+12|0,j);if(c){a=c;if(a>>>0>153391689){xc(30917);L()}a=jc(B(a,28),4)}v[e>>2]=a;g=B(g,28)+a|0;v[e+8>>2]=g;v[e+4>>2]=g;m=bc(e),n=B(c,28)+a|0,v[m>>2]=n;gb=d+16|0;a=v[e+8>>2];v[23048]=0;tu(j,a,b);a=v[23048];v[23048]=0;d:{e:{if((a|0)==1){break e}v[e+8>>2]=v[e+8>>2]+28;v[23048]=0;XQ(h,e);a=v[23048];v[23048]=0;if((a|0)==1){break e}WQ(e);gb=i+32|0;break d}a=P()|0;O()|0;WQ(e);R(a|0);L()}}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;if(!w[a+4242|0]){Ry(a);a:{if(!w[a+4240|0]){break a}e=WO(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Ot(a)}g=a+4256|0;b:{if(w[a+4244|0]){if(!(A[g>>3]<=1)){v[g>>2]=0;v[g+4>>2]=1072693248}break b}j=(v[a+4232>>2]&-2)!=4;e=A[g>>3];c:{if(D(e)<2147483648){f=~~e;break c}f=-2147483648}if(!(j|(f|0)<1)){Oy(a);e=A[a+4256>>3]}A[g>>3]=e-+(f|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=ji(A[a+4256>>3]*6.283185307179586);break d;case 1:e=D(A[a+4256>>3]+-.5)*-4+1;break d;case 2:e=A[a+4256>>3];e=e+e+-1;break d;case 3:e=A[a+4256>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];i=A[a+4272>>3];e=e*e*e*(A[a+4280>>3]-i)*((e*6+-15)*e+10)+i}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];hg(h+8|0,0,1);f=ek(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){l=f,m=g>>>8&15|176|(g&127)<<8|Xm(A[h+8>>3]*127)<<16,k=v[v[f>>2]+68>>2],kb[k](l|0,m|0)|0;break f}kb[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}f=a;a=a+44|0;si(f,b,c,Pd(a,0),Pd(a,1),d);gb=h+16|0}function spa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;g=gb-144|0;gb=g;l=Kr(a);if(l){p=g+8|4;q=g+8|6;r=g+8|5;k=g+8|2;m=g+8|3;n=g+16|0;while(1){f=gb-32|0;gb=f;h=g+8|0;cc(f+24|0,h,136);j=xb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=a;fc(f+16|0,e,f);i=xb(f+16|0);if((i|0)==(j|0)){Vb(e,xb(f+24|0))}gb=f+32|0;if((i|0)!=(j|0)){Pb(h,0,136)}e=Ib(w[g+8|0]|w[g+9|0]<<8);a:{if(!e|e>>>0>x[c+480192>>1]){break a}e=v[((e<<2)+c|0)+900380>>2];if(!e){break a}e=ci(e,b);b:{if(!w[m|0]){break b}if(t[k|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[k|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[k|0]&4)){break b}t[e+12|0]=w[e+12|0]|2}t[g+4|0]=w[m|0];t[g+7|0]=31;h=w[$b(g+4|0,g+7|0)|0]+1|0;j=h&255;Eg(e,j);t[e+13|0]=w[r|0];t[e+14|0]=w[q|0];f=w[p|0];t[e+15|0]=f;t[e+16|0]=f;f=0;if((h|0)!=(j|0)){break a}while(1){h=f<<2;i=h+n|0;i=Ib(w[i|0]|w[i+1|0]<<8);s=Mb(e,f),y=i,u[s>>1]=y;h=(h|2)+n|0;h=Ib(w[h|0]|w[h+1|0]<<8);u[g+4>>1]=d?h+128>>>2|0:h;og(g+4|0,64);h=w[g+4|0];s=Mb(e,f),y=h,t[s+2|0]=y;f=f+1|0;if((j|0)!=(f|0)){continue}break}}o=o+1|0;if((o&65535)>>>0<l>>>0){continue}break}}gb=g+144|0}function qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=gb-48|0;gb=j;if(Te(b)>>>0>c>>>0){while(1){f=l&65535;if(ai(ef(b,f))){e=Rb(ef(b,f));f=Ub(ef(b,f));m=kT(j,d);n=m;h=gb-16|0;gb=h;v[h>>2]=f;v[h+8>>2]=e;if(Fb(h+8|0,h)){while(1){f=n;i=gb-16|0;gb=i;e=v[h+8>>2];if(!(w[e+3|0]!=4|w[e+5|0])){ve(i+8|0,f,x[f+14>>1]);Ef(i+8|0,0);t[e+3|0]=0}g=w[e+2|0];a:{if((g|0)!=11){break a}g=11;if(w[e+4|0]){break a}ve(i+8|0,f,x[f+14>>1]);g=0;Ef(i+8|0,0);t[e+2|0]=0}b:{c:{d:{if(!w[e|0]){ve(i+8|0,f,x[f+14>>1]);if(Cb(i+8|0)){break d}g=w[e+2|0]}k=w[e+3|0];ve(i+8|0,f,x[f+14>>1]);Ef(i+8|0,(g|0)==11|(k|0)==4);g=w[e+3|0];break c}g=w[e+3|0];k=w[e+2|0];if(!(g|(k|0)==11)){t[e+5|0]=0;t[e+3|0]=4;break b}if(k|(g|0)==4){break c}t[e+4|0]=0;t[e+2|0]=11}e:{if(!(!w[f+16|0]|g)){t[e+5|0]=125;t[e+3|0]=17;break e}f:{switch(g-16|0){case 1:break e;case 0:break f;default:break b}}if(w[e+5|0]){break b}t[e+5|0]=6;t[f+16|0]=1;break b}t[f+16|0]=0}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];gb=i+16|0;Oj(h+8|0);if(Fb(h+8|0,h)){continue}break}}jT(j+24|0,n);gb=h+16|0;Ee(j+24|0);Ee(m)}l=l+1|0;if((l&65535)>>>0<=c>>>0){continue}break}}jT(a,d);gb=j+48|0}function oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Xd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=gg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Kd(v[f+8>>2],u[(i<<1)+g>>1]/4<<16>>16);Jd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Kd(b,u[g+(v[e+44>>2]<<1)>>1]/4<<16>>16);Jd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Sb(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function Rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;i=gb-16|0;gb=i;wd(d,32);IT(i+8|0,a+20|0,b);p=i+8|0;g=dc(i+8|0);IT(i,a+36|0,c);q=i;f=dc(i);a=0;g=v[g>>2];if(g-1>>>0<=838859){a=v[f>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;n=Mm(d);if(n){r=+(g>>>0);s=+(a>>>0);m=g<<2;z=m>>>0>1?m:1;o=1/+(m>>>0);A=1/+y[d>>2];g=0;while(1){k=+(g>>>0);a=v[p>>2];j=0;if(Od(b)){e=k*r*o+ +(a>>>0);a:{if(e<4294967296&e>=0){a=~~e>>>0;break a}a=0}f=ld(b);h=B(a,f);e=e-J(e);b:{if(t[b+34|0]&1){l=v[b+20>>2];a=u[l+(h<<1)>>1];f=x[l+(f+h<<1)>>1];break b}a=v[b+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}j=+(a<<16>>16);j=(+(f<<16>>16)-j)*e+j}a=v[q>>2];if(Od(c)){e=k*s*o+ +(a>>>0);c:{if(e<4294967296&e>=0){a=~~e>>>0;break c}a=0}f=ld(c);h=B(a,f);e=e-J(e);d:{if(t[c+34|0]&1){l=v[c+20>>2];a=u[l+(h<<1)>>1];f=x[l+(f+h<<1)>>1];break d}a=v[c+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}k=+(a<<16>>16);e=(+(f<<16>>16)-k)*e+k}else{e=0}e=e-j;f=1;a=g;while(1){h=HT(e*+(a>>>0)*A+j);u[v[d+20>>2]+(a<<1)>>1]=h;if((f|0)!=80){a=a+m|0;f=f+1|0;continue}break}g=g+1|0;if((z|0)!=(g|0)){continue}break}}a=(n|0)!=0}gb=i+16|0;return a|0}function rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Xd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=gg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Kd(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Jd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Kd(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Sb(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function uca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;g=dd(a);v[23048]=0;_(1658,g|0);b=v[23048];v[23048]=0;a:{if((b|0)!=1){b=47040;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){d=Ng(44);if(d){h=v[b>>2];f=v[b+4>>2];v[23048]=0;f=Q(91,c+32|0,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break k}v[23048]=0;S(1659,c+48|0,f|0);e=v[23048];v[23048]=0;if((e|0)==1){break j}e=v[b+8>>2];v[23048]=0;e=Q(91,c|0,e|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break i}v[23048]=0;S(1659,c+16|0,e|0);i=v[23048];v[23048]=0;if((i|0)==1){break h}v[23048]=0;ba(1660,d|0,h|0,c+48|0,c+16|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break g}Hb(c+16|0);vb(e);Hb(c+48|0);vb(f);v[c+60>>2]=d;v[23048]=0;S(1661,g|0,c+60|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=47328){continue}break}gb=c- -64|0;return a|0}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;Hb(c+16|0)}vb(e)}Hb(c+48|0)}vb(f)}Zb(d);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}sl(g);R(b|0);L()}function gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Pf(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>11>>>0){c=gb-16|0;gb=c;g=a;b=c;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);d:{if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(g);a=v[b+4>>2];v[23048]=0;Py(a);a=v[23048];v[23048]=0;if((a|0)==1){break d}a=v[b+4>>2]+2048|0;v[b+4>>2]=a;if((a|0)!=v[b+8>>2]){continue}break}}_b(b);gb=c+16|0;break c}a=P()|0;O()|0;_b(b);R(a|0);L()}h=wb(a);i=f+8|0;b=Pf(a)+e|0;d=gb-16|0;gb=d;v[d+12>>2]=b;c=b;b=gb-16|0;gb=b;g=a;wb(a);v[b+12>>2]=2097151;v[23048]=0;v[b+8>>2]=2147483647;j=Gb(b+12|0,b+8|0);k=v[23048];v[23048]=0;e:{if((k|0)!=1){gb=b+16|0;b=v[j>>2];break e}V(0)|0;O()|0;Ab();L()}f:{if(b>>>0>=c>>>0){c=nl(g);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[Jc(d+8|0,d+12|0)>>2]}gb=d+16|0;break f}Mc();L()}b=VM(i,b,Pf(a),h);v[23048]=0;S(1554,b|0,e|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(1550,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}St(b)}gb=f+32|0;break a}a=P()|0;O()|0;St(b);R(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<11)|0;Pf(a);TM(a,b);WM(a)}}function dK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);e=gb-48|0;gb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+52>>2]){case 0:d=0;b=gb-96|0;gb=b;f=v[c>>2];h=v[f+4>>2];g=v[f+24>>2];v[b+48>>2]=v[f+20>>2];v[b+52>>2]=g;g=v[f+16>>2];v[b+40>>2]=v[f+12>>2];v[b+44>>2]=g;bk(b+72|0,b+40|0,h);f=lf(b+56|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];g=v[v[c+8>>2]>>2];v[b+32>>2]=v[b+88>>2];c=v[b+84>>2];v[b+24>>2]=v[b+80>>2];v[b+28>>2]=c;c=v[b+76>>2];v[b+16>>2]=v[b+72>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;i=b+16|0;c=b;if(h){while(1){f=0;if(g){while(1){j=A[lj(c,f,d)>>3];k=py(i,f,d),l=C(j),z[k>>2]=l;f=f+1|0;if((g|0)!=(f|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=b+96|0;break a;case 2:tt(c,ye(b));break a;case 3:tt(c,gk(b));break a;case 1:tt(c,ye(b));break a;default:break b}}tt(c,ye(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];gb=e+48|0}function hc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){_a(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if((c|0)<1){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function Efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-16|0;gb=e;v[e+8>>2]=c>>>4;v[e+4>>2]=v[a>>2];j=v[Gb(e+8|0,e+4|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){d=b;f=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+8>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+12>>2]=i;hg(e+8|0,-1,1);h=A[e+8>>3]*32768;A[e+8>>3]=h;d=a;h=fe(h);a:{if(D(h)<2147483648){f=~~h;break a}f=-2147483648}m=d,n=Uc(f),u[m>>1]=n;d=b;f=w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24);g=w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+8>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+12>>2]=i;hg(e+8|0,-1,1);h=A[e+8>>3]*32768;A[e+8>>3]=h;d=a;h=fe(h);b:{if(D(h)<2147483648){f=~~h;break b}f=-2147483648}m=d,n=Uc(f),u[m+2>>1]=n;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return j<<4}function Fc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{f=w[b+8|0];c=v[b>>2];d=v[b+4>>2];b=gb-48|0;gb=b;e=Jb(a);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((f|0)!=1){if(!d|(f|0)!=4){break k}break l}if(d){break l}a=c;break j}d=d-1|0}m:{switch(f-1|0){case 0:case 1:break m;case 2:case 3:break i;default:break h}}a=c+d|0}t[b+32|0]=0;a=ho(c,a,b+32|0);v[23048]=0;T(118,e|0,c|0,a|0);a=v[23048];v[23048]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}v[23048]=0;T(118,e|0,c|0,c+d|0);a=v[23048];v[23048]=0;if((a|0)==1){break g}c=Ld(e);d=hf(e);f=Ld(e);a=gb-32|0;gb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=f;if(Fb(a+24|0,a+16|0)){while(1){c=t[v[a+24>>2]];t[v[a+8>>2]]=c?c:32;Se(a+24|0);Se(a+8|0);if(Fb(a+24|0,a+16|0)){continue}break}}gb=a+32|0;v[23048]=0;c=Q(119,b+16|0,e|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break f}v[23048]=0;d=Q(91,b|0,10272)|0;a=v[23048];v[23048]=0;if((a|0)==1){break e}v[23048]=0;T(120,b+32|0,c|0,d|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}Eb(e,b+32|0);vb(b+32|0);vb(d);vb(c)}gb=b+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d)}vb(c)}vb(e);R(a|0);L()}}function pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Xd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=gg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Kd(v[f+8>>2],t[g+i|0]<<6);Jd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Kd(b,t[g+v[e+44>>2]|0]<<6);Jd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Sb(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function Xna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;f=b;d=Lb(f);e=c;a:{if(d>>>0<e>>>0){k=gb-32|0;gb=k;b:{c:{i=e-d|0;d:{if(i>>>0<=v[wb(f)>>2]-v[f+4>>2]>>2>>>0){h=gb-16|0;gb=h;e:{e=Ug(h,f,i);if(v[e+4>>2]!=v[e+8>>2]){while(1){wb(f);d=v[e+4>>2];v[23048]=0;Bk(d);d=v[23048];v[23048]=0;if((d|0)==1){break e}d=v[e+4>>2]+4|0;v[e+4>>2]=d;if((d|0)!=v[e+8>>2]){continue}break}}_b(e);gb=h+16|0;break d}a=P()|0;O()|0;_b(e);R(a|0);L()}j=wb(f);e=Tg(f,Lb(f)+i|0);m=Lb(f);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;Zf(d+12|0,j);if(e){h=e;if(e>>>0>1073741823){xc(19251);L()}h=jc(h<<2,1)}v[d>>2]=h;j=(m<<2)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=bc(d),o=(e<<2)+h|0,v[n>>2]=o;gb=l+16|0;v[23048]=0;S(705,d|0,i|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}v[23048]=0;S(706,f|0,d|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}IW(d)}gb=k+32|0;break b}a=P()|0;O()|0;IW(d);R(a|0);L()}break a}if(e>>>0<d>>>0){Ui(f,v[f>>2]+(e<<2)|0)}}c=Nb(a,c<<2);if(c){f=gb-16|0;gb=f;cc(g+24|0,v[b>>2],Lb(b)<<2);gb=f+16|0;b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function OT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=Wg(a);if(c>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{i=b-c|0;c:{if(i>>>0<=v[wb(a)>>2]-v[a+4>>2]>>8>>>0){b=gb-16|0;gb=b;c=b;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+(i<<8);a=v[c+4>>2];if((a|0)!=v[c+8>>2]){while(1){nB(a);a=v[c+4>>2]+256|0;v[c+4>>2]=a;if(v[c+8>>2]!=(a|0)){continue}break}}_b(c);gb=b+16|0;break c}k=wb(a);d=j+8|0;e=a;b=Wg(a)+i|0;f=gb-16|0;gb=f;v[f+12>>2]=b;g=gb-16|0;gb=g;v[g+12>>2]=16777215;v[23048]=0;v[g+8>>2]=2147483647;h=Gb(g+12|0,g+8|0);c=v[23048];v[23048]=0;d:{if((c|0)!=1){gb=g+16|0;c=v[h>>2];break d}V(0)|0;O()|0;Ab();L()}e:{if(b>>>0<=c>>>0){b=qB(e);if(b>>>0<c>>>1>>>0){v[f+8>>2]=b<<1;c=v[Jc(f+8|0,f+12|0)>>2]}gb=f+16|0;break e}Mc();L()}e=Wg(a);b=0;h=gb-16|0;gb=h;v[h+12>>2]=0;vd(d+12|0,k);if(c){b=c;if(c>>>0>=16777216){xc(26612);L()}b=jc(b<<8,1)}v[d>>2]=b;e=(e<<8)+b|0;v[d+8>>2]=e;v[d+4>>2]=e;l=bc(d),m=(c<<8)+b|0,v[l>>2]=m;gb=h+16|0;v[23048]=0;tT(d,i);b=v[23048];v[23048]=0;if((b|0)==1){break b}Ji(a,d);sT(d)}gb=j+32|0;break a}a=P()|0;O()|0;sT(d);R(a|0);L()}return}if(b>>>0<c>>>0){Hj(a,v[a>>2]+(b<<8)|0)}}function vZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;f=b;d=uc(f);e=c;a:{if(d>>>0<e>>>0){k=gb-32|0;gb=k;b:{c:{i=e-d|0;d:{if(i>>>0<=v[wb(f)>>2]-v[f+4>>2]>>1>>>0){h=gb-16|0;gb=h;e:{e=di(h,f,i);if(v[e+4>>2]!=v[e+8>>2]){while(1){wb(f);d=v[e+4>>2];v[23048]=0;Dk(d);d=v[23048];v[23048]=0;if((d|0)==1){break e}d=v[e+4>>2]+2|0;v[e+4>>2]=d;if((d|0)!=v[e+8>>2]){continue}break}}_b(e);gb=h+16|0;break d}a=P()|0;O()|0;_b(e);R(a|0);L()}j=wb(f);e=Jk(f,uc(f)+i|0);m=uc(f);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;Zf(d+12|0,j);if(e){h=e;if(e>>>0>2147483647){xc(16609);L()}h=jc(h<<1,1)}v[d>>2]=h;j=(m<<1)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=bc(d),o=(e<<1)+h|0,v[n>>2]=o;gb=l+16|0;v[23048]=0;S(406,d|0,i|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}v[23048]=0;S(407,f|0,d|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}TD(d)}gb=k+32|0;break b}a=P()|0;O()|0;TD(d);R(a|0);L()}break a}if(e>>>0<d>>>0){pn(f,v[f>>2]+(e<<1)|0)}}c=Nb(a,c<<1);if(c){f=gb-16|0;gb=f;cc(g+24|0,v[b>>2],uc(b)<<1);gb=f+16|0;b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,t=0,u=C(0);a:{if(!v[a+4272>>2]){break a}h=a+44|0;if(!ei(h)){break a}k=Pd(h,0);l=Pd(h,1);m=qd(h,0);n=qd(h,1);if(d){j=a+4256|0;e=v[a+4268>>2];o=d;while(1){f=z[l>>2];g=z[k>>2];t=Mb(j,e<<1),u=g,z[t>>2]=u;t=Mb(j,v[a+4268>>2]<<1|1),u=f,z[t>>2]=u;f=C(D(mM(C(C(C(D(g))+C(D(f)))*C(536870912)),31,5)));g=z[a+4276>>2];f=C(f*C(4.656612873077393e-10));f=C(C(C(g-f)*z[(f<g?4240:4236)+a>>2])+f);z[a+4276>>2]=f;p=m;q=C(z[a+4232>>2]*C(4.656612873077393e-10));g=z[a+4244>>2];f=C(C(C(z[a+4248>>2]*C(2147483648))*C(g-C(G(f,g))))+C(2147483392));b:{if(f<C(4294967296)&f>=C(0)){i=~~f>>>0;break b}i=0}e=i<<5;r=e|-2147483648;s=e;e=i>>>26|0;f=C(q*C((e?r:s)>>>(e?32-e|0:31)>>>0));e=v[a+4272>>2];e=(((e+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(e|0)<<1;t=p,u=C(f*z[Mb(j,e)>>2]),z[t>>2]=u;t=n,u=C(f*z[Mb(j,e|1)>>2]),z[t>>2]=u;i=v[a+4268>>2];e=i-1|0;v[a+4268>>2]=e;if(!i){e=v[a+4272>>2]+e|0;v[a+4268>>2]=e}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}si(a,b,c,qd(h,0),qd(h,1),d)}}function Uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=e;e:{if(d){while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;e=(f<<1)+m|0;f=(k>>>16&65520)+l|0;f=(((((((B(u[e-4>>1],u[f+2>>1])+B(u[e-6>>1],u[f>>1])|0)+B(u[e-2>>1],u[f+4>>1])|0)+B(u[e>>1],u[f+6>>1])|0)+B(u[e+2>>1],u[f+8>>1])|0)+B(u[e+4>>1],u[f+10>>1])|0)+B(u[e+6>>1],u[f+12>>1])|0)+B(u[e+8>>1],u[f+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,f);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,h);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];f=v[g+12>>2];continue}break}k=v[g+8>>2];f=v[g+12>>2];break e}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=k;v[a+4>>2]=f;gb=g+16|0}function Cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2];break a}e=k>>12;j=l>>12}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=f+32|0}function tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+q|0;m=t[e+1|0];e=t[e|0];g=v[a+60>>2];n=g;o=g>>31;g=ac(b,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);g=Fpa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=Fpa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=((B(m-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=g;i=Fpa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+q|0;m=u[e+2>>1];e=u[e>>1];g=v[a+60>>2];n=g;o=g>>31;g=ac(b,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);g=Fpa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=Fpa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=e+((B(m-e|0,i>>>18|0)|0)/16384|0)<<8;e=g;i=Fpa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function nJ(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>=1){p=B(d,g);m=v[b>>2];while(1){if(v[a+1396>>2]<=9){hl(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=rm(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<=-1){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}ec(a,21);return 0}k=B(d,l);m=(k+(j+m|0)|0)>(p|0)?(j+p|0)-k|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(z[v[b+28>>2]+(g+k<<2)>>2]+n);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+z[v[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}ec(a,21);return 0}ha(69952,69696,1872,69988);L()}function Vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(d){while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2];break e}g=i>>12;e=j>>12}v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=k;v[a+4>>2]=b;gb=f+16|0}function Ioa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-32|0;gb=f;v[f+24>>2]=b;b=v[a>>2];n=f,o=Rb(a),v[n>>2]=o;b=Hk(f+24|0,f)+b|0;a:{g=JX(c,d);b:{if((g|0)<1){break b}i=v[wb(a)>>2];e=v[a+4>>2];if((g|0)<=(i-e|0)){v[f>>2]=d;j=e-b|0;if((j|0)<(g|0)){v[f>>2]=c;fw(f,j);l=v[f>>2];k=gb-16|0;gb=k;i=Jj(k,a,g-j|0);wb(a);h=gb-16|0;gb=h;v[h>>2]=d;v[h+8>>2]=l;if(Fb(h+8|0,h)){while(1){Qp(v[i+4>>2],v[h+8>>2]);Se(h+8|0);v[i+4>>2]=v[i+4>>2]+1;if(Fb(h+8|0,h)){continue}break}}gb=h+16|0;_b(i);gb=k+16|0;if((j|0)<1){break b}}k=gb-16|0;gb=k;h=e;i=b;j=a;l=v[a+4>>2];a=(l-(b+g|0)|0)+b|0;g=Jj(k,j,e-a|0);c:{d:{if(a>>>0<e>>>0){d=a;while(1){e=wb(j);m=v[g+4>>2];v[23048]=0;Ml(e,m,d);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[g+4>>2]=v[g+4>>2]+1;d=d+1|0;if(h>>>0>d>>>0){continue}break}}_b(g);Sm(i,a,l);gb=k+16|0;break c}a=P()|0;O()|0;_b(g);R(a|0);L()}Hi(c,v[f>>2],b);break b}e=wb(a);e=Zg(f,qh(a,qc(a)+g|0),b-v[a>>2]|0,e);v[23048]=0;IX(e,c,d);c=v[23048];v[23048]=0;if((c|0)==1){break a}b=HX(a,e,b);ee(e)}Uh(b);gb=f+32|0;return}a=P()|0;O()|0;ee(e);R(a|0);L()}function iz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;e=a+2|0;if(!(w[e|0]==255|!w[e|0])){v[f+12>>2]=w[e|0]+1;v[f+8>>2]=10;Eg(b,v[sd(f+12|0,f+8|0)>>2]);e=w[a+3|0];t[b+15|0]=e;t[b+16|0]=e;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=511;e=0;a:{b:{switch(c-1|0){case 1:e=4096;g=128;break a;case 0:break b;default:break a}}e=32768;g=1024}if(Lb(b)){i=g>>>1|e;while(1){h=(d<<2)+a|0;c=h+6|0;c=w[c|0]|w[c+1|0]<<8;j=Mb(b,d),k=c>>>4|0,u[j>>1]=k;c:{d:{if(!d){e=0;c=0;break d}c=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,c)>>1]){break c}e=d;c=x[Mb(b,c)>>1]+1|0}j=Mb(b,e),k=c,u[j>>1]=k}c=h+8|0;v[f+12>>2]=(i+((w[c|0]|w[c+1|0]<<8)<<16>>16)|0)/(g|0);v[f+8>>2]=0;v[f+4>>2]=64;c=v[Gm(f+12|0,f+8|0,f+4|0)>>2];j=Mb(b,d),k=c,t[j+2|0]=k;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;c=b;e:{f:{if(!(w[a|0]&2)){break f}d=w[b+15|0];if(Lb(b)>>>0<d>>>0){break f}d=w[b+12|0]|4;break e}d=w[b+12|0]&-5}t[c+12|0]=d;c=b;g:{h:{if(!(w[a|0]&4)){break h}a=w[b+13|0];if(a>>>0>w[b+14|0]){break h}if(Lb(b)>>>0<a>>>0){break h}a=w[b+12|0]|2;break g}a=w[b+12|0]&-3}t[c+12|0]=a}gb=f+16|0}function Nea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{f=gb+-64|0;gb=f;e=f;g=e+16|0;while(1){j=(h<<2)+g|0;b=0;c=0;i=gb-16|0;gb=i;Cc(i+8|0,92200);b:{c:{d:{e:{f:{g:{h:{if(v[23054]){while(1){i:{d=v[23054];v[23048]=0;d=U(101,d|0)|0;k=v[23048];v[23048]=0;if((k|0)==1){break i}c=c|d;d=b+32|0;b=31;if(d>>>0<32){continue}break g}break}b=V(90472)|0;if((O()|0)!=(da(90472)|0)){break c}Z(b|0)|0;v[23048]=0;t[92220]=0;X(90);b=v[23048];v[23048]=0;if((b|0)==1){break h}v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break g}b=P()|0;O()|0;break c}t[92220]=0;break f}b=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){break c}V(0)|0;O()|0;Ab();L()}if(w[92220]){break e}}b=v[23056];v[23048]=0;b=wO(b);d=v[23048];v[23048]=0;if((d|0)==1){break d}c=b^c}gb=i+16|0;break b}b=P()|0;O()|0}R(b|0);L()}v[j>>2]=c;h=h+1|0;if((h|0)!=12){continue}break}b=nc(e);v[23048]=0;T(109,e|0,g|0,g+48|0);c=v[23048];v[23048]=0;if((c|0)==1){a=P()|0;O()|0;Qc(b);R(a|0);L()}v[23048]=0;MM(a,e);a=v[23048];v[23048]=0;if((a|0)!=1){Qc(e);gb=f- -64|0;break a}a=P()|0;O()|0;Qc(e);R(a|0);L()}}function Kma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-432|0;gb=d;yc(b);nC(b,d+376|0,d+296|0,d+8|0);g=d;e=1;a:{if(!Wb(w[d+408|0]|w[d+409|0]<<8|(w[d+410|0]<<16|w[d+411|0]<<24))){break a}e=w[d+427|0]+1|0}k=g,l=Ki(e),t[k+4|0]=l;e=w[$b(19759,d+4|0)|0];t[d+7|0]=e;u[d+4>>1]=4;b:{c:{if(!e){break c}while(1){e=Ib(w[d+8|0]|w[d+9|0]<<8);d:{e:{if(w[d+291|0]>63){break e}e=e<<16>>16;if((e|0)<0){break e}if(e){e=e&65535;f=0;while(1){f:{if(!Rc(b,Wb(w[d+392|0]|w[d+393|0]<<8|(w[d+394|0]<<16|w[d+395|0]<<24))+(f<<2)|0)){break f}if(!Rc(b,Lv(b))){break f}g=d;g:{if(!c){i=Hd(b);break g}i=Kr(b)}u[g+2>>1]=i;k=d,l=x[Le(d+4|0,d+2|0)>>1],u[k+4>>1]=l}f=f+1|0;if((e|0)!=(f|0)){continue}break}}if(Wb(w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24))>>>0>j>>>0){if(Rc(b,Wb(w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24)))){break d}}t[d+7|0]=h+1;break c}Ur(a);break b}j=Wb(w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24));nC(b,d+376|0,d+296|0,d+8|0);h=h+1|0;if(w[d+7|0]>(h&255)>>>0){continue}break}}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}gb=d+432|0}function FV(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!pf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!pf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!pf(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!pf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!pf(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}gb=f+16|0}function _J(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);e=gb-48|0;gb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+52>>2]){case 0:d=0;b=gb-80|0;gb=b;f=v[c>>2];g=v[f+4>>2];v[b+40>>2]=v[f+20>>2];h=v[f+16>>2];v[b+32>>2]=v[f+12>>2];v[b+36>>2]=h;ak(b- -64|0,b+32|0,g);f=lf(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);g=v[v[c+12>>2]>>2];h=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;i=b+16|0;c=b;if(g){while(1){f=0;if(h){while(1){j=A[lj(c,f,d)>>3];k=my(i,f,d),l=C(j),z[k>>2]=l;f=f+1|0;if((h|0)!=(f|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}gb=b+80|0;break a;case 2:st(c,ye(b));break a;case 3:st(c,gk(b));break a;case 1:st(c,ye(b));break a;default:break b}}st(c,ye(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];gb=e+48|0}function xoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;wd(b,32);e=a+4|0;h=b,i=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h>>2]=i;e=a+10|0;e=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[b+4>>2]=e;g=e;e=a+14|0;h=b,i=g+Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0,v[h+8>>2]=i;e=b;if(!(d?0:c)){c=a+46|0;c=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}v[e+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!Ib(w[d|0]|w[d+1|0]<<8)){break a}if((Ib(w[d|0]|w[d+1|0]<<8)|0)==48){break a}c=(c-(Ib(w[d|0]|w[d+1|0]<<8)<<7)|0)+6144|0}Jo(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[$b(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}gb=f+16|0}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),x=0,y=0,A=C(0);h=a+44|0;g=Pd(h,0);k=Pd(h,1);m=qd(h,0);n=qd(h,1);p=B(w[a+4233|0],v[v[a+16>>2]+1074396>>2]);e=p<<1;i=a+4208|0;if(Lb(i)>>>0<e>>>0){pl(i,e)}j=EM(a);a:{if(j){if(!d){break a}e=v[a+4220>>2];x=j-1|0;j=0;while(1){if(e>>>0>=p>>>0){v[a+4220>>2]=0;e=0}s=z[k>>2];t=z[g>>2];o=e;e=e-p|0;e=((e|0)<0?o:e)<<1;u=z[Mb(i,e)>>2];f=z[Mb(i,e|1)>>2];q=C(u+t);z[m>>2]=q;r=C(f+s);z[n>>2]=r;f=C(0);l=C(0);b:{c:{switch(x|0){case 0:f=z[a+4224>>2];l=C(f*r);f=C(f*q);break b;case 1:case 2:f=z[a+4224>>2];l=C(f*q);f=C(f*r);break b;case 3:break c;default:break b}}f=C(z[a+4224>>2]*C(u+C(C(s+t)*C(.5))));l=f}n=n+4|0;m=m+4|0;k=k+4|0;g=g+4|0;y=Mb(i,v[a+4220>>2]<<1),A=C(D(f))<C(1.0000000195414814e-24)?C(0):f,z[y>>2]=A;y=Mb(i,v[a+4220>>2]<<1|1),A=C(D(l))<C(1.0000000195414814e-24)?C(0):l,z[y>>2]=A;e=v[a+4220>>2]+1|0;v[a+4220>>2]=e;j=j+1|0;if((j|0)!=(d|0)){continue}break}break a}o=g;g=d<<2;DM(o,o+g|0,m);DM(k,g+k|0,n)}si(a,b,c,qd(h,0),qd(h,1),d)}function Vj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;Ic(i+8|0,d);v[23048]=0;j=U(2375,i+8|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){Xb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){if(al(i+24|0,i+16|0)){v[e>>2]=4;break a}b:{if((In(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){v[e>>2]=4;break a}c:{d:{e:{b=In(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break c}k=b;b=In(j,v[g+8>>2])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break b}v[e>>2]=4;break a}if(bl(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(bl(j,8192,v[g>>2])){continue}}break}if(!lm(i+24|0,i+16|0)){break b}while(1){if(!bl(j,8192,km(i+24|0))){break b}jm(i+24|0);if(lm(i+24|0,i+16|0)){continue}break}break b}if((gn(j,km(i+24|0))|0)==(gn(j,v[g>>2])|0)){g=g+4|0;jm(i+24|0);break b}v[e>>2]=4}if(v[e>>2]){break a}if((g|0)!=(h|0)){continue}break}}if(al(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Xb(i+8|0);R(a|0);L()}function Ona(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;i=gb-16|0;gb=i;h=gb-16|0;gb=h;g=$g(i,1,0);a:{b:{c:{while(1){f=Ob(g);j=Ob(g);k=Bb(g);l=v[c>>2];v[23048]=0;cK(h+8|0,f,j+k|0,l);f=v[23048];v[23048]=0;if((f|0)==1){break b}if(!v[h+12>>2]){break c}f=Bb(g);v[23048]=0;v[h+4>>2]=f;f=Bj(h+4|0);j=v[23048];v[23048]=0;if((j|0)!=1){v[23048]=0;T(123,g|0,f|0,0);f=v[23048];v[23048]=0;if((f|0)!=1){continue}}break}break b}c=v[h+8>>2];f=Ob(g);v[23048]=0;S(124,g|0,c-f|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}gb=h+16|0;break a}a=P()|0;O()|0;vb(g);R(a|0);L()}v[23048]=0;T(13,e+24|0,0,i|0);c=v[23048];v[23048]=0;d:{if((c|0)!=1){vb(i);gb=i+16|0;break d}a=P()|0;O()|0;vb(i);R(a|0);L()}v[23048]=0;T(678,e+36|0,e+16|0,d|0);c=v[23048];v[23048]=0;e:{f:{if((c|0)!=1){v[23048]=0;Ci(e+8|0,e+24|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;c=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=c;T(78,a|0,b|0,e|0);a=v[23048];v[23048]=0;if((a|0)!=1){break e}}a=P()|0;O()|0;Jf(e+24|0);break f}a=P()|0;O()|0;vb(e+24|0)}R(a|0);L()}Jf(e+24|0);gb=e+48|0}function fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;o=d,p=Bf(a)>>>5|0,u[o+32>>1]=p;u[d+16>>1]=3999;o=c,p=x[Vc(d+32|0,d+16|0)>>1],u[o+480190>>1]=p;RU(b,x[c+480190>>1],0);a:{if(x[c+480190>>1]){h=d+62|0;k=d+58|0;l=d+56|0;n=d+52|0;m=d+60|0;i=1;j=1;while(1){f=El(c,j&65535);dv(a,d+32|0);wd(f,0);Mj(d,2,d+32|0);Fc(d+16|0,d);v[23048]=0;Q(354,((i<<5)+c|0)+946300|0,d+16|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break a}vb(d+16|0);u[f+32>>1]=64;v[f+24>>2]=8287;o=d,p=Ib(w[m|0]|w[m+1|0]<<8),u[o+16>>1]=p;u[d>>1]=64;o=f,p=x[Vc(d+16|0,d)>>1]<<2,u[o+30>>1]=p;e=n;o=f,p=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))&-2,v[o>>2]=p;e=Ib(w[l|0]|w[l+1|0]<<8);g=Ib(w[k|0]|w[k+1|0]<<8);b:{if(g>>>0<2){break b}g=e+g<<1;if(g>>>0>y[f>>2]){break b}v[f+16>>2]=g;v[f+12>>2]=e<<1;u[f+34>>1]=x[f+34>>1]|8}e=1;c:{if(!Ib(w[h|0]|w[h+1|0]<<8)){break c}e=(Ib(w[h|0]|w[h+1|0]<<8)|0)==2}ve(d+16|0,b,i-1|0);Ef(d+16|0,e);j=j+1|0;i=j&65535;if(i>>>0<=x[c+480190>>1]){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}
function Dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];break a}g=k>>12;e=l>>12}v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=h;gb=f+32|0}function Wj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;Ic(i+8|0,d);v[23048]=0;j=U(21,i+8|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){Xb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){if(Zj(i+24|0,i+16|0)){v[e>>2]=4;break a}b:{if((Jn(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){v[e>>2]=4;break a}c:{d:{e:{b=Jn(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break c}k=b;b=Jn(j,t[g+2|0])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break b}v[e>>2]=4;break a}if(fh(j,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(fh(j,8192,t[g|0])){continue}}break}if(!_j(i+24|0,i+16|0)){break b}while(1){if(!fh(j,8192,fl(i+24|0))){break b}el(i+24|0);if(_j(i+24|0,i+16|0)){continue}break}break b}if((nx(j,fl(i+24|0))|0)==(nx(j,t[g|0])|0)){g=g+1|0;el(i+24|0);break b}v[e>>2]=4}if(v[e>>2]){break a}if((g|0)!=(h|0)){continue}break}}if(Zj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Xb(i+8|0);R(a|0);L()}function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];i=v[a+4>>2];h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=i;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=i+n|0;i=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=ac(b,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);e=Fpa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];k=Fpa(e,e>>31,f,f>>31);e=w+k|0;f=jb+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(u[e+40882>>1],p)+B(q,u[e+40880>>1])|0)+B(o,u[e+40884>>1])|0)+B(i,u[e+40886>>1])<<8)/16384<<8;e=i;h=Fpa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,m);v[c+4>>2]=v[c+4>>2]+B(h,l);e=f-(e&i)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function _ia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-48|0;gb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;dp(b,f+44|0);a:{if(!VS(f+44|0)){break a}c=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;d=(h|0)!=3;i=e>>>1&3;e=i^3;g=g>>>0<192;u[a+2>>1]=x[(B(d,6)+(e<<1)|0)+27688>>1]<<g;e=B(B(w[(e+B(d,3)|0)+27464|0],x[((B(d,90)+B(e,30)|0)+(c>>>3&30)|0)+27472>>1]),1e3);c=c>>>1|0;c=B(((e>>>0)/x[(B(h,6)+(c&6)|0)+27664>>1]|0)+(c&1)|0,(i|0)==3?4:1);u[a>>1]=c;e=w[(g|d<<1)+27700|0];if(e+8>>>0>(c&65535)>>>0){break a}d=f;c=gb-48|0;gb=c;v[c+44>>2]=e+4;v[c+24>>2]=36;g=v[Gb(c+44|0,c+24|0)>>2];if(!Nb(b,g)){g=Bf(b)}bs(c+24|0,d);h=_d(c+32|0,v[c+24>>2],g);i=v[h+4>>2];v[c+8>>2]=v[h>>2];v[c+12>>2]=i;fc(c+16|0,b,c+8|0);bs(c+24|0,d);Pb(v[c+24>>2]+g|0,0,36-g|0);Vb(b,v[c+44>>2]);gb=c+48|0;b=2;if(e>>>0>2){while(1){if(w[b+f|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=a;d=e+f|0;c=1;b:{if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1868983881){break b}c=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1735289176}t[b+5|0]=c}gb=f+48|0;return a|0}function Uoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-2608|0;gb=f;d=f;Ok(d,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[23048]=0;_(534,d|0);a=v[23048];v[23048]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!c){break d}f:{while(1){v[23048]=0;j=Q(252,d|0,1)|0;a=v[23048];v[23048]=0;if((a|0)==1){break f}a=0;g:{while(1){v[23048]=0;k=Q(252,d|0,1)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}a=B(a,6)+d|0;a=u[(k?a+1070|0:a+1068|0)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1072|0];if(u[e+1068>>1]<0){break h}if(u[e+1070>>1]>-1){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break d}break}a=V(15256)|0;break e}a=V(15256)|0;break e}a=V(15256)|0}if((O()|0)!=(da(15256)|0)){break a}Z(a|0)|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break c}}v[23048]=0;b=jp(d);a=v[23048];v[23048]=0;if((a|0)==1){break b}yb(d);gb=f+2608|0;return b|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(d);R(a|0);L()}function mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=gb-16|0;gb=l;o=l,p=Ub(a),v[o>>2]=p;d=v[Sd(l+8|0,l)>>2];h=gb-32|0;gb=h;v[h+24>>2]=d;d=v[a>>2];o=h,p=Rb(a),v[o>>2]=p;i=d+(sp(h+24|0,h)<<1)|0;a:{b:{f=hp(b,c);c:{if((f|0)<1){break c}g=v[wb(a)>>2];j=v[a+4>>2];if((f|0)<=g-j>>1){d=j-i|0;g=d>>1;d:{if((g|0)>=(f|0)){m=c;break d}v[h>>2]=b;nS(h,g);m=v[h>>2];gS(a,m,c,f-g|0);if((d|0)<1){break c}}n=gb-16|0;gb=n;g=i;d=a;e=j;k=v[a+4>>2];a=(k-((f<<1)+i|0)|0)+i|0;f=di(n,d,e-a>>1);if(a>>>0<e>>>0){c=a;while(1){wb(d);Gu(v[f+4>>2],c);v[f+4>>2]=v[f+4>>2]+2;c=c+2|0;if(e>>>0>c>>>0){continue}break}}_b(f);Sm(g,a,k);gb=n+16|0;To(b,m,i);break c}d=wb(a);g=Jk(a,uc(a)+f|0);m=i-v[a>>2]>>1;j=gb-16|0;gb=j;v[j+12>>2]=0;e=h;Zf(e+12|0,d);if(g){d=g;if(d>>>0>2147483647){xc(16280);L()}k=jc(d<<1,2)}v[e>>2]=k;d=(m<<1)+k|0;v[e+8>>2]=d;v[e+4>>2]=d;o=bc(e),p=(g<<1)+k|0,v[o>>2]=p;gb=j+16|0;v[23048]=0;eR(e,b,c);b=v[23048];v[23048]=0;if((b|0)==1){break b}i=tS(a,e,i);zh(e)}Uh(i);gb=h+32|0;break a}a=P()|0;O()|0;zh(e);R(a|0);L()}gb=l+16|0}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(g<<1)+o|0;j=u[e>>1];p=u[e-2>>1];q=u[e+2>>1];r=u[e+4>>1];l=v[a+60>>2];e=ac(b,-16777216,16776704);k=v[a+64>>2];g=ac(f,-16777216,16776704);f=Fpa(k,k>>31,e,e>>31);k=jb;e=f;f=i>>>21&2040;i=(((B(j,u[f+40882>>1])+B(p,u[f+40880>>1])|0)+B(u[f+40884>>1],q)|0)+B(r,u[f+40886>>1])|0)/16384<<8;f=i;j=Fpa(l,l>>31,f,f>>31);e=e+j|0;f=jb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=v[a+68>>2];g=Fpa(e,e>>31,g,g>>31);e=j+g|0;f=jb+f|0;f=e>>>0<g>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Lc(e,f,24);e=v[a+72>>2];g=(f|0)/256|0;v[c>>2]=v[c>>2]+B(g,n);v[c+4>>2]=v[c+4>>2]+B(g,m);e=f-(e&i)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-112|0;gb=d;bf(b);a:{b:{if(Nb(a,1)){c:{d:{e:{f:{g:{h:{while(1){v[23048]=0;AX(d+24|0,d+48|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}v[23048]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;T(579,d+32|0,a|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}h=d,i=xb(d+32|0),v[h+44>>2]=i;e=Bb(b);v[23048]=0;v[d+20>>2]=c-e;e=Gb(d+44|0,d+20|0);f=v[23048];v[23048]=0;if((f|0)==1){break h}e=v[e>>2];if(!e){break c}t[d+32|0]=0;f=e+(d+48|0)|0;e=ho(d+48|0,f,d+32|0);h=d,i=hf(b),v[h+32>>2]=i;Sd(d+16|0,d+32|0);v[23048]=0;ba(580,b|0,v[d+16>>2],d+48|0,e|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break g}v[23048]=0;Q(370,a|0,e-(d+48|0)|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break f}if(e>>>0>=f>>>0){continue}break}v[23048]=0;Q(370,a|0,1)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break c}a=V(90496)|0;break d}a=V(90496)|0;break d}a=V(90496)|0;break d}a=V(90496)|0;break d}a=V(90496)|0}if((O()|0)!=(da(90496)|0)){break b}Z(a|0)|0;$()}e=(Bb(b)|0)!=0}gb=d+112|0;break a}R(a|0);L()}return e|0}function Zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=zb(b);a:{b:{c:{d:{e:{while(1){b=c;if(!c){break e}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)!=4){break c}c=0;while(1){f:{g:{h:{d=w[c+h|0];switch(d-10|0){case 3:break h;case 0:break g;default:break f}}e=e+1|0;break f}f=f+1|0}i=((g&255)==13&(c|0)!=0&(d|0)==10)+i|0;g=d;c=c+1|0;if((c|0)!=(b|0)){continue}break}c=(e|0)==(i|0);break d}if((d|0)!=4){break b}c=1}i:{if((e|0)==(f|0)){d=2;if(c){break i}}if(e){d=0;if(!f){break i}}d=e?3:f?1:3}if(!b){break b}}g=0;f=(d|0)!=2;c=0;e=0;while(1){e=(f|w[c+h|0]!=10)+e|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}break a}b=0;g=1;e=0}lq(a,e);if(!g){g=(d|0)==2;f=d&-3;i=(d|0)==1?32:13;c=0;e=0;while(1){j:{k:{l:{m:{n:{o:{d=t[c+h|0];switch(d-10|0){case 1:case 2:break l;case 0:break n;case 3:break o;default:break m}}j=Rn(a,e),k=i,t[j|0]=k;c=c+g|0;break j}d=Rn(a,e);if(f){t[d|0]=13;break j}t[d|0]=32;break j}if(!d){break k}}j=Rn(a,e),k=d,t[j|0]=k;break j}j=Rn(a,e),k=32,t[j|0]=k}e=e+1|0;c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function NY(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b:{if((w[a|0]-1&255)>>>0>14){break b}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<=-2){break b}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){c=B(d,13)+a|0;if(w[c+14|0]){break a}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break a}b=e+422|0;if(w[c+942|0]|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>=1048576){break a}c=B(d,11)+a|0;g=c+1346|0;if(w[g|0]>=16|w[c+1351|0]>=4|w[c+1356|0]>=4){break a}c:{if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break c}c=e+430|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048574){break c}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break a}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break a}}d:{e:{if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)|f){break e}if(zd(g,16867,11)){break e}f=0;break d}f=1}d=d+1|0;if((d|0)!=32){continue}break}}return f}return 0}function XZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-112|0;gb=d;yc(b);ps(a);a:{if(!dF(b,d+72|0)){break a}if(!eF(d+72|0)){break a}if(!c){e=1;break a}c=d+72|4;if(!Nb(b,Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-28|0)){break a}Hw(a);Gw(d+48|0);Fw(Yi(a)+32|0,d+48|0);os(d+48|0);f=v[Yi(a)+32>>2];v[23048]=0;S(334,d+48|0,b|0);b=v[23048];v[23048]=0;b:{c:{d:{if((b|0)==1){break d}b=v[d+48>>2];c=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));e=Wb(w[d+84|0]|w[d+85|0]<<8|(w[d+86|0]<<16|w[d+87|0]<<24));v[23048]=0;b=ba(335,b|0,c-28|0,f|0,e|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break d}e=0;if(b){break c}break a}b=Ba(90496,16160)|0;a=O()|0;if((da(90496)|0)!=(a|0)){if((da(16160)|0)!=(a|0)){break b}}Z(b|0)|0;$();e=0;break a}me(d+32|0,f);b=v[d+36>>2];v[d+16>>2]=v[d+32>>2];v[d+20>>2]=b;Ch(d+40|0,d+16|0);c=Xd(d+24|0);v[23048]=0;b=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=b;b=W(254,d+48|0,d+8|0,c|0)|0;f=v[23048];v[23048]=0;e=1;if((f|0)!=1){id(Yi(a)+12|0,b);yb(b);Bc(c);break a}b=P()|0;O()|0;Bc(c)}R(b|0);L()}gb=d+112|0;return e|0}function mJ(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[d>>2];j=z[a>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=z[b>>2]+f;i=C(j-i);f=C(f-g);z[d>>2]=C(z[e>>2]*i)-C(z[e+4>>2]*f);z[b>>2]=C(z[e+4>>2]*i)+C(z[e>>2]*f);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=j+f;h=a-12|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+32>>2]*f)-C(z[e+36>>2]*g);z[b>>2]=C(z[e+36>>2]*f)+C(z[e+32>>2]*g);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=j+f;h=a-20|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+64>>2]*f)-C(z[e+68>>2]*g);z[b>>2]=C(z[e+68>>2]*f)+C(z[e+64>>2]*g);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=j+f;h=a-28|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+96>>2]*f)-C(z[e+100>>2]*g);z[b>>2]=C(z[e+100>>2]*f)+C(z[e+96>>2]*g);d=d-32|0;a=a-32|0;e=e+128|0;b=(k|0)>1;k=k-1|0;if(b){continue}break}}return}ha(71104,69696,2408,71117);L()}function a3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=nc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((Hs(b,c,0)|0)!=-1){while(1){f=Hs(b,c,e);v[23048]=0;Y(190,d|0,b|0,e|0,f-e|0);f=v[23048];v[23048]=0;if((f|0)==1){break j}v[23048]=0;S(191,d+16|0,d|0);f=v[23048];v[23048]=0;if((f|0)==1){break i}v[23048]=0;S(192,a|0,d+16|0);f=v[23048];v[23048]=0;if((f|0)==1){break h}vb(d+16|0);vb(d);e=Hs(b,c,e)+Bb(c)|0;if((Hs(b,c,e)|0)!=-1){continue}break}}k:{if(cd(a)){v[23048]=0;Y(190,d+16|0,b|0,e|0,-1);c=v[23048];v[23048]=0;if((c|0)==1){break f}c=Bb(d+16|0);vb(d+16|0);if(!c){break k}}v[23048]=0;Y(190,d|0,b|0,e|0,-1);b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;S(191,d+16|0,d|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}v[23048]=0;S(192,a|0,d+16|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}vb(d+16|0);vb(d)}gb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;vb(d+16|0)}vb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0)}vb(d)}em(a);R(e|0);L()}function Wu(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=b?33:0;return;case 27:t[a+3|0]=b?34:0;return;case 30:t[a+3|0]=b?35:0;return;case 31:t[a+3|0]=b?36:0;return;default:break b}}t[a+3|0]=0}}function Xx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;i=c;a:{if((f|0)==(e|0)&c>>>0>c>>>0|e>>>0>f>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;h=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}f=c;e=e+1073741824|0;if(a|h^134217728){break a}b=c&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!i&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){f=c;c=d<<4|c>>>28;f=f<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Uf(g+16|0,a,b,c,e,h-15233|0);Hn(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;c=a;b=v[g>>2]|((v[g+16>>2]|v[g+24>>2])!=0|(v[g+20>>2]|v[g+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=f+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}gb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function sq(a){a=a|0;var b=0,c=0,d=0,e=C(0),f=0,g=0,h=C(0),i=0,j=0,k=0,l=C(0);b=v[a+36>>2];if(!b){xg(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){xg(c);return}pl(c,b);b=x[a+28>>1];d=a+4|0;Lb(d);e=vm(a,(b<<16)+65536>>16);f=u[a+28>>1];Lb(d);b=1;e=re(C(e/vm(a,f)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){h=re(e,C(b>>>0));k=Mb(c,b-1|0),l=h,z[k>>2]=l;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:c=a+16|0;d=x[a+30>>1];if(d>>>0>1e3/(b>>>0)>>>0){xg(c);return}pl(c,B(b,d));b=u[a+28>>1];Lb(a+4|0);i=b;b=x[a+30>>1];i=mo(i,b);if(!d){break b}while(1){b=mo(f+i<<16>>16,b&65535)<<16;j=b>>16;e=re(C(vm(a,b+65536>>16)/vm(a,j)),C(C(1)/C(v[a+36>>2]+1>>>0)));d:{if(!v[a+36>>2]){break d}b=1;g=0;while(1){h=re(e,C((b&65535)>>>0));k=Mb(c,B(v[a+36>>2],j)+g|0),l=h,z[k>>2]=l;b=b+1|0;g=b&65535;if(g>>>0>y[a+36>>2]){break d}g=g-1|0;continue}}f=f+1|0;if(d>>>0<=(f&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}xg(a+16|0);v[a+36>>2]=0}return}xg(a+16|0)}function OO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=Fpa(c,c>>31,5e4,0);f=jb;b=v[Jc(d+12|0,d+8|0)>>2];c=vc(Gpa(c,f,b,b>>31),jb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=Fpa(c,c>>31,1e4,0);f=jb;b=v[Jc(d+12|0,d+8|0)>>2];c=vc(Gpa(c,f,b,b>>31),jb);break a;case 1:break b}}e=+y[a+24620>>2]*60/(+y[b+44>>2]*1e-4*(+(Fpa(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(jb>>>0)*4294967296));c:{d:{c=a+484344|0;if(!oe(c,x[b+70>>1])){break d}if(!(cd(Yb(c,x[b+70>>1])+24|0)^1)){break d}c=Yb(c,x[b+70>>1])+24|0;break c}c=a+480248|0}if(!cd(c)){e=e*5.960464477539063e-8*+y[Mb(c,y[b+48>>2]%(Lb(c)>>>0)|0)>>2]}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+A[b+8>>3];A[b+8>>3]=e;if(!(e<1)){A[b+8>>3]=e+-1;c=c+1|0;break a}if(A[a+1074376>>3]>-1){break a}A[b+8>>3]=e+1;c=c-1|0}b=Fpa(v[a+480244>>2],0,c,0)+32768|0;a=jb;a=b>>>0<32768?a+1|0:a;a=Xc((a&65535)<<16|b>>>16,a>>>16|0);gb=d+16|0;return(a?a:1)|0}function MO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-560|0;gb=e;u[e+558>>1]=b;a:{b:{if((b-1&65535)>>>0>254){break b}d=((b<<2)+a|0)+900380|0;f=v[d>>2];c:{if(f){c=IS(e,c);d=v[c+4>>2];b=f;v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);g=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=g;t[b+8|0]=g>>>8;t[b+9|0]=g>>>16;t[b+10|0]=g>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;Mz(b+48|0,c+48|0);Mz(b+68|0,c+68|0);Mz(b+88|0,c+88|0);hc(b+108|0,c+108|0,448);mv(c);break c}b=Ng(556);if(!b){f=0;v[d>>2]=0;break b}v[23048]=0;f=Q(1341,b|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}v[((x[e+558>>1]<<2)+a|0)+900380>>2]=b}h=a,i=x[Le(a+480192|0,e+558|0)>>1],u[h+480192>>1]=i}gb=e+560|0;return f|0}a=P()|0;O()|0;Zb(b);R(a|0);L()}function mm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;v[a+4>>2]=0;if(w[$j(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[23048]=0;b=v[(a+b|0)+24>>2];d=v[23048];v[23048]=0;if((d|0)==1){break c}v[23048]=0;b=U(2237,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}if(Ke(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!Ke(b,c)){continue}break}d=0;break a}while(1){if(v[a+4>>2]>=(b|0)){break a}e=v[v[a>>2]-12>>2];v[23048]=0;e=v[(a+e|0)+24>>2];g=v[23048];v[23048]=0;d:{if((g|0)==1){break d}v[23048]=0;e=U(2237,e|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break d}if(Ke(e,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!Ke(e,c)){continue}break a}break}}b=V(0)|0;O()|0;Z(b|0)|0;d=1;Yj(v[v[a>>2]-12>>2]+a|0,1);e:{f:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break f}R(a|0);L()}$();break a}V(0)|0;O()|0;Ab()}L()}d=2}uh(v[v[a>>2]-12>>2]+a|0,d)}gb=f+16|0;return a|0}function u3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Ic(g,d);v[23048]=0;b=U(2375,g|0)|0;a=v[23048];v[23048]=0;d:{e:{f:{g:{if((a|0)!=1){Xb(g);Ic(g,d);v[23048]=0;a=U(2376,g|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break g}Xb(g);v[23048]=0;S(2377,g|0,a|0);d=v[23048];v[23048]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23048]=0;S(2378,g|12,a|0);a=v[23048];v[23048]=0;if((a|0)==1){break e}v[23048]=0;d=g+24|0;a=sa(2379,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Pc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Xb(g);break d}b=P()|0;O()|0;Xb(g);break d}b=P()|0;O()|0;while(1){d=Pc(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;Pc(g)}R(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function YB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;sV(a,b);i=gb-16|0;gb=i;wd(c,1);a=b+22|0;k=c,l=Ib(w[a|0]|w[a+1|0]<<8)<<1,v[k>>2]=l;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[$b(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;j=Ib(w[a|0]|w[a+1|0]<<8);a=j<<1;f=b+28|0;g=Ib(w[f|0]|w[f+1|0]<<8);f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(f-a>>>0>3?!(f>>>0<4|a>>>0>f>>>0):0)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>=g>>>0|a|(!e|f>>>0>8))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}gb=i+16|0;Fk(h,3,b);Fc(h+16|0,h);v[23048]=0;Q(354,d|0,h+16|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){a=d+32|0;vb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=ZB(b);gb=h+32|0;return a}a=P()|0;O()|0;vb(h+16|0);R(a|0);L()}function P3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Ic(g,d);v[23048]=0;b=U(21,g|0)|0;a=v[23048];v[23048]=0;d:{e:{f:{g:{if((a|0)!=1){Xb(g);Ic(g,d);v[23048]=0;a=U(2346,g|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break g}Xb(g);v[23048]=0;S(2347,g|0,a|0);d=v[23048];v[23048]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23048]=0;S(2348,g|12,a|0);a=v[23048];v[23048]=0;if((a|0)==1){break e}v[23048]=0;d=g+24|0;a=sa(2349,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Xb(g);break d}b=P()|0;O()|0;Xb(g);break d}b=P()|0;O()|0;while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;vb(g)}R(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function My(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);b=gb-48|0;gb=b;a:{b:{e=v[a+20>>2];c:{if(!e){break c}if(qc(e+4|0)>>>0<4){break c}me(b+16|0,v[a+20>>2]+4|0);c=Xd(b+8|0);v[23048]=0;e=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=e;e=W(549,b+24|0,b|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}Bc(c);v[23048]=0;c=U(376,e|0)|0;d=v[23048];v[23048]=0;d:{if((d|0)!=1){if(c){break d}c=v[v[a>>2]+40>>2];v[23048]=0;c=U(c|0,a|0)|0;d=v[23048];v[23048]=0;e:{if((d|0)==1){break e}if(qc(v[a+20>>2]+4|0)-4>>>0<c<<2>>>0){break d}f=v[v[a>>2]+172>>2];d=0;v[23048]=0;S(f|0,a|0,-1);f=v[23048];v[23048]=0;if((f|0)==1){break e}if(c){while(1){v[23048]=0;g=C(Aa(677,e|0));f=v[23048];v[23048]=0;if((f|0)==1){break e}f=v[v[a>>2]+44>>2];v[23048]=0;za(f|0,a|0,d|0,C(g));f=v[23048];v[23048]=0;if((f|0)==1){break e}d=d+1|0;if((c|0)!=(d|0)){continue}break}}c=v[v[a>>2]+176>>2];v[23048]=0;_(c|0,a|0);a=v[23048];v[23048]=0;if((a|0)!=1){break d}}}a=P()|0;O()|0;yb(e);break a}yb(e)}gb=b+48|0;return}a=P()|0;O()|0;Bc(c)}R(a|0);L()}function fq(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[d>>2];k=z[a>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=z[c>>2]+g;j=C(k-j);g=C(g-h);z[d>>2]=C(z[e>>2]*j)-C(z[e+4>>2]*g);z[c>>2]=C(z[e+4>>2]*j)+C(z[e>>2]*g);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=k+g;i=a-12|0;h=z[i>>2];z[i>>2]=z[f>>2]+h;i=c;c=b+e|0;g=C(g-k);h=C(h-j);z[i>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[f>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=k+g;i=a-20|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=k+g;i=a-28|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=b+c|0;d=d-32|0;a=a-32|0;c=(l|0)>1;l=l-1|0;if(c){continue}break}}}function sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Xd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=gg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=(h<<1)+j|0;a:{if((b|0)<=0){break a}while(1){Kd(v[f+8>>2],u[(i<<1)+h>>1]/4<<16>>16);Jd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Kd(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function qpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-32|0;gb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=Rb(a),v[m>>2]=n;b=b+(sp(f+24|0,f)<<1)|0;d=v[a+4>>2];a:{b:{if(d>>>0<y[wb(a)>>2]){if((b|0)==(d|0)){d=gb-16|0;gb=d;a=di(d,a,1);Gv(v[a+4>>2],c);v[a+4>>2]=v[a+4>>2]+2;_b(a);gb=d+16|0;break b}j=gb-16|0;gb=j;h=d;l=v[a+4>>2];g=b;e=b+(l-(b+2|0)|0)|0;i=di(j,a,d-e>>1);if(d>>>0>e>>>0){k=v[i+4>>2];d=e;while(1){Gv(k,d);k=v[i+4>>2]+2|0;v[i+4>>2]=k;d=d+2|0;if(h>>>0>d>>>0){continue}break}}_b(i);d=l;h=g;if((g|0)!=(e|0)){while(1){d=d-2|0;e=e-2|0;rY(d,e);if((e|0)!=(h|0)){continue}break}}gb=j+16|0;c=c>>>0>=g>>>0?y[a+4>>2]>c>>>0?c+2|0:c:c;t[b|0]=w[c|0];t[g+1|0]=w[c+1|0];break b}d=wb(a);d=zY(f,AY(a,uc(a)+1|0),b-v[a>>2]>>1,d);v[23048]=0;S(495,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}c=v[d+4>>2];g=d+4|0;Tk(v[a>>2],b,g);h=b;b=d+8|0;Pl(h,v[a+4>>2],b);zc(a,g);zc(a+4|0,b);zc(wb(a),bc(d));v[d>>2]=v[d+4>>2];b=c;rp(d)}Uh(b);gb=f+32|0;return}a=P()|0;O()|0;rp(d);R(a|0);L()}function Jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=u[(g<<1)+o>>1];i=v[a+60>>2];f=ac(b,-16777216,16776704);n=v[a+64>>2];g=ac(e,-16777216,16776704);j=j<<8;e=j;e=Fpa(i,i>>31,e,e>>31);i=jb;k=Fpa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=Fpa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Lc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function Yd(a){var b=0,c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;v[c+12>>2]=0;v[c+8>>2]=2455;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=v[c+4>>2];b=c+16|0;v[b+4>>2]=v[c>>2];v[b+8>>2]=d;v[b>>2]=a;d=gb-16|0;gb=d;e=a;if(v[a>>2]!=-1){Cc(d,pT(d+8|0,b));b=d;a:{b:{c:{if(!v[e>>2]){d:{_e(e,1);v[23048]=0;f=v[23048];v[23048]=0;e:{if((f|0)==1){break e}v[23048]=0;_(2463,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;b=v[23048];v[23048]=0;if((b|0)==1){break e}v[e>>2]=-1;v[23048]=0;b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;b=v[23048];v[23048]=0;if((b|0)!=1){break d}}a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;a=v[23048];v[23048]=0;f:{if((a|0)==1){break f}_e(e,0);v[23048]=0;a=v[23048];v[23048]=0;if((a|0)==1){break f}v[23048]=0;a=v[23048];v[23048]=0;if((a|0)==1){break f}v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[23048]=0;X(20);d=v[23048];v[23048]=0;if((d|0)==1){break c}R(a|0);L()}}break a}V(0)|0;O()|0;Ab()}L()}}gb=d+16|0;gb=c+32|0;return v[a+4>>2]-1|0}function GP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=B(b,880)+a|0;a:{if(c){Db(e+8|0,a+1074308|0,90);if(!Cb(e+8|0)){t[(B(b,880)+a|0)+1075797|0]=c}t[(B(b,880)+a|0)+1075798|0]=c;break a}c=w[g+1075798|0]}f=g+1074984|0;h=c&255;j=0-h|0;i=d?i:!(v[a+480180>>2]&204473357);BP(a,b,j,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}g=v[(B(b,880)+a|0)+1075640>>2];if(!g|!v[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){AP(a,f,240-h|0);break b}if(!(b>>>0<224|d)){zP(f,224-h|0);break b}yP(f,j);break b}if(v[a+480180>>2]==268435456){v[(B(b,880)+a|0)+1075692>>2]=65535}if(!(!i|(c&255)>>>0<224)){d:{d=h&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}vP(a,f,d);break b}if(v[a+480180>>2]==524288){break d}DP(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,880)+a|0)+1075837|0]&1)){break e}if(v[a+1074408>>2]==1){Db(e+8|0,a+1074308|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}wP(a,f,h<<2)}gb=e+16|0}function Kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=t[g+o|0];i=v[a+60>>2];f=ac(b,-16777216,16776704);n=v[a+64>>2];g=ac(e,-16777216,16776704);j=j<<16;e=j;e=Fpa(i,i>>31,e,e>>31);i=jb;k=Fpa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=Fpa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Lc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function F0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{b=v[a+12>>2];d:{if(d>>>0>b>>>0){while(1){c=v[b>>2];if(c>>>0>1114111|(c&-2048)==55296){break b}e:{if(c>>>0<=127){f=v[a+8>>2];b=1;if((g-f|0)<1){break d}v[a+8>>2]=f+1;t[f|0]=c;break e}if(c>>>0<=2047){b=v[a+8>>2];if((g-b|0)<2){break c}v[a+8>>2]=b+1;t[b|0]=c>>>6|192;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}b=v[a+8>>2];f=g-b|0;if(c>>>0<=65535){if((f|0)<3){break c}v[a+8>>2]=b+1;t[b|0]=c>>>12|224;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}if((f|0)<4){break c}v[a+8>>2]=b+1;t[b|0]=c>>>18|240;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>12&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;if(b>>>0<d>>>0){continue}break}}b=0}break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return b|0}function HP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;h=B(b,880)+a|0;a:{if(c){Db(e+8|0,a+1074308|0,90);if(!Cb(e+8|0)){t[(B(b,880)+a|0)+1075798|0]=c}t[(B(b,880)+a|0)+1075797|0]=c;break a}c=w[h+1075797|0]}f=h+1074984|0;g=c&255;i=d?i:!(v[a+480180>>2]&204473357);BP(a,b,g,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}h=v[(B(b,880)+a|0)+1075640>>2];if(!h|!v[h+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){AP(a,f,g-240|0);break b}if(!(b>>>0<224|d)){zP(f,g-224|0);break b}yP(f,g);break b}if(v[a+480180>>2]==268435456){v[(B(b,880)+a|0)+1075692>>2]=1}if(!(!i|(c&255)>>>0<224)){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}xP(a,f,d);break b}if(v[a+480180>>2]==524288){break d}CP(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,880)+a|0)+1075837|0]&1)){break e}if(v[a+1074408>>2]==1){Db(e+8|0,a+1074308|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}wP(a,f,0-(g<<2)|0)}gb=e+16|0}function sba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{d=gb-16|0;gb=d;e=Jb(a);i=b;b:{if(Bb(b)){while(1){b=v[ck(i,g)>>2];c:{if(b>>>0>=2097152){v[23048]=0;S(117,e|0,63);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break b}c=0;d:{e:{f:{while(1){f=b&63;t[(d+10|0)+c|0]=f;a=c+1|0;b=b>>>6|0;if(!b){break f}c=a;if((a|0)!=6){continue}break}a=7;b=1;break e}if(!c){v[23048]=0;S(117,e|0,t[d+10|0]);a=v[23048];v[23048]=0;if((a|0)!=1){break c}break b}b=7-c|0;if((a|0)!=2){break e}if((f|0)==1){break d}a=2;b=6}f=(-1<<a^-1)<<b;c=a-1|0;j=c+(d+10|0)|0;b=a;while(1){g:{if((a|0)==(b|0)){b=w[j|0];v[23048]=0;S(117,e|0,(b|f)<<24>>24);h=v[23048];v[23048]=0;b=c;if((h|0)!=1){break g}break b}v[23048]=0;b=b-1|0;S(117,e|0,t[b+(d+10|0)|0]|-128);h=v[23048];v[23048]=0;if((h|0)==1){break b}}if(b){continue}break}break c}v[23048]=0;S(117,e|0,t[d+10|0]|64);a=v[23048];v[23048]=0;if((a|0)==1){break b}}g=g+1|0;if(Bb(i)>>>0>g>>>0){continue}break}}gb=d+16|0;break a}a=P()|0;O()|0;vb(e);R(a|0);L()}}function uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;g=gb-16|0;gb=g;d=b;c=a+33|0;v[d>>2]=w[c+206|0]|w[c+207|0]<<8;_N(c,d+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);_N(c,d+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);h=d+236|0;while(1){j=w[c+e|0];k=ud(h,e+12|0),l=j,u[k>>1]=l;e=e+1|0;if((e|0)!=96){continue}break}if(w[c+208|0]){t[d+31|0]=w[c+209|0]+1;h=w[d+31|0];a:{b:{if(!h){e=1;break b}e=16;if(h>>>0<17){break a}}t[d+31|0]=e}u[g+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[g+12>>1]=127;k=d,l=w[Vc(g+14|0,g+12|0)|0]+1|0,t[k+30|0]=l}t[d+33|0]=w[c+212|0];gb=g+16|0;c=b+236|0;while(1){d=0;e=a+i|0;if(w[e+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){d=w[e+33|0]}k=ud(c,i+12|0),l=d,u[k>>1]=l;i=i+1|0;if((i|0)!=96){continue}break}Fk(f,3,a+4|0);Fc(f+16|0,f);v[23048]=0;Q(354,b+492|0,f+16|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){vb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}gb=f+32|0;return}a=P()|0;O()|0;vb(f+16|0);R(a|0);L()}function ZI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-208|0;gb=d;v[d+8>>2]=1;v[d+12>>2]=0;a:{h=b<<2;if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;f=4;e=2;while(1){g=f;f=b;b=(b+4|0)+g|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;if(b>>>0<h>>>0){continue}break}b:{f=(a+h|0)-4|0;if(f>>>0<=a>>>0){e=1;b=1;break b}e=1;b=1;while(1){c:{if((e|0)==3){Sx(a,c,b,d+16|0);ht(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){gt(a,c,d+8|0,b,0,d+16|0);break d}Sx(a,c,b,d+16|0)}if((b|0)==1){ft(d+8|0,1);b=0;break c}ft(d+8|0,g);b=1}e=v[d+8>>2]|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0<=a>>>0){break b}e=e&3;continue}}gt(a,c,d+8|0,b,0,d+16|0);while(1){e:{f:{g:{if(!((e|0)!=1|(b|0)!=1)){if(v[d+12>>2]){break g}break a}if((b|0)>1){break f}}f=YI(d+8|0);ht(d+8|0,f);e=v[d+8>>2];b=b+f|0;break e}ft(d+8|0,2);v[d+8>>2]=v[d+8>>2]^7;ht(d+8|0,1);g=a-4|0;f=b-2|0;gt(g-v[(d+16|0)+(f<<2)>>2]|0,c,d+8|0,b-1|0,1,d+16|0);ft(d+8|0,1);e=v[d+8>>2]|1;v[d+8>>2]=e;gt(g,c,d+8|0,f,1,d+16|0);b=f}a=a-4|0;continue}}gb=d+208|0}function n8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;lK(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;_b(c);gb=c+16|0;return}i=gb-32|0;gb=i;j=wb(a);d=i+8|0;e=a;h=bo(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=h;a:{c=CV();if(h>>>0<=c>>>0){e=hv(e);if(e>>>0<c>>>1>>>0){v[f+8>>2]=e<<1;c=v[Jc(f+8|0,f+12|0)>>2]}gb=f+16|0;break a}Mc();L()}h=bo(a);f=gb-16|0;gb=f;v[f+12>>2]=0;vd(d+12|0,j);if(c){e=c;if(c>>>0>=178956971){xc(57827);L()}g=jc(B(e,24),8)}v[d>>2]=g;e=B(h,24)+g|0;v[d+8>>2]=e;v[d+4>>2]=e;k=bc(d),l=B(c,24)+g|0,v[k>>2]=l;gb=f+16|0;c=d;lK(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;b=a;e=c+4|0;g=v[a>>2];a=v[a+4>>2]-g|0;f=v[e>>2]+B((a|0)/-24|0,24)|0;v[e>>2]=f;if((a|0)>=1){hc(f,g,a)}zc(b,e);zc(b+4|0,d+8|0);zc(wb(b),bc(d));v[d>>2]=v[d+4>>2];a=c;b=v[c+8>>2];d=v[c+4>>2];if((b|0)!=(d|0)){v[a+8>>2]=b+B(((b-d|0)-24>>>0)/24^-1,24)}a=v[c>>2];if(a){sy(a,(v[bc(c)>>2]-v[c>>2]|0)/24|0)}gb=i+32|0}function gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;wd(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[Vc(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[Vc(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+45006|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}gb=e+16|0}function YK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{b:{c:{d:{e:{f:{g:{if(mj(a)){lh(c+24|0);break g}fo(c+8|0,a);v[23048]=0;S(2087,c+24|0,c+8|0);d=v[23048];v[23048]=0;if((d|0)==1){break f}Tf(c+8|0)}d=a+36|0;h:{if(mj(a)){break h}d=v[c+24>>2]}if((b|0)==-1){e=4194304;break d}if((b|0)>=0){f=b;if((bo(d)|0)>(b|0)){break d}}b=aa(8)|0;v[23048]=0;d=Q(91,c+8|0,56869)|0;a=v[23048];v[23048]=0;if((a|0)==1){break e}rc(b,d);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(d);break c}a=P()|0;O()|0;Tf(c+8|0);break b}a=P()|0;O()|0;ca(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|e;b=v[b>>2];e=w[Il(d,f)+16|0];v[23048]=0;Fi(b+484360|0,e);b=v[23048];v[23048]=0;i:{if((b|0)==1){break i}b=Il(d,f);d=v[b+8>>2];b=v[b+12>>2];v[23048]=0;+oa(1953,a|0,b|0,d|0);b=v[23048];v[23048]=0;if((b|0)==1){break i}v[a+16>>2]=0;v[a+20>>2]=0;ll(c+24|0);gb=c+32|0;return}a=P()|0;O()|0}ll(c+24|0)}R(a|0)}L()}function P_(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb+-64|0;gb=c;a=Jb(a);v[23048]=0;b=fa(215)|0;d=v[23048];v[23048]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[23048]=0;d=Q(2,c+32|0,15219)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;b=fa(215)|0;e=v[23048];v[23048]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[23048]=0;v[c+12>>2]=b;S(221,c+16|0,c+12|0);b=v[23048];v[23048]=0;if((b|0)==1){break h}v[23048]=0;T(3,c+48|0,d|0,c+16|0);b=v[23048];v[23048]=0;if((b|0)==1){break g}Eb(a,c+48|0);vb(c+48|0);vb(c+16|0);vb(d);v[23048]=0;b=fa(217)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(!b){break e}v[23048]=0;Q(222,a|0,15222)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(c+16|0)}vb(d);break a}v[23048]=0;b=fa(216)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}if(!b){break d}v[23048]=0;Q(222,a|0,15224)|0;b=v[23048];v[23048]=0;if((b|0)==1){break b}}gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}vb(a);R(b|0);L()}function KS(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;g=gb-16|0;gb=g;if(wj(a)){f=w[(ue(w[a+799|0])?a+799|0:a+801|0)|0];Db(g+8|0,d+1074308|0,34);a:{if(!Cb(g+8|0)){break a}d=f;if(f){if(d>>>0>120){break a}f=w[lc(v[a+656>>2]+108|0,d-1|0)|0];break a}f=0}d=a;k=C(C(v[a+704>>2]<<4)*b);e=v[v[a+656>>2]+44>>2];c=(c+f<<16)-3997696>>16;b:{c:{a=v[a+856>>2]+u[a+774>>1]|0;if(a){i=v[e+36>>2];if(i){break c}}b=vm(e,a+c<<16>>16);break b}j=i+1|0;l=Xy(a,j);f=mo(a,j);a=u[e+28>>1];h=e+4|0;Lb(h);b=C(1);c=c+l<<16>>16;d:{if((c|0)<(a|0)){break d}if((c|0)>(x[e+28>>1]+Lb(h)<<16)-65536>>16){break d}if(!f){b=z[Mb(h,c-u[e+28>>1]|0)>>2];break b}a=x[e>>1];e:{if((a|0)==3){a=e+16|0;if(Lb(a)){b=z[Mb(a,f-1|0)>>2];break e}a=x[e>>1]}f:{if((a&65535)!=1){break f}a=e+16|0;if(!Lb(a)){break f}b=z[Mb(a,(B(i,mo(c,x[e+30>>1])<<16>>16)+f|0)-1|0)>>2];break e}b=re(C(vm(e,(c<<16)+65536>>16)/vm(e,c)),C(C(f|0)/C(j|0)))}b=C(z[Mb(h,c-u[e+28>>1]|0)>>2]*b)}}m=d,n=vj(C(k*b)),v[m+700>>2]=n}gb=g+16|0}function tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Xd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=gg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=h+j|0;a:{if((b|0)<=0){break a}while(1){Kd(v[f+8>>2],t[h+i|0]<<6);Jd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Kd(b,t[h+v[e+44>>2]|0]<<6);Jd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function oL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){v[23048]=0;b=c;U(1313,b|0)|0;a=v[23048];v[23048]=0;a:{if((a|0)!=1){c=v[b+4>>2];if(c){a=c;ik(a);if(v[a>>2]){f=a;g=v[a>>2];d=v[a+4>>2];b:{while(1){if((d|0)==(g|0)){break b}e=wb(f);v[23048]=0;d=d-4|0;S(1343,e|0,d|0);e=v[23048];v[23048]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[f+4>>2]=g;Ph(wb(a),v[a>>2],Ce(a))}Zb(c)}v[b+4>>2]=0;Zz(b+1300408|0);hu(b+1300344|0);vb(b+1300332|0);vb(b+1300320|0);vb(b+1300308|0);gu(b+1300304|0);fu(b+1300300|0);Mq(b+1300264|0);a=b+946300|0;c=b+906300|0;while(1){a=Iq(a-160|0);if((c|0)!=(a|0)){continue}break}Eu(b+484360|0);Wz(b+484344|0);Qc(b+480248|0);break a}V(0)|0;O()|0;Zz(b+1300408|0);hu(b+1300344|0);vb(b+1300332|0);vb(b+1300320|0);vb(b+1300308|0);gu(b+1300304|0);fu(b+1300300|0);Mq(b+1300264|0);a=b+946300|0;c=b+906300|0;while(1){a=Iq(a-160|0);if((c|0)!=(a|0)){continue}break}Eu(b+484360|0);Wz(b+484344|0);Qc(b+480248|0);Ab();L()}Zb(b)}}}function Gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];i=v[a+4>>2];e=i;g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;gb=f+32|0}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=e+o|0;p=t[g+1|0];g=t[g|0];e=v[a+60>>2];q=e;r=e>>31;e=ac(b,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);e=Fpa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=Fpa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=((B(p-g|0,i>>>10&4194048)|0)/16384|0)+(g<<8)<<8;i=Fpa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Lc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function gN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Fq(c,a);wb(a);Ty(v[d+4>>2],b);v[d+4>>2]=v[d+4>>2]+4;_b(d);gb=c+16|0;return}i=gb-32|0;gb=i;f=wb(a);c=Jl(a,Lb(a)+1|0);h=Lb(a);g=gb-16|0;gb=g;v[g+12>>2]=0;d=i+8|0;vd(d+12|0,f);if(c){e=c;if(c>>>0>=1073741824){xc(46171);L()}e=jc(e<<2,4)}v[d>>2]=e;f=(h<<2)+e|0;v[d+8>>2]=f;v[d+4>>2]=f;j=bc(d),k=(c<<2)+e|0,v[j>>2]=k;gb=g+16|0;Ty(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+4;b=a;ik(a);wb(a);c=d;h=c+4|0;e=h;g=v[a>>2];a=v[a+4>>2];if((g|0)!=(a|0)){f=v[e>>2];while(1){a=a-4|0;Ty(f-4|0,a);f=v[e>>2]-4|0;v[e>>2]=f;if((a|0)!=(g|0)){continue}break}}zc(b,h);zc(b+4|0,c+8|0);zc(wb(b),bc(c));v[c>>2]=v[c+4>>2];ol(b,Lb(b));a=d;b=a;d=v[a+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-4|0;v[b+8>>2]=c;v[23048]=0;S(1343,e|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}b=v[a>>2];if(b){Ph(v[a+16>>2],b,fk(a))}gb=i+32|0}function Yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=(e<<1)+o|0;p=u[g+2>>1];g=u[g>>1];e=v[a+60>>2];q=e;r=e>>31;e=ac(b,-16777216,16776704);j=v[a+64>>2];f=ac(f,-16777216,16776704);e=Fpa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=Fpa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=g+((B(p-g|0,i>>>18|0)|0)/16384|0)<<8;i=Fpa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Lc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function No(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;t[a+843|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+799|0]=0;v[a+768>>2]=0;v[a+804>>2]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;Db(e+8|0,b+1074308|0,23);if(Cb(e+8|0)){t[a+809|0]=1;t[a+810|0]=0}t[a+848|0]=0;t[a+841|0]=0;u[a+776>>1]=0;t[a+852|0]=255;v[a+660>>2]=0;t[a+853|0]=w[a+853|0]&252;Vm(a+790|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+847|0]=0;t[a+840|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+822>>1]=0;t[a+821|0]=0;u[a+838>>1]=32512;u[a+844>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+856>>2]=0;v[a+860>>2]=0;t[a+853|0]=w[a+853|0]&243;a:{if(c>>>0>126){c=64;b=128;d=0;break a}d=(c<<5)+b|0;c=x[d+480286>>1];b=x[d+480284>>1];d=v[d+480280>>2]}u[a+786>>1]=0;v[a+748>>2]=c;v[a+692>>2]=b;v[a+88>>2]=d;t[a+797|0]=0;t[a+798|0]=0;gb=e+16|0}function R4(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;v[23048]=0;g=Q(15,d+24|0,a|0)|0;c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}Ic(d+16|0,v[v[a>>2]-12>>2]+a|0);v[23048]=0;c=U(2245,d+16|0)|0;e=v[23048];v[23048]=0;e:{f:{if((e|0)!=1){Xb(d+16|0);e=Nj(d+8|0,a);f=v[v[a>>2]-12>>2];v[23048]=0;f=a+f|0;h=U(16,f|0)|0;i=v[23048];v[23048]=0;if((i|0)==1){break f}e=v[e>>2];v[23048]=0;c=Qa(2246,c|0,e|0,f|0,h|0,+b)|0;e=v[23048];v[23048]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!Yv(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[23048]=0;S(18,a+c|0,5);c=v[23048];v[23048]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Xb(d+16|0);break e}c=V(0)|0;O()|0}dl(g);break c}dl(g);break b}c=V(0)|0;O()|0}Z(c|0)|0;c=v[v[a>>2]-12>>2];v[23048]=0;_(19,a+c|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}$()}gb=d+32|0;return a|0}a=P()|0;O()|0;v[23048]=0;X(20);d=v[23048];v[23048]=0;if((d|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Mf(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function ix(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Bb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Bb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=hx(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+84064|0];d:{e:{switch(Jpa(f-88|0,30)|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Bb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function $f(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;d=v[a+28>>2];bp(v[v[d>>2]-12>>2]+d|0,0);if(!nd(a,4)){Nw(a)}a:{if(!v[a+4>>2]){break a}if(nd(a,6)){break a}if(nd(a,7)){break a}g=v[a+28>>2];e=v[a+84>>2];h=B(v[a+20>>2],v[a+4>>2]);f=h+v[a+80>>2]|0;e=ph(c- -64|0,f,f>>>0<h>>>0?e+1|0:e);f=v[e+12>>2];v[c+24>>2]=v[e+8>>2];v[c+28>>2]=f;d=v[e+4>>2];v[c+16>>2]=v[e>>2];v[c+20>>2]=d;Xj(g,c+16|0)}d=0;b:{if(!nd(a,5)){break b}g=0;e=a+44|0;h=vf(e);d=0;if(!h){break b}d=a+32|0;while(1){c:{f=(v[a+96>>2]+g>>>0)%(h>>>0)|0;if(y[Tc(e,f)>>2]>=qc(d)>>>0){break c}i=En(c+48|0,oc(d,v[Tc(e,f)>>2]),x[Tc(e,f)+12>>1]);j=Pw(b,i);Hb(i);if(!j){break c}v[a+96>>2]=(f+1>>>0)%(h>>>0);b=v[Tc(e,f)+4>>2];if(b){h=v[a+28>>2];g=b+v[a+8>>2]|0;a=v[a+12>>2];a=ph(c+32|0,g,b>>>0>g>>>0?a+1|0:a);b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;Xj(h,c)}d=Tc(e,f);break b}g=g+1|0;if((h|0)!=(g|0)){continue}break}d=0}gb=c+80|0;return d}function tJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[a+32>>2];a:{b:{c:{b=v[a+1380>>2];d:{if((b|0)==-1){h=1;b=-1;break d}d=v[a+1116>>2];e:{if((d|0)<=(b|0)){break e}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break e}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){break c}b=(b|0)==(d|0)?-1:b}while(1){if((b|0)!=-1){return 1}g=v[a+40>>2];if(g>>>0<=c+26>>>0){ec(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[91480]|w[91481]<<8|(w[91482]<<16|w[91483]<<24))){ec(a,21);break a}if(w[c+4|0]){ec(a,21);break a}f:{if(h){if(!v[a+992>>2]|!(t[c+5|0]&1)){break f}ec(a,21);break a}if(t[c+5|0]&1){break f}ec(a,21);break a}d=c+27|0;e=w[c+26|0];c=d+e|0;if(g>>>0<c>>>0){break b}h=0;b=0;f=0;g:{if(!e){break g}while(1){i=w[b+d|0];c=i+c|0;f=b;if((i|0)!=255){break g}b=b+1|0;if((e|0)!=(b|0)){continue}break}f=e}d=f;b=(d|0)==(e|0)?-1:d;if(c>>>0<=g>>>0){continue}break}ec(a,1);break a}ec(a,1);break a}ec(a,1)}return 0}function Zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function pu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;f=a+1074308|0;Db(e+8|0,f,77);a:{if(i=Cb(e+8|0),j=0,k=v[c+88>>2]&1024,k?i:j){break a}if(!d){v[c+768>>2]=v[b+48>>2];break a}g=w[c+843|0];b:{if(g){d=g-1|0;t[c+843|0]=d;if(d&255){break b}Db(e+8|0,f,16);if(i=!Cb(e+8|0),j=0,k=v[a+480180>>2]!=2,k?i:j){break a}v[c+768>>2]=v[b+48>>2]+1;break a}Db(e+8|0,f,17);if(!(Cb(e+8|0)|v[a+480180>>2]&3|!x[a+480188>>1])){g=b+616|0;while(1){if(w[g+843|0]?(c|0)!=(g|0):0){break a}g=g+880|0;h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}}t[c+843|0]=d}d=v[c+768>>2];v[b+56>>2]=d;c:{if((d|0)==-1){break c}d:{if(v[b+60>>2]==-1){break d}Db(e+8|0,f,68);if(!Cb(e+8|0)){break d}v[b+60>>2]=d}v[b+64>>2]=d;Db(e+8|0,f,103);if(!Cb(e+8|0)){break c}u[b+68>>1]=65535}if(!x[a+480188>>1]|v[a+480180>>2]!=2){break a}d=0;while(1){f=B(d,880)+b|0;v[f+1384>>2]=v[c+768>>2];t[f+1459|0]=w[c+843|0];d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}gb=e+16|0}function lx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Bb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Bb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=ho(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+84064|0];d:{e:{switch(f-22|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Bb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function Hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];i=h;e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;h=a;if(d){while(1){g=(((i&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;i=a;a=0;e=1;if(i){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];i=v[f+28>>2];continue}break}e=v[f+24>>2];i=v[f+28>>2]}v[h>>2]=e;v[h+4>>2]=i;gb=f+32|0}function dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){m=B(c,d);c=0;while(1){if((m|0)>=1){j=(l<<1)+b|0;p=j+(m<<1)|0;n=c;while(1){u[e+6>>1]=0;FV(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{if(!i){h=x[e+6>>1];break a}h=x[e+6>>1];c=x[e+12>>1];f=i;while(1){b:{g=c<<1;c=g&254;u[e+12>>1]=c;if(c){k=(g&65534)>>>0>255}else{if(!pf(a,e+5|0)){break b}g=w[e+5|0];c=g<<1&254|1;u[e+12>>1]=c;k=g>>>7|0}h=k|h<<1;f=f-1|0;if(f&255){continue}}break}u[e+6>>1]=h}k=e;o=h&65535;c=i+1|0;c:{if(o>>>0<=3){break c}c=15;while(1){f=c;g=c&255;if(g>>>0>=2){c=f-1|0;if(!(o&1<<g)){continue}}break}c=f+i|0}i=c>>>1&127;t[k+15|0]=i;c=h&1;t[e+14|0]=c;f=c-1^(h&65534)>>>1;c=f+x[e+8>>1]|0;u[j>>1]=c;v[e+8>>2]=((f>>1)-(n<<16>>16)|0)+(c<<16>>16<<1);Vd(e+8|0,-32768,32767);n=c;j=(d<<1)+j|0;if(p>>>0>j>>>0){continue}break}}l=l+1|0;if((l|0)!=(d|0)){continue}break}}gb=e+16|0}function eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=0,y=C(0);if(v[a+4220>>2]){f=a+44|0;i=Pd(f,0);j=Pd(f,1);k=qd(f,0);l=qd(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[j>>2];o=z[i>>2];w=h;e=e-v[a+4228>>2]|0;if((e|0)<=-1){e=e+v[a+4220>>2]|0}e=e<<1;p=z[Mb(w,e)>>2];e=Mb(h,e|1);r=z[a+4248>>2];s=z[a+4256>>2];t=z[a+4252>>2];u=z[a+4244>>2];q=z[e>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(u*q));x=Mb(h,v[a+4224>>2]<<1),y=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[x>>2]=y;g=C(C(C(C(r*o)+C(s*n))+C(t*q))+C(u*p));x=Mb(h,v[a+4224>>2]<<1|1),y=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[x>>2]=y;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(p*z[a+4236>>2])+C(o*z[a+4240>>2]);z[l>>2]=C(q*z[a+4236>>2])+C(n*z[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}si(a,b,c,qd(f,0),qd(f,1),d)}}function afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;e=a;c=gb-16|0;gb=c;v[c+8>>2]=1073741824;u[c+14>>1]=12;v[c+4>>2]=15;d=wf(64);v[23048]=0;g=U(1333,d|0)|0;h=v[23048];v[23048]=0;a:{b:{c:{if((h|0)!=1){d=ns(c,g);g=v[d>>2];v[23048]=0;S(1334,g|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}b=v[d>>2];v[23048]=0;b=W(1335,b|0,c+14|0,c+8|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break c}d:{if(!b){Oz(e);break d}b=v[d>>2];v[23048]=0;S(1336,b|0,c+4|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}gi(e,d)}yg(d);gb=c+16|0;break a}a=P()|0;O()|0;Zb(d);break b}a=P()|0;O()|0;yg(d)}R(a|0);L()}b=0;e:{f:{g:{while(1){c=v[a>>2];v[23048]=0;u[f+14>>1]=b;e=Q(2,f|0,(b<<2)+33152|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break g}v[23048]=0;T(1332,c|0,f+14|0,e|0);c=v[23048];v[23048]=0;if((c|0)==1){break f}vb(e);b=b+1|0;if((b|0)!=12){continue}break}gb=f+16|0;return}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(e)}yg(a);R(b|0);L()}function yM(a,b,c){var d=0;a:{b:{switch(b|0){case 0:uM(a,c);return;case 1:b=0;a=Jb(a);d=Bb(c);v[23048]=0;S(113,a|0,d|0);d=v[23048];v[23048]=0;c:{if((d|0)!=1){d:{if(Bb(c)){while(1){d=t[pc(c,b)|0];e:{if((d|0)>=0){v[23048]=0;S(112,a|0,d&255);d=v[23048];v[23048]=0;if((d|0)!=1){break e}break d}v[23048]=0;S(112,a|0,65533);d=v[23048];v[23048]=0;if((d|0)==1){break d}}b=b+1|0;if(Bb(c)>>>0>b>>>0){continue}break}}break c}}break a}return;case 2:b=0;a=Jb(a);d=Bb(c);v[23048]=0;S(113,a|0,d|0);d=v[23048];v[23048]=0;f:{if((d|0)!=1){g:{if(Bb(c)){while(1){d=w[pc(c,b)|0];v[23048]=0;S(112,a|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break g}b=b+1|0;if(Bb(c)>>>0>b>>>0){continue}break}}break f}}break a}return;case 3:io(a,c,4128);return;case 4:io(a,c,5152);return;case 5:io(a,c,6176);return;case 6:io(a,c,7200);return;case 7:io(a,c,8224);return;case 8:io(a,c,9248);return;default:break b}}Jb(a);return}b=P()|0;O()|0;Pc(a);R(b|0);L()}function KI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-32|0;gb=h;f=d&2147483647;g=f;e=f-1065418752|0;i=f-1082064896|0;f=c;a:{if((e|0)==(i|0)&f>>>0<f>>>0|e>>>0<i>>>0){g=(d&33554431)<<7|c>>>25;f=0;j=f;i=c&33554431;if(!(!f&(i|0)==16777216?!(a|b):!f&i>>>0<16777216)){e=g+1073741825|0;break a}e=g+1073741824|0;if(i^16777216|a|(b|j)){break a}e=(g&1)+e|0;break a}if(!(!f&(g|0)==2147418112?!(a|b):g>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(g>>>0>1082064895){break a}e=0;f=g>>>16|0;if(f>>>0<16145){break a}g=c;e=d&65535|65536;Uf(h+16|0,a,b,g,e,f-16129|0);Hn(h,a,b,g,e,16257-f|0);b=v[h+8>>2];e=(v[h+12>>2]&33554431)<<7|b>>>25;g=v[h+4>>2];f=g;a=0;i=a;j=v[h>>2]|((v[h+16>>2]|v[h+24>>2])!=0|(v[h+20>>2]|v[h+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|j):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|j|(f|i)){break a}e=(e&1)+e|0}gb=h+32|0;return l(2,d&-2147483648|e),q()}function VH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Wf(c+24|0,a+44|0)>>2];if((e|0)>=1){h=(e|0)>0?e:0;while(1){f=Rs(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;if((h|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(UH(v[a+36>>2],g,c+24|0,d,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=Rs(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Qs(ah(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}j=a,k=ah(t[c+23|0]),v[j+48>>2]=k}d=ah(t[c+23|0]);break a}d=-1}gb=c+32|0;return d}function _N(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;t[k+15|0]=c;t[k+14|0]=12;Eg(b,w[$b(k+15|0,k+14|0)|0]);if(Lb(b)){c=0;l=a+96|0;a=a+144|0;while(1){a:{b:{c:{switch(h|0){case 0:i=c<<2;j=i+l|0;j=w[j|0]|w[j+1|0]<<8;n=Mb(b,c),o=j,u[n>>1]=o;i=(i|2)+l|0;break b;case 1:break c;default:break a}}i=c<<2;j=i+a|0;j=w[j|0]|w[j+1|0]<<8;n=Mb(b,c),o=j,u[n>>1]=o;i=a+(i|2)|0}i=w[i|0];n=Mb(b,c),o=i,t[n+2|0]=o}d:{if(!c){break d}i=c-1|0;if(x[Mb(b,c)>>1]>=x[Mb(b,i)>>1]){break d}if(x[Mb(b,c)>>1]>255){break d}j=w[Mb(b,i)+1|0];m=Mb(b,c);u[m>>1]=x[m>>1]|j<<8;if(x[Mb(b,c)>>1]>=x[Mb(b,i)>>1]){break d}i=Mb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Lb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if(cd(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}gb=k+16|0}function lT(a,b,c){var d=0;d=w[a|0]&15;t[a|0]=w[d+26880|0];a:{b:{c:{switch(d|0){case 0:if(w[b|0]?c>>>0>=51:0){break b}t[a|0]=0;return;case 5:d=w[b|0];if(!((d&240)!=32?(d&15)!=2:0)){t[a|0]=20;t[b|0]=159;d=159}if(!((d&15)==12|(d&240)==192)|c>>>0<51){break b}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:d:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break d;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function xP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+815|0];if(c){t[b+815|0]=e&15|c<<4;break a}c=(e&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}b:{if(!v[b+700>>2]|(!(t[b+853|0]&1)|!(c&255))){break b}if(v[a+480180>>2]==512){v[b+700>>2]=v[b+700>>2]+(B(c&255,145272)>>>10|0);break b}if(!(!(w[a+480208|0]&16)|v[a+480180>>2]==4)){e=v[b+700>>2];c=cA(a,c&15);f=Fpa(c,c>>31,e,e>>31)+32768|0;c=jb;c=vc(Gpa(f,f>>>0<32768?c+1|0:c,65536,0),jb);v[b+700>>2]=c;if((c|0)!=(e|0)){break b}a=a+1074308|0;Db(d+8|0,a,7);if(!(!Cb(d+8|0)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break b}Db(d+8|0,a,7);if(Cb(d+8|0)){break b}a=v[b+700>>2];if((a|0)<2){break b}v[b+700>>2]=a-1;break b}c=v[b+700>>2]-((c&255)<<2)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}gb=d+16|0}function Cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=uc(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>1>>>0){f=gb-16|0;gb=f;e=di(f,e,i);d=v[e+4>>2];if((d|0)!=v[e+8>>2]){while(1){Dk(d);d=v[e+4>>2]+2|0;v[e+4>>2]=d;if(v[e+8>>2]!=(d|0)){continue}break}}_b(e);gb=f+16|0;break d}j=wb(e);f=AY(e,uc(e)+i|0);m=uc(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;vd(d+12|0,j);if(f){h=f;if((f|0)<=-1){xc(19760);L()}h=jc(h<<1,1)}v[d>>2]=h;j=(m<<1)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=bc(d),o=(f<<1)+h|0,v[n>>2]=o;gb=l+16|0;v[23048]=0;OV(d,i);f=v[23048];v[23048]=0;if((f|0)==1){break c}Ji(e,d);rp(d)}gb=k+32|0;break b}a=P()|0;O()|0;rp(d);R(a|0);L()}break a}if(d>>>0<f>>>0){Hj(e,v[e>>2]+(d<<1)|0)}}c=Nb(a,c<<1);if(c){cc(g+24|0,v[b>>2],uc(b)<<1);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function qy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb-96|0;gb=c;d=v[a>>2];g=v[d+4>>2];e=v[d+24>>2];v[c+48>>2]=v[d+20>>2];v[c+52>>2]=e;e=v[d+16>>2];v[c+40>>2]=v[d+12>>2];v[c+44>>2]=e;bk(c+72|0,c+40|0,g);d=lf(c+56|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);g=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];v[c+32>>2]=v[c+88>>2];a=v[c+84>>2];v[c+24>>2]=v[c+80>>2];v[c+28>>2]=a;a=v[c+76>>2];v[c+16>>2]=v[c+72>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;j=c+16|0;a=c;d=gb-16|0;gb=d;if(g){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(Lm(fe(A[lj(a,b,h)>>3]*134217728))+jd(vt(k),21)|0)*7.450580596923828e-9,A[l+8>>3]=m;hg(d+8|0,-1,1);f=A[d+8>>3]*32768;A[d+8>>3]=f;f=fe(f);a:{if(D(f)<2147483648){i=~~f;break a}i=-2147483648}i=Uc(i);l=_n(j,b,h),n=i,u[l>>1]=n;b=b+1|0;if((e|0)!=(b|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}gb=d+16|0;gb=c+96|0}function hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=g>>>21&2040;g=u[b+40886>>1];m=u[b+40884>>1];n=u[b+40882>>1];o=u[b+40880>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2];break a}b=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=f;gb=e+32|0}function Eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=C(0),s=C(0),t=C(0),u=0,x=0,y=C(0);f=gb-16|0;gb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!ei(g)){break a}t=z[a+4220>>2];u=f,x=Pd(g,0),v[u+8>>2]=x;u=f,x=Pd(g,1),v[u+12>>2]=x;u=f,x=qd(g,0),v[u>>2]=x;u=f,x=qd(g,1),v[u+4>>2]=x;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;e=v[a+4244>>2]-v[((n<<2)+a|0)+4248>>2]|0;if((e|0)<=-1){e=v[a+4240>>2]+e|0}o=h<<2;p=o+(f+8|0)|0;q=v[p>>2];v[p>>2]=q+4;l=z[q>>2];r=z[Mb(m,(e<<1)+n|0)>>2];s=C(C(z[a+4224>>2]*r)+C(l*z[a+4260>>2]));u=Mb(m,v[a+4244>>2]<<1|h),y=C(D(s))<C(1.0000000195414814e-24)?C(0):s,z[u>>2]=y;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=l+C(C(r-l)*t);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}si(a,b,c,qd(g,0),qd(g,1),d)}gb=f+16|0}function AG(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{b:{if((b|0)!=8){g=28;f=b>>>2|0;while(1){d=e;if(f){f=f-1&f;e=e+1|0;continue}break}if(b&3|(d|0)!=1){break b}g=48;if(-64-b>>>0<c>>>0){break b}d=16;e=b>>>0>16?b:16;c:{if(!(e-1&e)){b=e;break c}while(1){b=d;d=b<<1;if(b>>>0<e>>>0){continue}break}}if(-64-b>>>0<=c>>>0){v[115529]=48;return 48}e=c>>>0<11?16:c+11&-8;d=Ad((e+b|0)+12|0);if(!d){break b}c=d-8|0;d:{if(!(d&b-1)){b=c;break d}g=d-4|0;h=v[g>>2];d=((b+d|0)-1&0-b)-8|0;b=d-c>>>0>15?d:b+d|0;d=b-c|0;f=(h&-8)-d|0;if(!(h&3)){c=v[c>>2];v[b+4>>2]=f;v[b>>2]=c+d;break d}v[b+4>>2]=f|v[b+4>>2]&1|2;f=b+f|0;v[f+4>>2]=v[f+4>>2]|1;v[g>>2]=d|v[g>>2]&1|2;f=c+d|0;v[f+4>>2]=v[f+4>>2]|1;ws(c,d)}c=v[b+4>>2];e:{if(!(c&3)){break e}d=c&-8;if(d>>>0<=e+16>>>0){break e}v[b+4>>2]=e|c&1|2;c=b+e|0;e=d-e|0;v[c+4>>2]=e|3;d=b+d|0;v[d+4>>2]=v[d+4>>2]|1;ws(c,e)}b=b+8|0;break a}b=Ad(c);if(b){break a}g=48}return g}v[a>>2]=b;return 0}function Kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Ie(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>5>>>0){f=gb-16|0;gb=f;e=Nu(f,e,i);d=v[e+4>>2];if((d|0)!=v[e+8>>2]){while(1){MB(d);d=v[e+4>>2]+32|0;v[e+4>>2]=d;if(v[e+8>>2]!=(d|0)){continue}break}}_b(e);gb=f+16|0;break d}j=wb(e);f=fr(e,Ie(e)+i|0);m=Ie(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;vd(d+12|0,j);if(f){h=f;if(f>>>0>=134217728){xc(26612);L()}h=jc(h<<5,1)}v[d>>2]=h;j=(m<<5)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=bc(d),o=(f<<5)+h|0,v[n>>2]=o;gb=l+16|0;v[23048]=0;zT(d,i);f=v[23048];v[23048]=0;if((f|0)==1){break c}Ji(e,d);yT(d)}gb=k+32|0;break b}a=P()|0;O()|0;yT(d);R(a|0);L()}break a}if(d>>>0<f>>>0){Hj(e,v[e>>2]+(d<<5)|0)}}if(Nb(a,c<<5)){cc(g+24|0,v[b>>2],Ie(b)<<5);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0}function Kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;f=Jb(d+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[23048]=0;c=U(1434,b|0)|0;e=v[23048];v[23048]=0;d:{if((e|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[23048]=0;Q(91,a|0,43936)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break b}}break a}v[23048]=0;c=U(511,b|0)|0;e=v[23048];v[23048]=0;e:{if((e|0)==1){break e}c=Ii(c);v[23048]=0;v[d+8>>2]=c;c=sd(d+12|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}c=v[c>>2];v[23048]=0;S(111,f|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[23048]=0;c=U(373,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break g}if(!c){break f}v[23048]=0;W(1435,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}}break}break a}v[23048]=0;Q(370,b|0,4)|0;b=v[23048];v[23048]=0;if((b|0)==1){break a}Dc(a,f)}vb(f);gb=d+32|0;return}a=P()|0;O()|0;vb(f);R(a|0);L()}function Gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=vf(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>4>>>0){f=gb-16|0;gb=f;e=Pp(f,e,i);d=v[e+4>>2];if((d|0)!=v[e+8>>2]){while(1){zv(d);d=v[e+4>>2]+16|0;v[e+4>>2]=d;if(v[e+8>>2]!=(d|0)){continue}break}}_b(e);gb=f+16|0;break d}j=wb(e);f=Mw(e,vf(e)+i|0);m=vf(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;vd(d+12|0,j);if(f){h=f;if(f>>>0>=268435456){xc(26612);L()}h=jc(h<<4,1)}v[d>>2]=h;j=(m<<4)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=bc(d),o=(f<<4)+h|0,v[n>>2]=o;gb=l+16|0;v[23048]=0;vT(d,i);f=v[23048];v[23048]=0;if((f|0)==1){break c}Ji(e,d);uT(d)}gb=k+32|0;break b}a=P()|0;O()|0;uT(d);R(a|0);L()}break a}if(d>>>0<f>>>0){Hj(e,v[e>>2]+(d<<4)|0)}}if(Nb(a,c<<4)){cc(g+24|0,v[b>>2],vf(b)<<4);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0}function G0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){f=t[a|0];b=a+1|0;b:{if((f|0)>=0){break b}b=f&255;if(b>>>0<194){break a}if(b>>>0<=223){if((w[a+1|0]&192)!=128|(d-a|0)<2){break a}b=a+2|0;break b}if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}if((h&192)!=128){break a}b=a+3|0;break b}if(e-g>>>0<2|b>>>0>244|(d-a|0)<4){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(b<<18&1835008|(f&48)<<12)>>>0>1114111){break a}g=g+1|0;b=a+4|0}a=b;g=g+1|0;if(g>>>0>=e>>>0){break a}if(a>>>0<d>>>0){continue}break}}return a-c|0}function yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=gb-32|0;gb=h;d=gb-16|0;gb=d;HF(d+8|0,b);gb=d+16|0;v[h+16>>2]=v[d+8>>2];c=gb-32|0;gb=c;f=b;e=a;b=$d(e);d=dc(e);a:{b:{if(b){c:{while(1){d:{g=b+16|0;e:{if(uu(wb(e),f,g)){if(!v[b>>2]){break b}d=b;break e}if(!uu(wb(e),g,f)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=d;break a}v[c+28>>2]=b;b=d;break a}b=dc(e)}v[c+28>>2]=b}d=b;b=v[b>>2];t[c+27|0]=0;if(!b){e=gb-16|0;gb=e;f=dc(a);g=jc(40,4);b=e+8|0;t[b+4|0]=0;v[b>>2]=f;f=ms(c+8|0,g,b);b=v[f>>2];v[23048]=0;g=b+16|0;b=v[23048];v[23048]=0;f:{if((b|0)!=1){b=gb-16|0;gb=b;v[b+8>>2]=v[h+16>>2];Dc(g,v[b+8>>2]);Jb(g+12|0);gb=b+16|0;i=dc(f),j=1,t[i+4|0]=j;gb=e+16|0;break f}a=P()|0;O()|0;UQ(f);R(a|0);L()}ES(a,v[c+28>>2],d,v[c+8>>2]);b=Bd(c+8|0);t[c+27|0]=1;UQ(c+8|0)}Xh(h+24|0,Cc(c+8|0,b),c+27|0);gb=c+32|0;a=se(h+24|0);gb=h+32|0;return a+12|0}function IS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=VA(a+48|0);e=VA(a+68|0);f=VA(a+88|0);v[23048]=0;br(a+492|0);c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;br(a+524|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}v[23048]=0;Zl(a,0,0);c=v[23048];v[23048]=0;if((c|0)==1){break a}v[23048]=0;Yl(a,0,0);c=v[23048];v[23048]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[23048]=0;sr(a,b);b=v[23048];v[23048]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=lc(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;Zo(f);Zo(e);Zo(d);R(a|0);L()}function cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;u[e+12>>1]=0;v[e+8>>2]=0;if(d){g=4;l=B(c,d);o=(l|0)<1;c=0;while(1){if(!o){j=b+k|0;p=l+j|0;m=c;while(1){t[e+7|0]=0;EV(a,e+15|0,e+12|0,e+7|0);a:{if(!g){h=w[e+7|0];break a}h=w[e+7|0];c=x[e+12>>1];f=g;b:{while(1){i=c<<1;c=i&254;c:{if(c){i=(i&65534)>>>0>255;break c}if(!pf(a,e+6|0)){break b}c=w[e+6|0];i=c>>>7|0;c=c<<1&254|1}h=h<<1|i;f=f-1|0;if(f&255){continue}break}t[e+7|0]=h;u[e+12>>1]=c;break a}t[e+7|0]=h;u[e+12>>1]=0}i=h&255;f=g+1|0;d:{if(i>>>0<=3){break d}c=7;while(1){f=c;n=c&255;if(n>>>0>=2){c=f-1|0;if(!(i&1<<n)){continue}}break}f=g+f|0}c=h&1;t[e+15|0]=c;g=c-1^(h&254)>>>1;c=g+w[e+8|0]|0;t[j|0]=c;v[e+8>>2]=((g>>1)-(m<<24>>24)|0)+(c<<24>>24<<1);Vd(e+8|0,-128,127);g=(f&254)>>>1|0;m=c;j=d+j|0;if(p>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function $da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb+-64|0;gb=e;g=no(a);a:{b:{if(b-1>>>0>1023){break b}f=v[a+12>>2];if((f|0)==(b|0)){break b}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break b}f=v[a+12>>2]}f=B(wi(a),b>>>0>f>>>0?b-f|0:f-b|0);c:{if(y[a+12>>2]<b>>>0){c=e;d:{if(d){d=Ub(a);break d}d=Rb(a)}v[c+48>>2]=d;c=Sd(e+56|0,e+48|0);$h(e+40|0);c=v[c>>2];v[23048]=0;Y(1488,a|0,c|0,f|0,e+40|0);c=v[23048];v[23048]=0;if((c|0)!=1){break c}a=V(90496)|0;if((O()|0)!=(da(90496)|0)){break a}Z(a|0)|0;$();break b}if(d){i=e,j=Ub(a),v[i+48>>2]=j;i=e,j=LC(e+48|0,f),v[i+40>>2]=j;c=Sd(e+32|0,e+40|0);i=e,j=Ub(a),v[i+16>>2]=j;d=Sd(e+24|0,e+16|0);PN(a,v[c>>2],v[d>>2]);break c}i=e,j=Rb(a),v[i+40>>2]=j;c=Sd(e+8|0,e+40|0);i=e,j=Rb(a),v[i+16>>2]=j;i=e,j=oX(e+16|0,f),v[i+48>>2]=j;d=Sd(e,e+48|0);PN(a,v[c>>2],v[d>>2])}v[a+12>>2]=b;h=1}gb=e- -64|0;return h|0}R(a|0);L()}function zy(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;Dq(v[h>>2]);t[v[h>>2]+1300420|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=dL(g+32|0,g+80|0,eL(g+80|0),b);e=v[a+32>>2];j=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;c=gb-16|0;gb=c;d=v[g+12>>2];v[c+8>>2]=v[g+8>>2];v[c+12>>2]=d;d=v[g+4>>2];v[c>>2]=v[g>>2];v[c+4>>2]=d;f=g+48|0;d=f;xt(d);v[d+8>>2]=e;v[d+4>>2]=0;v[d>>2]=58696;e=v[c+4>>2];v[d+12>>2]=v[c>>2];v[d+16>>2]=e;e=v[c+12>>2];v[d+20>>2]=v[c+8>>2];v[d+24>>2]=e;z[d+28>>2]=j;v[d>>2]=58476;gb=c+16|0;a:{if(b){while(1){b:{c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Dt(c,v[Wl(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break b}b=b-c|0;if(b){continue}}break}if(i){break a}}i=0;if(v[a+52>>2]!=1){break a}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function yy(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;Dq(v[h>>2]);t[v[h>>2]+1300420|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=dL(g+32|0,g+80|0,eL(g+80|0),b);e=v[a+32>>2];j=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;c=gb-16|0;gb=c;d=v[g+12>>2];v[c+8>>2]=v[g+8>>2];v[c+12>>2]=d;d=v[g+4>>2];v[c>>2]=v[g>>2];v[c+4>>2]=d;f=g+48|0;d=f;xt(d);v[d+8>>2]=e;v[d+4>>2]=0;v[d>>2]=58924;e=v[c+4>>2];v[d+12>>2]=v[c>>2];v[d+16>>2]=e;e=v[c+12>>2];v[d+20>>2]=v[c+8>>2];v[d+24>>2]=e;z[d+28>>2]=j;v[d>>2]=58744;gb=c+16|0;a:{if(b){while(1){b:{c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Dt(c,v[Wl(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break b}b=b-c|0;if(b){continue}}break}if(i){break a}}i=0;if(v[a+52>>2]!=1){break a}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function SH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Wf(c+24|0,a+44|0)>>2];if((e|0)>=1){h=(e|0)>0?e:0;while(1){f=Rs(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;if((h|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(UH(v[a+36>>2],g,c+24|0,d,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=Rs(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Qs(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}gb=c+32|0;return d}function $8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23048]=0;_(2016,a|0);e=v[23048];v[23048]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[23048]=0;_(1969,b|0);e=v[23048];v[23048]=0;if((e|0)==1){break e}e=0;v[23048]=0;_(2017,c|0);f=v[23048];v[23048]=0;if((f|0)==1){break e}a=Pb(c,0,d);if(!w[b|0]){break b}if(hj(b,55350)|(d|0)!=8){break d}v[a+4>>2]=2018;v[a>>2]=2019;break c}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55374,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();return 0}if(hj(b,55362)|(d|0)!=64){break b}v[a+60>>2]=2020;v[a+56>>2]=2021;v[a+52>>2]=2022;v[a+48>>2]=2023;v[a+44>>2]=2024;v[a+40>>2]=2025;v[a+36>>2]=2026;v[a+32>>2]=2027;v[a+28>>2]=2028;v[a+24>>2]=2029;v[a+20>>2]=2030;v[a+16>>2]=2031;v[a+12>>2]=2032;v[a+8>>2]=2033;v[a+4>>2]=2034;v[a>>2]=2035}e=1}return e|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-16|0;gb=g;v[g+12>>2]=1;a:{if(nh(a)){n=g,o=Ie(a),v[n+8>>2]=o;f=v[a>>2];c=b;k=v[Gb(g+12|0,g+8|0)>>2];if(k){while(1){d=c;if((c|0)!=(f|0)){h=Rb(d);l=Ub(d);i=gb-16|0;gb=i;j=fD(h,l);e=f;b:{if(j>>>0<=Gg(e)>>>0){if(uc(e)>>>0<j>>>0){v[i+8>>2]=h;nS(i+8|0,uc(e));m=h;h=v[i+8>>2];Hi(m,h,v[e>>2]);xS(e,h,l,j-uc(e)|0);break b}pn(e,Hi(h,l,v[e>>2]));break b}wS(e);OB(e,Jk(e,j));xS(e,h,l,j)}gb=i+16|0;Np(f+12|0,d+12|0);u[f+28>>1]=x[d+28>>1]}f=f+32|0;k=k-1|0;if(k){continue}break}}d=v[g+12>>2];c=v[g+8>>2];if(d>>>0>c>>>0){TA(a,d-c|0,b);break a}pS(a,v[a>>2]+(d<<5)|0);break a}c=a;if(v[c>>2]){Ie(c);kS(c);iS(c);_l(wb(c),v[c>>2],nh(c));n=wb(c),o=0,v[n>>2]=o;v[c>>2]=0;v[c+4>>2]=0}f=fr(a,1);if(xT()>>>0<f>>>0){Mc();L()}wb(c);d=hS(f);v[c>>2]=d;v[c+4>>2]=d;n=wb(c),o=d+(f<<5)|0,v[n>>2]=o;SA(c,0);TA(a,1,b)}gb=g+16|0}function D0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){f=t[a|0];b=a+1|0;b:{if((f|0)>=0){break b}b=f&255;if(b>>>0<194){break a}if(b>>>0<=223){if((w[a+1|0]&192)!=128|(d-a|0)<2){break a}b=a+2|0;break b}if(b>>>0<=239){if((d-a|0)<3){break a}g=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}if((g&192)!=128){break a}b=a+3|0;break b}if((d-a|0)<4|b>>>0>244){break a}g=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(g&192)!=128|(b<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=a+4|0}a=b;h=h+1|0;if(h>>>0>=e>>>0){break a}if(a>>>0<d>>>0){continue}break}}return a-c|0}function uM(a,b){var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=Jb(a);f=d,g=Ld(b),v[f+8>>2]=g;f=d,g=hf(b),v[f>>2]=g;a:{b:{if(!Fb(d+8|0,d)){break b}a=0;b=0;while(1){c=w[v[d+8>>2]];c:{if(!a){if(!(c&128)){a=0;v[23048]=0;S(112,e|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){break c}break a}if((c&224)==192){b=c&31;a=1;break c}if((c&240)==224){b=c&15;a=2;break c}if((c&248)==240){b=c&7;a=3;break c}b=0;v[23048]=0;S(112,e|0,65533);c=v[23048];v[23048]=0;a=0;if((c|0)==1){break a}break c}if((c&192)!=128){v[23048]=0;S(112,e|0,65533);a=v[23048];v[23048]=0;if((a|0)==1){break a}b=c&63;a=-1;break c}c=c&63|b<<6;a=a-1|0;if(a){b=c;break c}b=0;v[23048]=0;S(112,e|0,c|0);c=v[23048];v[23048]=0;a=0;if((c|0)==1){break a}}Se(d+8|0);if(Fb(d+8|0,d)){continue}break}if(!a){break b}v[23048]=0;S(112,e|0,65533);a=v[23048];v[23048]=0;if((a|0)!=1){break b}break a}gb=d+16|0;return}a=P()|0;O()|0;Pc(e);R(a|0);L()}function rm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;hl(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){d=v[b+2084>>2];if(d){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}d=v[b+2084>>2];if(!d){break c}}h=v[a+1392>>2];j=qm(h);e=v[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+d>>2];c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}v[a+1392>>2]=h>>>b;a=d-b|0}v[e+1396>>2]=a;return c}if(w[b+23|0]){break a}if((f|0)>=1){d=v[b+8>>2];while(1){f:{e=w[c+d|0];if((e|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=v[a+1396>>2];if((d|0)>=(e|0)){v[a+1392>>2]=h>>>e;v[a+1396>>2]=d-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}ec(a,21);v[a+1396>>2]=0}return-1}ha(69914,69696,1690,69925);L()}function iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=h>>>21&2040;h=u[b+40886>>1];m=u[b+40884>>1];n=u[b+40882>>1];o=u[b+40880>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2];break a}f=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=g;gb=e+32|0}function tna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;g=$f(a,c);we(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{if(!g){if(nd(a,5)){break a}}d=gb-48|0;gb=d;h=v[a+28>>2];Yf(h,d+46|0);b:{c:{d:{e:{f:{if(x[d+46>>1]>=4001){j=v[b+12>>2];f=gb-16|0;gb=f;i=Tb(f,28121);Dc(d+16|0,i);vb(i);gb=f+16|0;v[23048]=0;T(1118,d+32|0,d+16|0,d+46|0);f=v[23048];v[23048]=0;if((f|0)==1){break f}v[23048]=0;T(601,j|0,2,d+32|0);f=v[23048];v[23048]=0;if((f|0)==1){break e}vb(d+32|0);Hb(d+16|0);u[d+46>>1]=4e3}Cf(Ej(b,0),x[d+46>>1]);b=Ej(b,0);k=d,l=Rb(b),v[k+32>>2]=l;k=d,l=Ub(b),v[k+16>>2]=l;if(Fb(d+32|0,d+16|0)){break c}break b}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d+32|0)}Hb(d+16|0);R(a|0);L()}while(1){b=v[d+32>>2];Yf(h,d+14|0);u[b>>1]=x[d+14>>1];sf(d+32|0);if(Fb(d+32|0,d+16|0)){continue}break}}gb=d+48|0}Rf(a,g,c,e+24|0);gb=e+32|0}function Y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb+-64|0;gb=e;c=gi(a,c);g=lh(a+4|0);h=lh(a+24|0);i=lh(a+32|0);j=dd(a+36|0);v[a+56>>2]=3;k=nc(a+68|0);v[23048]=0;S(2082,a|0,d|0);f=v[23048];v[23048]=0;a:{b:{c:{d:{e:{if((f|0)!=1){f=v[b>>2];l=v[b+4>>2];m=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=m;v[e+24>>2]=f;v[e+28>>2]=l;b=Xd(e+16|0);f=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=f;v[23048]=0;f=v[e+28>>2];v[e>>2]=v[e+24>>2];v[e+4>>2]=f;T(2077,e+40|0,e|0,b|0);f=v[23048];v[23048]=0;if((f|0)==1){break e}v[23048]=0;T(2083,a|0,e+40|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}yb(e+40|0);Bc(b);v[23048]=0;_(2084,a|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}gb=e- -64|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(e+40|0)}Bc(b);break a}a=P()|0;O()|0}yd(k);Tf(j);mq(i);ri(h);qi(g);mf(c);R(a|0);L()}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=u[(g<<1)+n>>1];j=v[a+60>>2];f=ac(b,-16777216,16776704);k=v[a+64>>2];g=ac(e,-16777216,16776704);i=i<<8;e=i;e=Fpa(j,j>>31,e,e>>31);j=jb;k=Fpa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=Fpa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Lc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function gA(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1300300|0;while(1){e=B(d,880)+a|0;c=e+1075060|0;b:{if(v[c>>2]){break b}if(!kk(e+1074984|0)){break a}if(v[c>>2]){break b}if(w[e+1075073|0]&24){break a}}if(w[e+1075073|0]&2){if(!Fd(f)){break a}if(!MP(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,880)+a|0;if(!v[b+1075680>>2]){d=65535;if(v[b+1075060>>2]){break a}}g=v[b+1075672>>2]|v[b+1075664>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,880)+a|0;if(!(v[c+1075680>>2]?0:v[c+1075060>>2])){f=(v[c+1075672>>2]|v[c+1075664>>2]<<9)>>>(v[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075708>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075708>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function m9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){d=Jb(b+32|0);c=v[a+24>>2];v[23048]=0;S(2003,b+16|0,c|0);c=v[23048];v[23048]=0;d:{if((c|0)!=1){e=b,f=Rb(b+16|0),v[e+8>>2]=f;e=b,f=Ub(b+16|0),v[e>>2]=f;if(!Fb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[23048]=0;Q(1201,d|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break e}wr(b+8|0);e=b,f=Ub(b+16|0),v[e>>2]=f;if(!Fb(b+8|0,b)){break b}v[23048]=0;Q(1926,d|0,52201)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;yd(b+16|0);break d}c=V(0)|0;O()|0}vb(d);break c}c=V(0)|0;O()|0}Z(c|0)|0;c=0;v[23048]=0;Y(1920,54905,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}c=ie(Ob(d));yd(b+16|0);vb(d)}gb=b+48|0;return c|0}function Y_(){var a=0,b=0,c=0,d=0;c=gb-32|0;gb=c;a:{a=Tb(c+16|0,15177);if(!Bb(a)){break a}b:{if((ng(a,15183)|0)!=-1){b=ng(a,15183);v[23048]=0;Y(219,c|0,a|0,b+1|0,-1);b=v[23048];v[23048]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((ng(a,11241)|0)!=-1){b=ng(a,11241);v[23048]=0;Y(219,c|0,a|0,b+1|0,-1);b=v[23048];v[23048]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((ng(a,15185)|0)!=-1){b=ng(a,15185);v[23048]=0;Y(219,c|0,a|0,0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((ng(a,15187)|0)!=-1){b=ng(a,15187);v[23048]=0;Y(219,c|0,a|0,0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((ng(a,15189)|0)!=-1){b=ng(a,15189);v[23048]=0;Y(219,c|0,a|0,0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}v[23048]=0;b=U(220,a|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;vb(a);R(c|0);L()}vb(a);gb=c+32|0;return b|0}function T9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)!=1){d=Jb(b+32|0);c=v[a+24>>2];v[23048]=0;S(1968,b+16|0,c|0);c=v[23048];v[23048]=0;d:{if((c|0)!=1){e=b,f=Rb(b+16|0),v[e+8>>2]=f;e=b,f=Ub(b+16|0),v[e>>2]=f;if(!Fb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[23048]=0;Q(1201,d|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break e}wr(b+8|0);e=b,f=Ub(b+16|0),v[e>>2]=f;if(!Fb(b+8|0,b)){break b}v[23048]=0;Q(1926,d|0,52201)|0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;yd(b+16|0);break d}c=V(0)|0;O()|0}vb(d);break c}c=V(0)|0;O()|0}Z(c|0)|0;c=0;v[23048]=0;Y(1920,53662,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}c=ie(Ob(d));yd(b+16|0);vb(d)}gb=b+48|0;return c|0}function Oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=t[g+n|0];j=v[a+60>>2];f=ac(b,-16777216,16776704);k=v[a+64>>2];g=ac(e,-16777216,16776704);i=i<<16;e=i;e=Fpa(j,j>>31,e,e>>31);j=jb;k=Fpa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=Fpa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Lc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function ux(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=Lf(a);a:{if(!v[116332]|!w[a|0]){break a}b=a;b:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break b}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];c:{if((c^-1)&c-16843009&-2139062144){break c}while(1){c=c^1027423549;if((c^-1)&c-16843009&-2139062144){break c}c=v[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;d=w[b|0];if(d){b=c+1|0;if((d|0)!=61){continue}}break}b=c}if(w[b|0]==61?b:0){break a}e=v[v[116332]>>2];if(!e){break a}d:{while(1){h=v[116332];b=a;c=g;d=0;e:{if(!c){break e}d=w[b|0];f:{if(d){while(1){c=c-1|0;if(!c){break f}i=w[e|0];if(!i){break f}g:{if((d|0)==(i|0)){break g}break f}e=e+1|0;d=w[b+1|0];b=b+1|0;if(d){continue}break}}d=0}d=d-w[e|0]|0}if(!d){b=v[(f<<2)+h>>2]+g|0;if(w[b|0]==61){break d}}f=f+1|0;e=v[(f<<2)+h>>2];if(e){continue}break}return 0}f=b+1|0}return f}function Ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=d;i=$f(a,c);we(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!i){if(nd(a,5)){break a}}k=v[e+24>>2];d=gb-48|0;gb=d;h=v[a+28>>2];Uk(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>=257|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){Yf(h,d+38|0);f=Jb(d+24|0);v[23048]=0;W(696,h|0,f|0,255)|0;g=v[23048];v[23048]=0;if((g|0)==1){break f}v[23048]=0;T(13,d+8|0,k|0,f|0);g=v[23048];v[23048]=0;if((g|0)==1){break e}v[23048]=0;g=Q(1528,b|0,d+38|0)|0;l=v[23048];v[23048]=0;if((l|0)==1){break d}Eb(g,d+8|0);vb(d+8|0);vb(f);f=v[d+44>>2];j=j+1|0;if(!f&j>>>0<y[d+40>>2]|f){continue}break}}gb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d+8|0)}vb(f);R(a|0);L()}}Rf(a,i,c,e+16|0);gb=e+32|0}function ny(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb-80|0;gb=c;d=v[a>>2];f=v[d+4>>2];v[c+40>>2]=v[d+20>>2];g=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=g;ak(c- -64|0,c+32|0,f);d=lf(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];g=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;j=c+16|0;a=c;d=gb-16|0;gb=d;if(f){k=b+12|0;while(1){b=0;if(g){while(1){l=d,m=+(Lm(fe(A[lj(a,b,h)>>3]*134217728))+jd(vt(k),21)|0)*7.450580596923828e-9,A[l+8>>3]=m;hg(d+8|0,-1,1);e=A[d+8>>3]*32768;A[d+8>>3]=e;e=fe(e);a:{if(D(e)<2147483648){i=~~e;break a}i=-2147483648}i=Uc(i);l=Zn(j,b,h),n=i,u[l>>1]=n;b=b+1|0;if((g|0)!=(b|0)){continue}break}}h=h+1|0;if((f|0)!=(h|0)){continue}break}}gb=d+16|0;gb=c+80|0}function Vz(a,b){var c=0;c=gb-16|0;gb=c;a=$z(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Kb(a,7,1);Kb(a,9,1);Kb(a,10,1);Kb(a,13,1);Kb(a,15,1);Kb(a,16,1);Kb(a,17,1);Kb(a,18,1);Kb(a,20,1);Kb(a,21,1);Kb(a,24,1);Kb(a,25,1);Kb(a,26,1);Kb(a,28,1);Kb(a,30,1);Kb(a,31,1);Kb(a,33,1);Kb(a,34,1);Kb(a,39,1);Kb(a,41,1);Kb(a,44,1);Kb(a,46,1);Kb(a,45,1);Kb(a,47,1);Kb(a,48,1);Kb(a,50,1);Kb(a,99,1);Kb(a,102,1);Kb(a,104,1);Kb(a,105,1);Kb(a,108,1);break a;case 1:Tz(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Cg(a,107);break a;case 3:Tz(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Cg(a,4);break a;case 2:break b;case 0:break c}}Kb(a,88,1);break a}Tz(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}gb=c+16|0}function Eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function yJ(a,b,c,d){var e=0,f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=gb-96|0;gb=e;if((d|0)>=1){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){j=f<<3;h=f<<4;i=z[(h|8)+a>>2];g=z[(h|4)+a>>2];z[(e+48|0)+(j|4)>>2]=i+g;k=f<<1;z[(8-k<<2)+e>>2]=g-i;i=z[(a+h|0)+16>>2];g=z[(h|12)+a>>2];z[(7-k<<2)+e>>2]=i-g;z[(e+j|0)+56>>2]=-C(g+i);f=f+1|0;if((f|0)!=4){continue}break}xJ(e+48|0);xJ(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];h=0;while(1){f=h<<2;j=f+b|0;i=z[j>>2];g=z[f+68128>>2];l=z[f+(e+48|0)>>2];m=z[e+f>>2];n=z[f+68164>>2];z[j>>2]=C(g*l)-C(m*n);j=a+f|0;f=c+f|0;g=C(C(g*m)+C(n*l));z[j>>2]=C(i*z[f>>2])-C(z[f+36>>2]*g);z[(17-h<<2)+a>>2]=C(z[f>>2]*g)+C(i*z[f+36>>2]);h=h+1|0;if((h|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}gb=e+96|0}function yp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{if(!b){break a}if(c){c=pe(f+8|0,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Gb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Pb(e,255,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]|-1>>>32-b}gb=a+16|0;break a}c=pe(f,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Gb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Pb(e,0,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}gb=a+16|0}gb=f+16|0}function xfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+32;wb(a);lP(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;_b(c);gb=c+16|0;return}g=gb-32|0;gb=g;f=wb(a);d=fr(a,Ie(a)+1|0);i=Ie(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=g+8|0;vd(c+12|0,f);if(d){e=d;if(d>>>0>=134217728){xc(32256);L()}e=jc(e<<5,8)}v[c>>2]=e;f=(i<<5)+e|0;v[c+8>>2]=f;v[c+4>>2]=f;j=bc(c),k=(d<<5)+e|0,v[j>>2]=k;gb=h+16|0;lP(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;ev(a);wb(a);b=c+4|0;Tk(v[a>>2],v[a+4>>2],b);zc(a,b);zc(a+4|0,c+8|0);zc(wb(a),bc(c));v[c>>2]=v[c+4>>2];SA(a,Ie(a));a=c;b=c;c=v[c+4>>2];a:{while(1){d=v[b+8>>2];if((d|0)==(c|0)){break a}v[b+8>>2]=d-32;v[23048]=0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}b=v[a>>2];if(b){jV(v[a+16>>2],b,oB(a))}gb=g+32|0}function Qw(a){var b=0,c=0,d=0,e=0,f=0,g=0;o(+a);e=j(1)|0;j(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){o(+a);b=j(1)|0;b=b&2147483647;if((b|0)==2146435072&(j(0)|0)!=0|b>>>0>2146435072){return a}if(a>709.782712893384){return a*8.98846567431158e307}if(!(a<-708.3964185322641)|!(a<-745.1332191019411)){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+A[(e<<3)+91440>>3];if(D(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=!e-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=Qi(c,b)}return c}return a+1}function Nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-32|0;gb=g;j=g,k=qk(b),v[j+16>>2]=k;c=gb-32|0;gb=c;e=b;d=a;b=$d(d);f=dc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+13|0;e:{if(Lu(e,d)){if(!v[b>>2]){break b}f=b;break e}if(!Lu(d,e)){break c}f=b+4|0;if(!v[b+4>>2]){break d}b=f;f=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=f;break a}v[c+28>>2]=b;b=f;break a}b=dc(d)}v[c+28>>2]=b}f=b;b=v[b>>2];t[c+27|0]=0;if(!b){h=gb-16|0;gb=h;b=dc(a);i=Wh(c+8|0,bC(),Ij(h+8|0,b));e=v[i>>2];d=gb-16|0;gb=d;v[d+8>>2]=v[g+16>>2];b=v[d+8>>2];b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[e+17|0]=0;t[e+13|0]=b;t[e+14|0]=b>>>8;t[e+15|0]=b>>>16;t[e+16|0]=b>>>24;gb=d+16|0;j=dc(i),k=1,t[j+4|0]=k;gb=h+16|0;tk(a,v[c+28>>2],f,v[c+8>>2]);b=Bd(c+8|0);t[c+27|0]=1;cC(c+8|0)}Xh(g+24|0,Cc(c+8|0,b),c+27|0);gb=c+32|0;gb=g+32|0;return v[g+24>>2]+17|0}function UF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[23048]=0;g=Q(15,d+24|0,a|0)|0;e=v[23048];v[23048]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=Nj(d+8|0,a);h=v[(v[v[a>>2]-12>>2]+a|0)+4>>2];f=v[v[a>>2]-12>>2];v[23048]=0;f=a+f|0;i=U(16,f|0)|0;j=v[23048];v[23048]=0;if((j|0)==1){break d}e=v[e>>2];v[23048]=0;c=b+c|0;b=la(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!Yv(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[23048]=0;S(18,a+b|0,5);b=v[23048];v[23048]=0;if((b|0)!=1){break e}break d}dl(g);break b}b=V(0)|0;O()|0;dl(g);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=v[v[a>>2]-12>>2];v[23048]=0;_(19,a+b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}$()}gb=d+32|0;return a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){V(0)|0;O()|0;Ab();L()}R(a|0);L()}function uN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;i=f,j=qk(b),v[i+16>>2]=j;c=gb-32|0;gb=c;g=b;d=a;b=$d(d);e=dc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{h=b+16|0;e:{if(lN(d,g,h)){if(!v[b>>2]){break b}e=b;break e}if(!kN(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=dc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){g=gb-16|0;gb=g;b=dc(a);d=Wh(c+8|0,PW(),Ij(g+8|0,b));b=v[d>>2];v[23048]=0;h=b+16|0;b=v[23048];v[23048]=0;f:{if((b|0)!=1){b=gb-16|0;gb=b;v[b+8>>2]=v[f+16>>2];u[h>>1]=x[v[b+8>>2]>>1];Jb(h+4|0);gb=b+16|0;i=dc(d),j=1,t[i+4|0]=j;gb=g+16|0;break f}a=P()|0;O()|0;jN(d);R(a|0);L()}tk(a,v[c+28>>2],e,v[c+8>>2]);b=Bd(c+8|0);t[c+27|0]=1;jN(c+8|0)}Xh(f+24|0,Cc(c+8|0,b),c+27|0);gb=c+32|0;a=se(f+24|0);gb=f+32|0;return a+4|0}function Vs(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;c=v[v[a>>2]-12>>2];v[23048]=0;c=v[(a+c|0)+24>>2];b=v[23048];v[23048]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}v[23048]=0;c=Q(15,d+8|0,a|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break d}if(!w[c|0]){break e}b=v[v[a>>2]-12>>2];v[23048]=0;b=v[(a+b|0)+24>>2];e=v[23048];v[23048]=0;f:{if((e|0)==1){break f}v[23048]=0;b=U(2230,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[23048]=0;S(18,a+b|0,1);b=v[23048];v[23048]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;dl(c);break c}b=V(0)|0;O()|0;break c}dl(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[23048]=0;_(19,a+c|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function B6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;i=a;a:{b:{if(!((b|0)==(c|0)|(e|0)>-1)){t[b|0]=45;f=d;d=0-d|0;e=0-(((f|0)!=0)+e|0)|0;b=b+1|0}f=c-b|0;if((f|0)<=19){g=E(e);g=B(64-((g|0)==32?E(d|1)+32|0:g)|0,1233)>>>12|0;h=(g<<3)+10368|0;j=f;f=v[h+4>>2];if((j|0)<((g-((e|0)==(f|0)&d>>>0<y[h>>2]|e>>>0<f>>>0)|0)+1|0)){break b}}c=a;c:{if(!e&d>>>0<=99999999){a=Nx(b,d);break c}if((e|0)==2328306&d>>>0<=1874919423|e>>>0<2328306){a=Ipa(d,e,1e8,0);e=jb;f=Nx(b,a);a=d-Fpa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=gj(gj(f,b),a-B(b,1e4)|0);break c}a=Ipa(d,e,1874919424,2328306);f=jb;g=Mx(b,a);a=Fpa(a,f,1874919424,2328306);b=d-a|0;a=Ipa(b,e-(jb+(a>>>0>d>>>0)|0)|0,1e8,0);e=jb;f=(a>>>0)/1e4|0;d=gj(gj(g,f),a-B(f,1e4)|0);a=b-Fpa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=gj(gj(d,b),a-B(b,1e4)|0)}v[c>>2]=a;a=0;break a}v[a>>2]=c;a=61}v[i+4>>2]=a}function uU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-48|0;gb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;wb(b);gf(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){Vr(a,v[b+4>>2]);rk(c+32|0,b);Dl(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=gb-80|0;gb=b;i=a;f=v[a+4>>2];d=v[c+20>>2];j=d;g=v[c+16>>2];v[b+72>>2]=g;v[b+76>>2]=d;e=v[c+12>>2];k=e;h=v[c+8>>2];v[b+64>>2]=h;v[b+68>>2]=e;v[b+24>>2]=g;v[b+28>>2]=d;v[b+16>>2]=h;v[b+20>>2]=e;d=tU(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^f-1)>>>0<32?f:0)){e=v[i>>2];v[(d>>>0<33?e:(d-1>>>3&536870908)+e|0)>>2]=0}v[b+48>>2]=h;v[b+52>>2]=k;v[b+56>>2]=g;v[b+60>>2]=j;zp(b+40|0,i,f);d=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=d;d=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=d;QU(b+32|0,b+8|0,b,b+40|0);gb=b+80|0}gb=c+48|0;return a|0}function zca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=gb-4112|0;gb=c;i=kb[v[v[a>>2]+116>>2]](a)|0;if(!i){kb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;d=gb-16|0;gb=d;h=a+44|0;if(Pf(h)){while(1){f=vn(h,e);g=vn(h,e);v[d+12>>2]=0;g=(g+2048|0)-f>>2;if((g|0)>=1){while(1){z[f>>2]=z[d+12>>2];f=f+4|0;j=(g|0)>1;g=g-1|0;if(j){continue}break}}e=e+1|0;if(Pf(h)>>>0>e>>>0){continue}break}}gb=d+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;tc(c+8|0,512);er(c+16|0);kb[v[v[a>>2]+60>>2]](a,c+16|0,f,v[c+8>>2]);e=0;if(v[c+8>>2]){while(1){d=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[d>>2]);k=c,l=z[Ny(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[d+2048>>2]);k=c,l=z[Ny(c+12|0,c+4|0)>>2],z[k+12>>2]=l;e=e+1|0;d=v[c+8>>2];if(e>>>0<d>>>0){continue}break}b=b-d|0}if(b){continue}break}}if(!i){kb[v[v[a>>2]+124>>2]](a)}gb=c+4112|0;return C(z[c+12>>2])}function fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;h=8;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);while(1){if((m|0)>=1){j=(l<<1)+b|0;p=j+(m<<1)|0;while(1){u[e+10>>1]=0;FV(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{if(!h){g=x[e+10>>1];break a}g=x[e+10>>1];c=x[e+12>>1];i=h;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){k=(f&65534)>>>0>255}else{if(!pf(a,e+9|0)){break a}f=w[e+9|0];c=f<<1&254|1;u[e+12>>1]=c;k=f>>>7|0}g=k|g<<1;i=i-1|0;if(i&255){continue}break}u[e+10>>1]=g}k=e;f=g&65535;c=h+1|0;b:{if(f>>>0<=3){break b}c=15;while(1){i=c;n=c&255;if(n>>>0>=2){c=i-1|0;if(!(f&1<<n)){continue}}break}c=h+i|0}h=c>>>1&127;t[k+15|0]=h;c=g&1;t[e+14|0]=c;o=(c-1^(g&65534)>>>1)+o|0;u[j>>1]=o;j=(d<<1)+j|0;if(p>>>0>j>>>0){continue}break}}l=l+1|0;if((l|0)!=(d|0)){continue}break}}gb=e+16|0}function Fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function h9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[23048]=0;_(1943,a|0);d=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[23048]=0;_(1969,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break g}v[23048]=0;_(1969,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break g}f=v[a+24>>2];v[23048]=0;d=Q(91,e+16|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;c=Q(91,e|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break f}v[23048]=0;Y(2009,f|0,d|0,c|0,1);b=v[23048];v[23048]=0;if((b|0)==1){break e}vb(c);vb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;vb(c)}vb(d)}Z(b|0)|0;b=0;v[23048]=0;Y(1920,55079,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}gb=e+32|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=gb-16|0;gb=i;j=a+44|0;if(ei(j)){h=Pd(j,0);v[i+8>>2]=h;k=Pd(j,1);v[i+12>>2]=k;e=qd(j,0);v[i>>2]=e;f=qd(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4228>>2];r=z[a+4224>>2];s=z[a+4220>>2];t=z[a+4236>>2];u=z[a+4232>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(n*r)+C(s*l))+C(p*q))-C(C(w*t)+C(o*u)));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;hc(e,g,h);hc(f,k,h)}si(a,b,c,qd(j,0),qd(j,1),d)}gb=i+16|0}function FY(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+17104|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function z9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;S(1989,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}if(Gc(d)>>>0<2147483647){break h}c=aa(8)|0;v[23048]=0;Q(1990,c|0,54392)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;T(84,c|0,90844,259);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=52181;j:{if((b|0)<0){break j}if((Gc(d)|0)<=(b|0)){break j}a=Ob(Id(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[23048]=0;Y(1920,54407,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}R(a|0);L()}function y9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;S(1991,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}if(Gc(d)>>>0<2147483647){break h}c=aa(8)|0;v[23048]=0;Q(1990,c|0,54392)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;T(84,c|0,90844,259);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=52181;j:{if((b|0)<0){break j}if((Gc(d)|0)<=(b|0)){break j}a=Ob(Id(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[23048]=0;Y(1920,54439,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}R(a|0);L()}function x9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;S(1992,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}if(Gc(d)>>>0<2147483647){break h}c=aa(8)|0;v[23048]=0;Q(1990,c|0,54392)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;T(84,c|0,90844,259);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=52181;j:{if((b|0)<0){break j}if((Gc(d)|0)<=(b|0)){break j}a=Ob(Id(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[23048]=0;Y(1920,54471,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}R(a|0);L()}function w9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;S(1993,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}if(Gc(d)>>>0<2147483647){break h}c=aa(8)|0;v[23048]=0;Q(1990,c|0,54392)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;T(84,c|0,90844,259);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=52181;j:{if((b|0)<0){break j}if((Gc(d)|0)<=(b|0)){break j}a=Ob(Id(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[23048]=0;Y(1920,54501,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}R(a|0);L()}function v9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;S(1994,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}if(Gc(d)>>>0<2147483647){break h}c=aa(8)|0;v[23048]=0;Q(1990,c|0,54392)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;T(84,c|0,90844,259);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=52181;j:{if((b|0)<0){break j}if((Gc(d)|0)<=(b|0)){break j}a=Ob(Id(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[23048]=0;Y(1920,54533,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}R(a|0);L()}function u9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;S(1995,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break i}if(Gc(d)>>>0<2147483647){break h}c=aa(8)|0;v[23048]=0;Q(1990,c|0,54392)|0;b=v[23048];v[23048]=0;if((b|0)==1){break g}v[23048]=0;T(84,c|0,90844,259);b=v[23048];v[23048]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=52181;j:{if((b|0)<0){break j}if((Gc(d)|0)<=(b|0)){break j}a=Ob(Id(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[23048]=0;Y(1920,54568,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}R(a|0);L()}function RU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-80|0;gb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){g=Xd(d+72|0);f=b-e|0;b=$u(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){Dl(d+56|0,a);b=v[d+60>>2];v[d+72>>2]=v[d+56>>2];v[d+76>>2]=b;v[a+4>>2]=v[a+4>>2]+f;break b}wb(a);b=av(d+56|0);e=v[a+4>>2];v[23048]=0;e=Q(867,a|0,e+f|0)|0;h=v[23048];v[23048]=0;c:{if((h|0)==1){break c}v[23048]=0;S(868,b|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;rk(d+40|0,a);Dl(d+32|0,a);rk(d+24|0,b);v[23048]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;Y(869,d+48|0,d+8|0,d|0,d+24|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}e=v[d+52>>2];v[d+72>>2]=v[d+48>>2];v[d+76>>2]=e;KB(a,b);Ee(b);break b}a=P()|0;O()|0;Ee(b);R(a|0);L()}v[a+4>>2]=b;break a}yp(pe(d+16|0,g),f,c)}gb=d+80|0}function vP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+815|0];if(c){t[b+815|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}b:{c:{if(!v[b+700>>2]|(!(t[b+853|0]&1)|!(c&255))){break c}if(v[a+480180>>2]==512){v[b+700>>2]=v[b+700>>2]-(B(c&255,145272)>>>10|0);break c}if(!(w[a+480208|0]&16)|v[a+480180>>2]==4){break b}e=v[b+700>>2];c=bA(a,c&15);f=Fpa(c,c>>31,e,e>>31)+32768|0;c=jb;c=vc(Gpa(f,f>>>0<32768?c+1|0:c,65536,0),jb);v[b+700>>2]=c;if((c|0)!=(e|0)){break c}a=a+1074308|0;Db(d+8|0,a,7);if(!(Cb(d+8|0)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break c}Db(d+8|0,a,7);if(!Cb(d+8|0)){break c}a=v[b+700>>2];if((a|0)<2){break c}v[b+700>>2]=a-1}gb=d+16|0;return}a=v[b+700>>2]+((c&255)<<2)|0;v[b+700>>2]=(a|0)<65535?a:65535;gb=d+16|0}function Ofa(){var a=0,b=0,c=0;b=gb-16|0;gb=b;Jb(92204);a=gb-16|0;gb=a;v[a+12>>2]=0;v[23054]=v[a+12>>2];gb=a+16|0;t[92220]=0;a=gb-16|0;gb=a;v[a+12>>2]=0;v[23056]=v[a+12>>2];gb=a+16|0;v[23048]=0;_(88,b+8|0);a=v[23048];v[23048]=0;a:{b:{c:{d:{e:{if((a|0)!=1){RP(92216,Bd(b+8|0));qA(b+8|0);t[92220]=0;a=0;break e}a=Ba(90496,90472)|0;c=O()|0;if((c|0)==(da(90496)|0)){Z(a|0)|0;v[23048]=0;X(89);a=v[23048];v[23048]=0;if((a|0)==1){break c}L()}if((da(90472)|0)!=(c|0)){break b}Z(a|0)|0;v[23048]=0;t[92220]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){a=P()|0;O()|0;break b}a=w[92220]}if(a&255){break d}v[23048]=0;X(90);a=v[23048];v[23048]=0;if((a|0)!=1){break d}a=P()|0;O()|0;break b}gb=b+16|0;return}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break a}}Dm(92224);qA(92216);vb(92204);R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Cm(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-16|0;gb=f;if(e){v[e>>2]=0}i=a+484344|0;a:{if(!oe(i,b)){break a}d=Wc(Yb(i,b),c,d);g=w[d+5|0];b:{c:{d:{e:{h=w[d+3|0];switch(h-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(h-35>>>0>=2){break a}}v[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=v[a+480180>>2]==4;break b}v[f+12>>2]=2;j=0}m=f,n=v[Yb(i,b)+12>>2]+(c^-1)|0,v[m+8>>2]=n;a=v[Gb(f+8|0,f+12|0)>>2];f:{g:{h:{i:{if(a){c=0;k=a;j:{while(1){d=B(wi(Yb(i,b)),6)+d|0;if(w[d+3|0]!=34){break j}l=g<<8;g=w[d+5|0]|(j?g>>>0<256?l+-8192|0:l:l);c=c+1|0;k=k-1|0;if(k){continue}break}c=a}if((h|0)!=35){break i}break h}c=0;if((h|0)==35){break g}}if((h|0)!=36){break f}}if(c){break f}}g=g<<8;c=0}if(!e){break a}v[e>>2]=c}gb=f+16|0;return g|0}function bea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=a+1300264|0;g=a+1074984|0;m=so(a);n=b+4|0;o=b+12|0;p=b+8|0;q=b+16|0;while(1){if(v[g+104>>2]==(b|0)){if(v[g+16>>2]){v[g+16>>2]=c}if(y[g+4>>2]>d>>>0){v[g>>2]=0;v[g+4>>2]=0}if(v[g+76>>2]){tc(g+76|0,d)}h=aF(g);i=v[(h?o:n)>>2];v[g+84>>2]=v[(h?q:p)>>2];v[g+80>>2]=i;h=v[g+88>>2]|v[e>>2];v[g+88>>2]=h;v[g+88>>2]=h&(v[f>>2]^-1);a:{if(!v[g+704>>2]|!v[b+24>>2]){break a}if(ep(a)){break a}h=v[g+700>>2];if(m){j=v[g+704>>2];k=Fpa(v[b+24>>2],0,h,0);i=(j>>>1|0)+k|0;h=jb;r=g,s=Xc(Ipa(i,i>>>0<k>>>0?h+1|0:h,j,0),jb),v[r+700>>2]=s;break a}j=v[b+24>>2];k=Fpa(v[g+704>>2],0,h,0);i=(j>>>1|0)+k|0;h=jb;r=g,s=Xc(Ipa(i,i>>>0<k>>>0?h+1|0:h,j,0),jb),v[r+700>>2]=s}v[g+704>>2]=v[b+24>>2]}g=g+880|0;if((l|0)!=(g|0)){continue}break}}function V6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;v[b+24>>2]=c;c=v[b+24>>2];d=v[c+12>>2];v[b+16>>2]=v[c+8>>2];v[b+20>>2]=d;d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;e=gb-16|0;gb=e;c=v[b+20>>2];v[e+8>>2]=v[b+16>>2];v[e+12>>2]=c;c=v[b+12>>2];v[e>>2]=v[b+8>>2];v[e+4>>2]=c;d=BT(e);c=a;qr(c);t[c+8|0]=0;v[c+4>>2]=d;v[c>>2]=1368;d=nc(c+12|0);t[c+24|0]=0;v[23048]=0;Q(41,c+28|0,0)|0;f=v[23048];v[23048]=0;a:{if((f|0)!=1){d=c+40|0;f=d+192|0;while(1){v[d>>2]=0;v[d+4>>2]=0;t[d+8|0]=0;d=d+12|0;if((f|0)!=(d|0)){continue}break}if(w[c+24|0]){c=c+232|0;d=0;while(1){g=Dj(c,d),h=d,v[g>>2]=h;d=d+1|0;if((d|0)!=16){continue}break}}break a}a=P()|0;O()|0;gc(d);R(a|0);L()}v[a>>2]=1476;c=v[b+12>>2];v[a+296>>2]=v[b+8>>2];v[a+300>>2]=c;c=v[b+20>>2];v[a+304>>2]=v[b+16>>2];v[a+308>>2]=c;gb=e+16|0;gb=b+32|0;return a|0}function Gq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074412>>2]<<1;d=Fpa(b,d,5e4,0);e=jb;b=v[Jc(c+8|0,c)>>2];b=vc(Gpa(d,e,b,b>>31),jb);v[a+1074396>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=Fpa(v[a+1074412>>2],0,Fpa(v[a+1074400>>2],0,v[a+1074408>>2],0),jb),v[g>>2]=h;v[c+4>>2]=jb;d=gb-16|0;gb=d;e=c+8|0;f=ew(e,c);gb=d+16|0;d=Fpa(b,0,6e5,0);b=f?c:e;b=Ipa(d,jb,v[b>>2],v[b+4>>2]);v[a+1074396>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074412>>2];d=Fpa(b,d,1e4,0);e=jb;b=v[Jc(c+8|0,c)>>2];b=vc(Gpa(d,e,b,b>>31),jb);v[a+1074396>>2]=b}d=a+1074396|0;a=v[a+480244>>2];b=Fpa(a,a>>31,b,b>>31)+32768|0;a=jb;a=vc(Gpa(b,b>>>0<32768?a+1|0:a,65536,0),jb);v[d>>2]=a?a:1;gb=c+16|0}function EH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;g=gb-1040|0;gb=g;h=v[b>>2];v[g+12>>2]=h;j=a?a:g+16|0;a:{b:{c:{d=a?d:256;if(!d|!h){break c}f=c>>>2|0;k=f>>>0>=d>>>0;if(d>>>0>f>>>0?c>>>0<=131:0){break b}while(1){f=k?d:f;c=c-f|0;f=rx(j,g+12|0,f,e);if((f|0)==-1){d=0;h=v[g+12>>2];i=-1;break c}h=(g+16|0)==(j|0);j=h?j:(f<<2)+j|0;i=f+i|0;d=d-(h?0:f)|0;h=v[g+12>>2];if(!d|!h){break c}f=c>>>2|0;k=f>>>0>=d>>>0;if(d>>>0<=f>>>0|c>>>0>131){continue}break}break b}if(!h){break a}}if(!c|!d){break a}f=i;while(1){d:{i=dq(j,h,c,e);e:{if(i+2>>>0<=2){f:{switch(i+1|0){case 1:v[g+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}h=v[g+12>>2]+i|0;v[g+12>>2]=h;f=f+1|0;d=d-1|0;if(d){break d}}i=f;break a}j=j+4|0;c=c-i|0;i=f;if(c){continue}break}}if(a){v[b>>2]=v[g+12>>2]}gb=g+1040|0;return i|0}function c7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;c=e+24|0;d=rt(c+56|0);v[c>>2]=10540;v[d>>2]=10560;v[23048]=0;f=c+4|0;W(135,c|0,10572,f|0)|0;g=v[23048];v[23048]=0;a:{if((g|0)!=1){b:{v[c>>2]=10540;v[d>>2]=10560;v[23048]=0;Q(136,f|0,16)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}break a}}a=P()|0;O()|0;gh(d);R(a|0);L()}d=v[v[c>>2]-12>>2];v[23048]=0;f=fa(131)|0;g=v[23048];v[23048]=0;c:{d:{if((g|0)==1){break d}v[23048]=0;T(132,e+16|0,d+(e+24|0)|0,f|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}Xb(e+16|0);d=gb-16|0;gb=d;v[d+8>>2]=17;gb=d+16|0;v[e+8>>2]=v[d+8>>2];tm(c+v[v[c>>2]-12>>2]|0,v[e+8>>2]);h=A[b>>3];v[23048]=0;Za(133,c|0,+h)|0;b=v[23048];v[23048]=0;if((b|0)==1){break d}v[23048]=0;S(134,a|0,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;nq(c);R(a|0);L()}nq(c);gb=e+160|0}function IL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=gb+-64|0;gb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[23048]=0;v[j+20>>2]=d?d:1928;T(1929,j+24|0,j+20|0,j+60|0);a=v[23048];v[23048]=0;a:{b:{c:{d:{if((a|0)!=1){a=oq(j+32|0,j+24|0);b=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=b;v[23048]=0;b=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=b;c=+ya(1930,j|0,+c,a|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}mf(a);oj(j+24|0);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;mf(a);oj(j+24|0)}Z(b|0)|0;v[23048]=0;ia(1931,52536,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();c=0}gb=j- -64|0;return+c}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function dW(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-48|0;gb=b;f=b,g=Wb(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[f+8>>2]=g;v[b+12>>2]=0;f=b,g=Wb(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[f+16>>2]=g;v[b+20>>2]=0;e=b;c=b;d=52;a:{if(!Wb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))){break a}d=Wb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))}v[c+24>>2]=d;v[e+28>>2]=0;a=Wb(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24));v[b+44>>2]=4;v[b+32>>2]=a+80;v[b+36>>2]=0;v[b+40>>2]=b+8;a=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=a;e=gb-16|0;gb=e;a=v[b>>2];d=v[b>>2]+(v[b+4>>2]<<3)|0;b:{if((a|0)==(d|0)){break b}c=a+8|0;if((d|0)==(c|0)){break b}while(1){a=ew(a,c)?c:a;c=c+8|0;if((d|0)!=(c|0)){continue}break}}gb=e+16|0;gb=b+48|0;b=v[a>>2];e=b-52|0;jb=v[a+4>>2]-(b>>>0<52)|0;return e}function Xj(a,b){var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;d=v[v[a>>2]-12>>2]+a|0;f=v[d+16>>2]&-3;bp(d,f);a:{b:{if(w[$j(c+56|0,a,1)|0]){d=v[v[a>>2]-12>>2];v[23048]=0;d=v[(a+d|0)+24>>2];e=v[23048];v[23048]=0;c:{d:{if((e|0)==1){break d}v[23048]=0;e=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=e;e=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=e;Y(2240,c+40|0,d|0,c+8|0,8);b=v[23048];v[23048]=0;if((b|0)==1){break d}b=ph(c+24|0,-1,-1);v[23048]=0;b=tW(c+40|0,b);d=v[23048];v[23048]=0;if((d|0)==1){break d}b=b?f|4:f;break c}b=V(0)|0;O()|0;Z(b|0)|0;b=f|1;Yj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break b}R(a|0);L()}$()}uh(v[v[a>>2]-12>>2]+a|0,b)}gb=c- -64|0;return}V(0)|0;O()|0;Ab()}L()}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;wd(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;f=c,g=w[$b(d+16|0,d)|0]<<2,u[f+30>>1]=g;e=b+14|0;v[c+24>>2]=(w[e|0]|w[e+1|0]<<8)<<1;zk(d,2,b+1|0);Fc(d+16|0,d);v[23048]=0;Q(355,c+43|0,d+16|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){vb(d+16|0);e=Sc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}Li(e,16);tf(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}function jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;i=g,j=Jp(b),v[i+16>>2]=j;c=gb-32|0;gb=c;e=b;f=a;b=$d(a);d=dc(a);a:{b:{if(b){f=wb(f);c:{while(1){d:{h=b+16|0;e:{if(AC(f,e,h)){if(!v[b>>2]){break b}d=b;break e}if(!zC(h,e)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=d;break a}v[c+28>>2]=b;b=d;break a}b=dc(f)}v[c+28>>2]=b}d=b;b=v[b>>2];t[c+27|0]=0;if(!b){e=gb-16|0;gb=e;b=dc(a);h=Wh(c+8|0,PW(),Ij(e+8|0,b));f=v[h>>2]+16|0;b=gb-16|0;gb=b;v[b+8>>2]=v[g+16>>2];u[f>>1]=x[v[b+8>>2]>>1];Jb(f+4|0);gb=b+16|0;i=dc(h),j=1,t[i+4|0]=j;gb=e+16|0;tk(a,v[c+28>>2],d,v[c+8>>2]);b=Bd(c+8|0);t[c+27|0]=1;d=c+8|0;e=d;a=v[e>>2];v[e>>2]=0;if(a){if(w[dc(d)+4|0]){Ll(a+16|0)}if(a){OW(a)}}}Xh(g+24|0,Cc(c+8|0,b),c+27|0);gb=c+32|0;a=se(g+24|0);gb=g+32|0;return a+4|0}function TY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;wd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Or(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Or(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(Fu(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[$b(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}gb=d+16|0}function hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((Pf(a)|0)==(b|0)){if((Pf(a+12|0)|0)==(c|0)){break b}}v[23048]=0;S(1547,a|0,b|0);d=v[23048];v[23048]=0;c:{d:{if((d|0)==1){break d}v[23048]=0;e=a+12|0;S(1547,e|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;f=a+24|0;S(1548,f|0,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;g=a+36|0;S(1548,g|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=vn(a,d);i=Mb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(90496)|0;if((O()|0)!=(da(90496)|0)){break a}Z(b|0)|0;fN(a);eN(a);b=a+12|0;fN(b);eN(b);b=a+24|0;xg(b);cN(b);a=a+36|0;xg(a);cN(a);$();return 0}a=0;while(1){b=vn(e,a);i=Mb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}R(b|0);L()}function H7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb+-64|0;gb=d;a:{b:{if((b|0)>=0){e=a+24|0;if((Gi(Qb(v[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}f=x[sc(Qb(v[e>>2]+484360|0),b)>>1];c:{if(!Ul(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[Yb(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074440>>1]=b;c=b&65535;VO(v[e>>2],c);v[v[e>>2]+1074420>>2]=g;v[v[e>>2]+1074384>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;qu(d+48|0,e,f?7:1,d);h=a,i=A[PO(d+48|0)>>3],A[h+16>>3]=i;Rm(d+48|0);a=a+16|0}gb=d- -64|0;return+A[a>>3]}function c5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[$j(c+24|0,a,0)|0]){Ic(c+16|0,v[v[a>>2]-12>>2]+a|0);v[23048]=0;d=U(2231,c+16|0)|0;e=v[23048];v[23048]=0;d:{e:{f:{g:{if((e|0)==1){break g}e=Nj(c+8|0,a);f=yk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[23048]=0;ka(2233,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[23048];v[23048]=0;if((d|0)==1){break g}Xb(c+16|0);break f}b=V(0)|0;O()|0;Xb(c+16|0);Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Yj(v[v[a>>2]-12>>2]+a|0,b);if(!(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1)){break e}v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break c}R(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}$()}uh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function Hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;f=c+32|0;Rc(b,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));h=dd(a);f=c+28|0;a=f;e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=0;v[23048]=0;S(1439,h|0,e|0);e=v[23048];v[23048]=0;if((e|0)!=1){a:{e=f;b:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break b}e=c+4|0;while(1){v[23048]=0;c=Q(250,b|0,4)|0;i=v[23048];v[23048]=0;if((i|0)==1){break a}if(!c){break b}c=w[e|0]|w[e+1|0]<<8;v[23048]=0;c=Q(1440,b|0,c|0)|0;i=v[23048];v[23048]=0;c:{if((i|0)!=1){v[g+12>>2]=c;if(Gc(d)>>>0<=c>>>0){break c}v[23048]=0;S(1441,h|0,g+12|0);c=v[23048];v[23048]=0;if((c|0)!=1){break c}}break a}a=a+1|0;c=f;if(a>>>0<(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){continue}break}}gb=g+16|0;return}}a=P()|0;O()|0;Qc(h);R(a|0);L()}function p1(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=Lb(467232);if(b>>>0<a>>>0){g=gb-32|0;gb=g;a:{b:{e=a-b|0;c:{if(e>>>0<=v[116812]-v[116809]>>2>>>0){gx(e);break c}f=Zw(467232);b=g+8|0;d=Lb(467232)+e|0;c=gb-16|0;gb=c;v[c+12>>2]=d;d:{a=an();if(d>>>0<=a>>>0){d=LG(467232);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;break d}Mc();L()}h=Lb(467232);c=0;d=gb-16|0;gb=d;v[d+12>>2]=0;vd(b+12|0,f);if(a){c=MG(v[b+16>>2],a)}v[b>>2]=c;f=(h<<2)+c|0;v[b+8>>2]=f;v[b+4>>2]=f;i=bc(b),j=(a<<2)+c|0,v[i>>2]=j;gb=d+16|0;v[23048]=0;IG(b,e);a=v[23048];v[23048]=0;if((a|0)==1){break b}a=b+4|0;Tk(v[116808],v[116809],a);zc(467232,a);zc(467236,b+8|0);zc(467248,bc(b));v[b>>2]=v[b+4>>2];HG(b)}gb=g+32|0;break a}a=P()|0;O()|0;HG(b);R(a|0);L()}return}if(a>>>0<b>>>0){Ae(467232,v[116808]+(a<<2)|0)}}function tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;wd(b,4);u[b+30>>1]=w[a+12|0]<<2;og(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Tb(d,44834);v[23048]=0;Q(355,b+43|0,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){vb(a);gb=d+16|0;return}b=P()|0;O()|0;vb(a);R(b|0);L()}function s8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=Pp(c,a,1);ty(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;_b(a);gb=c+16|0;return}i=gb-32|0;gb=i;e=wb(a);d=Mw(a,vf(a)+1|0);h=vf(a);f=gb-16|0;gb=f;v[f+12>>2]=0;c=i+8|0;vd(c+12|0,e);if(d){g=nK(d)}v[c>>2]=g;e=(h<<4)+g|0;v[c+8>>2]=e;v[c+4>>2]=e;j=bc(c),k=(d<<4)+g|0,v[j>>2]=k;gb=f+16|0;ty(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;b=c;h=c+4|0;f=h;d=a;e=v[a>>2];a=v[a+4>>2];if((e|0)!=(a|0)){g=v[f>>2];while(1){a=a-16|0;ty(g-16|0,a);g=v[f>>2]-16|0;v[f>>2]=g;if((a|0)!=(e|0)){continue}break}}zc(d,h);zc(d+4|0,b+8|0);zc(wb(d),bc(b));v[b>>2]=v[b+4>>2];a=c;b=a;d=v[a+8>>2];c=v[a+4>>2];if((d|0)!=(c|0)){while(1){d=d-16|0;v[b+8>>2]=d;Ll(d);d=v[b+8>>2];if((c|0)!=(d|0)){continue}break}}b=v[a>>2];if(b){oK(b,Kw(a))}gb=i+32|0}function r7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=nc(a);f=b+24|0;a=v[f>>2];v[23048]=0;a=uq(a+484344|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)==1){break c}v[23048]=0;S(1436,e|0,a|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[23048]=0;c=uq(c+484344|0);g=v[23048];v[23048]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=Yb(v[f>>2]+484344|0,a);v[23048]=0;S(2101,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;T(2095,d+16|0,b|0,d|0);c=v[23048];v[23048]=0;if((c|0)==1){break g}v[23048]=0;S(1438,e|0,d+16|0);c=v[23048];v[23048]=0;if((c|0)==1){break f}a=a+1|0;vb(d+16|0);vb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+16|0)}vb(d);break a}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(e);R(a|0);L()}function Afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Gb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());le(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;d=a;f=Fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=d,k=Uc(g),u[j>>1]=k;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());le(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;d=a;f=Fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=d,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=c;e=gb-32|0;gb=e;h=b;f=b;b=$d(b);d=dc(f);a:{b:{if(b){wb(f);c:{while(1){d:{f=b+14|0;e:{if(un(c,f)){if(!v[b>>2]){break b}d=b;break e}if(!un(f,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=dc(f)}v[e+28>>2]=b}c=b;b=v[b>>2];t[e+27|0]=0;if(!b){b=gb-16|0;gb=b;d=dc(h);d=Wh(e+8|0,DS(),Ij(b+8|0,d));Gu(v[d>>2]+14|0,i);j=dc(d),k=1,t[j+4|0]=k;gb=b+16|0;ES(h,v[e+28>>2],c,v[e+8>>2]);b=Bd(e+8|0);t[e+27|0]=1;d=e+8|0;c=v[d>>2];v[d>>2]=0;if(c){f:{g:{d=dc(d);if(w[d+4|0]){v[23048]=0;f=v[23048];v[23048]=0;if((f|0)==1){break g}}if(c){Op(v[d>>2],c,1)}break f}V(0)|0;O()|0;Ab();L()}}}Xh(g+8|0,Cc(e+8|0,b),e+27|0);gb=e+32|0;GS(a,g+8|0);gb=g+16|0}function HM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-16|0;gb=g;ii(g+8|0,b);c=g;b=v[c+12>>2];f=v[c+8>>2];v[c>>2]=f;v[c+4>>2]=b;f=gb-32|0;gb=f;e=v[c+4>>2];b=f;c=v[c>>2];v[b+8>>2]=c;v[b+12>>2]=e;v[b+16>>2]=c;v[b+20>>2]=e;Ch(b+24|0,b+8|0);c=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=c;c=b;e=gb-16|0;gb=e;d=v[a+8>>2];b=v[a+12>>2];a:{if((b|0)<0){break a}if(j=1,k=(m=xb(a)>>>0<d>>>0,n=0,o=(b|0)>=0,o?m:n),l=(b|0)>0,l?j:k){break a}d=xb(a);h=v[a+8>>2];i=0-((d>>>0<h>>>0)+v[a+12>>2]|0)|0;b=e;v[b+8>>2]=d-h;v[b+12>>2]=i;j=b,k=xb(c),v[j>>2]=k;v[b+4>>2]=0;b=Zu(b+8|0,b);b=LU(v[b>>2],v[b+4>>2]);if((b|0)!=(xb(c)|0)){break a}vg(v[c>>2],v[c>>2]+b|0,zb(v[a>>2]+v[a+8>>2]|0));c=a;d=b+v[c+8>>2]|0;a=v[c+12>>2];v[c+8>>2]=d;v[c+12>>2]=b>>>0>d>>>0?a+1|0:a}gb=e+16|0;gb=f+32|0;gb=g+16|0}function HH(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=ux(80081);if(w[b|0]?b:0){break a}b=ux(B(a,12)+80096|0);if(w[b|0]?b:0){break a}b=ux(80168);if(w[b|0]?b:0){break a}b=80173}b:{while(1){e=w[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=80173;c:{d:{c=w[b|0];e:{f:{if(!(w[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!w[d+1|0]){break e}}if(!hj(d,80173)){break e}if(hj(d,80181)){break d}}if(!a){c=75716;if(w[d+1|0]==46){break c}}return 0}c=v[116335];if(c){while(1){if(!hj(d,c+8|0)){break c}c=v[c+24>>2];if(c){continue}break}}c=v[116335];if(c){while(1){if(!hj(d,c+8|0)){return c}c=v[c+24>>2];if(c){continue}break}}c=Ad(28);g:{if(!c){c=0;break g}v[c+4>>2]=20;v[c>>2]=75696;b=c+8|0;hc(b,d,e);t[b+e|0]=0;v[c+24>>2]=v[116335];v[116335]=c}c=a|c?c:75716}return c}function Qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-528|0;gb=d;c=-1;a:{if(!Qf(a,1468)){break a}Gl(a,1464);BV(a,d+524|0);if(!ke(d+524|0,24794)){c=0;if(!ke(d+524|0,24799)){break a}}Gl(a,20);b=1;while(1){c=-1;if(!yV(a,d)){break a}e=ZB(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}e=d+520|0;c=gb-32|0;gb=c;b=a;b:{if(Qf(a,2)){rn(c+24|0,e);e=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=e;RB(c+16|0,b,c+8|0);break b}t[c+16|0]=0;WD(e,c+16|0)}gb=c+32|0;e=rd(d+520|0);c=0;if(w[d+520|0]>128){break a}b=d;c=gb-32|0;gb=c;c:{if(Qf(a,512)){mD(c+24|0,b);f=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=f;RB(c+16|0,a,c+8|0);break c}gV(b)}gb=c+32|0;a=d+512|0;c=w[e|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}gb=d+528|0;return c|0}function V7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-48|0;gb=f;d=gi(a,d);g=lh(a+4|0);h=lh(a+24|0);i=lh(a+32|0);j=dd(a+36|0);v[a+56>>2]=3;k=nc(a+68|0);v[23048]=0;S(2082,a|0,e|0);l=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{if((l|0)!=1){v[23048]=0;cc(f+16|0,b,c);b=v[23048];v[23048]=0;if((b|0)==1){break f}b=Xd(f+8|0);v[23048]=0;c=v[f+20>>2];v[f>>2]=v[f+16>>2];v[f+4>>2]=c;T(2086,f+24|0,f|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break e}v[23048]=0;T(2083,a|0,f+24|0,e|0);c=v[23048];v[23048]=0;if((c|0)==1){break d}yb(f+24|0);Bc(b);v[23048]=0;_(2084,a|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(f+24|0)}Bc(b)}yd(k);Tf(j);mq(i);ri(h);qi(g);mf(d);R(a|0);L()}gb=f+48|0;return a|0}function rW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}pW(g+15|0,g+13|0);pW(g+14|0,g+12|0);a:{if(w[g+15|0]==10){t[g+13|0]=w[g+13|0]&15?-1:w[g+12|0];if(w[g+14|0]!=10){break a}t[g+14|0]=0;break a}if(w[g+14|0]!=10){break a}t[g+12|0]=w[g+12|0]&15?-1:0}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}cz(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];b:{if(!c){break b}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break b}if(!b){oo(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break b}if(po(c)>>>0<=po(w[g+14|0])>>>0){break b}th(g+15|0,g+14|0);th(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0];gb=g+16|0}function nj(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-48|0;gb=d;e=a+24|0;f=v[v[e>>2]+24620>>2];a:{if(!((f|0)!=(b|0)|v[v[e>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}DO(v[e>>2],1);break a}hc(d+8|0,v[e>>2]+24604|0,40);g=v[d+40>>2];h=v[d+44>>2];v[d+28>>2]=c;v[d+24>>2]=b;Gt(d+8|0,g);Go(d+8|0,h);Iz(v[e>>2],d+8|0);if((b|0)==(f|0)){break a}b=v[e>>2];f=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break b}kb[v[v[b>>2]+108>>2]](b,0);kb[v[v[b>>2]+96>>2]](b);kb[v[v[b>>2]+124>>2]](b)}c=c+160|0;if((f|0)!=(c|0)){continue}break}b=v[e>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(kb[v[v[b>>2]+116>>2]](b)|0){break c}kb[v[v[b>>2]+108>>2]](b,1);kb[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}}t[a+29|0]=1;gb=d+48|0}function ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;t[e+15|0]=0;u[e+12>>1]=0;if(d){f=4;l=B(c,d);o=(l|0)<1;while(1){if(!o){j=b+k|0;p=l+j|0;while(1){t[e+11|0]=0;EV(a,e+15|0,e+12|0,e+11|0);a:{if(!f){h=w[e+11|0];break a}h=w[e+11|0];c=x[e+12>>1];i=f;b:{while(1){g=c<<1;c=g&254;c:{if(c){g=(g&65534)>>>0>255;break c}if(!pf(a,e+10|0)){break b}c=w[e+10|0];g=c>>>7|0;c=c<<1&254|1}h=h<<1|g;i=i-1|0;if(i&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}g=h&255;c=f+1|0;d:{if(g>>>0<=3){break d}c=7;while(1){i=c;m=c&255;if(m>>>0>=2){c=i-1|0;if(!(g&1<<m)){continue}}break}c=f+i|0}f=h&1;t[e+15|0]=f;n=(f-1^(h&254)>>>1)+n|0;t[j|0]=n;f=(c&254)>>>1|0;j=d+j|0;if(p>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function $7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb+-64|0;gb=d;e=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=e;e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;i=GT(d+8|0);a:{if(i){g=d+40|0;e=gb-32|0;gb=e;f=Wh(e+8|0,jc(324,4),vK(e,e+24|0));h=v[f>>2];v[23048]=0;Q(2080,h|0,b|0)|0;b=v[23048];v[23048]=0;b:{if((b|0)!=1){uK(g,bc(v[f>>2]),Bd(f));tK(f);gb=e+32|0;break b}a=P()|0;O()|0;tK(f);R(a|0);L()}vw(d+48|0,d+40|0);break a}g=d+32|0;e=gb-32|0;gb=e;f=Wh(e+8|0,jc(56,4),vK(e,e+24|0));h=v[f>>2];v[23048]=0;Q(2081,h|0,b|0)|0;b=v[23048];v[23048]=0;c:{if((b|0)!=1){uK(g,bc(v[f>>2]),Bd(f));sK(f);gb=e+32|0;break c}a=P()|0;O()|0;sK(f);R(a|0);L()}vw(d+48|0,d+32|0)}e=a;a=Uj(d+56|0,d+48|0);b=Uj(d+24|0,c);pF(e,a,b);Bc(b);Bc(a);Bc(d+48|0);d:{if(!i){Bc(d+32|0);break d}Bc(d+40|0)}gb=d- -64|0}function vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-32|0;gb=g;j=g,k=qk(b),v[j+16>>2]=k;c=gb-32|0;gb=c;f=b;d=a;b=$d(d);e=dc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+14|0;e:{if(kP(f,d)){if(!v[b>>2]){break b}e=b;break e}if(!kP(d,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=dc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){d=gb-16|0;gb=d;b=dc(a);i=Wh(c+8|0,bC(),Ij(d+8|0,b));b=v[i>>2];f=gb-16|0;gb=f;v[f+8>>2]=v[g+16>>2];h=v[f+8>>2];h=x[h>>1]|x[h+2>>1]<<16;u[b+18>>1]=0;u[b+14>>1]=h;u[b+16>>1]=h>>>16;gb=f+16|0;j=dc(i),k=1,t[j+4|0]=k;gb=d+16|0;tk(a,v[c+28>>2],e,v[c+8>>2]);b=Bd(c+8|0);t[c+27|0]=1;cC(c+8|0)}Xh(g+24|0,Cc(c+8|0,b),c+27|0);gb=c+32|0;a=Kl(g+24|0);gb=g+32|0;return a+4|0}function wP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if(!v[b+700>>2]){break a}f=v[a+480180>>2]==64?B(c,-20):c;b:{if(!(!(w[a+480208|0]&16)|v[a+480180>>2]==4)){g=v[b+700>>2];c=f>>31;v[e+12>>2]=(c+f^c)>>>2;tc(e+12|0,255);d=v[e+12>>2];c:{if(!d){break c}h=b;c=v[b+700>>2];i=c;c=c>>31;d:{if((f|0)<=-1){d=cA(a,d);break d}d=bA(a,d)}d=Fpa(i,c,d,d>>31)+32768|0;c=jb;c=vc(Gpa(d,d>>>0<32768?c+1|0:c,65536,0),jb);v[h+700>>2]=c;if((c|0)!=(g|0)){break c}Db(e,a+1074308|0,7);d=Cb(e);c=v[b+700>>2];if((d|0)==(f>>>31|0)){if((c|0)==2147483647){break c}v[b+700>>2]=v[b+700>>2]+1;break c}if((c|0)<2){break c}v[b+700>>2]=c-1}c=v[b+700>>2];break b}c=f+v[b+700>>2]|0;v[b+700>>2]=c}if((c|0)>0){break a}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}gb=e+16|0}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2];break a}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=f;v[a+4>>2]=g;gb=e+32|0}function rV(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0>32768){break a}h=Ib(w[d+42|0]|w[d+43|0]<<8)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}b=w[b|0];if(b>>>0>63|(b|w[a+470|0]?0:!w[a+471|0])){break a}k=1}return k}function Zda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;c=wi(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((zg(a)|0)!=(c|0)){break b}b=gb-16|0;gb=b;c=Rb(a);d=Ub(a);$h(b+8|0);a=gb-16|0;gb=a;v[a>>2]=d;v[a+8>>2]=c;d=Wt(a,a+8|0);g=gb-16|0;gb=g;v[g+8>>2]=c;if((d|0)>=1){while(1){c=v[g+8>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=(d|0)>1;Oj(g+8|0);d=d-1|0;if(c){continue}break}}gb=g+16|0;gb=a+16|0;gb=b+16|0;break a}$h(f+8|0);c=ZW(f+16|0,c,f+8|0);JN(a);gp(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[wb(c)>>2];h=wb(a),i=d,v[h>>2]=i;h=wb(c),i=0,v[h>>2]=i;v[c>>2]=0;v[c+4>>2]=0;_m(c);v[a+12>>2]=b}a=1}else{a=0}gb=f+32|0;return a|0}function Tp(a){var b=C(0),c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=ki(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-ki(((e|0)>-1?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<=-1){b=li(f+1.5707963267948966);break a}b=li(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=ki(((e|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<=-1){b=li(-4.71238898038469-+a);break a}b=li(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(Ux(a,c+8|0)&3){case 0:b=ki(A[c+8>>3]);break a;case 1:b=li(-A[c+8>>3]);break a;case 2:b=C(-ki(A[c+8>>3]));break a;default:break b}}b=li(A[c+8>>3])}a=b;gb=c+16|0;return a}function zO(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=-1;a:{if(!Bz(a,b,2)){break a}h=v[b+656>>2];f=a+1074308|0;Db(e+8|0,f,31);b:{if(Cb(e+8|0)){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}Db(e+8|0,f,31);f=d-Cb(e+8|0)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=cr(h+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+746|0]&16){g=Rq(a,b,!(v[b+88>>2]&32768),d);break a}if(wj(b)){if((d|0)==u[b+774>>1]){break a}i=b,j=Uc(d),u[i+774>>1]=j;t[b+853|0]=w[b+853|0]|8;break a}b=so(a);v[e+8>>2]=d;f=c;c:{if((d|0)<=-1){v[e+8>>2]=0-d;Hl(e+8|0,255);a=(v[e+8>>2]<<2)+(b?39328:38304)|0;break c}Hl(e+8|0,255);a=(v[e+8>>2]<<2)+(b?38304:39328)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];i=f,j=vc(Gpa(Fpa(b,d,a,a>>31),jb,65536,0),jb),v[i>>2]=j}gb=e+16|0;return g}function vN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=C(0);f=gb-16|0;gb=f;g=u[d>>1];e=u[d+2>>1];if(!(!x[b>>1]|(g|0)>(e|0)|(!(z[c>>2]>C(0))|(e-g|0)>32766))){u[a>>1]=3;h=a+4|0;xg(h);u[a+28>>1]=65472;v[f+12>>2]=1065353216;xN(h,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;xg(a+16|0);u[a+28>>1]=x[d>>1];g=a;e=gb-16|0;gb=e;u[e+14>>1]=x[b>>1];v[23048]=0;u[e+12>>1]=32767;b=Vc(e+14|0,e+12|0);j=v[23048];v[23048]=0;a:{if((j|0)!=1){gb=e+16|0;b=u[b>>1];break a}V(0)|0;O()|0;Ab();L()}u[g+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=re(i,C(C(1)/C(u[a+30>>1])));j=1;pl(h,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){k=re(i,C(b|0));l=Mb(h,b-u[a+28>>1]|0),m=k,z[l>>2]=m;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}sq(a)}gb=f+16|0;return j|0}function l8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-32|0;gb=c;rL(c+24|0);oL(a+24|0,Bd(c+24|0));ri(c+24|0);u[a+28>>1]=0;f=c+24|0;e=kO();d=wf(56);v[23048]=0;e=Q(2055,d|0,e|0)|0;g=v[23048];v[23048]=0;a:{if((g|0)!=1){Ai(f,e);break a}a=P()|0;O()|0;Zb(d);R(a|0);L()}nL(a+32|0,Bd(c+24|0));mq(c+24|0);pL(c+24|0,v[a>>2]);mL(a+4|0,Bd(c+24|0));qi(c+24|0);eo(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;h=c,i=rr(b),v[h+24>>2]=i;h=c,i=Xg(b),v[h+16>>2]=i;b:{if(Xf(c+24|0,c+16|0)){while(1){d=se(c+24|0);b=cg(c,d);v[23048]=0;Y(2009,a|0,b|0,d+12|0,0);d=v[23048];v[23048]=0;if((d|0)==1){break b}vb(b);Fj(c+24|0);if(Xf(c+24|0,c+16|0)){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;vb(b);R(a|0);L()}function HL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Ob(b);d=Bb(b);h=Ob(c);i=Bb(c);g=d+f|0;d=-1;a:{while(1){if((f|0)==(g|0)){break a}g=g-1|0;if(vp(h,i,g)){continue}break}d=g-f|0}b:{c:{if((d|0)!=-1){k=e,l=Ld(b),v[k+16>>2]=l;k=e,l=Ne(e+16|0,d),v[k+24>>2]=l;k=e,l=Ne(e+24|0,1),v[k+32>>2]=l;c=Sd(e+40|0,e+32|0);k=e,l=hf(b),v[k>>2]=l;d=Sd(e+8|0,e);fG(b,v[c>>2],v[d>>2]);break c}if(!Bb(b)){break c}i=Ob(b);f=Bb(b);d=Ob(c);c=Bb(c);if(!c|!f){c=-1}else{g=d;j=c+d|0;d=i;f=f+d|0;d:{if((d|0)==(f|0)){break d}c=f;while(1){h=g;if((j|0)!=(g|0)){while(1){if(kb[26](t[d|0],t[h|0])|0){break d}h=h+1|0;if((j|0)!=(h|0)){continue}break}}d=d+1|0;if((c|0)!=(d|0)){continue}break}d=c}c=(d|0)==(f|0)?-1:d-i|0}if(c){break c}Jb(a);break b}Dc(a,b)}gb=e+48|0}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];break a}g=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=f;v[a+4>>2]=h;gb=e+32|0}function wo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;e=v[b+656>>2];if(!(!e|t[b+730|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}f=x[c+34>>1];if(f&2){v[b+88>>2]=(f&4?d|4:d&-135)|2;d=v[c>>2];v[b+76>>2]=d;f=v[c+4>>2];v[b+80>>2]=f;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<d>>>0){v[b+76>>2]=c;g=c}else{g=d}d=v[b+4>>2];if(g>>>0>=d>>>0){break b}v[b>>2]=0;v[b+4>>2]=((d-f>>>0)%(c-f>>>0)|0)+f;break b}v[b+88>>2]=d&-135;v[b+76>>2]=v[c>>2]}if(!e){break a}if(!(!v[e>>2]|(v[a+480180>>2]&1064964?0:!(w[e+60|0]&2)))){v[b+88>>2]=v[b+88>>2]|4096}if(w[e+65|0]==255|x[b+728>>1]!=65535){break a}a=e+48|0;h=b,i=Uc(cr(a,v[b+724>>2],256,64)),u[h+728>>1]=i;h=b,i=x[Mb(a,w[e+65|0])>>1],v[h+724>>2]=i}}function SN(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=gb-16|0;gb=h;t[h+15|0]=b;t[h+14|0]=10;Eg(g,w[$b(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Lb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Mb(g,c),j=d>>>4|0,u[i>>1]=j;a:{b:{if(!c){e=0;d=0;break b}d=c-1|0;if(x[Mb(g,c)>>1]>=x[Mb(g,d)>>1]){break a}e=c;d=x[Mb(g,d)>>1]+1|0}i=Mb(g,e),j=d,u[i>>1]=j}b=Gd(w[b+2|0],0,64);i=Mb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Lb(g)>>>0>c>>>0){continue}break}}c=w[g+12|0]&-2|a&1;t[g+12|0]=c;b=g;c:{d:{if(!(a&2)){break d}d=w[g+15|0];e=Lb(g);c=w[g+12|0];if(d>>>0>e>>>0){break d}c=c|4;break c}c=c&251}t[b+12|0]=c;b=g;e:{f:{if(!(a&4)){break f}a=w[g+13|0];if(a>>>0>w[g+14|0]){break f}d=Lb(g);c=w[g+12|0];if(a>>>0>d>>>0){break f}a=c|2;break e}a=c&253}t[b+12|0]=a;gb=h+16|0}function yG(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=li(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<=-1){a=C(-ki(d+1.5707963267948966));break a}a=ki(d+-1.5707963267948966);break a}a=li(-(((e|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<=-1){a=ki(d+4.71238898038469);break a}a=C(-ki(d+-4.71238898038469));break a}a=li(((e|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(Ux(a,b+8|0)&3){case 0:a=li(A[b+8>>3]);break a;case 1:a=ki(A[b+8>>3]);break a;case 2:a=li(-A[b+8>>3]);break a;default:break b}}a=C(-ki(A[b+8>>3]))}gb=b+16|0;return a}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=f>>>21&2040;l=u[b+40886>>1];m=u[b+40884>>1];n=u[b+40882>>1];o=u[b+40880>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function mw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;t[f+15|0]=d;t[b+12|0]=w[b+12|0]&240|w[a|0]&15;g=a+1|0;Eg(b,w[$b(g,f+15|0)|0]);d=w[$b(a+2|0,f+15|0)|0];t[b+13|0]=d;j=b,k=Gd(w[a+3|0],d,w[f+15|0]),t[j+14|0]=k;d=w[$b(a+4|0,f+15|0)|0];t[b+15|0]=d;j=b,k=Gd(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[$b(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=ac(w[e+6|0]+c<<24>>24,0,64);j=Mb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Mb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}if(x[Mb(b,d)>>1]>255){break a}h=w[Mb(b,e)+1|0];i=Mb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}e=Mb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[$b(f+14|0,g)|0]){continue}break}}gb=f+16|0}function hN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-16|0;gb=d;a:{if(Lb(a)>>>0>511){break a}if(!Sf(v[v[b>>2]-12>>2]+b|0)){break a}j=d+8|0;f=b;g=c;h=gb-16|0;gb=h;e=wf(64);v[23048]=0;i=U(1333,e|0)|0;k=v[23048];v[23048]=0;b:{c:{if((k|0)!=1){e=ns(h+8|0,i);i=v[e>>2];v[23048]=0;f=W(1542,i|0,f|0,g|0)|0;g=v[23048];v[23048]=0;d:{e:{if((g|0)!=1){if((f|0)==1){break e}Oz(j);break d}a=P()|0;O()|0;yg(e);break c}gi(j,e)}yg(e);gb=h+16|0;break b}a=P()|0;O()|0;Zb(e)}R(a|0);L()}f:{g:{if(!Fd(d+8|0)){v[23048]=0;T(1540,d|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break g}SW(d+8|0,Bd(d));yg(d)}if(!Fd(d+8|0)){break f}l=v[d+8>>2];v[23048]=0;S(1541,a|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;yg(d+8|0);R(a|0);L()}yg(d+8|0)}gb=d+16|0;return l}function Iaa(){var a=0,b=0,c=0,d=0,e=0;a=gb-48|0;gb=a;c=Jb(a+32|0);v[23048]=0;_(1925,a+16|0);b=v[23048];v[23048]=0;a:{b:{c:{d:{if((b|0)!=1){d=a,e=Rb(a+16|0),v[d+8>>2]=e;d=a,e=Ub(a+16|0),v[d>>2]=e;if(!Fb(a+8|0,a)){break c}while(1){e:{b=v[a+8>>2];v[23048]=0;Q(1201,c|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}wr(a+8|0);d=a,e=Ub(a+16|0),v[d>>2]=e;if(!Fb(a+8|0,a)){break c}v[23048]=0;Q(1926,c|0,52201)|0;b=v[23048];v[23048]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;yd(a+16|0);break d}b=V(0)|0;O()|0}vb(c);Z(b|0)|0;b=0;v[23048]=0;Y(1920,52203,0,0,0);c=v[23048];v[23048]=0;if((c|0)==1){break a}$();break b}b=ie(Ob(c));yd(a+16|0);vb(c)}gb=a+48|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+8>>2]=c>>>4;v[d+4>>2]=v[a>>2];h=v[Gb(d+8|0,d+4|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+8>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=f;hg(d+8|0,-1,1);e=A[d+8>>3]*32768;A[d+8>>3]=e;f=a;e=fe(e);a:{if(D(e)<2147483648){g=~~e;break a}g=-2147483648}i=f,j=Uc(g),u[i>>1]=j;f=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);v[d+8>>2]=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);v[d+12>>2]=f;hg(d+8|0,-1,1);e=A[d+8>>3]*32768;A[d+8>>3]=e;f=a;e=fe(e);b:{if(D(e)<2147483648){g=~~e;break b}g=-2147483648}i=f,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return h<<4}function xJ(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);b=z[a+32>>2];c=z[a+8>>2];e=z[a+16>>2];f=C(C(b-c)+e);i=z[a>>2];j=z[a+24>>2];k=C(i-j);z[a+16>>2]=f+k;d=z[a+4>>2];g=z[a+20>>2];h=z[a+28>>2];l=C(C(d-C(g+h))*C(.8660253882408142));k=C(k-C(f*C(.5)));z[a+4>>2]=l+k;m=C(C(g+d)*C(.9848077297210693));f=C(z[a+12>>2]*C(.8660253882408142));n=C(C(h+d)*C(-.6427876353263855));o=C(C(m-f)+n);d=C(i+C(j*C(.5)));i=C(C(b+c)*C(.7660444378852844));b=C(C(e-b)*C(.1736481785774231));j=C(C(d-i)+b);z[a+12>>2]=o+j;z[a+20>>2]=j-o;z[a+28>>2]=k-l;g=C(C(g-h)*C(.3420201539993286));h=C(g-C(f+m));c=C(C(e+c)*C(.9396926164627075));b=C(C(d+c)-b);z[a+32>>2]=h+b;e=C(C(g+f)+n);c=C(C(d-c)+i);z[a+24>>2]=e+c;z[a+8>>2]=c-e;z[a>>2]=b-h}function f5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[$j(c+24|0,a,0)|0]){Ic(c+16|0,v[v[a>>2]-12>>2]+a|0);v[23048]=0;f=U(2231,c+16|0)|0;d=v[23048];v[23048]=0;d:{e:{if((d|0)==1){break e}d=Nj(c+8|0,a);e=yk(c);g=v[v[a>>2]-12>>2];e=v[e>>2];d=v[d>>2];v[23048]=0;ka(2232,f|0,d|0,e|0,a+g|0,c+28|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}Xb(c+16|0);break d}b=V(0)|0;O()|0;Xb(c+16|0);Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Yj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break c}R(a|0);L()}$()}uh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function a5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[$j(c+24|0,a,0)|0]){Ic(c+16|0,v[v[a>>2]-12>>2]+a|0);v[23048]=0;f=U(2231,c+16|0)|0;d=v[23048];v[23048]=0;d:{e:{if((d|0)==1){break e}d=Nj(c+8|0,a);e=yk(c);g=v[v[a>>2]-12>>2];e=v[e>>2];d=v[d>>2];v[23048]=0;ka(2234,f|0,d|0,e|0,a+g|0,c+28|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}Xb(c+16|0);break d}b=V(0)|0;O()|0;Xb(c+16|0);Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Yj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break c}R(a|0);L()}$()}uh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function _4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[$j(c+24|0,a,0)|0]){Ic(c+16|0,v[v[a>>2]-12>>2]+a|0);v[23048]=0;f=U(2231,c+16|0)|0;d=v[23048];v[23048]=0;d:{e:{if((d|0)==1){break e}d=Nj(c+8|0,a);e=yk(c);g=v[v[a>>2]-12>>2];e=v[e>>2];d=v[d>>2];v[23048]=0;ka(2235,f|0,d|0,e|0,a+g|0,c+28|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}Xb(c+16|0);break d}b=V(0)|0;O()|0;Xb(c+16|0);Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Yj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break c}R(a|0);L()}$()}uh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function Y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[$j(c+24|0,a,0)|0]){Ic(c+16|0,v[v[a>>2]-12>>2]+a|0);v[23048]=0;f=U(2231,c+16|0)|0;d=v[23048];v[23048]=0;d:{e:{if((d|0)==1){break e}d=Nj(c+8|0,a);e=yk(c);g=v[v[a>>2]-12>>2];e=v[e>>2];d=v[d>>2];v[23048]=0;ka(2236,f|0,d|0,e|0,a+g|0,c+28|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break e}Xb(c+16|0);break d}b=V(0)|0;O()|0;Xb(c+16|0);Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Yj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break c}R(a|0);L()}$()}uh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function rs(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a=Jb(a);a:{b:{c:{switch(b|0){case 0:v[23048]=0;b=Q(2,d|0,11319)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}Eb(a,b);vb(b);break b;case 1:v[23048]=0;b=Q(2,d|0,11344)|0;c=v[23048];v[23048]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 2:v[23048]=0;b=Q(2,d|0,11389)|0;c=v[23048];v[23048]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 3:v[23048]=0;b=Q(2,d|0,11416)|0;c=v[23048];v[23048]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 4:v[23048]=0;b=Q(2,d|0,11442)|0;c=v[23048];v[23048]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 5:break c;default:break b}}v[23048]=0;b=Q(2,d|0,11471)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}Eb(a,b);vb(b)}gb=d+16|0;return}b=P()|0;O()|0;vb(a);R(b|0);L()}function b2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=fH(c);b:{if(b){Zk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Yk(k,a);break b}Cs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ih(k,a)}$i(i,k);Pc(k);l=e,m=dj(a),v[l>>2]=m;l=f,m=cj(a),v[l>>2]=m;Mg(k,a);Eb(g,k);vb(k);Jh(k,a);$i(h,k);Pc(k);a=Xk(a);break a}a=eH(c);c:{if(b){Zk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Yk(k,a);break c}Cs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ih(k,a)}$i(i,k);Pc(k);l=e,m=dj(a),v[l>>2]=m;l=f,m=cj(a),v[l>>2]=m;Mg(k,a);Eb(g,k);vb(k);Jh(k,a);$i(h,k);Pc(k);a=Xk(a)}v[j>>2]=a;gb=k+16|0}function dl(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[23048]=0;b=v[(b+c|0)+24>>2];c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[23048]=0;b=Sf(b+c|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(QH()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[23048]=0;b=v[(b+c|0)+24>>2];c=v[23048];v[23048]=0;c:{if((c|0)==1){break c}v[23048]=0;b=U(2230,b|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23048]=0;S(18,a+b|0,1);a=v[23048];v[23048]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;wd(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+45006|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function Ama(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-32|0;gb=f;j=f,k=Jp(b),v[j+16>>2]=k;c=gb-32|0;gb=c;g=b;d=a;b=$d(d);e=dc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{h=b+14|0;e:{if(AC(d,g,h)){if(!v[b>>2]){break b}e=b;break e}if(!zC(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=dc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){g=gb-16|0;gb=g;b=dc(a);h=Wh(c+8|0,bC(),Ij(g+8|0,b));d=v[h>>2];b=gb-16|0;gb=b;v[b+8>>2]=v[f+16>>2];i=x[v[b+8>>2]>>1];u[d+16>>1]=0;u[d+14>>1]=i;gb=b+16|0;j=dc(h),k=1,t[j+4|0]=k;gb=g+16|0;tk(a,v[c+28>>2],e,v[c+8>>2]);b=Bd(c+8|0);t[c+27|0]=1;cC(c+8|0)}Xh(f+24|0,Cc(c+8|0,b),c+27|0);gb=c+32|0;a=Kl(f+24|0);gb=f+32|0;return a+2|0}function h2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=iH(c);b:{if(b){Zk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Yk(k,a);break b}Cs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ih(k,a)}Eb(i,k);vb(k);l=e,m=dj(a),t[l|0]=m;l=f,m=cj(a),t[l|0]=m;Mg(k,a);Eb(g,k);vb(k);Jh(k,a);Eb(h,k);vb(k);a=Xk(a);break a}a=hH(c);c:{if(b){Zk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Yk(k,a);break c}Cs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ih(k,a)}Eb(i,k);vb(k);l=e,m=dj(a),t[l|0]=m;l=f,m=cj(a),t[l|0]=m;Mg(k,a);Eb(g,k);vb(k);Jh(k,a);Eb(h,k);vb(k);a=Xk(a)}v[j>>2]=a;gb=k+16|0}function Lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0;g=gb-16|0;gb=g;j=a+44|0;if(ei(j)){p=g,q=Pd(j,0),v[p+8>>2]=q;p=g,q=Pd(j,1),v[p+12>>2]=q;p=g,q=qd(j,0),v[p>>2]=q;p=g,q=qd(j,1),v[p+4>>2]=q;if(d){k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=v[f>>2];v[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=C(C(z[a+4236>>2]*z[m>>2])+C(z[a+4240>>2]*z[e>>2]));z[m>>2]=i;i=mM(C(i*C(1073741824)),w[a+4272|0],w[a+4273|0]);e=f+4244|0;n=z[a+4264>>2];f=f+4252|0;o=z[f>>2];i=C(C(i*z[a+4260>>2])-C(C(z[a+4268>>2]*z[e>>2])+C(n*o)));z[f>>2]=i;z[e>>2]=o+C(i*n);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=i*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}si(a,b,c,qd(j,0),qd(j,1),d)}gb=g+16|0}function VL(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=yf(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-9965.784284662086/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C(wg(d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(wg(d*+y[a+4292>>2])),z[m>>2]=n;l=(1/+g+-1)*d;c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=wg(l*+(j+v[(e+h|0)+16>>2]>>>0));b=wg(d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=f*.5;z[e+12>>2]=b*(.5-f);z[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=wg(+UL(z[a+4208>>2])*.16609640474436813);b=wg(+UL(z[a+4212>>2])*.33219280948873625);z[a+4228>>2]=d*4*K(b)/K(k);z[a+4224>>2]=d*K(1-b)}function Jfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];c=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(c){a=v[a+20>>2];h=c;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);le(d+12|0,C(-1));f=C(z[d+12>>2]*C(32768));z[d+12>>2]=f;e=a;f=Fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=e,j=Uc(g),u[i>>1]=j;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);le(d+12|0,C(-1));f=C(z[d+12>>2]*C(32768));z[d+12>>2]=f;e=a;f=Fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}i=e,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;h=h-1|0;if(h){continue}break}}gb=d+16|0;return c<<3}function hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=ti(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=49696;c=a+4960|0;e=a+4504|0;b=e;while(1){b=Co(b)+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[23048]=0;W(1545,a+44|0,2,2)|0;b=v[23048];v[23048]=0;a:{if((b|0)!=1){v[23048]=0;Oh(d);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;Qc(c);if((c|0)!=(e|0)){continue}break}nf(d);R(a|0);L()}return a|0}function y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;a:{if((b|0)!=(c|0)){j=v[115529];v[115529]=0;f=gb-16|0;gb=f;Be();g=gb-16|0;gb=g;h=gb-16|0;gb=h;Ix(h,b,e+28|0,2);b=v[h+4>>2];v[g>>2]=v[h>>2];v[g+4>>2]=b;b=v[h+12>>2];v[g+8>>2]=v[h+8>>2];v[g+12>>2]=b;gb=h+16|0;b=v[g+4>>2];v[f>>2]=v[g>>2];v[f+4>>2]=b;b=v[g+12>>2];v[f+8>>2]=v[g+8>>2];v[f+12>>2]=b;gb=g+16|0;b=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=b;b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;gb=f+16|0;i=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];b=v[115529];b:{if(b){if(v[e+28>>2]!=(c|0)){break b}if((b|0)!=68){break a}v[d>>2]=4;break a}v[115529]=j;if(v[e+28>>2]==(c|0)){break a}}}v[d>>2]=4;g=0;h=0;i=0;f=0}v[a>>2]=g;v[a+4>>2]=h;v[a+8>>2]=i;v[a+12>>2]=f;gb=e+32|0}function ry(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-96|0;gb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+48>>2]=v[d+20>>2];v[c+52>>2]=e;e=v[d+16>>2];v[c+40>>2]=v[d+12>>2];v[c+44>>2]=e;bk(c+72|0,c+40|0,f);d=lf(c+56|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];v[c+32>>2]=v[c+88>>2];a=v[c+84>>2];v[c+24>>2]=v[c+80>>2];v[c+28>>2]=a;a=v[c+76>>2];v[c+16>>2]=v[c+72>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=jd((v[xj(a,b,g)>>2]+jd(vt(i),21)|0)+2048|0,12);d=(d|0)>-32768?d:-32768;j=_n(h,b,g),k=(d|0)<32767?d:32767,u[j>>1]=k;b=b+1|0;if((e|0)!=(b|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}gb=c+96|0}function kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Gc(a);if(c>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/12>>>0){d=gb-16|0;gb=d;a=$p(d,a,c);b=v[a+4>>2];if((b|0)!=v[a+8>>2]){while(1){RT(b);b=v[a+4>>2]+12|0;v[a+4>>2]=b;if(v[a+8>>2]!=(b|0)){continue}break}}_b(a);gb=d+16|0;break c}b=wb(a);b=CB(e+8|0,AB(a,Gc(a)+c|0),Gc(a),b);v[23048]=0;UT(b,c);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=b;h=b+4|0;f=h;d=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[f>>2];while(1){a=a-12|0;zB(g-12|0,a);g=v[f>>2]-12|0;v[f>>2]=g;if((a|0)!=(i|0)){continue}break}}zc(d,h);zc(d+4|0,c+8|0);zc(wb(d),bc(c));v[c>>2]=v[c+4>>2];TT(b)}gb=e+32|0;break a}a=P()|0;O()|0;TT(b);R(a|0);L()}return}if(b>>>0<c>>>0){WT(a,v[a>>2]+B(b,12)|0)}}function Yt(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function vla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=zf(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>3>>>0){Cw(e,i);break d}j=wb(e);f=cv(e,zf(e)+i|0);m=zf(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;vd(d+12|0,j);if(f){h=f;if(f>>>0>=536870912){xc(25316);L()}h=jc(h<<3,1)}v[d>>2]=h;j=(m<<3)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=bc(d),o=(f<<3)+h|0,v[n>>2]=o;gb=l+16|0;v[23048]=0;$U(d,i);f=v[23048];v[23048]=0;if((f|0)==1){break c}Ji(e,d);_U(d)}gb=k+32|0;break b}a=P()|0;O()|0;_U(d);R(a|0);L()}break a}if(d>>>0<f>>>0){Hj(e,v[e>>2]+(d<<3)|0)}}if(Nb(a,c<<3)){cc(g+24|0,v[b>>2],zf(b)<<3);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0}function cL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;Dq(v[f>>2]);t[v[f>>2]+1300420|0]=v[a+52>>2]!=0;c=lf(e+32|0,d,c,b);h=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;xt(c);v[c+8>>2]=h;v[c+4>>2]=0;v[c>>2]=59140;h=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=h;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=58948;gb=d+16|0;a:{if(b){while(1){b:{c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Dt(c,v[Wl(e+24|0,e+16|0)>>2],i);g=c+g|0;if(!c){break b}b=b-c|0;if(b){continue}}break}if(g){break a}}g=0;if(v[a+52>>2]!=1){break a}a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return g}function bL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;Dq(v[f>>2]);t[v[f>>2]+1300420|0]=v[a+52>>2]!=0;c=lf(e+32|0,d,c,b);h=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;xt(c);v[c+8>>2]=h;v[c+4>>2]=0;v[c>>2]=59356;h=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=h;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=59164;gb=d+16|0;a:{if(b){while(1){b:{c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Dt(c,v[Wl(e+24|0,e+16|0)>>2],i);g=c+g|0;if(!c){break b}b=b-c|0;if(b){continue}}break}if(g){break a}}g=0;if(v[a+52>>2]!=1){break a}a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return g}function z7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Jb(a);a=Jb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480190>>1]){break d}b=1;while(1){c=v[f>>2];v[23048]=0;c=Qz(c,b&65535);d=v[23048];v[23048]=0;if((d|0)==1){break c}v[23048]=0;c=Q(91,e|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}d=hd(c);v[23048]=0;Q(1201,a|0,c|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}v[23048]=0;Q(1926,a|0,57011)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480190>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[23048]=0;Q(429,h|0,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);R(b|0);L()}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;h=$f(a,c);we(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{if(!h){if(nd(a,5)){break a}}g=v[a+28>>2];d=gb-16|0;gb=d;v[d+12>>2]=0;zG(g,d+12|0,1);e=v[d+12>>2];i=e>>>2&3;t[d+11|0]=i;if(i){t[d+4|0]=3;e=w[$b(d+4|0,d+11|0)|0];t[d+4|0]=0;t[d|0]=0;t[d+10|0]=0;b:{if(!e){break b}Eh(g,d+4|0);if((e|0)==1){break b}Eh(g,d);if(e>>>0<3){break b}Eh(g,d+10|0);j=w[d+10|0]<<24}e=w[d+12|0]|w[d+4|0]<<8|w[d|0]<<16|j;v[d+12>>2]=e}v[d+4>>2]=e>>>4;v[d>>2]=1e6;lq(b,v[Gb(d+4|0,d)>>2]);if(Bb(b)){e=0;while(1){cl(g,pc(b,e),1);e=e+1|0;if(Bb(b)>>>0>e>>>0){continue}break}}b=(v[d+12>>2]>>>4|0)-Bb(b)|0;v[d+12>>2]=b;if(b){mm(g,b,-1)}gb=d+16|0}Rf(a,h,c,f+24|0);gb=f+32|0}function A7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Jb(a);a=Jb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480192>>1]){break d}b=1;while(1){c=v[f>>2];v[23048]=0;c=Pz(c,b&65535);d=v[23048];v[23048]=0;if((d|0)==1){break c}v[23048]=0;c=Q(91,e|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}d=hd(c);v[23048]=0;Q(1201,a|0,c|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}v[23048]=0;Q(1926,a|0,57011)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480192>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[23048]=0;Q(429,h|0,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);R(b|0);L()}function L5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}k=-1;l=-1;h=f&24;a:{if(!h|((h|0)==24?(e|0)==1:0)){break a}h=v[b+44>>2];if(h){g=h-Ob(b+32|0)|0;m=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;i=e;j=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;i=e;j=e>>31;break b;case 0:break b;case 2:break c;default:break a}}i=m;j=g}d=d+j|0;c=c+i|0;d=i>>>0>c>>>0?d+1|0:d;e=c;c=d;if((d|0)<0|((d|0)>(g|0)?1:(g|0)<=(d|0)?e>>>0>m>>>0:0)){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(d){Wn(b,v[b+8>>2],e+v[b+8>>2]|0,v[b+44>>2])}if(f&16){Tx(b,v[b+20>>2],v[b+28>>2]);et(b,e)}k=e;l=c}ph(a,k,l)}function kh(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){return hc(a,b,c)}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){d=a;break b}if(!(a&3)){d=a;break c}d=a;while(1){if(!c){break a}t[d|0]=w[b|0];b=b+1|0;c=c-1|0;d=d+1|0;if(d&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[d>>2]=v[b>>2];b=b+4|0;d=d+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function aL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;b=v[a+4>>2];c=f;a=v[a>>2];v[c>>2]=a;v[c+4>>2]=b;v[c+8>>2]=a;v[c+12>>2]=b;b=gb+-64|0;gb=b;a:{b:{e=v[c+4>>2];if(!e){break b}d=33200;while(1){a=v[c+4>>2];v[b+56>>2]=v[c>>2];v[b+60>>2]=a;a=wc(b+48|0,v[d+8>>2]);g=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=g;g=v[a+4>>2];v[b+16>>2]=v[a>>2];v[b+20>>2]=g;if(pO(b+24|0,b+16|0)){break b}d=d+12|0;if((d|0)!=33752){continue}break}d=33760;while(1){c:{a=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=a;a=wc(b+32|0,v[d+8>>2]);e=v[b+44>>2];v[b+8>>2]=v[b+40>>2];v[b+12>>2]=e;e=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=e;a=pO(b+8|0,b);if(a){break c}d=d+12|0;if((d|0)!=33808){continue}}break}gb=b- -64|0;break a}gb=b- -64|0;a=(e|0)!=0}gb=f+16|0;return a|0}function nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=f>>>21&2040;l=u[b+40886>>1];m=u[b+40884>>1];n=u[b+40882>>1];o=u[b+40880>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function Gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-32|0;gb=d;wd(b,0);Pj(d,1,a);Fc(d+16|0,d);v[23048]=0;Q(355,b+43|0,d+16|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){vb(d+16|0);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;Jo(b,+((w[a+60|0]^8)-120|0)*.005208333333333333);t[d+16|0]=w[a+61|0];t[d|0]=64;e=b,f=w[$b(d+16|0,d)|0]<<2,u[e+30>>1]=f;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<=-1){u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}function q7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=nc(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[23048]=0;S(1436,g|0,a|0);c=v[23048];v[23048]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){while(1){c=v[f>>2];v[23048]=0;c=Pz(c,a&65535);e=v[23048];v[23048]=0;if((e|0)==1){break e}v[23048]=0;c=Q(91,d|0,c|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}v[23048]=0;T(2095,d+16|0,b|0,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;S(1438,g|0,d+16|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);R(a|0);L()}function p7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=nc(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[23048]=0;S(1436,g|0,a|0);c=v[23048];v[23048]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){while(1){c=v[f>>2];v[23048]=0;c=Qz(c,a&65535);e=v[23048];v[23048]=0;if((e|0)==1){break e}v[23048]=0;c=Q(91,d|0,c|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break e}v[23048]=0;T(2095,d+16|0,b|0,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;S(1438,g|0,d+16|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);R(a|0);L()}function K6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-80|0;gb=d;a=v[a+4>>2];lz(d+16|0,b);v[23048]=0;b=Q(2,d|0,56796)|0;e=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[23048]=0;T(3,d+32|0,d+16|0,b|0);e=v[23048];v[23048]=0;if((e|0)==1){break h}v[23048]=0;T(693,d+48|0,d+32|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break g}v[23048]=0;T(9,d- -64|0,0,d+48|0);c=v[23048];v[23048]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[23048]=0;S(c|0,a|0,d- -64|0);a=v[23048];v[23048]=0;if((a|0)==1){break e}vb(d- -64|0);vb(d+48|0);vb(d+32|0);vb(b);vb(d+16|0);gb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d- -64|0)}vb(d+48|0)}vb(d+32|0)}vb(b)}vb(d+16|0);R(a|0);L()}function qO(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:Bq(a,C(1));Aq(a,C(3.725290298461914e-9));zq(a,C(268435456));yq(a,0);break b;case 1:Bq(a,C(32));Aq(a,C(4.656612873077393e-10));zq(a,C(2147483648));yq(a,0);break b;case 2:Bq(a,C(2));Aq(a,C(7.450580596923828e-9));zq(a,C(134217728));yq(a,1);break b;default:Bq(a,C(1));Aq(a,C(7.450580596923828e-9));zq(a,C(134217728));yq(a,1);xz(a,0);wz(a,1);vz(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}Bq(a,C(.75));Aq(a,C(7.450580596923828e-9));zq(a,C(134217728));yq(a,1);xz(a,0);b=(b|0)==4;wz(a,b?2:3);vz(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}xz(a,1);wz(a,0);vz(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function __(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a:{g=gb-96|0;gb=g;Di(g+48|0,g+40|0,c);v[23048]=0;c=g+60|0;T(213,c|0,g+32|0,d|0);d=v[23048];v[23048]=0;b:{c:{h=g+48|0;d:{e:{f:{g:{if((d|0)!=1){v[23048]=0;T(213,g+72|0,g+24|0,e|0);c=v[23048];v[23048]=0;if((c|0)==1){break g}v[23048]=0;T(213,g+84|0,g+16|0,f|0);c=v[23048];v[23048]=0;if((c|0)==1){break f}c=g+48|0;v[g+8>>2]=c;v[g+12>>2]=c+48;v[23048]=0;c=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=c;T(78,a|0,b|0,g|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}ZF(g+48|0);gb=g+96|0;break a}a=P()|0;O()|0;break d}a=P()|0;O()|0;b=2;break e}a=P()|0;O()|0;b=3}c=h+B(b,12)|0}while(1){c=vb(c-12|0);if((c|0)!=(g+48|0)){continue}break}break b}a=P()|0;O()|0;ZF(g+48|0)}R(a|0);L()}}function Wp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;e=j(0)|0;a:{b:{c:{d:{if((b|0)>0?1:(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|e)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(e){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;e=j(0)|0;g=-1077}b=b+614242|0;d=+((b>>>20|0)+g|0);l(0,e|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);h=d*.6931471803691238;i=a;k=d*1.9082149292705877e-10;m=c;d=a*(a*.5);c=c*c;a=c*c;a=h+(i+(k+m*(d+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-d))}return a}function Jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Lb(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>2>>>0){Wm(e,i);break d}j=wb(e);f=Jl(e,Lb(e)+i|0);m=Lb(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;vd(d+12|0,j);if(f){h=f;if(f>>>0>=1073741824){xc(19760);L()}h=jc(h<<2,1)}v[d>>2]=h;j=(m<<2)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=bc(d),o=(f<<2)+h|0,v[n>>2]=o;gb=l+16|0;v[23048]=0;Yo(d,i);f=v[23048];v[23048]=0;if((f|0)==1){break c}Ji(e,d);Xo(d)}gb=k+32|0;break b}a=P()|0;O()|0;Xo(d);R(a|0);L()}break a}if(d>>>0<f>>>0){Hj(e,v[e>>2]+(d<<2)|0)}}if(Nb(a,c<<2)){iC(g+24|0,b);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Lb(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>2>>>0){Wm(e,i);break d}j=wb(e);f=Jl(e,Lb(e)+i|0);m=Lb(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;vd(d+12|0,j);if(f){h=f;if(f>>>0>=1073741824){xc(26612);L()}h=jc(h<<2,1)}v[d>>2]=h;j=(m<<2)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=bc(d),o=(f<<2)+h|0,v[n>>2]=o;gb=l+16|0;v[23048]=0;Yo(d,i);f=v[23048];v[23048]=0;if((f|0)==1){break c}Ji(e,d);Xo(d)}gb=k+32|0;break b}a=P()|0;O()|0;Xo(d);R(a|0);L()}break a}if(d>>>0<f>>>0){Hj(e,v[e>>2]+(d<<2)|0)}}if(Nb(a,c<<2)){iC(g+24|0,b);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0}function Pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=c;e=gb-32|0;gb=e;h=b;d=$d(b);f=dc(b);a:{b:{if(d){c:{while(1){d:{b=d+16|0;e:{if(wA(c,b)){if(!v[d>>2]){break b}b=d;break e}if(!wA(b,c)){break c}b=d+4|0;if(!v[d+4>>2]){break d}d=b;b=d}f=b;d=v[d>>2];continue}break}v[e+28>>2]=d;break a}v[e+28>>2]=d;b=f;break a}d=dc(b)}v[e+28>>2]=d;b=d}d=v[b>>2];t[e+27|0]=0;if(!d){c=gb-16|0;gb=c;d=dc(h);d=Wh(e+8|0,jc(28,4),Ij(c+8|0,d));f=v[d>>2];v[23048]=0;S(1432,f+16|0,i|0);f=v[23048];v[23048]=0;f:{if((f|0)!=1){j=dc(d),k=1,t[j+4|0]=k;gb=c+16|0;break f}a=P()|0;O()|0;iO(d);R(a|0);L()}tk(h,v[e+28>>2],b,v[e+8>>2]);d=Bd(e+8|0);t[e+27|0]=1;iO(e+8|0)}Xh(g+8|0,Cc(e+8|0,d),e+27|0);gb=e+32|0;GS(a,g+8|0);gb=g+16|0}function zX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=b;k=e,l=Ld(a),v[k+8>>2]=l;g=Hk(e+24|0,e+8|0);b=_h(c,d);a:{b:{if(!b){break b}if(PC(c,Ob(a),Ob(a)+Bb(a)|0)){b=pj(e+8|0,c,d);c=v[e+24>>2];d=Ob(b);g=Ob(b);h=Bb(b);v[23048]=0;c=ba(584,a|0,c|0,d|0,g+h|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);R(a|0);L()}h=Bb(a);f=Nc(a);c:{if(b>>>0<=f-h>>>0){f=Ob(a);i=h-g|0;if(!i){break c}j=g+f|0;mn(b+j|0,j,i);break c}op(a,f,(b+h|0)-f|0,h,g,0,b);f=v[a>>2]}b=b+h|0;yh(a,b);t[e+8|0]=0;Qd(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){Qd(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=Ld(a),v[k+8>>2]=l;c=Ne(e+8|0,g)}gb=e+32|0;return c|0}function WU(a){var b=0,c=0;a:{b:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break b}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<1108){break b}c=a+1104|0;if(((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-1108|0)!=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>262144){break b}b=a+1094|0;if(w[b|0]|w[b+1|0]<<8){break b}b=a+1096|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>4){break b}if(!bv(a+8|0)){break b}c=a+1094|0;b=a+40|0;while(1){if(w[b+32|0]>15|w[b+33|0]>64){break b}if(!bv(b)){break b}a=1;b=b+34|0;if((c|0)!=(b|0)){continue}break}break a}a=0}return a}function MJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{b:{c:{d:{if((b|0)>=0){if((ao(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[23048]=0;b=Q(91,f|0,59689)|0;c=v[23048];v[23048]=0;if((c|0)==1){break c}rc(a,b);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,880)|0)+1075072|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,880);if((b|0)==x[(e+v[d>>2]|0)+1075772>>1]){e=(e+v[d>>2]|0)+1075072|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}gb=f+16|0;return}c=P()|0;O()|0;ca(a|0)}R(c|0)}L()}function N5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;b=d+16|0;a:{b:{c:{if(!dt(wa(v[a+60>>2],d+16|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!dt(wa(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}gb=d+32|0;return a|0}function tt(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb-96|0;gb=b;c=v[a>>2];e=v[c+4>>2];d=v[c+24>>2];v[b+48>>2]=v[c+20>>2];v[b+52>>2]=d;d=v[c+16>>2];v[b+40>>2]=v[c+12>>2];v[b+44>>2]=d;bk(b+72|0,b+40|0,e);c=lf(b+56|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];d=v[v[a+8>>2]>>2];v[b+32>>2]=v[b+88>>2];a=v[b+84>>2];v[b+24>>2]=v[b+80>>2];v[b+28>>2]=a;a=v[b+76>>2];v[b+16>>2]=v[b+72>>2];v[b+20>>2]=a;v[b+8>>2]=v[c+8>>2];a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;g=b+16|0;a=b;if(e){while(1){c=0;if(d){while(1){h=Lm(fe(A[lj(a,c,f)>>3]*134217728));i=py(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}gb=b+96|0}function e9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[23048]=0;_(1943,a|0);e=v[23048];v[23048]=0;a:{b:{c:{if((e|0)==1){break c}v[23048]=0;_(1969,b|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}v[23048]=0;_(1969,c|0);f=v[23048];v[23048]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=wc(d+24|0,b);c=wc(d+16|0,c);v[23048]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;Y(2013,f|0,d+8|0,d|0,1);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55201,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();e=0}gb=d+32|0;return e|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];c=v[Gb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());le(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=Fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=h,k=Uc(g),u[j>>1]=k;z[e+12>>2]=i*(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());le(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=Fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=h,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<3}function Pb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}f=a+c|0;t[f-1|0]=b;t[a|0]=b;if(c>>>0<3){break a}t[f-2|0]=b;t[a+1|0]=b;t[f-3|0]=b;t[a+2|0]=b;if(c>>>0<7){break a}t[f-4|0]=b;t[a+3|0]=b;if(c>>>0<9){break a}f=0-a&3;e=f+a|0;d=B(b&255,16843009);v[e>>2]=d;b=c-f&-4;c=b+e|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[e+8>>2]=d;v[e+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[e+24>>2]=d;v[e+20>>2]=d;v[e+16>>2]=d;v[e+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=e&4|24;c=c-b|0;if(c>>>0<32){break a}d=Fpa(d,0,1,1);f=jb;b=b+e|0;while(1){v[b+24>>2]=d;e=f;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function qV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(Nb(a,1024)){SB(c+24|0,b);b=v[c+28>>2];v[c>>2]=v[c+24>>2];v[c+4>>2]=b;gd(c+8|0,a,c);break a}v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;a=64;while(1){d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}}gb=c+32|0}function ona(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=0;uk(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Jb(d+16|0);v[23048]=0;u[d+14>>1]=0;f=W(694,a|0,e|0,255)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}if(!f){break d}v[23048]=0;Q(688,a|0,d+14|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}v[23048]=0;T(13,d|0,c|0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break f}v[23048]=0;f=Q(695,b|0,d+14|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}Sf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);R(a|0);L()}function nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;u[d+30>>1]=0;Yf(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Jb(d+16|0);v[23048]=0;u[d+14>>1]=0;f=W(696,a|0,e|0,255)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}if(!f){break d}v[23048]=0;Q(688,a|0,d+14|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}v[23048]=0;T(13,d|0,c|0,e|0);f=v[23048];v[23048]=0;if((f|0)==1){break f}v[23048]=0;f=Q(695,b|0,d+14|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}Sf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);R(a|0);L()}function hm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0;k=gb-16|0;gb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Bb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=ho(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+84064|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+84064|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function gm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;k=gb-16|0;gb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Bb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=hx(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+84064|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+84064|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;a:{b:{c:{d:{e:{if(jk(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[Vc(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){ve(d+8|0,b,c);if(!Cb(d+8|0)){v[23048]=0;e=Q(1331,a|0,c&65535)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}if(e){v[23048]=0;e=Q(91,d+8|0,32397)|0;f=v[23048];v[23048]=0;if((f|0)==1){break d}v[23048]=0;Q(354,((c<<5)+a|0)+946300|0,e|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break c}vb(e);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}gb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(e);break a}c=P()|0;O()|0}R(c|0);L()}function cQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Gb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b|0]);d=zb(w[b+1|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+2|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+3|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+4|0])|(f|g);j=a,k=Lc(d,zb(w[b+5|0])<<8|f|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[j>>1]=k;e=zb(w[b+8|0]);d=zb(w[b+9|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+10|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+11|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+12|0])|(f|g);j=a,k=Lc(d,zb(w[b+13|0])<<8|f|zb(w[b+14|0])<<16|zb(w[b+15|0])<<24,48),u[j+2>>1]=k;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function bQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Gb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b+7|0]);d=zb(w[b+6|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+5|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+4|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+3|0])|(f|g);j=a,k=Lc(d,zb(w[b+2|0])<<8|f|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[j>>1]=k;e=zb(w[b+15|0]);d=zb(w[b+14|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+13|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+12|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+11|0])|(f|g);j=a,k=Lc(d,zb(w[b+10|0])<<8|f|zb(w[b+9|0])<<16|zb(w[b+8|0])<<24,48),u[j+2>>1]=k;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function Faa(a){a=a|0;var b=0;b=52280;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=52317;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=52181;break a}b=52294;break a}b=52336;break a}b=52350;break a}b=52364;break a}b=52376;break a}b=52396;break a}b=52417;break a}b=52429;break a}b=52448;break a}b=52480;break a}b=52502;break a}if((a|0)!=357){break a}b=52519}return ie(b)|0}function Xz(a){var b=0,c=0,d=0,e=0;e=a+128e3|0;while(1){d=gb-32|0;gb=d;br(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;gb=d+32|0;a=a+32|0;if((e|0)!=(a|0)){continue}break}}function NI(a,b,c,d,e,f){var g=0;g=gb-80|0;gb=g;a:{if((f|0)>=16384){Dd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if((f|0)<32767){f=f-16383|0;break a}Dd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Dd(g- -64|0,b,c,d,e,0,0,0,65536);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}Dd(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Dd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;gb=g+80|0}function jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;e=(e<<1)+k|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+40882>>1])+B(u[e-2>>1],u[f+40880>>1])|0)+B(u[e+2>>1],u[f+40884>>1])|0)+B(u[e+4>>1],u[f+40886>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(g,e);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function xo(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+811|0]=c;break a}c=w[b+811|0]}d=v[a+480180>>2]&202376205?c&240?c&-16:c&15:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){Oq(a,b,(d&240)>>>4|0,0);return}if(!(t[b+853|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){Nq(a,b,f,0);return}if(!(t[b+853|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(v[a+1074408>>2]!=1|v[a+480180>>2]!=524288?!(!(t[b+853|0]&1)|w[a+480208|0]&2):0){break c}e=d&255;d=d&15;d:{if(d){if(v[a+480180>>2]&16777248?e&240:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=ac(c,0,256),v[g+688>>2]=h}function Iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=(e<<1)+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function oy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-80|0;gb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;ak(c- -64|0,c+32|0,e);d=lf(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(e){i=b+12|0;while(1){b=0;if(f){while(1){d=jd((v[xj(a,b,g)>>2]+jd(vt(i),21)|0)+2048|0,12);d=(d|0)>-32768?d:-32768;j=Zn(h,b,g),k=(d|0)<32767?d:32767,u[j>>1]=k;b=b+1|0;if((f|0)!=(b|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}gb=c+80|0}function UY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-208|0;gb=e;FD(c,a);CD(c,e+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=e;d=gb-16|0;gb=d;v[d+12>>2]=64;v[23048]=0;v[d+8>>2]=255;f=Gb(d+12|0,d+8|0);g=v[23048];v[23048]=0;b:{if((g|0)!=1){gb=d+16|0;d=w[f|0];break b}V(0)|0;O()|0;Ab();L()}t[c+12|0]=d;Eg(b,w[$b(a+4|0,e+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Lb(b)){break a}a=0;while(1){if(a){c=x[Mb(b,a-1|0)>>1];v[e+12>>2]=1;d=(e+16|0)+B(a,3)|0;v[e+8>>2]=(t[d+1|0]&1)<<8|w[d|0];d=x[Wf(e+12|0,e+8|0)>>1];h=Mb(b,a),i=c+d|0,u[h>>1]=i}c=w[((e+16|0)+B(a,3)|0)+2|0];h=Mb(b,a),i=c,t[h+2|0]=i;a=a+1|0;if(Lb(b)>>>0>a>>>0){continue}break}}gb=e+208|0}function eJ(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 1:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return;case 4:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 5:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 6:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 8:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 9:break b;default:break a}}kb[d|0](a,c)}}function Oma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=gD(c,a);pC(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;_b(a);gb=c+16|0;return}i=gb-32|0;gb=i;e=wb(a);f=Rl(a,Je(a)+1|0);h=Je(a);g=gb-16|0;gb=g;v[g+12>>2]=0;c=i+8|0;vd(c+12|0,e);if(f){d=f;if(d>>>0>=153391690){xc(19375);L()}d=jc(B(d,28),4)}v[c>>2]=d;e=B(h,28)+d|0;v[c+8>>2]=e;v[c+4>>2]=e;j=bc(c),k=B(f,28)+d|0,v[j>>2]=k;gb=g+16|0;pC(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;b=c;h=c+4|0;d=h;f=a;g=v[a>>2];a=v[a+4>>2];if((g|0)!=(a|0)){e=v[d>>2];while(1){a=a-28|0;pC(e-28|0,a);e=v[d>>2]-28|0;v[d>>2]=e;if((a|0)!=(g|0)){continue}break}}zc(f,h);zc(f+4|0,b+8|0);zc(wb(f),bc(b));v[b>>2]=v[b+4>>2];Ql(c);gb=i+32|0}function Hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-16|0;gb=f;v[f+8>>2]=c>>>3;v[f+4>>2]=v[a>>2];j=v[Gb(f+8|0,f+4|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){k=0;d=b;g=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);e=g<<24|h>>>8;d=0;l=e&65280;e=d;d=g<<8|h>>>24;e=e|k;k=d&255|l|(h<<24|h<<8&16711680);d=f;v[d+8>>2]=((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24)|e;v[d+12>>2]=k;hg(d+8|0,-1,1);i=A[d+8>>3]*32768;A[d+8>>3]=i;d=a;i=fe(i);a:{if(D(i)<2147483648){e=~~i;break a}e=-2147483648}m=d,n=Uc(e),u[m>>1]=n;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=f+16|0;return j<<3}function $B(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;Eg(b,w[$b(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Lb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Mb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}e=x[Mb(b,e)>>1];h=Mb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=ac((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Mb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}gb=g+16|0}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;b=b+k|0;f=f>>>21&2040;b=(((B(t[b|0],u[f+40882>>1])+B(t[b-1|0],u[f+40880>>1])|0)+B(t[b+1|0],u[f+40884>>1])|0)+B(t[b+2|0],u[f+40886>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(g,b);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=b;gb=e+16|0}function jq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb-96|0;gb=b;c=v[a>>2];e=v[c+4>>2];d=v[c+24>>2];v[b+48>>2]=v[c+20>>2];v[b+52>>2]=d;d=v[c+16>>2];v[b+40>>2]=v[c+12>>2];v[b+44>>2]=d;bk(b+72|0,b+40|0,e);c=lf(b+56|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];d=v[v[a+8>>2]>>2];v[b+32>>2]=v[b+88>>2];a=v[b+84>>2];v[b+24>>2]=v[b+80>>2];v[b+28>>2]=a;a=v[b+76>>2];v[b+16>>2]=v[b+72>>2];v[b+20>>2]=a;v[b+8>>2]=v[c+8>>2];a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;g=b+16|0;a=b;if(e){while(1){c=0;if(d){while(1){h=v[xj(a,c,f)>>2];i=py(g,c,f),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}gb=b+96|0}function fO(a){var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;v[b+12>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+16>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);c=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);v[b+28>>2]=3;v[b+20>>2]=c+(a<<2);v[b+24>>2]=b+12;a=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=a;a=v[b>>2];d=SC(b);e=gb-16|0;gb=e;a:{if((a|0)==(d|0)){break a}c=a+4|0;if((d|0)==(c|0)){break a}while(1){a=Nd(a,c)?c:a;c=c+4|0;if((d|0)!=(c|0)){continue}break}}gb=e+16|0;gb=b+32|0;return v[a>>2]-36|0}function xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-32|0;gb=g;c=gb-16|0;gb=c;d=a;k=d;h=b;e=$d(d);f=dc(d);i=gb-16|0;gb=i;if(e){while(1){j=uu(wb(k),e+16|0,h);f=j?f:e;e=v[(j?4:0)+e>>2];if(e){continue}break}}h=v[Cc(i+8|0,f)>>2];gb=i+16|0;v[c+8>>2]=h;l=c,m=rh(d),v[l>>2]=m;a:{b:{if(!Nl(c+8|0,c)){break b}if(uu(wb(d),b,se(c+8|0))){break b}b=v[c+8>>2];break a}b=rh(d)}gb=c+16|0;v[g+24>>2]=b;l=g,m=rh(a),v[l+16>>2]=m;if(!Ck(g+24|0,g+16|0)){b=v[Cc(g+8|0,b)>>2];d=gb-16|0;gb=d;v[d+8>>2]=b;h=v[d+8>>2];e=h;c=gb-16|0;gb=c;f=Cc(c+8|0,e);Fj(f);b=a;if((e|0)==v[b>>2]){v[b>>2]=v[f>>2]}f=wb(b);v[f>>2]=v[f>>2]-1;iN(v[dc(b)>>2],e);gb=c+16|0;dc(a);Bo(se(d+8|0));uA(h);gb=d+16|0}gb=g+32|0}function Oea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-80|0;gb=d;h=NR(a,1<<b-1);v[a+12>>2]=b;a:{b=1<<b;f=b>>>2|0;if(f){i=1/+(b>>>0);b=f;g=1;while(1){A[d+40>>3]=+(b>>>0)*-6.283185307179586*i;e=v[10983];c=d+48|0;v[c+8>>2]=v[10982];v[c+12>>2]=e;e=v[10981];v[c>>2]=v[10980];v[c+4>>2]=e;HA(c,A[d+40>>3]);v[23048]=0;GA(d- -64|0,d+48|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}c=Tc(h,g);e=v[d+76>>2];v[c+8>>2]=v[d+72>>2];v[c+12>>2]=e;e=v[d+68>>2];v[c>>2]=v[d+64>>2];v[c+4>>2]=e;g=g<<1;b=b>>>1|0;if(b){continue}break}}b=Im(d+24|0,1,0);c=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=c;c=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=c;rz(a,0,f,d+8|0);gb=d+80|0;return a|0}a=P()|0;O()|0;Wq(h);R(a|0);L()}function Jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=e+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function l9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[23048]=0;_(1969,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break f}e=v[a+24>>2];v[23048]=0;c=Q(91,d|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;Y(2004,d+16|0,e|0,c|0,1);b=v[23048];v[23048]=0;if((b|0)==1){break d}b=ie(Ob(d+16|0));vb(d+16|0);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[23048]=0;Y(1920,54929,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function eZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;wd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Or(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Or(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[$b(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(Fu(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}gb=d+16|0}function Zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Lb(e);d=c;a:{if(f>>>0<d>>>0){j=gb-32|0;gb=j;b:{c:{h=d-f|0;d:{if(h>>>0<=v[wb(e)>>2]-v[e+4>>2]>>2>>>0){Wm(e,h);break d}i=wb(e);k=Jl(e,Lb(e)+h|0);m=Lb(e);f=0;l=gb-16|0;gb=l;v[l+12>>2]=0;d=j+8|0;vd(d+12|0,i);if(k){f=IU(k)}v[d>>2]=f;i=(m<<2)+f|0;v[d+8>>2]=i;v[d+4>>2]=i;n=bc(d),o=(k<<2)+f|0,v[n>>2]=o;gb=l+16|0;v[23048]=0;Yo(d,h);f=v[23048];v[23048]=0;if((f|0)==1){break c}Ji(e,d);Xo(d)}gb=j+32|0;break b}a=P()|0;O()|0;Xo(d);R(a|0);L()}break a}if(d>>>0<f>>>0){Hj(e,v[e>>2]+(d<<2)|0)}}if(Nb(a,c<<2)){iC(g+24|0,b);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0}function S9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[23048]=0;_(1969,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break f}e=v[a+24>>2];v[23048]=0;c=Q(91,d|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break e}v[23048]=0;T(1970,d+16|0,e|0,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break d}b=ie(Ob(d+16|0));vb(d+16|0);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[23048]=0;Y(1920,53695,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function OM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=gb-48|0;gb=c;v[c+8>>2]=542066252;d=c+8|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;sk(b,33);hc(v[b>>2],c+8|0,33);me(c,b);pe(a,c);gb=c+48|0}function r5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-16|0;gb=e;a:{b:{if(!Ke(b,-1)){f=v[a+12>>2];g=v[a+8>>2];if(v[a+24>>2]==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}h=v[a+24>>2];i=v[a+20>>2];j=v[a+44>>2];k=v[a+20>>2];v[23048]=0;c=a+32|0;S(110,c|0,0);d=v[23048];v[23048]=0;if((d|0)==1){break b}d=Nc(c);v[23048]=0;S(124,c|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}d=Ob(c);Tx(a,d,Bb(c)+d|0);et(a,h-i|0);v[a+44>>2]=v[a+20>>2]+(j-k|0)}v[e+12>>2]=v[a+24>>2]+1;l=a,m=v[Jc(e+12|0,a+44|0)>>2],v[l+44>>2]=m;if(w[a+48|0]&8){c=Ob(a+32|0);Wn(a,c,c+(f-g|0)|0,v[a+44>>2])}c=vI(a,Kh(b));break a}c=_s(b);break a}a=V(0)|0;O()|0;Z(a|0)|0;$();c=-1}gb=e+16|0;return c|0}function mpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;g=a+8|0;a:{c=v[a+8>>2];i=bc(a);b:{if((c|0)!=v[i>>2]){break b}h=a+4|0;d=v[a+4>>2];f=v[a>>2];if(d>>>0>f>>>0){f=((d-f>>1)+1|0)/-2<<1;a=f+d|0;if((c|0)!=(d|0)){while(1){rY(a,d);a=a+2|0;d=d+2|0;if((d|0)!=(c|0)){continue}break}}c=a;v[g>>2]=a;v[h>>2]=f+v[h>>2];break b}v[e+24>>2]=c-f;v[e+44>>2]=1;c=v[Jc(e+24|0,e+44|0)>>2];c=zY(e+24|0,c,c>>>2|0,v[a+16>>2]);d=Cc(e+16|0,v[a+4>>2]);f=v[Cc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[23048]=0;sY(c,d,f);d=v[23048];v[23048]=0;if((d|0)==1){break a}zc(a,c);zc(h,c+4|0);zc(g,c+8|0);zc(i,bc(c));rp(c);c=v[a+8>>2]}Gv(c,b);v[g>>2]=v[g>>2]+2;gb=e+48|0;return}a=P()|0;O()|0;rp(c);R(a|0);L()}function Eg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Lb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){e=gb-16|0;gb=e;d:{b=Ug(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(a);c=v[b+4>>2];v[23048]=0;Ur(c);c=v[23048];v[23048]=0;if((c|0)==1){break d}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}_b(b);gb=e+16|0;break c}a=P()|0;O()|0;_b(b);R(a|0);L()}b=wb(a);b=Ap(d+8|0,Tg(a,Lb(a)+c|0),Lb(a),b);v[23048]=0;S(352,b|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(353,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Ti(b)}gb=d+32|0;break a}a=P()|0;O()|0;Ti(b);R(a|0);L()}return}if(b>>>0<c>>>0){Ui(a,v[a>>2]+(b<<2)|0)}}function X2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){c=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}Ic(f+24|0,c);v[23048]=0;a=U(2376,f+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break b}Xb(f+24|0);e:{if(e){Jh(f+24|0,a);break e}Ih(f+24|0,a)}g=f,h=Ld(f+24|0),v[g+16>>2]=h;g=f,h=mi(f+24|0),v[g+8>>2]=h;if(Fb(f+16|0,f+8|0)){while(1){a=v[v[f+16>>2]>>2];v[23048]=0;Q(2395,f+40|0,a|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}Ag(f+16|0);g=f,h=mi(f+24|0),v[g+8>>2]=h;if(Fb(f+16|0,f+8|0)){continue}break}}c=v[f+40>>2];Pc(f+24|0)}gb=f+48|0;return c|0}c=P()|0;O()|0;Pc(f+24|0);break a}c=P()|0;O()|0;Xb(f+24|0)}R(c|0);L()}function Nk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{d=v[a+32>>2];if((d|0)>=(b|0)){f=v[a+28>>2];break a}i=a+36|0;g=v[a+24>>2];e=v[a+20>>2];h=d;while(1){b:{if(e>>>0>=g>>>0){_c(c+16|0,i,i+1024|0);d=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=d;gd(c+24|0,a,c+8|0);g=xb(c+24|0);v[a+24>>2]=g;v[a+20>>2]=0;if(!g){break b}e=0;h=v[a+32>>2]}j=e+1|0;v[a+20>>2]=j;e=w[(a+e|0)+36|0];d=h+8|0;v[a+32>>2]=d;f=v[a+28>>2]|e<<h;v[a+28>>2]=f;h=d;e=j;if((b|0)>(d|0)){continue}break a}break}a=aa(8)|0;v[23048]=0;U(258,a|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){b=P()|0;O()|0;ca(a|0);R(b|0);L()}ja(a|0,15256,259);L()}v[a+32>>2]=d-b;v[a+28>>2]=f>>>b;gb=c+32|0;return(-1<<b^-1)&f}function we(a,b){var c=0,d=0,e=0;d=gb-32|0;gb=d;a=ph(a,-1,-1);a:{b:{if(w[$j(d+24|0,b,1)|0]){c=v[v[b>>2]-12>>2];v[23048]=0;c=v[(b+c|0)+24>>2];e=v[23048];v[23048]=0;c:{d:{if((e|0)==1){break d}v[23048]=0;Fa(2239,d+8|0,c|0,0,0,1,8);c=v[23048];v[23048]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;Z(a|0)|0;a=1;Yj(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break b}R(a|0);L()}$()}uh(v[v[b>>2]-12>>2]+b|0,a)}gb=d+32|0;return}V(0)|0;O()|0;Ab()}L()}function oI(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[23048]=0;c=Q(2242,d+8|0,a|0)|0;b=v[23048];v[23048]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23048]=0;b=U(2243,b|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[23048]=0;_(2244,a+b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;nI(c);break c}nI(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[23048]=0;_(19,a+c|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function h3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){c=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}Ic(f+24|0,c);v[23048]=0;a=U(2346,f+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break b}Xb(f+24|0);e:{if(e){Jh(f+24|0,a);break e}Ih(f+24|0,a)}g=f,h=Ld(f+24|0),v[g+16>>2]=h;g=f,h=hf(f+24|0),v[g+8>>2]=h;if(Fb(f+16|0,f+8|0)){while(1){a=t[v[f+16>>2]];v[23048]=0;Q(2247,f+40|0,a|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}Se(f+16|0);g=f,h=hf(f+24|0),v[g+8>>2]=h;if(Fb(f+16|0,f+8|0)){continue}break}}c=v[f+40>>2];vb(f+24|0)}gb=f+48|0;return c|0}c=P()|0;O()|0;vb(f+24|0);break a}c=P()|0;O()|0;Xb(f+24|0)}R(c|0);L()}function Lz(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=gb-16|0;gb=c;if(!cd(a)){l=c,m=Rb(a),v[l+8>>2]=m;l=c,m=Ub(a),v[l>>2]=m;if(Fb(c+8|0,c)){while(1){b=v[c+8>>2];Fp(b,4194304,67108864);e=v[b>>2];f=e+f|0;b=g;b=f>>>0<e>>>0?b+1|0:b;g=b;Qg(c+8|0);if(Fb(c+8|0,c)){continue}break}}b=Lb(a);h=Lb(a);l=c,m=Rb(a),v[l+8>>2]=m;l=c,m=Ub(a),v[l>>2]=m;b=Ipa(f,g,b,0);e=jb;f=h<<24;g=0;if(Fb(c+8|0,c)){h=b;e=((e&1)<<31|b>>>1)&2147483647;while(1){b=v[c+8>>2];i=b;d=v[b>>2];b=d>>>8|0;d=e+(d<<24)|0;b=b+j|0;b=Xc(Ipa(d,e>>>0>d>>>0?b+1|0:b,h,k),jb);v[i>>2]=b;d=f;f=d-b|0;g=g-(b>>>0>d>>>0)|0;Qg(c+8|0);if(Fb(c+8|0,c)){continue}break}}if(!Lb(a)){Ox();L()}a=v[a>>2];v[a>>2]=f+v[a>>2]}gb=c+16|0}function fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=gb-112|0;gb=h;a:{if(!Od(a)){break a}if(Gc(b)>>>0<2){break a}f=Uo(h+8|0,a);v[f+20>>2]=0;v[f>>2]=0;c=Gc(b);b:{if(!c){break b}e=v[a>>2];while(1){d=Id(b,g);j=v[d>>2];if(e>>>0<=j>>>0){break b}d=v[d+4>>2];if(d>>>0>e-j>>>0|268435456-d>>>0<i>>>0){break b}i=d+i|0;v[f>>2]=i;g=g+1|0;if((c|0)!=(g|0)){continue}break}g=c}if(!Mm(f)){break a}if(g){c=0;e=0;while(1){d=Id(b,c);hc(zb(v[f+20>>2])+e|0,zb(v[a+20>>2])+v[d>>2]|0,v[d+4>>2]);v[d>>2]=e;if(!(!c|c>>>0>9)){v[((c<<2)+f|0)- -64>>2]=e}e=v[d+4>>2]+e|0;c=c+1|0;if((g|0)!=(c|0)){continue}break}}Al(a);Uo(a,f);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}gb=h+112|0}function dq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;f=d?d:465324;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[22953]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+77696>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[115529]=25;e=-1;break a}v[f>>2]=d}gb=h+16|0;return e|0}function st(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb-80|0;gb=b;c=v[a>>2];d=v[c+4>>2];v[b+40>>2]=v[c+20>>2];e=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=e;ak(b- -64|0,b+32|0,d);c=lf(b+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);d=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=a;a=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=a;v[b+8>>2]=v[c+8>>2];a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;g=b+16|0;a=b;if(d){while(1){c=0;if(e){while(1){h=Lm(fe(A[lj(a,c,f)>>3]*134217728));i=my(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((e|0)!=(c|0)){continue}break}}f=f+1|0;if((d|0)!=(f|0)){continue}break}}gb=b+80|0}function qN(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-48|0;gb=e;f=Jb(e+32|0);v[23048]=0;Q(1530,a|0,e+24|0)|0;d=v[23048];v[23048]=0;a:{b:{if((d|0)!=1){g=v[e+28>>2];d=v[e+24>>2];bf(f);v[23048]=0;g=!g&d>>>0<255?d:255;S(124,f|0,g|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=pc(f,d);v[23048]=0;Q(1531,a|0,h|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((GI(f)|0)!=-1){a=GI(f);v[23048]=0;S(124,f|0,a|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}}v[23048]=0;T(13,e+8|0,c|0,f|0);a=v[23048];v[23048]=0;if((a|0)!=1){break b}break a}break a}Eb(b,e+8|0);vb(e+8|0);vb(f);gb=e+48|0;return}a=P()|0;O()|0;vb(f);R(a|0);L()}function eA(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;a:{if(!d){break a}if(c){t[b+817|0]=c;break a}c=w[b+817|0]}c=v[a+480180>>2]&1048580?c&240?c&-16:c&15:c;b:{c:{d:{if(!(v[a+480180>>2]&1048580)){d=c&240;c=c&15;if(!(!d|(c|0)!=15)){if(!(w[a+480209|0]&16)){break b}c=0-(d>>>2|0)|0;break d}f=v[a+480208>>2]&4096;if(!(!c|(d|0)!=240)){if(!f){break b}c=c<<2;break c}if(f){break b}if(c){c=c<<2;if(!d|!(v[a+480180>>2]&16777248)){break c}break b}c=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}Db(e+8|0,a+1074308|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!Cb(e+8|0)){break d}c=(a|0)/4<<24>>24}if(!c){break b}}a=ac(v[b+692>>2]+c|0,0,256);u[b+786>>1]=0;v[b+692>>2]=a}gb=e+16|0}function Kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];g=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(g){a=v[a+20>>2];c=g;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);le(d+12|0,C(-1));e=C(z[d+12>>2]*C(32768));z[d+12>>2]=e;h=a;e=Fe(e);a:{if(C(D(e))<C(2147483648)){f=~~e;break a}f=-2147483648}i=h,j=Uc(f),u[i>>1]=j;v[d+12>>2]=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);le(d+12|0,C(-1));e=C(z[d+12>>2]*C(32768));z[d+12>>2]=e;h=a;e=Fe(e);b:{if(C(D(e))<C(2147483648)){f=~~e;break b}f=-2147483648}i=h,j=Uc(f),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return g<<3}function UP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=gb-112|0;gb=f;v[f+108>>2]=0;d=Cm(a,x[d+70>>1],v[d+48>>2],c,f+108|0);c=w[b+792|0];if(!v[f+108>>2]){e=!w[b+794|0]&(c|0)==15;d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}d=(e?0:w[b+838|0]<<16)+d|0}b:{if((c|0)!=15){break b}c=w[b+794|0];if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Jc(f,f+108|0)>>2]<<3;g=Fpa(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=jb;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=Xc(c,e);break b}aU(f,0);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[(c+(w[b+794|0]<<2)|0)- -64>>2]+d|0}Am(a,b,d);gb=f+112|0}function f2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=RF(v[v[a>>2]-12>>2]+a|0,10);e=gb-16|0;gb=e;v[23048]=0;c=a;d=Q(15,e+8|0,c|0)|0;b=v[23048];v[23048]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[d|0]){break e}b=Nj(e,c);v[23048]=0;Q(2247,b|0,f|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){if(!Yv(b)){break e}b=v[v[c>>2]-12>>2];v[23048]=0;S(18,b+c|0,1);b=v[23048];v[23048]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;dl(d);break d}dl(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;d=v[v[c>>2]-12>>2];v[23048]=0;_(19,c+d|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}$()}gb=e+16|0;break a}a=P()|0;O()|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}Vs(a);return a|0}function ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;SQ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;_b(c);gb=c+16|0;return}g=gb-32|0;gb=g;h=wb(a);i=g+8|0;j=a;f=xA(a)+1|0;d=gb-16|0;gb=d;v[d+12>>2]=f;e=gb-16|0;gb=e;v[e+12>>2]=613566756;v[23048]=0;v[e+8>>2]=2147483647;k=Gb(e+12|0,e+8|0);c=v[23048];v[23048]=0;a:{if((c|0)!=1){gb=e+16|0;c=v[k>>2];break a}V(0)|0;O()|0;Ab();L()}b:{if(c>>>0>=f>>>0){f=tA(j);if(f>>>0<c>>>1>>>0){v[d+8>>2]=f<<1;c=v[Jc(d+8|0,d+12|0)>>2]}gb=d+16|0;break b}Mc();L()}c=bR(i,c,xA(a),h);SQ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+7;$Q(a,c);_Q(c);gb=g+32|0}function cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-48|0;gb=d;a:{b:{if(v[a+8>>2]!=v[bc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];e=v[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>2)+1|0)/-2<<2;i=g,j=vg(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=d,j=v[bc(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[d+44>>2]=1;c=v[Jc(d+24|0,d+44|0)>>2];c=Ap(d+24|0,c,c>>>2|0,v[a+16>>2]);e=Cc(d+16|0,v[a+4>>2]);f=v[Cc(d+8|0,v[a+8>>2])>>2];e=v[e>>2];v[23048]=0;T(1108,c|0,e|0,f|0);e=v[23048];v[23048]=0;if((e|0)==1){break a}mc(a,c);mc(h,c+4|0);mc(g,c+8|0);mc(bc(a),bc(c));Ti(c)}$o(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;gb=d+48|0;return}a=P()|0;O()|0;Ti(c);R(a|0);L()}function z2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;c=gb-416|0;gb=c;v[c+12>>2]=c+416;d=gb-144|0;gb=d;v[d+28>>2]=d+132;lH(a+8|0,d+32|0,d+28|0,e,f,g);v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=d+32;f=c+16|0;h=RV(f,v[c+12>>2]);e=gb-16|0;gb=e;v[e+12>>2]=v[a+8>>2];g=ni(e+8|0,e+12|0);v[23048]=0;a=rx(f,d+12|0,h,d+16|0);h=v[23048];v[23048]=0;a:{if((h|0)!=1){jf(g);gb=e+16|0;break a}a=P()|0;O()|0;jf(g);R(a|0);L()}if((a|0)==-1){Es(84884);L()}v[c+12>>2]=f+(a<<2);gb=d+144|0;e=v[c+12>>2];a=gb-16|0;gb=a;v[a+8>>2]=b;d=c+16|0;if((e|0)!=(d|0)){while(1){fI(a+8|0,v[d>>2]);d=d+4|0;if((e|0)!=(d|0)){continue}break}b=v[a+8>>2]}gb=a+16|0;gb=c+416|0;return b|0}function Rna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb+-64|0;gb=c;a:{if(vr(a)){v[b>>2]=0;a=0;break a}DW(c+32|0,c+48|0);d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;fc(c+40|0,a,c+16|0);f=xb(c+40|0);d=zb(w[c+48|0]);e=d&127;v[b>>2]=e;g=d<<24>>24;h=(g|0)<0;d=1;e=e?32-E(e)|0:0;b:{if(f>>>0<2|(g|0)>-1){break b}while(1){h=zb(w[(c+48|0)+d|0]);v[b>>2]=h&127|v[b>>2]<<7;d=d+1|0;if((f|0)==(d|0)){Vb(a,f);DW(c+24|0,c+48|0);d=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=d;fc(c+40|0,a,c+8|0);f=xb(c+40|0);d=0}e=e+7|0;g=h<<24>>24;h=(g|0)<0;if((g|0)>-1){break b}if(d>>>0<f>>>0){continue}break}}Vb(a,d);if(e>>>0>=33){v[b>>2]=-1;a=0;break a}a=!h}gb=c- -64|0;return a|0}function $3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-32|0;gb=e;a:{if(GH(c)){while(1){if(a>>>d&1){j=(d<<2)+c|0,k=HH(d,b),v[j>>2]=k}d=d+1|0;if((d|0)!=6){continue}break}break a}while(1){i=(e+8|0)+(d<<2)|0;f=1<<d&a;g=v[(d<<2)+c>>2];b:{if(!(f|!c)){break b}g=HH(d,f?b:80187)}f=g;v[i>>2]=f;h=((f|0)!=0)+h|0;d=d+1|0;if((d|0)!=6){continue}break}c=75744;c:{d:{switch(h|0){case 0:break a;case 1:break d;default:break c}}if(v[e+8>>2]!=75716){break c}c=75768;break a}c=Ad(24);if(!c){break a}a=v[e+12>>2];v[c>>2]=v[e+8>>2];v[c+4>>2]=a;a=v[e+28>>2];v[c+16>>2]=v[e+24>>2];v[c+20>>2]=a;a=v[e+20>>2];v[c+8>>2]=v[e+16>>2];v[c+12>>2]=a}gb=e+32|0;return c|0}function iq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb-80|0;gb=b;c=v[a>>2];d=v[c+4>>2];v[b+40>>2]=v[c+20>>2];e=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=e;ak(b- -64|0,b+32|0,d);c=lf(b+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);d=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=a;a=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=a;v[b+8>>2]=v[c+8>>2];a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;g=b+16|0;a=b;if(d){while(1){c=0;if(e){while(1){h=v[xj(a,c,f)>>2];i=my(g,c,f),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((e|0)!=(c|0)){continue}break}}f=f+1|0;if((d|0)!=(f|0)){continue}break}}gb=b+80|0}function OJ(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=gb-16|0;gb=d;a:{b:{c:{d:{if((b|0)>=0){if((ao(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[23048]=0;d=Q(91,d|0,59689)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,d);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}if(!(c<=1?!(c<0):0)){a=aa(8)|0;v[23048]=0;d=Q(91,d|0,59667)|0;b=v[23048];v[23048]=0;if((b|0)!=1){rc(a,d);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=Ko(c*64);v[(v[a+32>>2]+B(b,880)|0)+1075732>>2]=e;gb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function Sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-608|0;gb=g;c=gb-32|0;gb=c;f=g+8|0;iV(c+24|0,f);e=xb(c+24|0);b=v[c+28>>2];d=v[c+24>>2];v[c+8>>2]=d;v[c+12>>2]=b;v[c>>2]=d;v[c+4>>2]=b;b=a;md(c+16|0,b,c);d=xb(c+16|0);if((d|0)==(e|0)){bd(b,xb(c+24|0))}gb=c+32|0;c=(d|0)==(e|0);if(!c){hV(f)}b=-1;a:{if(!c){break a}b=0;if(!rV(g+8|0)){break a}b=-1;if(!Qf(a,1024)){break a}b=0;e=gb-1024|0;gb=e;c=gb-32|0;gb=c;SB(c+24|0,e);f=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(f|0)){bd(a,xb(c+24|0))}gb=c+32|0;if((d|0)==(f|0)){b=UB(e,0)>>>0<17}gb=e+1024|0}gb=g+608|0;return b|0}function pd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=v[a+112>>2];d=v[a+116>>2];b:{if(c|d){b=c>>>0<=y[a+120>>2];c=v[a+124>>2];if((d|0)<(c|0)?1:(d|0)<=(c|0)?b:0){break b}}g=Kx(a);if((g|0)>-1){break a}}v[a+104>>2]=0;return-1}h=a;b=v[a+116>>2];i=b;d=v[a+8>>2];c=d;f=v[a+112>>2];c:{if(!(b|f)){break c}c=d;e=v[a+120>>2]^-1;f=e+f|0;b=(v[a+124>>2]^-1)+i|0;b=f>>>0<e>>>0?b+1|0:b;i=v[a+4>>2];e=d-i|0;j=f>>>0>=e>>>0;e=e>>31;if((b|0)>(e|0)?1:(e|0)<=(b|0)?j:0){break c}c=f+i|0}v[h+104>>2]=c;h=v[a+4>>2];if(d){c=a;b=(d-h|0)+1|0;d=b+v[a+120>>2]|0;a=v[a+124>>2]+(b>>31)|0;v[c+120>>2]=d;v[c+124>>2]=d>>>0<b>>>0?a+1|0:a}a=h-1|0;if(w[a|0]!=(g|0)){t[a|0]=g}return g}function Cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];g=v[a+4>>2];f=g;b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;gb=e+32|0}function hn(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;j=1;i=d&2147483647;m=i;k=c;a:{if(!c&(i|0)==2147418112?a|b:(i|0)==2147418112&(c|0)!=0|i>>>0>2147418112){break a}l=h&2147483647;n=l;i=g;if(!g&(l|0)==2147418112?e|f:(l|0)==2147418112&(g|0)!=0|l>>>0>2147418112){break a}if(!(a|e|(i|k)|(b|f|(m|n)))){return 0}k=d&h;if((k|0)>0?1:(k|0)>=0){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:(d|0)<(h|0)?1:(d|0)<=(h|0)?c>>>0<g>>>0:0){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:(d|0)>(h|0)?1:(d|0)>=(h|0)?c>>>0>g>>>0:0){break a}j=(a^e|c^g)!=0|(b^f|d^h)!=0}return j}function WI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;d=1;a:{b:{switch(b-a>>2){case 2:b=b-4|0;if(!Nd(b,a)){break a}mc(a,b);break a;case 3:Un(a,a+4|0,b-4|0);break a;case 4:Qx(a,a+4|0,a+8|0,b-4|0);break a;case 5:Px(a,a+4|0,a+8|0,a+12|0,b-4|0);break a;case 0:case 1:break a;default:break b}}e=a+8|0;Un(a,a+4|0,e);c=a+12|0;if((c|0)==(b|0)){break a}c:{while(1){g=c;if(Nd(c,e)){v[f+12>>2]=v[g>>2];d=g;while(1){d:{c=e;v[d>>2]=v[c>>2];if((a|0)==(c|0)){c=a;break d}d=c;e=c-4|0;if(Nd(f+12|0,e)){continue}}break}v[c>>2]=v[f+12>>2];h=h+1|0;if((h|0)==8){break c}}e=g;c=g+4|0;if((c|0)!=(b|0)){continue}break}d=1;break a}d=(g+4|0)==(b|0)}gb=f+16|0;return d}function Mka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;wd(b,0);MC(d,a+1|0);Fc(d+16|0,d);v[23048]=0;Q(355,b+43|0,d+16|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){vb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;tc(b+8|0,v[b>>2]);tc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}function Lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{d=gb-16|0;gb=d;c=b;wb(b);e=a;h=zN(a,d+8|0);b:{f=zg(b);if(!f){break b}v[23048]=0;S(659,e|0,f|0);g=v[23048];v[23048]=0;if((g|0)!=1){g=v[c+4>>2];c=v[c>>2];v[23048]=0;Y(1510,e|0,c|0,g|0,f|0);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}a=P()|0;O()|0;qv(h);R(a|0);L()}gb=d+16|0;v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[23048]=0;c=Q(1509,a+24|0,b+24|0)|0;d=v[23048];v[23048]=0;c:{d:{if((d|0)!=1){v[23048]=0;Q(119,a+36|0,b+36|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}v[a+48>>2]=v[b+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Qc(c)}_m(e);R(a|0);L()}}function XA(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+800|0]=0;return}t[a+800|0]=1;return}t[a+800|0]=2;return}t[a+800|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function wV(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0;while(1){k=x[sc(b,g)>>1];l=k+1|0;m=(h&65535)>>>0>k>>>0|k>>>0>127;i=m?i:c>>>0>g>>>0?l:i;j=(j&65535)>>>0>k>>>0?j:l;h=m?h:l;g=g+1|0;if((g|0)!=128){continue}break}Cf(b,c);c=v[a+8>>2];a:{b:{if(!f){break b}g=h&65535;if((c+((g<<11)+f|0)|0)!=(Pk(a)&-2)){break b}Rc(a,c+(g<<10)|0);if(XB(a,16,1)){u[e>>1]=8}Rc(a,c);break a}g=i&65535;if((g|0)==(h&65535)){h=i;break a}if(x[e>>1]!=4|f){break a}Rc(a,c+(g<<10)|0);f=XB(a,64,1);Rc(a,c);h=f?h:i}f=j&65535;c:{if(f>>>0>(h&65535)>>>0){if(((c+d|0)+(B(f,x[e>>1])<<8)|0)==(Pk(a)|0)){break c}}if(f>>>0>=255){fv(b,254,65534);fv(b,255,65535)}j=h}return j&65535}function V_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-32|0;gb=c;a:{b:{c:{d:{if(!(i=!hd(b),j=0,k=v[b+12>>2],k?i:j)){Jb(a);break d}f=gb-16|0;gb=f;e=Jb(c+16|0);d=Bb(b);g=Lf(11214);h=Ob(b);v[23048]=0;Y(186,e|0,h|0,d|0,d+g|0);d=v[23048];v[23048]=0;e:{if((d|0)!=1){v[23048]=0;W(187,e|0,11214,g|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;vb(e);R(a|0);L()}gb=f+16|0;v[23048]=0;S(221,c|0,b+12|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;T(3,a|0,c+16|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}vb(c);vb(c+16|0)}gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(c+16|0);R(b|0);L()}function Dw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=gb-32|0;gb=i;f=v[b+4>>2];d=i;b=v[b>>2];v[d+8>>2]=b;v[d+12>>2]=f;v[d+16>>2]=b;v[d+20>>2]=f;Ch(d+24|0,d+8|0);b=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=b;f=gb-16|0;gb=f;e=v[d+4>>2];b=f;d=v[d>>2];v[b>>2]=d;v[b+4>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;d=a;e=gb-16|0;gb=e;j=e+8|0;g=gb-48|0;gb=g;h=ms(g+24|0,jc(24,4),_c(g+16|0,g+40|0,1));k=v[h>>2];v[23048]=0;Q(266,k|0,b|0)|0;b=v[23048];v[23048]=0;a:{if((b|0)!=1){yw(j,bc(v[h>>2]),Bd(h));LF(h);gb=g+48|0;break a}a=P()|0;O()|0;LF(h);R(a|0);L()}Uj(d,e+8|0);Bc(e+8|0);gb=e+16|0;gb=f+16|0;v[a+8>>2]=0;Xi(a+12|0,c);gb=i+32|0;return a|0}function ih(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);d=_L(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));f=z[a+4268>>2];e=re(C(10),C(C(C(v[((b<<2)+a|0)+4292>>2])*C(-3))/C(C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612))*f)));c=C(C(re(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Tp(c>C(1)?C(3.1415927410125732):C(C(d*C(6.2831854820251465))/f))));a:{if(c==C(0)){break a}f=C(c+c);d=C(C(-2)-f);c=C(K(C(C(d*d)+C(C(c*c)*C(-4)))));g=C(C(c-d)/f);if(C(D(g))<=C(1)){break a}g=C(C(-C(c+d))/f)}b=(b<<3)+a|0;z[b+4404>>2]=g;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(C(C(C(d*d)*e)/C(C(1)-C(c*e)))+c)}function nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{d=gb+-64|0;gb=d;e=v[a+28>>2];bp(v[v[e>>2]-12>>2]+e|0,0);e=v[v[b>>2]+4>>2];if(e){h=v[a+28>>2];f=v[a+12>>2];g=e;e=v[a+8>>2]+e|0;f=g>>>0>e>>>0?f+1|0:f;e=ph(d+48|0,e,f);f=v[e+12>>2];v[d+16>>2]=v[e+8>>2];v[d+20>>2]=f;g=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=g;Xj(h,d+8|0)}we(d+24|0,v[a+28>>2]);e=v[d+36>>2];v[d+40>>2]=v[d+32>>2];v[d+44>>2]=e;oS(v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];b=En(d+24|0,oc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[23048]=0;ba(1539,a|0,c|0,b|0,d+40|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){Hb(b);gb=d- -64|0;break a}a=P()|0;O()|0;Hb(b);R(a|0);L()}}function ko(a,b,c){var d=0,e=0,f=0;d=Jb(a);a=Bb(b);v[23048]=0;S(111,d|0,a|0);a=v[23048];v[23048]=0;if((a|0)!=1){a:{if(Bb(b)){while(1){f=v[ck(b,e)>>2];a=32;b:{while(1){if(v[(a<<2)+c>>2]==(f|0)){v[23048]=0;S(110,d|0,a<<24>>24);a=v[23048];v[23048]=0;if((a|0)!=1){break b}break a}a=a+1|0;if((a|0)!=256){continue}break}a=0;while(1){if(v[(a<<2)+c>>2]==(f|0)){v[23048]=0;S(110,d|0,a<<24>>24);a=v[23048];v[23048]=0;if((a|0)!=1){break b}break a}a=a+1|0;if((a|0)!=32){continue}break}v[23048]=0;S(110,d|0,63);a=v[23048];v[23048]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Bb(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;vb(d);R(a|0);L()}function Dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=e+l|0;e=t[k|0];h=v[a+28>>2]+h|0;f=h>>12;e=((B(t[k+1|0]-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function bU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=b,g=Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)),v[f>>2]=g;t[d+15|0]=w[a+4|0];t[d+14|0]=64;f=b,g=w[$b(d+15|0,d+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;f=b,g=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),v[f+4>>2]=g;a=a+10|0;a=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0;v[b+8>>2]=a;e=v[b+4>>2];c=v[b>>2];if(e>>>0>=c>>>0){e=c-1|0;v[b+4>>2]=e}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<e>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=e>>>0){break a}v[b+68>>2]=e;u[b+34>>1]=x[b+34>>1]|2}gb=d+16|0}function oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];bp(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){h=v[a+28>>2];g=v[a+12>>2];f=v[a+8>>2]+d|0;g=f>>>0<d>>>0?g+1|0:g;f=ph(e+40|0,f,g);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;Xj(h,e)}we(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;qN(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=En(e+16|0,oc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[23048]=0;ba(1539,a|0,c|0,b|0,e+32|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);R(a|0);L()}function mfa(a){a=a|0;var b=0,c=0,d=0;c=a+1300264|0;b=a+1074984|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+880|0;if((c|0)!=(b|0)){continue}break}IN(a+484344|0);bf(a+1300308|0);bf(a+1300320|0);bf(a+1300332|0);dD(a+1300408|0);c=a+900380|0;b=a+484380|0;while(1){Al(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Zb(mv(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){GM(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];bp(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){h=v[a+28>>2];g=v[a+12>>2];f=v[a+8>>2]+d|0;g=f>>>0<d>>>0?g+1|0:g;f=ph(e+40|0,f,g);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;Xj(h,e)}we(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;hN(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=En(e+16|0,oc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[23048]=0;ba(1539,a|0,c|0,b|0,e+32|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);R(a|0);L()}function cl(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!w[$j(e+8|0,a,1)|0]){break c}d=v[v[a>>2]-12>>2];v[23048]=0;d=v[(a+d|0)+24>>2];f=v[23048];v[23048]=0;d:{if((f|0)==1){break d}v[23048]=0;b=W(2238,d|0,b|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;Z(b|0)|0;d=1;Yj(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23048]=0;X(1324);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)==1){break b}R(a|0);L()}$()}uh(v[v[a>>2]-12>>2]+a|0,d);gb=e+16|0;return}V(0)|0;O()|0;Ab()}L()}function Aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];h=v[a+28>>2]+h|0;f=h>>12;e=e+((B(u[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function cY(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;h=B(0-c|0,6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}c=i;a=w[(a+h|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function Noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-32|0;gb=d;wd(b,0);Pj(d,1,a);Fc(d+16|0,d);v[23048]=0;Q(355,b+43|0,d+16|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){vb(d+16|0);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;e=b,f=w[$b(d+16|0,d)|0]<<2,u[e+30>>1]=f;gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}function $F(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Ob(b);g=Bb(b);i=Ob(c);j=Bb(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(vp(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=Ld(b),v[k+32>>2]=l;c=Sd(e+40|0,e+32|0);k=e,l=Ld(b),v[k+8>>2]=l;k=e,l=Ne(e+8|0,h),v[k+16>>2]=l;d=Sd(e+24|0,e+16|0);fG(b,v[c>>2],v[d>>2]);break c}if(!Bb(b)){break c}f=Ob(b);h=Bb(b);g=Ob(c);d=-1;i=Bb(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!vp(g,i,c)){continue}break}d=c-f|0}}if((Bb(b)-1|0)!=(d|0)){break c}Jb(a);break b}Dc(a,b)}gb=e+48|0}function Pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;g=u[f+2>>1];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+B(e,u[f>>1]);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(g,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function bZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Ig(a,d+8|0)){v[d+4>>2]=w[d+8|0];e=v[Gb(d+4|0,d+12|0)>>2];c=gb+-64|0;gb=c;Ue(c+40|0,a,e);a=v[c+40>>2];v[23048]=0;e=Wd(c+40|0);f=v[23048];v[23048]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[23048]=0;Xe(c+8|0,3,e,a);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;S(398,c+24|0,c+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}_c(c,b,11);v[23048]=0;Q(450,c|0,c+24|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}vb(c+24|0);Ac(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}Ac(c+40|0);R(a|0);L()}}gb=d+16|0}function JA(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;h=zl(a,b);a:{if((h|0)==255){break a}if(ok(a)){break a}b:{if(c>>>0>6208431){i=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}i=f;c=Fpa(1<<20-f,0,c,0)+24858e3|0;f=jb;c=Xc(Ipa(c,c>>>0<24858e3?f+1|0:f,49716e3,0),jb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Vc(g+14|0,g+12|0)>>1]}e=Bu(h);b=lc(a+4|0,h);t[b|0]=(i<<10|c)>>>8|(d?0:32);Rh(v[a>>2],e|160,c&255);Rh(v[a>>2],e|176,w[b|0]);t[a+530|0]=1}gb=g+16|0}function KJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=gb-16|0;gb=e;a:{b:{c:{d=a+8|0;d:{if(!kl(d)){if((b|0)<0|(kq(d)|0)<=(b|0)){break d}a=El(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=kl(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}b=aa(8)|0;v[23048]=0;c=Q(91,e|0,59705)|0;a=v[23048];v[23048]=0;e:{if((a|0)!=1){rc(b,c);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;ca(b|0)}R(a|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}gb=e+16|0;return}L()}function JI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;gb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[22953]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+77696>>2];if(d<<B(c,6)-6<0?c>>>0<=3:0){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[115529]=25;e=-1}return e|0}function CP(a,b,c){var d=0,e=0;a:{if(v[a+480180>>2]==4){d=w[b+816|0];if(c){t[b+816|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}b:{if(!(t[b+853|0]&1)|!(c&255)){break b}d=v[b+700>>2];if(!d){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}e=b;a=uP(a,c&15);b=Fpa(a,a>>31,d,d>>31)+32768|0;a=jb;a=vc(Gpa(b,b>>>0<32768?a+1|0:a,65536,0),jb);v[e+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}}function gJ(a,b,c,d,e){var f=0,g=0,h=0;f=gb-208|0;gb=f;v[f+204>>2]=c;Pb(f+160|0,0,40);v[f+200>>2]=v[f+204>>2];a:{if((Wx(0,b,f+200|0,f+80|0,f+160|0,d,e)|0)<0){b=-1;break a}g=v[a+76>>2]>=0;c=v[a>>2];if(t[a+74|0]<=0){v[a>>2]=c&-33}h=c&32;b:{if(v[a+48>>2]){b=Wx(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}v[a+48>>2]=80;v[a+16>>2]=f+80;v[a+28>>2]=f;v[a+20>>2]=f;c=v[a+44>>2];v[a+44>>2]=f;d=Wx(a,b,f+200|0,f+80|0,f+160|0,d,e);b=d;if(!c){break b}kb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=c;v[a+28>>2]=0;v[a+16>>2]=0;b=v[a+20>>2];v[a+20>>2]=0;b=b?d:-1}c=a;a=v[a>>2];v[c>>2]=a|h;b=a&32?-1:b;if(!g){break a}}gb=f+208|0;return b}function aoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;t[d+16|0]=44;v[d+8>>2]=-1;v[d+12>>2]=0;v[d>>2]=1042;v[d+4>>2]=2;e=a;a=gb-16|0;gb=a;f=a;c=gb-48|0;gb=c;g=d;yL(c,b,v[d>>2]&2?16:10);Et(c+16|0,c,d);v[23048]=0;T(139,c+32|0,c+16|0,d|0);b=v[23048];v[23048]=0;a:{b:{c:{if((b|0)!=1){v[23048]=0;T(140,f|0,c+32|0,g|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}vb(c+32|0);vb(c+16|0);vb(c);gb=c+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);vb(c);R(a|0);L()}v[23048]=0;T(13,e|0,0,a|0);b=v[23048];v[23048]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);R(b|0);L()}gb=d+32|0}function q$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;l=gb-32|0;gb=l;n=v[c>>2];m=v[c+8>>2];k=l;c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=m;v[k+24>>2]=c;v[k+28>>2]=m;v[k+20>>2]=n;v[k+16>>2]=d;v[23048]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ja(1936,a|0,b|0,k|0)|0;b=v[23048];v[23048]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;ia(1931,52684,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}$();a=-255}gb=l+32|0;break a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+k|0;g=t[f+1|0];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+(B(e,t[f|0])<<8);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+(B(g,j)<<8);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function oJ(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(Pe(a)){ec(a,31);return 0}f=a,g=Pe(a),t[f+1375|0]=g;e=jj(a);b=jj(a);jj(a);f=a,g=jj(a),v[f+1112>>2]=g;jj(a);c=Pe(a);v[a+1116>>2]=c;if(!ay(a,a+1120|0,c)){ec(a,10);return 0}v[a+1404>>2]=-2;a:{if((b|0)==-1?(e|0)==-1:0){break a}b=v[a+1116>>2];while(1){if((b|0)<1){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=e;v[a+1404>>2]=b}if(w[a+1377|0]){c=0;d=v[a+1116>>2];b:{if((d|0)>0){b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}b=(c+d|0)+27|0;break b}b=d+27|0}v[a- -64>>2]=e;v[a+60>>2]=b+v[a+56>>2]}v[a+1380>>2]=0;return 1}function J_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=gb-32|0;gb=b;c=gb-32|0;gb=c;e=b+16|0;FF(c+24|0,e);g=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;md(c+16|0,d,c);f=xb(c+16|0);if((g|0)==(f|0)){bd(d,xb(c+24|0))}gb=c+32|0;c=(g|0)==(f|0);if(!c){EF(e)}d=-1;a:{if(!c){break a}d=0;if(!XF(b+16|0)){break a}c=gb-32|0;gb=c;d=b;DF(c+24|0,d);g=xb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;md(c+16|0,a,c);e=xb(c+16|0);if((e|0)==(g|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(e|0)==(g|0);if(!a){xw(d)}d=-1;if(!a){break a}d=WF(b)}gb=b+32|0;return d|0}function i9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;v[23048]=0;_(1943,a|0);d=v[23048];v[23048]=0;a:{b:{c:{if((d|0)==1){break c}v[23048]=0;_(1969,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break c}d=v[a+24>>2];b=wc(c+8|0,b);v[23048]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;Y(2008,c+16|0,d|0,c|0,1);b=v[23048];v[23048]=0;if((b|0)==1){break c}b=ie(Ob(c+16|0));vb(c+16|0);break b}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[23048]=0;Y(1920,55051,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}gb=c+32|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Lj(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/48>>>0){e=gb-16|0;gb=e;b=YX(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(a);GW(v[b+4>>2]);c=v[b+4>>2]+48|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}_b(b);gb=e+16|0;break c}b=wb(a);b=WX(d+8|0,XX(a,Lj(a)+c|0),Lj(a),b);v[23048]=0;HW(b,c);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(529,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Av(b)}gb=d+32|0;break a}a=P()|0;O()|0;Av(b);R(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Lj(a);ZX(a,b);fY(a)}}function o$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[23048]=0;_(1943,a|0);f=v[23048];v[23048]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[23048]=0;_(1969,b|0);f=v[23048];v[23048]=0;if((f|0)==1){break d}f=v[a+24>>2];b=wc(e+8|0,b);v[23048]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ha(2011,f|0,e|0,c|0,d|0,1);c=v[23048];v[23048]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55133,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break b}$();b=0}gb=e+16|0;break a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}return b|0}function Bna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-48|0;gb=c;d=c+24|0;f=nc(d+8|0);v[23048]=0;e=U(511,b|0)|0;g=v[23048];v[23048]=0;a:{b:{if((g|0)==1){break b}v[23048]=0;T(404,d|0,b|0,e|0);e=v[23048];v[23048]=0;if((e|0)==1){break b}d=v[d>>2];v[23048]=0;Q(370,b|0,d|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;gc(f);R(a|0);L()}v[23048]=0;Qr(c+16|0,c+24|0);b=v[23048];v[23048]=0;c:{if((b|0)==1){break c}v[23048]=0;b=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=b;S(681,a|0,c+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}Ac(c+24|0);gb=c+48|0;return}a=P()|0;O()|0;Ac(c+24|0);R(a|0);L()}function QM(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;Ry(a);le(d+12|0,C(0));a:{b:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];Rt(a);break a;case 3:t[a+4240|0]=z[d+12>>2]>=C(.5);Rt(a);break a;case 4:b=a;a=Bi(C(z[d+12>>2]*C(32)));v[b+4232>>2]=(a|0)<5?a:5;gb=d+16|0;return;case 5:t[a+4241|0]=z[d+12>>2]>=C(.5);break a;case 6:t[a+4242|0]=z[d+12>>2]>=C(.5);break a;case 7:t[a+4244|0]=z[d+12>>2]>=C(.5);break a;case 8:break b;default:break a}}b=a;c=z[d+12>>2];if(c==C(0)){Oy(a);c=z[d+12>>2]}A[b+4256>>3]=c}gb=d+16|0}function $j(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;t[a|0]=0;f=Sf(v[v[b>>2]-12>>2]+b|0);d=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){d=v[d+72>>2];if(d){Vs(d)}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}Ic(e+24|0,v[v[b>>2]-12>>2]+b|0);v[23048]=0;f=U(21,e+24|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}Xb(e+24|0);c=Nj(e+16|0,b);d=yk(e+8|0);d:{if(!_j(c,d)){break d}while(1){if(!fh(f,8192,fl(c))){break d}el(c);if(_j(c,d)){continue}break}}if(!Zj(c,d)){break c}uh(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=Sf(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}uh(d,4)}gb=e+32|0;return a}a=P()|0;O()|0;Xb(e+24|0);R(a|0);L()}function Pja(a,b){a=a|0;b=b|0;var c=0,d=0;c=Jg(a);a:{if(b){v[23048]=0;S(970,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=gb-16|0;gb=d;c=Nu(d,a,b);b=v[c+4>>2];if((b|0)!=v[c+8>>2]){while(1){v[b>>2]=0;v[b+4>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v[b+28>>2]=0;t[b+21|0]=64;t[b+19|0]=64;t[b+20|0]=100;u[b+22>>1]=0;u[b+24>>1]=0;t[b+15|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;v[b+8>>2]=0;v[b+12>>2]=0;t[b+26|0]=0;b=v[c+4>>2]+32|0;v[c+4>>2]=b;if(v[c+8>>2]!=(b|0)){continue}break}}_b(c);gb=d+16|0}return a|0}a=P()|0;O()|0;vB(c);R(a|0);L()}function wka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=gb-80|0;gb=f;Di(f+40|0,f+32|0,c);v[23048]=0;c=f+52|0;T(228,c|0,f+24|0,d|0);d=v[23048];v[23048]=0;b:{c:{if((d|0)!=1){d:{v[23048]=0;c=f- -64|0;T(213,c|0,f+16|0,e|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;qs(f+8|0,f+40|0);c=v[23048];v[23048]=0;if((c|0)==1){break c}v[23048]=0;c=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=c;T(78,a|0,b|0,f|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}Qk(f+40|0);gb=f+80|0;break a}}a=P()|0;O()|0;while(1){c=vb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break b}a=P()|0;O()|0;Qk(f+40|0)}R(a|0);L()}}function o2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=fH(b);Zk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Yk(k,a);$i(i,k);Pc(k);Ih(k,a);$i(h,k);Pc(k);l=d,m=dj(a),v[l>>2]=m;l=e,m=cj(a),v[l>>2]=m;Mg(k,a);Eb(f,k);vb(k);Jh(k,a);$i(g,k);Pc(k);a=Xk(a);break a}a=eH(b);Zk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Yk(k,a);$i(i,k);Pc(k);Ih(k,a);$i(h,k);Pc(k);l=d,m=dj(a),v[l>>2]=m;l=e,m=cj(a),v[l>>2]=m;Mg(k,a);Eb(f,k);vb(k);Jh(k,a);$i(g,k);Pc(k);a=Xk(a)}v[j>>2]=a;gb=k+16|0}function boa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=gb-80|0;gb=f;Di(f+40|0,f+32|0,c);v[23048]=0;c=f+52|0;T(213,c|0,f+24|0,d|0);d=v[23048];v[23048]=0;b:{c:{if((d|0)!=1){d:{v[23048]=0;c=f- -64|0;T(213,c|0,f+16|0,e|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;qs(f+8|0,f+40|0);c=v[23048];v[23048]=0;if((c|0)==1){break c}v[23048]=0;c=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=c;T(78,a|0,b|0,f|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}Qk(f+40|0);gb=f+80|0;break a}}a=P()|0;O()|0;while(1){c=vb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break b}a=P()|0;O()|0;Qk(f+40|0)}R(a|0);L()}}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=ti(a,b,c,d);v[a>>2]=46552;c=nc(a+4208|0);v[a+4236>>2]=2147483647;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Pb(a+4248|0,0,48);v[23048]=0;d=fa(1307)|0;e=v[23048];v[23048]=0;a:{if((e|0)==1){break a}v[23048]=0;d=U(1308,d|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break a}v[a+4296>>2]=d;Rt(a);Ot(a);v[23048]=0;W(1545,a+44|0,2,2)|0;d=v[23048];v[23048]=0;if((d|0)==1){break a}v[23048]=0;Oh(b);d=v[23048];v[23048]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;gc(c);nf(b);R(a|0);L()}function ti(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=46784;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;g=dd(b);e=dd(b+12|0);f=dd(b+24|0);d=dd(b+36|0);v[23048]=0;W(1545,b|0,2,0)|0;b=v[23048];v[23048]=0;if((b|0)==1){a=P()|0;O()|0;Qc(d);Qc(f);Nt(e);Nt(g);R(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;b=0;u[a+4204>>1]=0;v[c>>2]=a+99&-8;f=v[a+20>>2];e=v[a+16>>2];if((f|0)!=(e+906300|0)){d=a+4200|0;while(1){a:{c=b+1|0;if(b>>>0>247){break a}b=c;if((f|0)!=((e+B(b,160)|0)+906300|0)){continue}}break}t[d|0]=c}return a}function Q_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=gb-80|0;gb=f;Bn(f+40|0,f+32|0,c);v[23048]=0;c=f+52|0;T(228,c|0,f+24|0,d|0);d=v[23048];v[23048]=0;b:{c:{if((d|0)!=1){d:{v[23048]=0;c=f- -64|0;T(228,c|0,f+16|0,e|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;qs(f+8|0,f+40|0);c=v[23048];v[23048]=0;if((c|0)==1){break c}v[23048]=0;c=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=c;T(78,a|0,b|0,f|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}Qk(f+40|0);gb=f+80|0;break a}}a=P()|0;O()|0;while(1){c=vb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break b}a=P()|0;O()|0;Qk(f+40|0)}R(a|0);L()}}function Yea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}HS(g+16|0,b);i=g,j=lC(g+16|0),v[i+8>>2]=j;i=g,j=rh(g+16|0),v[i>>2]=j;while(1){b:{v[23048]=0;b=Nl(g+8|0,g);h=v[23048];v[23048]=0;if((h|0)==1){break b}if(!b){pr(g+16|0);break a}v[23048]=0;b=Kl(g+8|0);h=v[23048];v[23048]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Fj(g+8|0);continue}break}a=P()|0;O()|0;pr(g+16|0);R(a|0);L()}gb=g+32|0}function JC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Eg(b,Gd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Lb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Le(e+14|0,e+12|0)>>1];u[e+14>>1]=g;h=Mb(b,d),i=g,u[h>>1]=i;u[e+14>>1]=x[e+14>>1]+1;c=c+162|0;v[e+8>>2]=(w[c|0]|w[c+1|0]<<8)>>>f;v[e+4>>2]=64;c=v[sd(e+8|0,e+4|0)>>2];h=Mb(b,d),i=c,t[h+2|0]=i;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}gb=e+16|0}function w2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=iH(b);Zk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Yk(k,a);Eb(i,k);vb(k);Ih(k,a);Eb(h,k);vb(k);l=d,m=dj(a),t[l|0]=m;l=e,m=cj(a),t[l|0]=m;Mg(k,a);Eb(f,k);vb(k);Jh(k,a);Eb(g,k);vb(k);a=Xk(a);break a}a=hH(b);Zk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Yk(k,a);Eb(i,k);vb(k);Ih(k,a);Eb(h,k);vb(k);l=d,m=dj(a),t[l|0]=m;l=e,m=cj(a),t[l|0]=m;Mg(k,a);Eb(f,k);vb(k);Jh(k,a);Eb(g,k);vb(k);a=Xk(a)}v[j>>2]=a;gb=k+16|0}function vR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-32|0;gb=d;k=d,l=qk(b),v[k+16>>2]=l;c=gb-32|0;gb=c;h=lR(a,c+28|0,b);b=v[h>>2];t[c+27|0]=0;if(!b){f=gb-16|0;gb=f;b=dc(a);g=Wh(c+8|0,kR(),Ij(f+8|0,b));b=v[g>>2];v[23048]=0;b=b+16|0;e=v[23048];v[23048]=0;a:{if((e|0)!=1){e=gb-16|0;gb=e;v[e+8>>2]=v[d+16>>2];i=v[e+8>>2];j=v[i+4>>2];v[b>>2]=v[i>>2];v[b+4>>2]=j;dd(b+8|0);gb=e+16|0;k=dc(g),l=1,t[k+4|0]=l;gb=f+16|0;break a}a=P()|0;O()|0;zA(g);R(a|0);L()}tk(a,v[c+28>>2],h,v[c+8>>2]);b=Bd(c+8|0);t[c+27|0]=1;zA(c+8|0)}Xh(d+24|0,Cc(c+8|0,b),c+27|0);gb=c+32|0;a=se(d+24|0);gb=d+32|0;return a+8|0}function ot(a,b,c){var d=0,e=0;d=a,e=kj(C(C(C(C(C(C(C(C(C(z[c+3328>>2]+z[c+256>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+2816>>2]+z[c+768>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+2304>>2]+z[c+1280>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489)))+C(z[c+1792>>2]*C(75038)))),u[d>>1]=e;d=(b<<5)+a|0,e=kj(C(C(C(C(C(C(C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function YW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;e=Wd(d+40|0);f=v[23048];v[23048]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[23048]=0;Xe(d+8|0,2,e,a);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;Ye(d,b);b=v[23048];v[23048]=0;if((b|0)==1){break c}v[23048]=0;Q(450,d|0,d+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}vb(d+24|0);Ac(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}Ac(d+40|0);R(a|0);L()}return a|0}function _fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;cc(c+24|0,b,24);gb=d+16|0;d=xb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;fc(c+16|0,a,c);e=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function p$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23048]=0;_(1969,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break d}c=v[a+24>>2];e=wc(d+8|0,b);v[23048]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=vG(c,d,1);e=v[23048];v[23048]=0;c=jb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54983,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break b}$();b=0;c=0}gb=d+16|0;a=c;break a}b=P()|0;O()|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)!=1){R(b|0);L()}V(0)|0;O()|0;Ab();L()}ma(a|0);return b|0}function Sg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb+-64|0;gb=e;a:{b:{if(c-1>>>0>1023){break b}if(oe(a,b)){break b}c:{d:{if(Nf(a)>>>0<=b>>>0){d=$y(e+8|0,a);v[23048]=0;T(1503,a|0,b+1|0,d|0);f=v[23048];v[23048]=0;if((f|0)==1){break d}xm(d)}d=ef(a,b);v[23048]=0;Q(1504,d|0,c|0)|0;c=v[23048];v[23048]=0;e:{if((c|0)!=1){c=ef(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=ef(a,b);v[23048]=0;_(1505,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){break e}}a=V(90496)|0;b=O()|0;break c}g=ai(ef(a,b));break b}a=V(90496)|0;b=O()|0;xm(d)}if((da(90496)|0)!=(b|0)){break a}Z(a|0)|0;$()}gb=e- -64|0;return g|0}R(a|0);L()}function v5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-16|0;gb=c;v[c+12>>2]=b;a:{b:{c:{if(b>>>0<=1073741807){f=Zs(a);h=c,i=Bb(a),v[h+8>>2]=i;b=v[Jc(c+12|0,c+8|0)>>2];v[c+12>>2]=b;d=Qn(b);v[c+12>>2]=d;if((d|0)==(f|0)){break a}g=1;if((d|0)==1){b=a;e=v[a>>2];break b}b=v[c+12>>2]+1|0;if(d>>>0>f>>>0){b=om(b);break c}v[23048]=0;b=Q(2225,a|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}Og();L()}g=$e(a);e=Ob(a)}ej(b,e,Bb(a)+1|0);if(g){Ph(a,e,f+1|0)}d:{if((d|0)!=1){ch(a,v[c+12>>2]+1|0);Ae(a,v[c+8>>2]);_e(a,b);break d}Gf(a,v[c+8>>2])}}gb=c+16|0}function kD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-16|0;gb=c;v[c+12>>2]=b;a:{b:{c:{if(b>>>0<=4294967279){f=Nc(a);h=c,i=Bb(a),v[h+8>>2]=i;b=v[Jc(c+12|0,c+8|0)>>2];v[c+12>>2]=b;d=$l(b);v[c+12>>2]=d;if((d|0)==(f|0)){break a}if((d|0)==10){g=1;b=a;e=v[a>>2];break b}b=v[c+12>>2]+1|0;if(d>>>0>f>>>0){b=Tj(b);break c}v[23048]=0;b=Q(34,a|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}Og();L()}g=$e(a);e=Ob(a)}fi(b,e,Bb(a)+1|0);if(g){Rk(a,e,f+1|0)}d:{if((d|0)!=10){ch(a,v[c+12>>2]+1|0);Ae(a,v[c+8>>2]);_e(a,b);break d}Gf(a,v[c+8>>2])}}gb=c+16|0}function g9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[23048]=0;_(1943,a|0);e=v[23048];v[23048]=0;a:{b:{c:{if((e|0)==1){break c}v[23048]=0;_(1969,b|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}e=v[a+24>>2];b=wc(d+8|0,b);v[23048]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;Y(2010,e|0,d|0,(c|0)!=0|0,1);c=v[23048];v[23048]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55102,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-16|0;gb=d;b=x[b>>1];e=d;f=x[a+30>>1];if(f){b=mo(b<<16>>16,f<<16>>16)}u[e+14>>1]=b;a:{if(!hd(c)){Np(uN(a+52|0,d+14|0),c);break a}a=a+52|0;b=Yy(a,d+14|0);v[d+8>>2]=b;l=d,m=Xg(a),v[l>>2]=m;if(!Xf(d+8|0,d)){break a}e=gb-16|0;gb=e;k=e+8|0;b=v[Cc(e,b)>>2];c=gb-16|0;gb=c;v[c+8>>2]=b;f=gb-16|0;gb=f;j=v[c+8>>2];h=j;i=Cc(f+8|0,h);Fj(i);b=a;g=b;if(v[b>>2]==(h|0)){v[g>>2]=v[i>>2]}g=wb(b);v[g>>2]=v[g>>2]-1;iN(v[dc(b)>>2],h);b=v[i>>2];gb=f+16|0;a=dc(a);Ll(se(c+8|0));_l(a,j,1);gb=c+16|0;Cc(k,b);gb=e+16|0}gb=d+16|0}function $Y(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-32|0;gb=g;d=b;f=qc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>>0){mr(d,f);break d}e=wb(d);e=Zg(h+8|0,qh(d,qc(d)+f|0),qc(d),e);v[23048]=0;S(348,e|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break c}v[23048]=0;S(349,d|0,e|0);d=v[23048];v[23048]=0;if((d|0)==1){break c}ee(e)}gb=h+32|0;break b}a=P()|0;O()|0;ee(e);R(a|0);L()}break a}if(e>>>0<f>>>0){Tm(d,e+v[d>>2]|0)}}c=Nb(a,c);if(c){qD(g+24|0,b);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function Xoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;wd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;e=b;c=a+14|0;d=256;a:{if(!w[c|0]){break a}d=w[c|0]+1|0}u[e+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function US(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}bf(a);kD(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Gb(f+12|0,f+4|0)>>2];Ep(a,zb(b)+g|0,h);xu(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[Rn(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=Rn(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Gb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}gb=f+16|0;return(d|0)!=0|0}function JJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{c:{c=a+8|0;d:{if(!kl(c)){if((b|0)<0|(kq(c)|0)<=(b|0)){break d}c=(w[El(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=kl(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}b=aa(8)|0;v[23048]=0;c=Q(91,d|0,59705)|0;a=v[23048];v[23048]=0;e:{if((a|0)!=1){rc(b,c);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;ca(b|0)}R(a|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}gb=d+16|0;return c|0}L()}function Bw(a,b,c,d){var e=0,f=0;e=gb-48|0;gb=e;v[e+44>>2]=d;a:{f=v[b>>2];b:{if(!(kb[v[v[f>>2]+36>>2]](f,c,d)|0)){Ah(a);break b}Xi(e+24|0,b);v[23048]=0;b=v[b>>2];d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[23048]=0;b=U(d|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break a}v[23048]=0;v[e+20>>2]=b-c;b=Gb(e+44|0,e+20|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}b=v[b>>2];v[23048]=0;Y(265,e+32|0,e+24|0,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=a;a=Xd(e+8|0);pF(b,e+32|0,a);Bc(a);Bc(e+32|0);Bc(e+24|0)}gb=e+48|0;return}a=P()|0;O()|0;Bc(e+24|0);R(a|0);L()}function Bm(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;f=a+1074308|0;Db(e+8|0,f,84);a:{if(Cb(e+8|0)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){Db(e+8|0,f,10);if(!Cb(e+8|0)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+786>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;Db(e+8|0,f,10);if(!Cb(e+8|0)){break a}t[b+833|0]=0;u[b+780>>1]=0}gb=e+16|0}function Aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-48|0;gb=c;Fm(c+24|0,b,1819307379);id(a+40|0,c+24|0);yb(c+24|0);Fm(c+24|0,b,1953721961);id(a+60|0,c+24|0);yb(c+24|0);Fm(c+24|0,b,543520099);id(a+120|0,c+24|0);yb(c+24|0);Fm(c,b,1414744396);d=c+24|0;Lk(d,c);yb(c);v[23048]=0;e=Q(596,d|0,44800)|0;f=v[23048];v[23048]=0;a:{if((f|0)!=1){b:{if(e){v[23048]=0;T(1444,c|0,d|0,2);e=v[23048];v[23048]=0;if((e|0)==1){break b}cO(a+140|0,c);Nm(c)}v[23048]=0;T(1445,c|0,b|0,1634890872);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;yb(d);R(a|0);L()}id(a+80|0,c);yb(c);yb(d);gb=c+48|0}function f9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=gb-16|0;gb=e;v[23048]=0;_(1943,a|0);d=v[23048];v[23048]=0;a:{b:{c:{if((d|0)==1){break c}v[23048]=0;_(1969,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break c}d=v[a+24>>2];b=wc(e+8|0,b);v[23048]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;Wa(2012,d|0,e|0,+c,1);d=v[23048];v[23048]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55164,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}gb=e+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function x$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Kg(a,v[b+8>>2],f)){Uw(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;Sw(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;Sw(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function jx(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;Ic(f+8|0,b);v[23048]=0;b=U(2375,f+8|0)|0;g=v[23048];v[23048]=0;a:{if((g|0)==1){break a}v[23048]=0;Y(2387,b|0,84064,84096,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}v[23048]=0;b=U(2376,f+8|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}v[23048]=0;c=U(2388,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break a}v[d>>2]=c;v[23048]=0;c=U(2385,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break a}v[e>>2]=c;v[23048]=0;S(2386,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}Xb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Xb(f+8|0);R(a|0);L()}function lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;Ak(d,2,a+2|0);Fc(d+16|0,d);v[23048]=0;Q(354,b+492|0,d+16|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){vb(d+16|0);f=b+236|0;c=c+1|0;while(1){g=w[(a+e|0)+31|0];h=ud(f,e),i=c+g|0,u[h>>1]=i;e=e+1|0;if(e>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;e=a+2|0;f=a+3|0;g=a+4|0;SN(w[a|0]&15,w[c|0]&15,w[e|0]&15,w[f|0]&15,w[g|0]&15,a+5|0,b+48|0);SN(w[a|0]>>>4|0,w[c|0]>>>4|0,w[e|0]>>>4|0,w[f|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}function mx(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;Ic(f+8|0,b);v[23048]=0;b=U(21,f+8|0)|0;g=v[23048];v[23048]=0;a:{if((g|0)==1){break a}v[23048]=0;Y(2366,b|0,84064,84096,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}v[23048]=0;b=U(2346,f+8|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}v[23048]=0;c=U(2367,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break a}t[d|0]=c;v[23048]=0;c=U(2358,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break a}t[e|0]=c;v[23048]=0;S(2359,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}Xb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Xb(f+8|0);R(a|0);L()}function Gk(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-48|0;gb=d;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+28>>2]=c;a:{if(c){while(1){v[d+16>>2]=16;f=v[Gb(d+16|0,d+28|0)>>2];e=_d(d+8|0,d+32|0,f);g=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=g;e=gb-16|0;gb=e;g=v[a>>2];k=v[a+8>>2];i=v[d+4>>2];j=v[d>>2];v[e+8>>2]=j;v[e+12>>2]=i;l=v[v[g>>2]+28>>2];v[e>>2]=j;v[e+4>>2]=i;kb[l|0](d+16|0,g,h+k|0,e);gb=e+16|0;e=0;if((xb(d+16|0)|0)!=(f|0)){break a}if(zd(d+32|0,b+h|0,f)){break a}e=v[d+28>>2]-f|0;v[d+28>>2]=e;h=f+h|0;if(e){continue}break}}Vb(a,c);e=1}gb=d+48|0;return e}function hY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=YX(c,a,1);a=wb(a);e=v[d+4>>2];v[23048]=0;T(528,a|0,e|0,b|0);a=v[23048];v[23048]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+48;_b(d);gb=c+16|0;break a}a=P()|0;O()|0;_b(d);R(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=WX(c+8|0,XX(a,Lj(a)+1|0),Lj(a),e);f=v[a+8>>2];v[23048]=0;T(528,e|0,f|0,b|0);b=v[23048];v[23048]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+48;v[23048]=0;S(529,d|0,a|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}Av(a);gb=c+32|0;break b}b=P()|0;O()|0;Av(a);R(b|0);L()}}function QW(a,b){var c=0,d=0;c=(a|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}d=ig(v[b+8>>2]);c=v[b+8>>2];b:{c:{if(d){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){c=c+12|0;b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];break c}if(!ig(b)){b=v[b+8>>2];yr(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;xr(a);return}c=v[v[c+8>>2]>>2];if(!c|w[c+12|0]){break b}c=c+12|0;b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2]}t[b+12|0]=(a|0)==(b|0);t[c|0]=1;if((a|0)!=(b|0)){continue}break a}break}if(ig(b)){b=v[b+8>>2];xr(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;yr(a)}}function D4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;d=Ke(b,-1);e=w[a+52|0];a:{if(d){d=b;if(e){break a}d=v[a+48>>2];f=a,g=Ke(d,-1)^1,t[f+52|0]=g;break a}if(e){f=c,g=Kh(v[a+48>>2]),t[f+19|0]=g;b:{c:{switch(Os(v[a+36>>2],v[a+40>>2],c+19|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Qs(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}t[a+52|0]=1;v[a+48>>2]=b;d=b}gb=c+32|0;return d|0}function Ho(a){var b=0,c=0,d=0,e=0,f=0,g=0;e=x[a+24>>1];c=v[a+4>>2];d=!w[a+77|0]<<1;b=(e<<2)+(x[c+28>>1]>>>d|0)|0;v[a+40>>2]=((b&3)<<4)+28304;f=b>>>2|0;b=b>>>0<48;g=b?12-f|0:0;u[a+32>>1]=g;u[a+36>>1]=b?1:1<<f-12;u[a+34>>1]=-1<<g^-1;if((e|0)==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+52>>2]=((b&3)<<4)+28304;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+44>>1]=f;u[a+48>>1]=b?1:1<<e-12;u[a+46>>1]=-1<<f^-1;c=(x[a+30>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+64>>2]=((c&3)<<4)+28304;d=c>>>2|0;c=c>>>0<48;b=c?12-d|0:0;u[a+56>>1]=b;u[a+60>>1]=c?1:1<<d-12;u[a+58>>1]=-1<<b^-1}function j9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[23048]=0;_(1943,a|0);d=v[23048];v[23048]=0;a:{b:{c:{if((d|0)==1){break c}v[23048]=0;_(1969,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break c}d=v[a+24>>2];b=wc(c+8|0,b);v[23048]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(2007,d|0,c|0,1);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55014,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();e=0}gb=c+16|0;return+e}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function ZZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=BF(c,a);a=wb(a);e=v[d+4>>2];v[23048]=0;T(331,a|0,e|0,b|0);a=v[23048];v[23048]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+36;_b(d);gb=c+16|0;break a}a=P()|0;O()|0;_b(d);R(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=zF(c+8|0,AF(a,Mk(a)+1|0),Mk(a),e);f=v[a+8>>2];v[23048]=0;T(331,e|0,f|0,b|0);b=v[23048];v[23048]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+36;v[23048]=0;S(262,d|0,a|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}ks(a);gb=c+32|0;break b}b=P()|0;O()|0;ks(a);R(b|0);L()}}function Qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(hk(a)>>>0>=b>>>0){h=e,i=Nf(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Gb(e+12|0,e+8|0)>>2];if(f){while(1){NN(d,b);d=d+52|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){_y(a,b-d|0,c);break a}HN(a,v[a>>2]+B(b,52)|0);break a}d=a;if(v[d>>2]){Nf(d);IO(d);DN(d);Kz(wb(d),v[d>>2],hk(d));h=wb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=GN(a,b);if(CN()>>>0<f>>>0){Mc();L()}wb(d);g=BN(f);v[d>>2]=g;v[d+4>>2]=g;h=wb(d),i=B(f,52)+g|0,v[h>>2]=i;AN(d,0);_y(a,b,c)}gb=e+16|0}function rq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;ii(e+16|0,b);c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;d=gb-32|0;gb=d;c=v[e+4>>2];f=v[e>>2];v[d+8>>2]=f;v[d+12>>2]=c;v[d+16>>2]=f;v[d+20>>2]=c;f=gb-16|0;gb=f;g=v[d+12>>2];c=f;h=v[d+8>>2];v[c>>2]=h;v[c+4>>2]=g;v[c+8>>2]=h;v[c+12>>2]=g;g=gb-16|0;gb=g;h=v[c>>2];i=v[c>>2];c=xb(c);v[23048]=0;Dn(d+24|0,h,c+i|0);c=v[23048];v[23048]=0;a:{if((c|0)!=1){gb=g+16|0;break a}V(0)|0;O()|0;Ab();L()}gb=f+16|0;c=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=c;jW(e+24|0,a,d);gb=d+32|0;xb(e+24|0);ii(e+8|0,b);xb(e+8|0);gb=e+32|0}function oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=(e<<1)+j|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+40882>>1])+B(u[e-2>>1],u[f+40880>>1])|0)+B(u[e+2>>1],u[f+40884>>1])|0)+B(u[e+4>>1],u[f+40886>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function k9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{c:{if((c|0)==1){break c}v[23048]=0;_(1969,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break c}c=v[a+24>>2];b=wc(d+8|0,b);v[23048]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(2005,c|0,d|0,1)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54952,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function cr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;g=Lb(a)-1|0;a:{if((Lb(a)|0)==1){break a}while(1){if(x[Ec(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Lb(a)-1>>>0){continue}break}}h=x[Ec(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Ec(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Ec(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Ec(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}j=f,k=((B(((w[Ec(a,g)+2|0]<<16)/(d|0)|0)-i|0,b-e|0)|0)/(h-e|0)|0)+i|0,v[j+12>>2]=k}Vd(f+12|0,0,65536);gb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function v4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-32|0;gb=c;a:{b:{c:{if(Ke(b,-1)){break c}h=c,i=Kh(b),t[h+23|0]=i;if(w[a+44|0]){if((xk(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+23|0;while(1){e=Os(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((xk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if((xk(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=_s(b);break a}a=-1}gb=c+32|0;return a|0}function Bja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=gb-80|0;gb=f;Di(f+40|0,f+32|0,c);v[23048]=0;c=f+52|0;T(813,c|0,f+24|0,d|0);d=v[23048];v[23048]=0;b:{c:{if((d|0)!=1){d:{v[23048]=0;c=f- -64|0;T(813,c|0,f+16|0,e|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}c=f+40|0;v[f+8>>2]=c;v[f+12>>2]=c+36;v[23048]=0;c=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=c;T(498,a|0,b|0,f|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}Qk(f+40|0);gb=f+80|0;break a}}a=P()|0;O()|0;while(1){c=vb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break b}a=P()|0;O()|0;Qk(f+40|0)}R(a|0);L()}}function wg(a){var b=0,c=0,d=0,e=0;a:{o(+a);b=j(1)|0;j(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!((c|0)<0|b>>>0<1083179008)){return a*8.98846567431158e307}if(b>>>0>=2146435072){return-1/a}if(!(a<=-1075)){break a}d=0;if((c|0)<-1?1:(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}e=a+26388279066624;o(+e);j(1)|0;c=(j(0)|0)+128|0;b=c<<4&4080;d=A[b+19840>>3];a=a-(e+-26388279066624)-A[(b|8)+19840>>3];return Qi(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function RE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;g=w[a+8|0];f=v[a>>2];a=v[a+4>>2];d=Ob(b);b=Bb(b);c=gb-16|0;gb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Gb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=f;break b}b=e;a=f;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{d:{e:{switch(g-1|0){case 0:case 1:d=v[c+12>>2];t[c+7|0]=0;Fy(a,((a+d|0)-e|0)+b|0,c+7|0);break d;case 2:case 3:break e;default:break c}}d=v[c+12>>2];t[c+6|0]=32;Fy(a,((a+d|0)-e|0)+b|0,c+6|0)}f:{switch(g-1|0){case 0:case 3:break f;default:break c}}t[(v[c+12>>2]+f|0)-1|0]=0}gb=c+16|0}function j7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-32|0;gb=b;e=nc(a);Md(b+24|0);a=0;c=v[b+28>>2];d=v[b+24>>2];v[23048]=0;S(1436,e|0,vy(d,c)|0);c=v[23048];v[23048]=0;a:{if((c|0)!=1){b:{c:{c=v[b+24>>2];if((vy(c,v[b+28>>2])|0)>0){while(1){c=v[(a<<3)+c>>2];v[23048]=0;c=Q(91,b+8|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}v[23048]=0;S(1438,e|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}vb(c);c=v[b+24>>2];a=a+1|0;if((vy(c,v[b+28>>2])|0)>(a|0)){continue}break}}gb=b+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0}yd(e);R(a|0);L()}function e2(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-160|0;gb=c;a=Pn(c+16|0,a,8);d=v[v[a>>2]-12>>2];v[23048]=0;b=fa(131)|0;e=v[23048];v[23048]=0;a:{b:{if((e|0)==1){break b}v[23048]=0;T(132,c+8|0,d+(c+16|0)|0,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}Xb(c+8|0);v[23048]=0;d=XH(a);b=v[23048];v[23048]=0;if((b|0)==1){break b}v[23048]=0;d=Q(172,d|0,c+4|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break b}b=v[v[d>>2]-12>>2];v[23048]=0;d=cp(b+d|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}b=v[c+4>>2];ag(a);gb=c+160|0;a=d?0:b;break a}c=P()|0;O()|0;ag(a);R(c|0);L()}return a|0}function y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;d=Ke(b,-1);e=w[a+52|0];a:{if(d){d=b;if(e){break a}d=v[a+48>>2];f=a,g=Ke(d,-1)^1,t[f+52|0]=g;break a}if(e){v[c+16>>2]=v[a+48>>2];b:{c:{switch(Os(v[a+36>>2],v[a+40>>2],c+16|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Qs(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}t[a+52|0]=1;v[a+48>>2]=b;d=b}gb=c+32|0;return d|0}function UC(a,b,c){var d=0,e=0,f=0,g=0;g=b;d=v[c+16>>2];a:{if(!d){d=0;e=c;f=w[c+74|0];t[c+74|0]=f-1|f;f=v[c>>2];b:{if(f&8){v[e>>2]=f|32;e=-1;break b}v[e+4>>2]=0;v[e+8>>2]=0;f=v[e+44>>2];v[e+28>>2]=f;v[e+20>>2]=f;v[e+16>>2]=f+v[e+48>>2];e=0}if(e){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<g>>>0){return kb[v[c+36>>2]](c,a,b)|0}c:{if(t[c+75|0]>-1){d=b;while(1){g=d;d=b;if(!g){break c}d=g-1|0;if(w[d+a|0]!=10){continue}break}d=kb[v[c+36>>2]](c,a,g)|0;if(g>>>0>d>>>0){break a}a=a+g|0;f=v[c+20>>2];d=b-g|0;break c}d=b}e=d;hc(f,a,e);v[c+20>>2]=e+v[c+20>>2];d=b}return d}function Qv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-48|0;gb=d;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+28>>2]=c;a:{if(c){while(1){v[d+16>>2]=16;f=v[Gb(d+16|0,d+28|0)>>2];e=_d(d+8|0,d+32|0,f);g=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=g;e=gb-16|0;gb=e;j=v[a+12>>2];g=v[d+4>>2];i=v[d>>2];v[e+8>>2]=i;v[e+12>>2]=g;k=v[v[a>>2]+28>>2];v[e>>2]=i;v[e+4>>2]=g;kb[k|0](d+16|0,a,h+j|0,e);gb=e+16|0;e=0;if((xb(d+16|0)|0)!=(f|0)){break a}if(zd(d+32|0,b+h|0,f)){break a}e=v[d+28>>2]-f|0;v[d+28>>2]=e;h=f+h|0;if(e){continue}break}}bd(a,c);e=1}gb=d+48|0;return e}function pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=e+j|0;f=f>>>21&2040;e=(((B(t[e|0],u[f+40882>>1])+B(t[e-1|0],u[f+40880>>1])|0)+B(t[e+1|0],u[f+40884>>1])|0)+B(t[e+2|0],u[f+40886>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;wd(b,0);MC(d,a+1|0);Fc(d+16|0,d);v[23048]=0;Q(355,b+43|0,d+16|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){vb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;tc(b+8|0,v[b>>2]);tc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}function nI(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!Sf(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(QH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23048]=0;b=U(2243,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23048]=0;_(2244,a+b|0);a=v[23048];v[23048]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function e7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{d=gb-16|0;gb=d;c=$g(a,1,0);b:{c:{while(1){e=Ob(c);f=Ob(c);g=Bb(c);h=v[b+4>>2];a=v[b>>2];v[23048]=0;Oa(130,d+8|0,e|0,f+g|0,a|0,h|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}if(!v[d+12>>2]){break c}a=Bb(c);v[23048]=0;v[d+4>>2]=a;a=Bj(d+4|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;T(123,c|0,a|0,0);a=v[23048];v[23048]=0;if((a|0)!=1){continue}}break}break b}a=v[d+8>>2];b=Ob(c);v[23048]=0;S(124,c|0,a-b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}gb=d+16|0;break a}a=P()|0;O()|0;vb(c);R(a|0);L()}}function u7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=nc(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[23048]=0;S(2102,c|0,(d+(a<<5)|0)+480289|0);d=v[23048];v[23048]=0;if((d|0)==1){break e}v[23048]=0;T(2095,c+16|0,b|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}v[23048]=0;S(1438,f|0,c+16|0);d=v[23048];v[23048]=0;if((d|0)==1){break c}vb(c+16|0);vb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+16|0)}vb(c)}yd(f);R(a|0);L()}function gt(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=gb-240|0;gb=g;h=v[c>>2];v[g+232>>2]=h;c=v[c+4>>2];v[g>>2]=a;v[g+236>>2]=c;a:{b:{c:{d:{if((h|0)!=1){h=a;i=1;break d}h=a;i=1;if(c){break d}c=a;break c}while(1){c=h-v[(d<<2)+f>>2]|0;if((kb[b|0](c,a)|0)<1){c=h;break c}e:{if(!((d|0)<2|e)){e=v[((d<<2)+f|0)-8>>2];j=h-4|0;if((kb[b|0](j,c)|0)>-1){break e}if((kb[b|0](j-e|0,c)|0)>-1){break e}}v[(i<<2)+g>>2]=c;e=YI(g+232|0);ht(g+232|0,e);i=i+1|0;d=d+e|0;e=0;h=c;if(v[g+236>>2]|v[g+232>>2]!=1){continue}break b}break}c=h;break b}if(e){break a}}XI(g,i);Sx(c,b,d,f)}gb=g+240|0}function fy(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0);e=gb-32|0;gb=e;wJ(C(-z[a>>2]),C(z[a+12>>2]+z[a+24>>2]),C(z[a+36>>2]+z[a+48>>2]),e+20|0);wJ(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){d=a<<2;g=d+c|0;h=z[g>>2];f=z[d+68208>>2];i=z[d+(e+20|0)>>2];j=z[d+(e+8|0)>>2];k=z[d+68220>>2];z[g>>2]=C(f*i)-C(j*k);g=b+d|0;l=z[(0-a<<2)+68216>>2];d=5-a<<2;m=z[d+68208>>2];f=C(C(f*j)+C(k*i));z[g>>2]=C(h*l)-C(m*f);z[b+d>>2]=C(m*h)+C(f*l);a=a+1|0;if((a|0)!=3){continue}break}gb=e+32|0}function vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Ug(c,a,1);a=wb(a);e=v[d+4>>2];v[23048]=0;qq(a,e,b);a=v[23048];v[23048]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;_b(d);gb=c+16|0;break a}a=P()|0;O()|0;_b(d);R(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=Vy(c+8|0,Tg(a,Lb(a)+1|0),Lb(a),e);f=v[a+8>>2];v[23048]=0;qq(e,f,b);b=v[23048];v[23048]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[23048]=0;S(1514,d|0,a|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}Rg(a);gb=c+32|0;break b}b=P()|0;O()|0;Rg(a);R(b|0);L()}}function Sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=u[(f<<1)+k>>1];h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function mna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=$p(c,a,1);wb(a);a=v[d+4>>2];v[23048]=0;S(698,a|0,b|0);a=v[23048];v[23048]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;_b(d);gb=c+16|0;break a}a=P()|0;O()|0;_b(d);R(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=RG(c+8|0,bx(a,Gc(a)+1|0),Gc(a),e);e=v[a+8>>2];v[23048]=0;S(698,e|0,b|0);b=v[23048];v[23048]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[23048]=0;Fn(d,a);b=v[23048];v[23048]=0;if((b|0)==1){break c}zs(a);gb=c+32|0;break b}b=P()|0;O()|0;zs(a);R(b|0);L()}}function a8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;e=v[a>>2];f=v[a+4>>2];g=v[a+12>>2];v[d+48>>2]=v[a+8>>2];v[d+52>>2]=g;v[d+40>>2]=e;v[d+44>>2]=f;a=Xd(d+32|0);e=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=e;v[23048]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;T(2077,d+56|0,d+8|0,a|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){c=gi(d+24|0,c);v[23048]=0;b=+ya(2078,d+56|0,+b,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break b}mf(c);yb(d+56|0);Bc(a);gb=d+80|0;return+b}e=P()|0;O()|0;break a}e=P()|0;O()|0;mf(c);yb(d+56|0)}Bc(a);R(e|0);L()}function DD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=di(c,a,1);a=wb(a);e=v[d+4>>2];v[23048]=0;on(a,e,b);a=v[23048];v[23048]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;_b(d);gb=c+16|0;break a}a=P()|0;O()|0;_b(d);R(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=tp(c+8|0,Jk(a,uc(a)+1|0),uc(a),e);f=v[a+8>>2];v[23048]=0;on(e,f,b);b=v[23048];v[23048]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+2;v[23048]=0;S(365,d|0,a|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}zh(a);gb=c+32|0;break b}b=P()|0;O()|0;zh(a);R(b|0);L()}}function wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,26);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function Tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=t[f+k|0]<<8;h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function m0(){var a=0;a:{if(t[466512]&1){break a}if(!Ud(466512)){break a}a=466224;while(1){a=Jb(a)+12|0;if((a|0)!=466512){continue}break}Td(466512)}Zc(466224,89308);Zc(466236,89316);Zc(466248,89325);Zc(466260,89331);Zc(466272,89337);Zc(466284,89341);Zc(466296,89346);Zc(466308,89351);Zc(466320,89358);Zc(466332,89368);Zc(466344,89376);Zc(466356,89385);Zc(466368,89394);Zc(466380,89398);Zc(466392,89402);Zc(466404,89406);Zc(466416,89337);Zc(466428,89410);Zc(466440,89414);Zc(466452,89418);Zc(466464,89422);Zc(466476,89426);Zc(466488,89430);Zc(466500,89434)}function j0(){var a=0;a:{if(t[466816]&1){break a}if(!Ud(466816)){break a}a=466528;while(1){a=Jb(a)+12|0;if((a|0)!=466816){continue}break}Td(466816)}od(466528,89440);od(466540,89472);od(466552,89508);od(466564,89532);od(466576,89556);od(466588,89572);od(466600,89592);od(466612,89612);od(466624,89640);od(466636,89680);od(466648,89712);od(466660,89748);od(466672,89784);od(466684,89800);od(466696,89816);od(466708,89832);od(466720,89556);od(466732,89848);od(466744,89864);od(466756,89880);od(466768,89896);od(466780,89912);od(466792,89928);od(466804,89944)}function Hw(a){var b=0,c=0,d=0,e=0,f=0;a:{if(y[a+4>>2]<y[wb(a)>>2]){b=gb-16|0;gb=b;c=BF(b,a);d=wb(a);e=v[c+4>>2];v[23048]=0;S(261,d|0,e|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[c+4>>2]=v[c+4>>2]+36;_b(c);gb=b+16|0;break a}a=P()|0;O()|0;_b(c);R(a|0);L()}d=gb-32|0;gb=d;c=a;e=wb(a);b=zF(d+8|0,AF(a,Mk(a)+1|0),Mk(a),e);f=v[b+8>>2];v[23048]=0;S(261,e|0,f|0);e=v[23048];v[23048]=0;b:{c:{if((e|0)==1){break c}v[b+8>>2]=v[b+8>>2]+36;v[23048]=0;S(262,c|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break c}ks(b);gb=d+32|0;break b}a=P()|0;O()|0;ks(b);R(a|0);L()}}Yi(a)}function Gz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;a:{if(w[b+793|0]!=27){a=t[b+833|0];break a}e=a+1074308|0;Db(c+8|0,e,21);d=Cb(c+8|0);f=a;a=w[b+823|0];a=Cz(f,w[b+830|0],d?a:a+16>>>2|0);Db(c+8|0,e,45);b:{if(!(!Cb(c+8|0)|w[b+830|0]!=3)){f=b;d=w[b+823|0];c:{if(!(!d|d>>>0>=w[b+831|0])){a=w[b+834|0];d=d+1|0;break c}t[b+834|0]=a;d=1}t[f+823|0]=d;a=a<<24>>24;break b}t[b+823|0]=w[b+823|0]+w[b+831|0]}Db(c+8|0,e,47);if(!Cb(c+8|0)){break a}t[b+833|0]=a}if(a){g=b,h=ac(v[b+684>>2]+((B(w[b+832|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}gb=c+16|0}function poa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=QD(c,a,1);a=wb(a);e=v[d+4>>2];v[23048]=0;RC(a,e,b);a=v[23048];v[23048]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+20;_b(d);gb=c+16|0;break a}a=P()|0;O()|0;_b(d);R(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=CX(c+8|0,DX(a,cf(a)+1|0),cf(a),e);f=v[a+8>>2];v[23048]=0;RC(e,f,b);b=v[23048];v[23048]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+20;v[23048]=0;QC(d,a);b=v[23048];v[23048]=0;if((b|0)==1){break c}vv(a);gb=c+32|0;break b}b=P()|0;O()|0;vv(a);R(b|0);L()}}function fj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=gb-16|0;gb=f;o(+b);h=j(1)|0;e=j(0)|0;g=h&2147483647;c=g;d=e;g=c+-1048576|0;a:{if((g|0)==2145386495|g>>>0<2145386495){i=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){i=e<<28;c=h;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e|2147418112;break a}if(!(c|d)){c=0;d=0;break a}g=c;c=c>>>0<1?E(e)+32|0:E(c);Uf(f,d,g,0,0,c+49|0);k=v[f>>2];i=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=k;v[a+4>>2]=i;v[a+8>>2]=c;v[a+12>>2]=h&-2147483648|d;gb=f+16|0}function IP(a,b){var c=0,d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;a:{if(!w[b+848|0]|v[a+480180>>2]!=1){break a}c=v[b+104>>2];if(!c){break a}if(!Od(c)){break a}d=x[c+34>>1];if(!(d&10)){break a}e=w[b+849|0]+w[(w[b+848|0]&15)+34400|0]|0;t[b+849|0]=e;if(e<<24>>24>-1){break a}t[b+849|0]=0;e=d&2;d=v[(e?4:12)+c>>2];g=v[b+764>>2]+1|0;v[b+764>>2]=g>>>0<v[(e?8:16)+c>>2]-d>>>0?g:0;e=Wi(c);cc(f+8|0,zb(zb(v[c+20>>2]))+B(e,v[b+764>>2]+d|0)|0,e);b=v[f+8>>2];d=v[f+12>>2];if((b|0)!=(d|0)){while(1){t[b|0]=w[b|0]^-1;b=b+1|0;if((d|0)!=(b|0)){continue}break}}Sh(c,a,0)}gb=f+16|0}function r4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{b:{c:{if(Ke(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if((xk(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+20|0;while(1){e=Os(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((xk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if((xk(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=_s(b);break a}a=-1}gb=c+32|0;return a|0}function eW(a){var b=0;a:{if(zd(a,19755,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>4294966507){break a}b=a+16|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}b=a+24|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}}a=a+32|0;return Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<4294967216}return 0}function wQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Gb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;h=v[Gb(e+8|0,e+4|0)>>2]>>>1|0;c=zb(b);i=f>>>1|0;if(i){g=v[a+20>>2];f=i;j=d;while(1){j=(zb(w[c|0])+j|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=j;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(zb(w[c|0])+d|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}gb=e+16|0;return h+i<<1}function tQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Gb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;h=v[Gb(e+8|0,e+4|0)>>2]>>>1|0;c=zb(b);i=f>>>1|0;if(i){g=v[a+20>>2];f=i;j=d;while(1){j=(zb(w[c+1|0])+j|0)+(zb(w[c|0])<<8)|0;u[g>>1]=j;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(zb(w[c+1|0])+d|0)+(zb(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}gb=e+16|0;return h+i<<1}function xQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Gb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Gb(d+8|0,d+4|0)>>2]>>>1|0;c=zb(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=zb(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+h<<1}function uQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Gb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Gb(d+8|0,d+4|0)>>2]>>>1|0;c=zb(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=zb(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+h<<1}function kz(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;j=gb-16|0;gb=j;v[j+12>>2]=d;d=a+12|0;i=d;a:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break a}i=a+8|0;v[j+8>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);k=b,l=v[Gb(j+8|0,j+12|0)>>2],v[k>>2]=l;b=Gd(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24),v[b>>2],v[j+12>>2]);v[c>>2]=b;if(!(b>>>0>=y[j+12>>2]|h)){v[c>>2]=b+1}u[e>>1]=x[e>>1]|f;a=a+4|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1){break a}u[e>>1]=x[e>>1]|g}gb=j+16|0}function Cf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Vc(16544,d+14|0)>>1];c=uc(a);a:{if(b>>>0>c>>>0){e=gb-32|0;gb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){up(a,c,f);break d}b=wb(a);b=tp(e+8|0,Jk(a,uc(a)+c|0),uc(a),b);v[23048]=0;T(364,b|0,c|0,f|0);c=v[23048];v[23048]=0;if((c|0)==1){break c}v[23048]=0;S(365,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}zh(b)}gb=e+32|0;break b}a=P()|0;O()|0;zh(b);R(a|0);L()}break a}if(b>>>0<c>>>0){pn(a,v[a>>2]+(b<<1)|0)}}gb=d+16|0}function _la(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;bf(b);Ue(d+56|0,a,c);a=v[d+56>>2];v[23048]=0;c=Wd(d+56|0);e=v[23048];v[23048]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[23048]=0;Xe(d+8|0,3,c,a);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;S(398,d+24|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;T(13,d+40|0,5,d+24|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}Eb(b,d+40|0);vb(d+40|0);vb(d+24|0);Ac(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}Ac(d+56|0);R(a|0);L()}}function SZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=16384;e=v[Gb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=Nk(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Zr(d+4|0,Nk(a,4));break b}if((c|0)>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}Zr(d+4|0,e-c|0);break b}XE(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}XE(a,c,0,b)}c=v[d+4>>2];if((c|0)>17){break a}if(v[a+1072>>2]){continue}break}}gb=d+16|0}function Lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;bf(b);Ue(d+56|0,a,c);a=v[d+56>>2];v[23048]=0;c=Wd(d+56|0);e=v[23048];v[23048]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[23048]=0;Xe(d+8|0,2,c,a);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;S(398,d+24|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;T(13,d+40|0,2,d+24|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}Eb(b,d+40|0);vb(d+40|0);vb(d+24|0);Ac(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}Ac(d+56|0);R(a|0);L()}}function eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=Ug(d,a,1);wb(a);$S(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;_b(c);gb=d+16|0;return}g=gb-32|0;gb=g;f=wb(a);d=Tg(a,Lb(a)+1|0);i=Lb(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=g+8|0;vd(c+12|0,f);if(d){e=d;if(d>>>0>1073741823){xc(27353);L()}e=jc(e<<2,1)}v[c>>2]=e;f=(i<<2)+e|0;v[c+8>>2]=f;v[c+4>>2]=f;j=bc(c),k=(d<<2)+e|0,v[j>>2]=k;gb=h+16|0;$S(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;_S(a,c);a=c;ZS(c);b=v[c>>2];if(b){vC(v[a+16>>2],b,fk(a))}gb=g+32|0}function Woa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;e=Wd(d+40|0);f=v[23048];v[23048]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[23048]=0;Xe(d+8|0,3,e,a);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;Q(355,b|0,d+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}vb(d+24|0);Ac(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}Ac(d+40|0);R(a|0);L()}return a|0}function Wfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;e=Wd(d+40|0);f=v[23048];v[23048]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[23048]=0;Xe(d+8|0,1,e,a);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;Q(354,b|0,d+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}vb(d+24|0);Ac(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}Ac(d+40|0);R(a|0);L()}return a|0}function Una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;e=Wd(d+40|0);f=v[23048];v[23048]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[23048]=0;Xe(d+8|0,2,e,a);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;Q(449,b|0,d+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}vb(d+24|0);Ac(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}Ac(d+40|0);R(a|0);L()}return a|0}function wZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;e=Wd(d+40|0);f=v[23048];v[23048]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[23048]=0;Xe(d+8|0,1,e,a);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;Q(355,b|0,d+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}vb(d+24|0);Ac(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}Ac(d+40|0);R(a|0);L()}return a|0}function lE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;e=Wd(d+40|0);f=v[23048];v[23048]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[23048]=0;Xe(d+8|0,2,e,a);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;Q(354,b|0,d+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}vb(d+24|0);Ac(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}Ac(d+40|0);R(a|0);L()}return a|0}function PR(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=xq(b);d=a;e=Jg(a);v[23048]=0;S(1143,a|0,2048);a=v[23048];v[23048]=0;a:{if((a|0)!=1){v[23048]=0;HR(d);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Kf(e);R(a|0);L()}a=0;b:{while(1){c=1;if((a|0)!=1024){v[23048]=0;c=+(a-1024|0);g=xq(K(c*c*-9.5367431640625e-7+1)*b);e=v[23048];v[23048]=0;if((e|0)==1){break b}c=c*.0372006759294457;c=g*ji(c)/(c*f)}h=qe(d,a),i=c*.011841342921061943,A[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Kf(d);R(a|0);L()}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-16|0;gb=c;f=x[Si(a,b)>>1];a:{if(!Io(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=Rb(d),v[j+8>>2]=k;j=c,k=Ub(d),v[j>>2]=k;if(!Fb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=Ol(g);if(i){e=0;while(1){if(!(x[sc(g,e)>>1]!=(h|0)|((a|0)==(g|0)?(b|0)==(e|0):0))){d=FN(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}sS(c+8|0);if(Fb(c+8|0,c)){continue}break a}break}j=Si(a,b),k=d,u[j>>1]=k;f=d}gb=c+16|0;return f&65535}function RZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=32768;e=v[Gb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=Nk(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Zr(d+4|0,Nk(a,3));break b}if((c|0)>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}Zr(d+4|0,e-c|0);break b}WE(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}WE(a,c,0,b)}c=v[d+4>>2];if((c|0)>9){break a}if(v[a+1072>>2]){continue}break}}gb=d+16|0}function Uk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-16|0;gb=d;v[b>>2]=0;v[b+4>>2]=0;t[d+15|0]=0;i=Dh(a,d+15|0);e=w[d+15|0];v[b>>2]=(e&252)>>>2;v[b+4>>2]=0;a:{c=e&3;if(!c){break a}c=-1<<c;k=(c>>>0<4294967294?c:-2)^-1;h=1;c=0;while(1){t[d+15|0]=0;l=Dh(a,d+15|0);m=v[b+4>>2];j=w[d+15|0];g=(h<<3)-2|0;f=g&31;e=b;n=b;if((g&63)>>>0>=32){g=j<<f;f=0}else{g=(1<<f)-1&j>>>32-f;f=j<<f}v[n>>2]=f|v[b>>2];v[e+4>>2]=g|m;i=i&l;if(!c&(h|0)==(k|0)){break a}e=h+1|0;c=e>>>0<1?c+1|0:c;h=e;continue}}gb=d+16|0;return i|0}function Cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];g=v[Gb(e+8|0,e+4|0)>>2];i=z[d>>2];b=zb(b);if(g){d=v[a+20>>2];c=g;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());le(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;a=d;f=Fe(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}j=a,k=Uc(h),u[j>>1]=k;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return g<<2}function yL(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a=$g(a,1,0);a:{b:{while(1){d=Ob(a);f=Ob(a);g=Bb(a);h=x[b>>1];v[23048]=0;ea(127,e+8|0,d|0,f+g|0,h|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}if(!v[e+12>>2]){break b}d=Bb(a);v[23048]=0;v[e+4>>2]=d;d=Bj(e+4|0);f=v[23048];v[23048]=0;if((f|0)!=1){v[23048]=0;T(123,a|0,d|0,0);d=v[23048];v[23048]=0;if((d|0)!=1){continue}}break}break a}b=v[e+8>>2];c=Ob(a);v[23048]=0;S(124,a|0,b-c|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}gb=e+16|0;return}b=P()|0;O()|0;vb(a);R(b|0);L()}function xL(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a=$g(a,1,0);a:{b:{while(1){d=Ob(a);f=Ob(a);g=Bb(a);h=v[b>>2];v[23048]=0;ea(128,e+8|0,d|0,f+g|0,h|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}if(!v[e+12>>2]){break b}d=Bb(a);v[23048]=0;v[e+4>>2]=d;d=Bj(e+4|0);f=v[23048];v[23048]=0;if((f|0)!=1){v[23048]=0;T(123,a|0,d|0,0);d=v[23048];v[23048]=0;if((d|0)!=1){continue}}break}break a}b=v[e+8>>2];c=Ob(a);v[23048]=0;S(124,a|0,b-c|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}gb=e+16|0;return}b=P()|0;O()|0;vb(a);R(b|0);L()}function W2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[84112]|w[84113]<<8;v[a+24>>2]=w[84108]|w[84109]<<8|(w[84110]<<16|w[84111]<<24);$k(a+24|1,84100,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=Be();v[a>>2]=e;e=g>>>9&1;g=If(f,e+13|0,h,a+24|0,a)+f|0;h=Lg(f,g,c);e=f-((e<<3)+107&112)|0;gb=e;Ic(a+8|0,c);v[23048]=0;ia(2396,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){Xb(a+8|0);b=Kn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function AL(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a=$g(a,1,0);a:{b:{while(1){d=Ob(a);f=Ob(a);g=Bb(a);h=v[b>>2];v[23048]=0;ea(121,e+8|0,d|0,f+g|0,h|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}if(!v[e+12>>2]){break b}d=Bb(a);v[23048]=0;v[e+4>>2]=d;d=Bj(e+4|0);f=v[23048];v[23048]=0;if((f|0)!=1){v[23048]=0;T(123,a|0,d|0,0);d=v[23048];v[23048]=0;if((d|0)!=1){continue}}break}break a}b=v[e+8>>2];c=Ob(a);v[23048]=0;S(124,a|0,b-c|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}gb=e+16|0;return}b=P()|0;O()|0;vb(a);R(b|0);L()}function zL(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a=$g(a,1,0);a:{b:{while(1){d=Ob(a);f=Ob(a);g=Bb(a);h=w[b|0];v[23048]=0;ea(125,e+8|0,d|0,f+g|0,h|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}if(!v[e+12>>2]){break b}d=Bb(a);v[23048]=0;v[e+4>>2]=d;d=Bj(e+4|0);f=v[23048];v[23048]=0;if((f|0)!=1){v[23048]=0;T(123,a|0,d|0,0);d=v[23048];v[23048]=0;if((d|0)!=1){continue}}break}break a}b=v[e+8>>2];c=Ob(a);v[23048]=0;S(124,a|0,b-c|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}gb=e+16|0;return}b=P()|0;O()|0;vb(a);R(b|0);L()}function yQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Gb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Gb(d+8|0,d+4|0)>>2]>>>1|0;c=zb(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=zb(w[c|0])|zb(w[c+1|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=zb(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=zb(w[c|0])|zb(w[c+1|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+h<<1}function vQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Gb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Gb(d+8|0,d+4|0)>>2]>>>1|0;c=zb(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=zb(w[c+1|0])|zb(w[c|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=zb(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=zb(w[c+1|0])|zb(w[c|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+h<<1}function yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;f=$f(a,c);we(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{b:{if(!f){d=-1;if(!nd(a,5)){break b}break a}d=v[f+8>>2]}h=d;g=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 3:PA(g,b);break c;default:break d}}d=gb-32|0;gb=d;v[d+28>>2]=h;u[d+26>>1]=0;v[d+12>>2]=2;Zi(d+16|0,g,d+26|0,v[Gb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=2;Gb(d+28|0,d+16|0);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[d+16|0]|w[d+17|0]<<8;gb=d+32|0}}Rf(a,f,c,e+24|0);gb=e+32|0}function Ww(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Pb(d+24|0,0,39);a=a+f|0;a:{if(Kg(e,c,0)){v[d+56>>2]=1;kb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}kb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}gb=d- -64|0;return b}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{c:{d:{e:{if((a|0)!=(b|0)){g=v[115529];v[115529]=0;a=BH(a,e+12|0,d,Be());d=jb;f=v[115529];f:{if(f){if(v[e+12>>2]!=(b|0)){break f}if((f|0)==68){break d}break e}v[115529]=g;if(v[e+12>>2]==(b|0)){break e}}}v[c>>2]=4;a=0;break a}if((d|0)<-1?1:(d|0)<=-1?a>>>0<=2147483647:0){v[c>>2]=4;break c}if((d|0)<0?1:(d|0)<=0?a>>>0<=2147483647:0){break a}}v[c>>2]=4;if((d|0)>0?1:(d|0)>=0?a>>>0>=1:0){break b}}a=-2147483648;break a}a=2147483647}gb=e+16|0;return a|0}function FP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?b&240?b&-16:b&15:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(v[a+480180>>2]&59314208?b:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074448|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));Vd(d+12|0,0,256);v[c>>2]=v[d+12>>2]}gb=d+16|0}function F5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;f=gb-16|0;gb=f;e=gb-16|0;gb=e;h=e,i=Fpa(v[a>>2],v[a+4>>2],1e9,0),v[h>>2]=i;v[e+4>>2]=jb;a=ql(e+8|0,e);g=v[a+4>>2];a=v[a>>2];gb=e+16|0;gb=f+16|0;v[d+8>>2]=a;v[d+12>>2]=g;a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;gb=d+16|0;d=v[c+8>>2];e=v[c+12>>2];a=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=a;e=v[c+4>>2]+e|0;b=v[c>>2];d=d+b|0;v[c+16>>2]=d;v[c+20>>2]=b>>>0>d>>>0?e+1|0:e;a=ql(c+24|0,c+16|0);b=v[a+4>>2];a=v[a>>2];gb=c+32|0;jb=b;return a|0}function DP(a,b,c){var d=0,e=0;a:{if(v[a+480180>>2]==4){d=w[b+816|0];if(c){t[b+816|0]=d&240|c&15;break a}c=d&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}b:{if(!(t[b+853|0]&1)|!(c&255)){break b}d=v[b+700>>2];if(!d){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}e=b;a=tP(a,c&15);b=Fpa(a,a>>31,d,d>>31)+32768|0;a=jb;a=vc(Gpa(b,b>>>0<32768?a+1|0:a,65536,0),jb);v[e+700>>2]=a-((a|0)==(d|0));return}a=(c&255)+d|0;v[b+700>>2]=(a|0)<65535?a:65535}}function Yfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-32|0;gb=e;g=e;k=b;d=gb-32|0;gb=d;qY(d+24|0,e+24|0);i=xb(d+24|0);h=v[d+28>>2];f=v[d+24>>2];v[d+8>>2]=f;v[d+12>>2]=h;v[d>>2]=f;v[d+4>>2]=h;h=b;fc(d+16|0,b,d);f=xb(d+16|0);if((f|0)==(i|0)){Vb(h,xb(d+24|0))}gb=d+32|0;if((f|0)==(i|0)){j=Qm(e+24|0)}td(g,k,j);a=Tl(a,e+24|0,e);yb(e);a:{if(!c){break a}g=(j>>>0)%(c>>>0)|0;if(!g){break a}v[23048]=0;Q(370,b|0,c-g|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ae(a);R(b|0);L()}gb=e+32|0}function Jaa(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;a:{b:{if(!a){a=ie(52181);break b}v[23048]=0;c=Q(91,b|0,a|0)|0;a=v[23048];v[23048]=0;c:{d:{if((a|0)!=1){v[23048]=0;S(1924,b+16|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}a=ie(Ob(b+16|0));vb(b+16|0);vb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;vb(c)}Z(a|0)|0;a=0;v[23048]=0;Y(1920,52182,0,0,0);c=v[23048];v[23048]=0;if((c|0)==1){break a}$()}gb=b+32|0;return a|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function o9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[23048]=0;_(1943,a|0);h=v[23048];v[23048]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[23048]=0;ia(2001,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}b=ie(Ob(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[23048]=0;Y(1920,54818,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function n9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[23048]=0;_(1943,a|0);h=v[23048];v[23048]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[23048]=0;ia(2002,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}b=ie(Ob(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[23048]=0;Y(1920,54860,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Xja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-4112|0;gb=d;Om(a,b);if(qc(a)>>>0>=4096){h=d+16|0;i=d+4112|0;while(1){f=e<<12;b=0;c=0;while(1){b=zb(w[oc(a,c+f|0)|0])+b|0;g=zb(b&255);k=lc(d+16|0,c<<1|1),l=g,t[k|0]=l;c=c+1|0;if((c|0)!=2048){continue}break}g=f|2048;c=0;while(1){b=zb(w[oc(a,c+g|0)|0])+b|0;j=zb(b&255);k=lc(d+16|0,c<<1),l=j,t[k|0]=l;c=c+1|0;if((c|0)!=2048){continue}break}k=d,l=Rb(a),v[k+8>>2]=l;Tu(h,i,Ne(d+8|0,f));e=e+1|0;if(e>>>0<qc(a)>>>12>>>0){continue}break}}gb=d+4112|0}function wpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Ue(c+40|0,a,44);a=v[c+40>>2];v[23048]=0;d=Wd(c+40|0);e=v[23048];v[23048]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[23048]=0;Xe(c+8|0,2,d,a);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;S(398,c+24|0,c+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}_c(c,b,44);v[23048]=0;Q(450,c|0,c+24|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}vb(c+24|0);Ac(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}Ac(c+40|0);R(a|0);L()}}function Rma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Ue(c+40|0,a,16);a=v[c+40>>2];v[23048]=0;d=Wd(c+40|0);e=v[23048];v[23048]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[23048]=0;Xe(c+8|0,3,d,a);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;S(398,c+24|0,c+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}_c(c,b,17);v[23048]=0;Q(450,c|0,c+24|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}vb(c+24|0);Ac(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}Ac(c+40|0);R(a|0);L()}}function g3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[84112]|w[84113]<<8;v[a+24>>2]=w[84108]|w[84109]<<8|(w[84110]<<16|w[84111]<<24);$k(a+24|1,84100,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=Be();v[a>>2]=e;g=If(f,(g>>>9&1)+13|0,h,a+24|0,a)+f|0;h=Lg(f,g,c);e=f-32|0;gb=e;Ic(a+8|0,c);v[23048]=0;ia(2389,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){Xb(a+8|0);b=ln(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=gb-32|0;gb=f;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;e=Q(250,b|0,8)|0;g=v[23048];v[23048]=0;if((g|0)==1){break b}if(e){v[23048]=0;T(1481,f|0,b|0,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}v[23048]=0;S(1482,a|0,f|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}ae(f);e=DU(a);if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(d|0)){continue}}break}gb=f+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(f);break a}b=P()|0;O()|0}Cd(a);R(b|0);L()}
function WA(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a:{if(cd(a)){break a}u[v[a>>2]>>1]=0;Af(v[a>>2]+2|0,b);e=c,f=Rb(a),v[e>>2]=f;e=c,f=So(c,1),v[e+8>>2]=f;e=c,f=Ub(a),v[e>>2]=f;if(!Fb(c+8|0,c)){break a}while(1){d=v[c+8>>2];e=c,f=So(c+8|0,-1),v[e>>2]=f;d=Le(d,v[c>>2]);u[v[c+8>>2]>>1]=x[d>>1];Af(v[c+8>>2]+2|0,b);hE(c+8|0);e=c,f=Ub(a),v[e>>2]=f;if(Fb(c+8|0,c)){continue}break}}Af(a+14|0,Lb(a)-1&255);Af(a+13|0,w[a+14|0]);Af(a+16|0,Lb(a)-1&255);Af(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){Af(a+17|0,Lb(a)-1&255)}gb=c+16|0}function Fka(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-160|0;gb=b;a=Pn(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[23048]=0;c=fa(131)|0;e=v[23048];v[23048]=0;a:{b:{if((e|0)==1){break b}v[23048]=0;T(132,b+8|0,d+(b+16|0)|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}Xb(b+8|0);v[23048]=0;d=Q(166,a|0,b+6|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break b}c=v[v[d>>2]-12>>2];v[23048]=0;d=cp(c+d|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}c=x[b+6>>1];ag(a);gb=b+160|0;a=(d?0:c)&65535;break a}b=P()|0;O()|0;ag(a);R(b|0);L()}return a|0}function z$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Kg(a,v[b+8>>2],e)){Tw(b,c,d);return}a:{if(Kg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];kb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function bF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;d=b+80|0;g=a;c=v[b+84>>2];f=v[d>>2];a:{if(c>>>0<=15){break a}v[e+12>>2]=c-16;f=v[Jc(d,e+12|0)>>2]}v[g+8>>2]=f;b:{if(!(w[b+88|0]&2)|!w[b+796|0]){break b}c:{d:{e:{if(!aF(b)){c=v[b+104>>2];break e}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break e}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break d}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break b}b=48-b|0;break c}b=112-d|0}h=a,i=v[a>>2]+B(b+v[c>>2]|0,Wi(c))|0,v[h+4>>2]=i}gb=e+16|0}function JE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;xH(b);a:{if(!(w[a|0]|w[a+1|0]<<8)){c=a+2|0;if(!(w[c|0]|w[c+1|0]<<8)){break a}}v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;d=b,e=ac((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[d+16>>2]=e;d=b,e=ac((w[a|0]|w[a+1|0]<<8)&31,1,31),v[d+12>>2]=e;c=a+2|0;d=b,e=ac((w[c|0]|w[c+1|0]<<8)>>>11|0,0,23),v[d+8>>2]=e;d=b,e=ac((w[c|0]|w[c+1|0]<<8)>>>5&63,0,59),v[d+4>>2]=e;d=b,e=ac((w[c|0]|w[c+1|0]<<8)<<1&62,0,59),v[d>>2]=e}a=a+4|0;v[b+44>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function F6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=0,j=0,k=0;e=gb-16|0;gb=e;j=v[a+4>>2];eK(a,b,c,d);h=z[a+28>>2];b=v[a+24>>2];v[e+8>>2]=v[a+20>>2];v[e+12>>2]=b;b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=gb-16|0;gb=a;b=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=b;b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=a;if(!(!d|h==C(1))){while(1){if(c){k=g+j|0;f=0;while(1){i=OS(b,f,k);z[i>>2]=z[i>>2]*h;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}gb=a+16|0;gb=e+16|0}function d3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[84112]|w[84113]<<8;v[a+24>>2]=w[84108]|w[84109]<<8|(w[84110]<<16|w[84111]<<24);$k(a+24|1,84100,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=Be();v[a>>2]=e;g=If(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Lg(f,g,c);e=f-32|0;gb=e;Ic(a+8|0,c);v[23048]=0;ia(2389,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){Xb(a+8|0);b=ln(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function T2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[84112]|w[84113]<<8;v[a+24>>2]=w[84108]|w[84109]<<8|(w[84110]<<16|w[84111]<<24);$k(a+24|1,84100,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=Be();v[a>>2]=e;g=If(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Lg(f,g,c);e=f-96|0;gb=e;Ic(a+8|0,c);v[23048]=0;ia(2396,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){Xb(a+8|0);b=Kn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function Nga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;f=$f(a,c);we(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{b:{if(!f){d=-1;if(!nd(a,5)){break b}break a}d=v[f+8>>2]}h=d;g=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 2:Eh(g,b);break c;default:break d}}d=gb-32|0;gb=d;v[d+28>>2]=h;t[d+27|0]=0;v[d+12>>2]=1;Zi(d+16|0,g,d+27|0,v[Gb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=1;Gb(d+28|0,d+16|0);t[d+16|0]=w[d+27|0];t[b|0]=w[d+16|0];gb=d+32|0}}Rf(a,f,c,e+24|0);gb=e+32|0}function Rka(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;t[b+15|0]=128;d=Ev(a,127,b+15|0);v[23048]=0;t[b+14|0]=64;e=W(816,a+12|0,127,b+14|0)|0;c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[23048]=0;t[b+13|0]=0;W(902,a+24|0,127,b+13|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;t[a+44|0]=0;t[a+45|0]=0;t[a+46|0]=0;t[a+47|0]=0;t[a+48|0]=0;t[a+49|0]=0;t[a+50|0]=0;t[a+51|0]=0;t[a+52|0]=0;t[a+53|0]=0;gb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;gc(e)}gc(d);R(a|0);L()}function Zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb+-64|0;gb=c;Om(c+48|0,b);v[23048]=0;me(c+16|0,c+48|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=Xd(c+8|0);v[23048]=0;d=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=d;d=W(254,c+24|0,c|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}Bc(b);b=dd(a);a=qc(c+48|0);v[23048]=0;T(960,d|0,b|0,a>>>5|0);a=v[23048];v[23048]=0;if((a|0)==1){a=P()|0;O()|0;Uu(b);yb(d);break a}yb(d);gc(c+48|0);gb=c- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bc(b)}gc(c+48|0);R(a|0);L()}function Wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb+-64|0;gb=c;Om(c+48|0,b);v[23048]=0;me(c+16|0,c+48|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=Xd(c+8|0);v[23048]=0;d=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=d;d=W(254,c+24|0,c|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}Bc(b);b=dd(a);a=qc(c+48|0);v[23048]=0;T(961,d|0,b|0,a>>>2|0);a=v[23048];v[23048]=0;if((a|0)==1){a=P()|0;O()|0;Vh(b);yb(d);break a}yb(d);gc(c+48|0);gb=c- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bc(b)}gc(c+48|0);R(a|0);L()}function Vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb+-64|0;gb=c;Om(c+48|0,b);v[23048]=0;me(c+16|0,c+48|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=Xd(c+8|0);v[23048]=0;d=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=d;d=W(254,c+24|0,c|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}Bc(b);b=dd(a);a=qc(c+48|0);v[23048]=0;T(962,d|0,b|0,a>>>8|0);a=v[23048];v[23048]=0;if((a|0)==1){a=P()|0;O()|0;Su(b);yb(d);break a}yb(d);gc(c+48|0);gb=c- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bc(b)}gc(c+48|0);R(a|0);L()}function Tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb+-64|0;gb=c;Om(c+48|0,b);v[23048]=0;me(c+16|0,c+48|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=Xd(c+8|0);v[23048]=0;d=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=d;d=W(254,c+24|0,c|0,b|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}Bc(b);b=dd(a);a=qc(c+48|0);v[23048]=0;T(963,d|0,b|0,a>>>4|0);a=v[23048];v[23048]=0;if((a|0)==1){a=P()|0;O()|0;Ru(b);yb(d);break a}yb(d);gc(c+48|0);gb=c- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bc(b)}gc(c+48|0);R(a|0);L()}function O2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-208|0;gb=a;u[a+204>>1]=w[84118]|w[84119]<<8;v[a+200>>2]=w[84114]|w[84115]<<8|(w[84116]<<16|w[84117]<<24);f=Be();v[a>>2]=e;h=If(a+176|0,20,f,a+200|0,a);e=h+(a+176|0)|0;f=Lg(a+176|0,e,c);Ic(a+8|0,c);v[23048]=0;g=U(2375,a+8|0)|0;i=v[23048];v[23048]=0;if((i|0)!=1){Xb(a+8|0);uH(g,a+176|0,e,a+16|0);g=b;b=(a+16|0)+(h<<2)|0;b=Kn(g,a+16|0,(e|0)==(f|0)?b:((f-a<<2)+a|0)-688|0,b,c,d);gb=a+208|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function Hn(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;j=64-f|0;g=j&31;if((j&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|h<<g;j=i<<g}i=b;g=f;b=g&31;if((g&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function YY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{if(!Qf(a,7)){break b}d=0;if(!LD(a,16766)){break a}if(!Qf(a,1)){break b}d=-1;if(!bd(a,Nr(a))){break a}c=gb-32|0;gb=c;g=e+8|0;jn(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;md(c+16|0,a,c);f=xb(c+16|0);if((f|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){Lr(g)}d=-1;if(!c){break a}d=0;if(!HD(e+8|0)){break a}d=Qe(a,b,GD(e+8|0),jb);break a}d=-1}gb=e+16|0;return d|0}function GC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c;g=e+12|0;c=a;d=Lb(c);a:{if(d>>>0<b>>>0){f=gb-32|0;gb=f;b:{d=b-d|0;c:{if(d>>>0<=v[wb(c)>>2]-v[c+4>>2]>>2>>>0){eE(c,d,g);break c}b=wb(c);b=EN(f+8|0,Tg(c,Lb(c)+d|0),Lb(c),b);v[23048]=0;T(702,b|0,d|0,g|0);d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;S(100,c|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}Rg(b)}gb=f+32|0;break a}a=P()|0;O()|0;Rg(b);R(a|0);L()}if(b>>>0<d>>>0){Ui(c,v[c>>2]+(b<<2)|0)}}Lz(a);gb=e+16|0}function BP(a,b,c,d){var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}Db(e+8|0,a+1074308|0,3);if(Cb(e+8|0)){break c}if(!(t[(B(b,880)+a|0)+1075837|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,880)+a|0)+1075837|0]&1){Db(e+8|0,a+1074308|0,3);if(!Cb(e+8|0)){break a}}c=c<<2}if(!c){break a}d=ku(a,b);if(!d){break a}g=d;a=v[(B(b,880)+a|0)+1075640>>2];f=13;d:{if(!a){break d}f=w[a+33|0]}kb[v[v[d>>2]+84>>2]](g,c,f<<24>>24,b)}gb=e+16|0}function lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Ue(c+40|0,a,31);a=v[c+40>>2];v[23048]=0;d=Wd(c+40|0);e=v[23048];v[23048]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[23048]=0;Xe(c+8|0,2,d,a);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;S(398,c+24|0,c+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;Q(355,b|0,c+24|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}vb(c+24|0);Ac(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}Ac(c+40|0);R(a|0);L()}}function yz(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;a:{if((c|0)<2){break a}j=(c-2|0)/2|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=Cq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(Cq(b,x[e>>1],x[d>>1])){break a}u[h+14>>1]=x[d>>1];while(1){b:{f=e;u[d>>1]=x[e>>1];if((g|0)>(j|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){i=Cq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?d:g}d=f;if(!Cq(b,x[e>>1],x[h+14>>1])){continue}}break}u[f>>1]=x[h+14>>1]}gb=h+16|0}function sv(a,b){a=a|0;b=b|0;var c=0,d=0;c=w[a+3|0];a:{if(c>>>0>18){break a}c=1<<c;b:{if(!(c&126991)){if(c&396800){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{f:{switch(w[a+3|0]){case 9:c=2;break c;case 10:case 17:case 18:c=1;break c;case 11:break e;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:break f;default:break d}}c=w[a|0];if(c&7){break e}c=c>>>3|0;break c}c=w[a+3|0];return B(Zm(a),b+1>>>1|0)+(((c|0)==11)<<4)|0}c=0}d=w[a+3|0];d=B(Zm(a),B(b,c))+(((d|0)==11)<<4)|0}return d|0}function cpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[wb(a)>>2]){e=gb-16|0;gb=e;a=gD(e,a);TX(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+28;_b(a);gb=e+16|0;return}h=gb-32|0;gb=h;g=wb(a);e=Rl(a,Je(a)+1|0);j=Je(a);i=gb-16|0;gb=i;v[i+12>>2]=0;d=h+8|0;vd(d+12|0,g);if(e){f=e;if(e>>>0>=153391690){xc(17250);L()}f=jc(B(f,28),4)}v[d>>2]=f;g=B(j,28)+f|0;v[d+8>>2]=g;v[d+4>>2]=g;k=bc(d),l=B(e,28)+f|0,v[k>>2]=l;gb=i+16|0;TX(v[d+8>>2],b,c);v[d+8>>2]=v[d+8>>2]+28;en(a,d);Ql(d);gb=h+32|0}function Cz(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;Db(e+8|0,a+1074308|0,21);a:{if(Cb(e+8|0)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+34608|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=vO(vo(a))+-64|0;break a}d=t[(c>>>1&31)+33104|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+34480|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+34544|0]}a=d;gb=e+16|0;return a}function CU(a,b){var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Ue(c+40|0,a,4);a=v[c+40>>2];v[23048]=0;d=Wd(c+40|0);e=v[23048];v[23048]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[23048]=0;Xe(c+8|0,3,d,a);a=v[23048];v[23048]=0;if((a|0)==1){break d}v[23048]=0;S(398,c+24|0,c+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}_c(c,b,5);v[23048]=0;Q(450,c|0,c+24|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}vb(c+24|0);Ac(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}Ac(c+40|0);R(a|0);L()}}function zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=C(0);e=gb-32|0;gb=e;g=$f(a,c);we(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{if(!g){if(nd(a,5)){break a}}d=gb-32|0;gb=d;h=v[a+28>>2];Uk(h,d+24|0);j=d,k=Xc(v[d+24>>2],v[d+28>>2]),v[j+16>>2]=k;v[d+12>>2]=256;pl(b,v[Gb(d+16|0,d+12|0)>>2]);if(Lb(b)){while(1){v[d+16>>2]=0;rq(h,d+16|0);i=z[d+16>>2];j=Mb(b,f),l=i,z[j>>2]=l;f=f+1|0;if(Lb(b)>>>0>f>>>0){continue}break}}gb=d+32|0}Rf(a,g,c,e+24|0);gb=e+32|0}function yS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<1)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-((c|0)!=0&w[a+17|0]!=0)|0;break a}if(!((e|0)>-1|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function tD(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;e=Wd(d+40|0);f=v[23048];v[23048]=0;a:{b:{c:{if((f|0)==1){break c}e=zb(e);v[23048]=0;Xe(d+8|0,3,e,a);e=v[23048];v[23048]=0;if((e|0)==1){break c}v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break c}v[23048]=0;Q(354,b|0,d+24|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break b}vb(d+24|0);Ac(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}Ac(d+40|0);R(c|0);L()}function q9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[23048]=0;_(1943,a|0);g=v[23048];v[23048]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[23048]=0;ka(1999,f|0,g|0,b|0,c|0,d|0,e|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}b=ie(Ob(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[23048]=0;Y(1920,54715,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Lo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){b=a;if(d&512){CS(a);d=x[a+34>>1]}u[b+34>>1]=d&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;Mm(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function Ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+8>>2]=c>>>3;v[d+4>>2]=v[a>>2];f=v[Gb(d+8|0,d+4|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+8>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=g;hg(d+8|0,-1,1);e=A[d+8>>3]*32768;A[d+8>>3]=e;g=a;e=fe(e);a:{if(D(e)<2147483648){h=~~e;break a}h=-2147483648}i=g,j=Uc(h),u[i>>1]=j;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return f<<3}function $fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;cc(c+24|0,b,16);gb=d+16|0;d=xb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;fc(c+16|0,a,c);e=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function p9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[23048]=0;_(1943,a|0);g=v[23048];v[23048]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[23048]=0;ka(2e3,f|0,g|0,b|0,c|0,d|0,e|0);b=v[23048];v[23048]=0;if((b|0)==1){break c}b=ie(Ob(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[23048]=0;Y(1920,54765,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function j2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=Bb(a);e=Zs(a);g=nr(b,c);a:{if(!g){break a}if(PC(b,Ob(a),Ob(a)+(Bb(a)<<2)|0)){d=gb-16|0;gb=d;zH(f,b,c);gb=d+16|0;b=f;c=Ob(b);d=Bb(b);v[23048]=0;W(2416,a|0,c|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){Pc(b);break a}a=P()|0;O()|0;Pc(b);R(a|0);L()}if(e-d>>>0<g>>>0){CI(a,e,(d+g|0)-e|0,d,d)}e=Ob(a)+(d<<2)|0;if((b|0)!=(c|0)){while(1){je(e,b);e=e+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f>>2]=0;je(e,f);yh(a,d+g|0)}gb=f+16|0}function Lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+8>>2]=c>>>2;v[d+4>>2]=v[a>>2];g=v[Gb(d+8|0,d+4|0)>>2];b=zb(b);if(g){c=v[a+20>>2];a=g;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);le(d+12|0,C(-1));f=C(z[d+12>>2]*C(32768));z[d+12>>2]=f;e=c;f=Fe(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}i=e,j=Uc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}gb=d+16|0;return g<<2}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;df(d,2,a+6|0);Fc(d+16|0,d);v[23048]=0;Q(354,b+492|0,d+16|0)|0;e=v[23048];v[23048]=0;if((e|0)!=1){e=b+236|0;c=c+1|0;vb(d+16|0);while(1){g=w[(a+f|0)+38|0];h=ud(e,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if((f|0)!=128){continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;iz(a+180|0,b+48|0,0);iz(a+228|0,b+88|0,2);iz(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){nB(e)}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);R(a|0);L()}function Y2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-96|0;gb=a;u[a+92>>1]=w[84118]|w[84119]<<8;v[a+88>>2]=w[84114]|w[84115]<<8|(w[84116]<<16|w[84117]<<24);f=Be();v[a>>2]=e;h=If(a- -64|0,20,f,a+88|0,a);e=h+(a- -64|0)|0;f=Lg(a- -64|0,e,c);Ic(a+8|0,c);v[23048]=0;g=U(21,a+8|0)|0;i=v[23048];v[23048]=0;if((i|0)!=1){Xb(a+8|0);vH(g,a- -64|0,e,a+16|0);g=b;b=(a+16|0)+h|0;b=ln(g,a+16|0,(e|0)==(f|0)?b:((f-a|0)+a|0)-48|0,b,c,d);gb=a+96|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function Ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=zg(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/6>>>0){FC(a,d,c);break c}b=wb(a);b=AW(e+8|0,rC(a,zg(a)+d|0),zg(a),b);v[23048]=0;T(684,b|0,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}DC(a);c=b+4|0;yW(wb(a),v[a>>2],v[a+4>>2],c);mc(a,c);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];tC(a,zg(a));ov(b)}gb=e+32|0;break a}a=P()|0;O()|0;ov(b);R(a|0);L()}return}if(b>>>0<d>>>0){EC(a,v[a>>2]+B(b,6)|0)}}function Tfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Jb(a);a:{b:{c:{if(Gc(b)){a=0;while(1){d:{if(!a){break d}v[23048]=0;Q(1201,f|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Id(b,a);v[23048]=0;S(1202,e|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break c}v[23048]=0;Q(1201,f|0,e|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Gc(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);R(a|0);L()}function E3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115529];v[115529]=0;a=qx(a,e+12|0,d,Be());d=jb;e:{g=v[115529];if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68){break e}break b}v[115529]=h;if(v[e+12>>2]==(b|0)){break b}break c}v[c>>2]=4;a=-1;b=-1;break a}}v[c>>2]=4;a=0;b=0;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+((b|0)!=0)|0)|0:d}gb=e+16|0;jb=b;return a|0}function Uf(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if((f&63)>>>0>=32){h=g<<d;j=0}else{h=(1<<d)-1&g>>>32-d|e<<d;j=g<<d}d=c;g=b;f=64-f|0;e=f&31;if((f&63)>>>0>=32){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=j|d;e=f|h;f=b;b=i&31;if((i&63)>>>0>=32){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function Tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;c=Q(250,b|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}if(c){v[23048]=0;S(900,d|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break d}v[23048]=0;S(901,a|0,d|0);c=v[23048];v[23048]=0;if((c|0)==1){break c}ae(d);c=DU(a);if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1413891155){continue}}break}gb=d+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(d);break a}b=P()|0;O()|0}Cd(a);R(b|0);L()}function Ex(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=Ld(a),v[m+16>>2]=n;j=Hk(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Bb(b);if(g>>>0>=h>>>0){if(c){f=Nc(b);b:{if(f-g>>>0>=c>>>0){f=Ob(b);k=g-h|0;if(!k){break b}l=f+h|0;mn(l+c|0,l,k);break b}op(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Ov(f+h|0,c,d);d=b;b=c+g|0;yh(d,b);t[i+15|0]=0;Qd(b+f|0,i+15|0)}gb=i+16|0;break a}Sn();L()}m=e,n=Ld(a),v[m+8>>2]=n;a=Ne(e+8|0,j);gb=e+32|0;return a|0}function Qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;e=Fq(c,a);wb(a);Eq(v[e+4>>2],b);v[e+4>>2]=v[e+4>>2]+4;_b(e);gb=c+16|0;return}g=gb-32|0;gb=g;f=wb(a);e=Jl(a,Lb(a)+1|0);i=Lb(a);h=gb-16|0;gb=h;v[h+12>>2]=0;d=g+8|0;vd(d+12|0,f);if(e){c=e;if(c>>>0>=1073741824){xc(43847);L()}c=jc(c<<2,4)}v[d>>2]=c;f=(i<<2)+c|0;v[d+8>>2]=f;v[d+4>>2]=f;j=bc(d),k=(e<<2)+c|0,v[j>>2]=k;gb=h+16|0;Eq(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+4;_S(a,d);tz(d);gb=g+32|0}function L_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Jb(a);a:{b:{c:{if(Gc(b)){a=0;while(1){d:{if(!a){break d}v[23048]=0;Q(183,f|0,c|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Id(b,a);v[23048]=0;S(244,e|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break c}v[23048]=0;Q(183,f|0,e|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Gc(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);R(a|0);L()}function Ux(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=(p(a),j(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+-6755399441055744;A[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(D(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}h=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,h-(c<<23)|0),q());c=$I(e+8|0,e,c,1,0);d=A[e>>3];if((f|0)<=-1){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}gb=e+16|0;return c}function J7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-32|0;gb=b;a:{b:{if(mj(a)){lh(b+24|0);break b}fo(b+8|0,a);v[23048]=0;S(2087,b+24|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}Tf(b+8|0)}c=a+36|0;c:{if(mj(a)){break c}c=v[b+24>>2]}a=v[a+8>>2];d:{if((a|0)==-1){e=b,f=Rb(c),v[e+8>>2]=f;e=b,f=Ub(c),v[e>>2]=f;if(!Fb(b+8|0,b)){break d}while(1){d=A[v[b+8>>2]>>3]+d;ZK(b+8|0);if(Fb(b+8|0,b)){continue}break}break d}d=A[Il(c,a)>>3]}ll(b+24|0);gb=b+32|0;return+d}a=P()|0;O()|0;Tf(b+8|0);R(a|0);L()}function Dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];c=v[Gb(e+8|0,e+4|0)>>2];h=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=h*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());le(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;i=a;f=Fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=i,k=Uc(g),u[j>>1]=k;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<2}function faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23048]=0;_(1943,a|0);d=v[23048];v[23048]=0;a:{if((d|0)==1){break a}v[23048]=0;_(1954,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[a+24>>2];v[23048]=0;b=Q(1955,d|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53262,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=e+j|0;e=t[f|0];e=((B(t[f+1|0]-e|0,g>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function Kn(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((kn(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>=1){f=AI(i,b,f);h=Ob(f);v[23048]=0;h=W(2398,a|0,h|0,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break a}Pc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((kn(a,c,b)|0)!=(b|0)){break b}}EB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;Pc(f);R(a|0);L()}function zS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=b?33:32;e=v[a+8>>2]-1|0;j=e-((e|0)!=0&w[a+17|0]!=0)|0;f=v[a+12>>2];g=v[a>>2]+B(f,62)|0;d=b?1:-1;k=B(f,d)<<1;c=e;while(1){if((f|0)>=1){l=B(c,f);m=v[a+4>>2];b=0;while(1){u[(b<<1)+g>>1]=x[(b+l<<1)+m>>1];b=b+1|0;if((f|0)!=(b|0)){continue}break}}a:{if(!((c|0)!=(e|0)|(d|0)<1)){b=w[a+16|0];d=b?-1:1;c=b?j:0;break a}if(!((d|0)>-1|c)){b=w[a+16|0];d=b?1:-1;c=b?0:e;break a}c=d+c|0}g=g+k|0;h=h+1|0;if((i|0)!=(h|0)){continue}break}}function fp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Nb(b,c);a:{if(!g){break a}tc(f+28|0,65535);Cf(a,x[f+28>>1]);i=f,j=Rb(a),v[i+16>>2]=j;i=f,j=Ub(a),v[i+8>>2]=j;if(!Fb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!Ig(b,c)){h=gb-16|0;gb=h;Re(c);gb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}sf(f+16|0);if(Fb(f+16|0,f+8|0)){continue}break}}gb=f+32|0;return g|0}function U2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;$k(a+24|1,84102,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=Be();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=If(g,e+23|0,i,a+24|0,a)+g|0;h=Lg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;Ic(a+8|0,c);v[23048]=0;ia(2396,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){Xb(a+8|0);b=Kn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function S2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;$k(a+24|1,84102,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=Be();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=If(g,e+23|0,i,a+24|0,a)+g|0;h=Lg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;Ic(a+8|0,c);v[23048]=0;ia(2396,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){Xb(a+8|0);b=Kn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function tN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(Ce(a)>>>0>=b>>>0){h=e,i=Lb(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Gb(e+12|0,e+8|0)>>2];if(f){while(1){z[d>>2]=z[b>>2];d=d+4|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){Wy(a,b-d|0,c);break a}Ui(a,v[a>>2]+(b<<2)|0);break a}KN(a);f=Tg(a,b);d=a;if(Ut(a)>>>0<f>>>0){Mc();L()}wb(d);g=pN(f);v[d>>2]=g;v[d+4>>2]=g;h=wb(d),i=(f<<2)+g|0,v[h>>2]=i;ol(d,0);Wy(a,b,c)}gb=e+16|0}function sD(a,b,c){var d=0,e=0;d=gb+-64|0;gb=d;Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;c=Wd(d+40|0);e=v[23048];v[23048]=0;a:{b:{c:{if((e|0)==1){break c}c=zb(c);v[23048]=0;Xe(d+8|0,3,c,a);a=v[23048];v[23048]=0;if((a|0)==1){break c}v[23048]=0;S(398,d+24|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break c}v[23048]=0;Q(449,b|0,d+24|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}vb(d+24|0);Ac(d+40|0);gb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}Ac(d+40|0);R(c|0);L()}function Z_(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=Tb(b,11186);v[23048]=0;T(211,b+16|0,a|0,c|0);a=v[23048];v[23048]=0;a:{b:{c:{if((a|0)!=1){vb(c);if(Gc(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;vb(c);break b}a=0;while(1){d:{c=Id(b+16|0,d);v[23048]=0;c=U(212,c|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=Gc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;em(b+16|0)}R(d|0);L()}em(b+16|0);gb=b+32|0;return a|0}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=(e<<1)+j|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function J3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115529];v[115529]=0;a=qx(a,e+12|0,d,Be());d=jb;g=v[115529];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115529]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a&65535}function YZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-48|0;gb=d;f=-1;c=gb-32|0;gb=c;g=d+8|0;bs(c+24|0,g);h=xb(c+24|0);e=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=e;v[c>>2]=i;v[c+4>>2]=e;md(c+16|0,a,c);e=xb(c+16|0);if((e|0)==(h|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(e|0)==(h|0);if(!a){as(g)}a:{if(!a){break a}f=0;if(!eF(d+8|0)){break a}if(b){c=v[b>>2];a=d+12|0;if(!v[b+4>>2]&c>>>0<Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))-8>>>0){break a}}f=1}gb=d+48|0;return f|0}function kI(a){var b=0,c=0,d=0,e=0;b=gb-160|0;gb=b;a=Pn(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[23048]=0;c=fa(131)|0;e=v[23048];v[23048]=0;a:{if((e|0)==1){break a}v[23048]=0;T(132,b+8|0,d+(b+16|0)|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}Xb(b+8|0);v[23048]=0;d=Q(164,a|0,b+4|0)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}c=v[v[d>>2]-12>>2];v[23048]=0;d=cp(c+d|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}c=v[b+4>>2];ag(a);gb=b+160|0;return d?0:c}b=P()|0;O()|0;ag(a);R(b|0);L()}function Uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){g=g<<8;h=h<<8;while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+B(h,t[e|0]);v[c+4>>2]=v[c+4>>2]+B(f,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function r2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-32|0;gb=f;d=Bb(a);e=Nc(a);g=_h(b,c);a:{if(!g){break a}if(PC(b,Ob(a),Ob(a)+Bb(a)|0)){b=pj(f+16|0,b,c);c=Ob(b);d=Bb(b);v[23048]=0;W(2228,a|0,c|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);R(a|0);L()}if(e-d>>>0<g>>>0){op(a,e,(d+g|0)-e|0,d,d,0,0)}e=Ob(a)+d|0;if((b|0)!=(c|0)){while(1){Qd(e,b);e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Qd(e,f+15|0);yh(a,d+g|0)}gb=f+32|0}function xda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;g=$f(a,c);we(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{b:{if(!g){d=-1;if(!nd(a,5)){break b}break a}d=v[g+8>>2]}h=v[a+28>>2];c:{if(!((d|0)!=-1?(d|0)!=4:0)){d=gb-16|0;gb=d;v[d+8>>2]=0;rq(h,d+8|0);z[b>>2]=z[d+8>>2];gb=d+16|0;break c}e=gb-32|0;gb=e;v[e+28>>2]=0;v[e+24>>2]=d;v[e+20>>2]=4;Zi(e+8|0,h,e+28|0,v[Gb(e+24|0,e+20|0)>>2]);v[b>>2]=0;gb=e+32|0}}Rf(a,g,c,f+24|0);gb=f+32|0}function eQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Gb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b|0]);d=zb(w[b+1|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+2|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+3|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+4|0])|(g|i);j=a,k=Lc(d,zb(w[b+5|0])<<8|g|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function dQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Gb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b+7|0]);d=zb(w[b+6|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+5|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+4|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+3|0])|(g|i);j=a,k=Lc(d,zb(w[b+2|0])<<8|g|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function JQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Gb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Gb(d+8|0,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function IQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];h=v[Gb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Gb(e+8|0,e+4|0)>>2];c=zb(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=zb(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=zb(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=zb(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}gb=e+16|0;return h+i|0}function bH(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;jb=v[e+4>>2];return v[e>>2]}function _Y(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Nb(b,c<<1);a:{if(!g){break a}tc(f+28|0,65535);Cf(a,x[f+28>>1]);h=f,i=Rb(a),v[h+16>>2]=i;h=f,i=Ub(a),v[h+8>>2]=i;if(!Fb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;if(!Dp(b,c)){pD(c)}c=w[f+24|0]|w[f+25|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}sf(f+16|0);if(Fb(f+16|0,f+8|0)){continue}break}}gb=f+32|0;return g|0}function eK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;c=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;b=e;a:{b:{switch(v[c+52>>2]){case 0:jq(b,c);break a;case 2:jq(b,ye(c));break a;case 3:jq(b,gk(c));break a;case 1:jq(b,ye(c));break a;default:break b}}jq(b,ye(c))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];gb=e+48|0}function $J(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;c=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;b=e;a:{b:{switch(v[c+52>>2]){case 0:iq(b,c);break a;case 2:iq(b,ye(c));break a;case 3:iq(b,gk(c));break a;case 1:iq(b,ye(c));break a;default:break b}}iq(b,ye(c))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];gb=e+48|0}function qU(a){var b=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>32){break a}b=a+32|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+34|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}return(w[a|0]|w[a+1|0]<<8)>>>0<129}return 0}function ln(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>=1){if((kn(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>=1){f=$g(i,b,f);g=Ob(f);v[23048]=0;g=W(28,a|0,g|0,b|0)|0;h=v[23048];v[23048]=0;if((h|0)==1){break a}vb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((kn(a,c,b)|0)!=(b|0)){break b}}EB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;vb(f);R(a|0);L()}function Uja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;DB(b,c,xb(d));e=v[b+16>>2];a:{if(e>>>0<=c>>>0){Gj(a,d,0);break a}v[f+28>>2]=e-c;i=f,j=xb(d),v[i+24>>2]=j;g=v[Gb(f+28|0,f+24|0)>>2];yB(f+16|0,d,0,g);e=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=e;e=gb-32|0;gb=e;b=b+4|0;i=e,j=Rb(b),v[i+24>>2]=j;h=Ne(e+24|0,c);i=e,j=Rb(b),v[i+8>>2]=j;i=e,j=Ne(e+8|0,c),v[i+16>>2]=j;b=f+8|0;Hi(h,Ne(e+16|0,xb(b)),v[b>>2]);gb=e+32|0;yB(a,d,0,g)}gb=f+32|0}function K0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(!(!e|(c|0)==(d|0))){while(1){a:{g=1;f=gb-16|0;gb=f;v[f+12>>2]=v[a+8>>2];h=ni(f+8|0,f+12|0);v[23048]=0;i=CH(c,d-c|0,b);l=v[23048];v[23048]=0;b:{if((l|0)!=1){jf(h);gb=f+16|0;break b}a=P()|0;O()|0;jf(h);R(a|0);L()}c:{switch(i+2|0){default:g=i;break;case 0:case 1:break a;case 2:break c}}j=g+j|0;c=c+g|0;if((d|0)==(c|0)){break a}k=k+1|0;if(k>>>0<e>>>0){continue}}break}return j|0}return 0}function e3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;$k(a+24|1,84102,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=Be();v[a>>2]=e;v[a+4>>2]=f;f=If(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Lg(g,f,c);e=g-48|0;gb=e;Ic(a+8|0,c);v[23048]=0;ia(2389,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){Xb(a+8|0);b=ln(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{if((b-1&65535)>>>0>3998){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!Od(e)){break a}g=a+1300264|0;d=a+1074984|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+880|0;if((g|0)!=(d|0)){continue}break}Al(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Lo(e,0,c)}gb=c+32|0;return f|0}function c3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;$k(a+24|1,84102,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=Be();v[a>>2]=e;v[a+4>>2]=f;f=If(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Lg(g,f,c);e=g-48|0;gb=e;Ic(a+8|0,c);v[23048]=0;ia(2389,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[23048];v[23048]=0;if((f|0)!=1){Xb(a+8|0);b=ln(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Xb(a+8|0);R(b|0);L()}function Sea(a,b){a=a|0;b=b|0;var c=0;b=33200;a=dd(a);a:{while(1){b:{if(!cd(a)){if(!hj(v[b+8>>2],v[qo(a)>>2])){break b}}v[23048]=0;S(1428,a|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=33752){continue}break}b=33760;while(1){c:{if(!cd(a)){if(!hj(v[b+8>>2],v[qo(a)>>2])){break c}}v[23048]=0;S(1428,a|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=33808){continue}break}return}b=P()|0;O()|0;Qc(a);R(b|0);L()}function kt(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!c|!(a&3)){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}a=a+1|0;c=c-1|0;d=(c|0)!=0;if(!c){break c}if(a&3){continue}break}}if(!d){break a}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function dea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;f=-1;c=gb-32|0;gb=c;g=d+8|0;$N(c+24|0,g);h=xb(c+24|0);e=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=e;v[c>>2]=i;v[c+4>>2]=e;md(c+16|0,a,c);e=xb(c+16|0);if((e|0)==(h|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(e|0)==(h|0);if(!a){jz(g)}a:{if(!a){break a}f=0;if(!TN(d+8|0)){break a}if(b){a=d+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}f=1}gb=d+32|0;return f|0}function KQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Gb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Gb(d+8|0,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=Kh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=Kh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function Gi(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;if(!cd(a)){uS(b+32|0,Ub(a));uS(b+24|0,Rb(a));c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=c;c=b+16|0;e=b+8|0;a:{if(!vS(c,e)){break a}while(1){d=gb-16|0;gb=d;v[d+8>>2]=v[c+4>>2];f=lS(d+8|0);gb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}lS(c+4|0);if(vS(c,e)){continue}break}}d=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=d;c=fD(Rb(a),v[b+44>>2])}gb=b+48|0;return c&65535}function aaa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[23048]=0;_(1943,a|0);h=v[23048];v[23048]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[23048]=0;b=sa(1960,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53378,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function EV(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!pf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!pf(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}gb=f+16|0}function Z9(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[23048]=0;_(1943,a|0);h=v[23048];v[23048]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[23048]=0;b=sa(1963,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53467,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function wH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115529];v[115529]=0;a=qx(a,e+12|0,d,Be());d=jb;g=v[115529];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115529]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a|0}function hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Jg(a);a:{if(b){v[23048]=0;S(933,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=gb-16|0;gb=d;c=d;v[c>>2]=a;e=v[a+4>>2];v[c+4>>2]=e;v[c+8>>2]=B(b,9)+e;b=v[c+4>>2];if((b|0)!=v[c+8>>2]){while(1){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=v[c+4>>2]+9|0;v[c+4>>2]=b;if(v[c+8>>2]!=(b|0)){continue}break}}_b(c);gb=d+16|0}return a|0}a=P()|0;O()|0;BB(c);R(a|0);L()}function gl(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[22953]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344?b>>>0>=55296:0)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[115529]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function Z6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a:{f=a;if((e|0)!=10){a=c;while(1){b:{if((a|0)==(b|0)){a=b;break b}g=d&255;d=(g|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(g-B(d,e)|0)+10274|0];if(d&255){continue}}break}c:{if(!(d&255)){d=c-a|0;if(d){break c}}v[f+4>>2]=61;v[f>>2]=c;break a}a=kh(b,a,d);v[f+4>>2]=0;v[f>>2]=a+d;break a}a=f;d:{e:{e=c-b|0;if((e|0)<=2){if((wy(d)|0)>(e|0)){break e}}h=f,i=uy(d,b),v[h>>2]=i;b=0;break d}v[f>>2]=c;b=61}v[a+4>>2]=b}}function X8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[23048]=0;_(2016,a|0);f=v[23048];v[23048]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[23048]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,56106,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function A6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=0,j=0,k=0;e=gb-16|0;gb=e;j=v[a+4>>2];$J(a,b,c,d);h=z[a+24>>2];v[e+8>>2]=v[a+20>>2];b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=gb-16|0;gb=a;v[a+8>>2]=v[e+8>>2];b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=a;if(!(!d|h==C(1))){while(1){if(c){k=g+j|0;f=0;while(1){i=xj(b,f,k);z[i>>2]=z[i>>2]*h;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}gb=a+16|0;gb=e+16|0}function EI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=gb-16|0;gb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Ob(a);a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Qn(v[Jc(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=om(k);if(e){ej(c,j,e)}if(g){ej(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;ej((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}b=b+1|0;if((b|0)!=2){Ph(a,j,b)}_e(a,c);ch(a,k);b=a;a=d+(e+g|0)|0;Ae(b,a);v[i+4>>2]=0;je(c+(a<<2)|0,i+4|0);gb=i+16|0;return}Og();L()}function Tma(a,b){a=a|0;b=b|0;var c=0,d=0;c=cf(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/20>>>0){dE(a,c);break c}b=wb(a);b=CX(d+8|0,DX(a,cf(a)+c|0),cf(a),b);v[23048]=0;S(725,b|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;QC(a,b);a=v[23048];v[23048]=0;if((a|0)==1){break b}vv(b)}gb=d+32|0;break a}a=P()|0;O()|0;vv(b);R(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,20)|0;cf(a);ND(a,b);Vl(a);cf(a)}}function Mfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+8>>2]=c>>>2;v[d+4>>2]=v[a>>2];f=v[Gb(d+8|0,d+4|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);le(d+12|0,C(-1));e=C(z[d+12>>2]*C(32768));z[d+12>>2]=e;h=a;e=Fe(e);a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}i=h,j=Uc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return f<<2}function At(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Bt(b)){break a}a=a+24|0;if(!oe(v[a>>2]+484344|0,b&65535)){break a}b=Yb(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0|(x[v[a>>2]+480188>>1]<=(d|0)|e>>>0>5)){break a}a=Wc(b,c,d&65535);b:{switch(e|0){case 0:f=w[a|0];break a;case 1:f=w[a+1|0];break a;case 2:f=w[a+2|0];break a;case 3:f=w[a+3|0];break a;case 4:f=w[a+4|0];break a;case 5:break b;default:break a}}f=w[a+5|0]}return f|0}function w6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-48|0;gb=e;f=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=f;f=v[b+4>>2];v[e+32>>2]=v[b>>2];v[e+36>>2]=f;b=gi(e+24|0,c);c=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=c;v[23048]=0;c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;ba(1941,a+8|0,e+8|0,b|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){mf(b);ZJ(a);b=YJ(a+88|0);v[a>>2]=59432;v[b>>2]=59520;gb=e+48|0;return a|0}a=P()|0;O()|0;mf(b);R(a|0);L()}function aY(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1064>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1072|0,g=Nk(a,7),t[f|0]=g;d=Nk(a,1);e=Nk(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;aY(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function _8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23048]=0;_(2016,a|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[23048]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55790,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ti(a,b,c,d);v[a>>2]=48976;d=nc(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=yf(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[23048]=0;W(1545,a+44|0,2,2)|0;c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;Oh(b);c=v[23048];v[23048]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Qc(d);nf(b);R(a|0);L()}function kc(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){c:{if((b|0)>(c|0)){if((b|0)>=25){break b}if(!c){v[a+1392>>2]=0}while(1){c=-1;e=nt(a);d=0;if((e|0)==-1){break c}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}return kc(a,24)+(kc(a,b-24|0)<<24)|0}ha(69750,69696,1617,69769);L()}function Z8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23048]=0;_(2016,a|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[23048]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55747,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Kc(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;if(v[a+4>>2]==v[b+4>>2]){c=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=c;v[d+8>>2]=b;v[d+12>>2]=c;e=gb-16|0;gb=e;v[e+12>>2]=v[a+4>>2];b=d;c=v[b+4>>2];v[23048]=0;v[e+8>>2]=c;c=Gb(e+12|0,e+8|0);f=v[23048];v[23048]=0;a:{if((f|0)!=1){c=lo(v[a>>2],v[b>>2],v[c>>2]);b:{if(c){break b}c=0;if(v[a+4>>2]==v[b+4>>2]){break b}c=y[a+4>>2]<y[b+4>>2]?-1:1}gb=e+16|0;break a}V(0)|0;O()|0;Ab();L()}c=!c}gb=d+16|0;return c}function V8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23048]=0;_(2016,a|0);d=v[23048];v[23048]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[23048]=0;T(f|0,d|0,b|0,(c|0)!=0|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,56052,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function T8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23048]=0;_(2016,a|0);d=v[23048];v[23048]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[23048]=0;T(f|0,d|0,b|0,(c|0)!=0|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,56004,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function $K(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=gb-48|0;gb=b;v[b+40>>2]=e;v[b+44>>2]=f;c=_d(b+32|0,c,d);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;a:{a=Sz(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=aa(8)|0;v[23048]=0;b=Q(91,b+16|0,56799)|0;c=v[23048];v[23048]=0;b:{if((c|0)!=1){rc(a,b);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;ca(a|0)}R(c|0);L()}gb=b+48|0;return a|0}L()}function NN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=a;d=b;if((c|0)!=(d|0)){e=gb-16|0;gb=e;g=v[d+4>>2];d=v[d>>2];f=(g-d|0)/6|0;a:{if(f>>>0<=Kj(c)>>>0){if(zg(c)>>>0<f>>>0){v[e+12>>2]=d;h=zg(c);v[e+12>>2]=v[e+12>>2]+B(h,6);h=d;d=v[e+12>>2];bz(h,d,v[c>>2]);az(c,d,g,f-zg(c)|0);break a}EC(c,bz(d,g,v[c>>2]));break a}JN(c);WW(c,rC(c,f));az(c,d,g,f)}gb=e+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];MN(a+24|0,b+24|0);$s(a+36|0,b+36|0)}function p5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[sd(e+12|0,sd(e+8|0,e+4|0))>>2];fi(b,v[a+12>>2],d);v[a+12>>2]=d+v[a+12>>2];f=d+f|0;b=b+d|0;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=Kh(d),t[h|0]=i;f=f+1|0;b=b+1|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function zM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ti(a,b,c,d);v[a>>2]=48108;c=nc(a+4260|0);v[a+4232>>2]=1061997773;d=a+4224|0;v[d>>2]=1061158912;v[d+4>>2]=1059082943;d=a+4216|0;v[d>>2]=1038174126;v[d+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[23048]=0;W(1545,a+44|0,2,2)|0;d=v[23048];v[23048]=0;a:{if((d|0)==1){break a}v[23048]=0;Oh(b);d=v[23048];v[23048]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Qc(c);nf(b);R(a|0);L()}function xN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Lb(a);if(c>>>0<=127){e=gb-32|0;gb=e;a:{b:{d=128-c|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){Wy(a,d,b);break c}c=wb(a);c=Vy(e+8|0,Tg(a,Lb(a)+d|0),Lb(a),c);v[23048]=0;T(1513,c|0,d|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break b}v[23048]=0;S(1514,a|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Rg(c)}gb=e+32|0;break a}a=P()|0;O()|0;Rg(c);R(a|0);L()}return}if((c|0)!=128){Ui(a,v[a>>2]+512|0)}}function nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb+-64|0;gb=e;Di(e+40|0,e+32|0,c);v[23048]=0;T(813,e+52|0,e+24|0,d|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[23048]=0;Ci(e+16|0,e+40|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;T(498,a|0,b|0,e+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jf(e+40|0);break b}a=P()|0;O()|0;vb(e+40|0)}R(a|0);L()}Jf(e+40|0);gb=e- -64|0}function SS(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=-1;f=d&2147483647;i=f;g=c;a:{if(!c&(f|0)==2147418112?a|b:(f|0)==2147418112&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;j=f;if((f|0)==2147418112?0:f>>>0>2147418112){break a}if(!(a|g|(i|j|b))){return 0}g=d&e;if((g|0)>0?1:(g|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?a|b:(d|0)>(e|0)?1:(d|0)>=(e|0)?c:0){break a}h=(a|c)!=0|(d^e|b)!=0}return h}function roa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb+-64|0;gb=e;aR(e+40|0,e+32|0,c);v[23048]=0;T(581,e+52|0,e+24|0,d|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[23048]=0;Ci(e+16|0,e+40|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;T(78,a|0,b|0,e+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jf(e+40|0);break b}a=P()|0;O()|0;vb(e+40|0)}R(a|0);L()}Jf(e+40|0);gb=e- -64|0}function ipa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb+-64|0;gb=e;Bn(e+40|0,e+32|0,c);v[23048]=0;T(228,e+52|0,e+24|0,d|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[23048]=0;Ci(e+16|0,e+40|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;T(78,a|0,b|0,e+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jf(e+40|0);break b}a=P()|0;O()|0;vb(e+40|0)}R(a|0);L()}Jf(e+40|0);gb=e- -64|0}function baa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[23048]=0;_(1943,a|0);f=v[23048];v[23048]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[23048]=0;b=ga(1959,f|0,b|0,c|0,d|0,e|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53351,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function TN(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1095062050?(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1346458146:0){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;return((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return 0}function Qna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb+-64|0;gb=e;Bn(e+40|0,e+32|0,c);v[23048]=0;T(213,e+52|0,e+24|0,d|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[23048]=0;Ci(e+16|0,e+40|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;T(78,a|0,b|0,e+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jf(e+40|0);break b}a=P()|0;O()|0;vb(e+40|0)}R(a|0);L()}Jf(e+40|0);gb=e- -64|0}function PL(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];a:{b:{if(!v[Gb(c+12|0,c+8|0)>>2]){break b}while(1){e=pq(t[oc(a,d)|0]);f=pq(t[oc(b,d)|0]);if((e|0)!=(f|0)){d=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];d=d+1|0;if(d>>>0>=y[Gb(c+12|0,c+8|0)>>2]){break b}continue}break}d=0;break a}d=0;if(v[a+4>>2]==v[b+4>>2]){break a}d=y[a+4>>2]<y[b+4>>2]?-1:1}gb=c+16|0;return d}function hZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb+-64|0;gb=e;bw(e+40|0,e+32|0,c);v[23048]=0;T(426,e+52|0,e+24|0,d|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[23048]=0;Ci(e+16|0,e+40|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;T(78,a|0,b|0,e+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jf(e+40|0);break b}a=P()|0;O()|0;vb(e+40|0)}R(a|0);L()}Jf(e+40|0);gb=e- -64|0}function _9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[23048]=0;_(1943,a|0);f=v[23048];v[23048]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[23048]=0;b=ga(1962,f|0,b|0,c|0,d|0,e|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53434,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=c;c=Nb(b,c<<2);a:{if(!c){break a}tc(d+28|0,65535);Cf(a,x[d+28>>1]);g=d,h=Rb(a),v[g+16>>2]=h;g=d,h=Ub(a),v[g+8>>2]=h;if(!Fb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];e=d+24|0;if(!is(b,e)){f=gb-16|0;gb=f;Bk(e);gb=f+16|0}e=w[d+24|0]|w[d+25|0]<<8;u[a>>1]=e;if((e|0)==65535){u[a>>1]=65535}sf(d+16|0);if(Fb(d+16|0,d+8|0)){continue}break}}gb=d+32|0;return c|0}function R8(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23048]=0;_(2016,a|0);d=v[23048];v[23048]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[23048]=0;Va(f|0,d|0,b|0,+c);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55966,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=qc(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){sn(a,d,c);break c}b=wb(a);b=Zg(e+8|0,qh(a,qc(a)+d|0),qc(a),b);v[23048]=0;T(679,b|0,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(349,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}ee(b)}gb=e+32|0;break a}a=P()|0;O()|0;ee(b);R(a|0);L()}return}if(b>>>0<d>>>0){Tm(a,v[a>>2]+b|0)}}function $_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb+-64|0;gb=e;Di(e+40|0,e+32|0,c);v[23048]=0;T(213,e+52|0,e+24|0,d|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[23048]=0;Ci(e+16|0,e+40|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;T(78,a|0,b|0,e+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jf(e+40|0);break b}a=P()|0;O()|0;vb(e+40|0)}R(a|0);L()}Jf(e+40|0);gb=e- -64|0}function l5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g>>2;v[e+4>>2]=c-f;d=v[sd(e+12|0,sd(e+8|0,e+4|0))>>2];ej(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+(d<<2);f=d+f|0;b=(d<<2)+b|0;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;f=f+1|0;b=b+4|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function i8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;d=Jg(a);v[23048]=0;_(2113,a|0);e=v[23048];v[23048]=0;a:{if((e|0)!=1){v[23048]=0;yt(c);c=v[23048];v[23048]=0;if((c|0)!=1){break a}}a=P()|0;O()|0;$n(d);R(a|0);L()}c=a;v[23048]=0;d=U(2058,a+16|0)|0;e=v[23048];v[23048]=0;b:{c:{if((e|0)!=1){v[23048]=0;Q(2059,a+36|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}v[a+52>>2]=1;return a|0}a=P()|0;O()|0;break b}a=P()|0;O()|0;$n(d)}$n(c);R(a|0);L()}function R7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){a=aa(8)|0;v[23048]=0;c=Q(91,h|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,4);c=zy(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=h+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function Qe(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=ro(a);f=e;i=e;a:{if(b){j=v[b+4>>2];h=v[b>>2];break a}h=ro(a)}v[i+8>>2]=h;v[f+12>>2]=j;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=Wl(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}gb=e+16|0;return a}function O7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){a=aa(8)|0;v[23048]=0;c=Q(91,h|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,4);c=yy(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=h+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function Au(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;e=1;a:{while(1){b:{KR(b,A[qe(c,0)>>3]);if((e|0)==1e4){f=d,g=Rb(c),v[f+8>>2]=g;f=d,g=Ub(c),v[f>>2]=g;if(Fb(d+8|0,d)){break b}break a}else{e=e+1|0;continue}}break}while(1){e=v[d+8>>2];f=e,h=KR(b,A[e>>3]),A[f>>3]=h;zu(d+8|0);if(Fb(d+8|0,d)){continue}break}}zB(a,c);gb=d+16|0}function fda(a,b){a=a|0;b=b|0;var c=0,d=0;c=Lb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){oN(a,c);break c}b=wb(a);b=UM(d+8|0,Tg(a,Lb(a)+c|0),Lb(a),b);v[23048]=0;S(1555,b|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(1552,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Rg(b)}gb=d+32|0;break a}a=P()|0;O()|0;Rg(b);R(a|0);L()}return}if(b>>>0<c>>>0){Ui(a,v[a>>2]+(b<<2)|0)}}function pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;e=Q(250,b|0,8)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}if(!e){break c}v[23048]=0;T(1481,d|0,b|0,c|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;S(1482,a|0,d|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}ae(d);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(d);break a}gb=d+32|0;return}b=P()|0;O()|0}Cd(a);R(b|0);L()}function ie(a){var b=0,c=0,d=0;d=Zp(Lf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function Zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=Co(a);a:{b:{c:{d:{while(1){v[23048]=0;e=Q(250,b|0,8)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}if(!e){break c}v[23048]=0;T(1194,d|0,b|0,c|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;S(1195,a|0,d|0);e=v[23048];v[23048]=0;if((e|0)==1){break d}ae(d);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(d);break a}gb=d+32|0;return}b=P()|0;O()|0}Nm(a);R(b|0);L()}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb+-64|0;gb=d;rA(d+40|0,d+32|0,c);v[23048]=0;T(678,d+52|0,d+24|0,45024);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[23048]=0;Ci(d+16|0,d+40|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;T(78,a|0,b|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jf(d+40|0);break b}a=P()|0;O()|0;vb(d+40|0)}R(a|0);L()}Jf(d+40|0);gb=d- -64|0}function K4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);f=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=f;e=-1;a:{b:{if(!dt(eb(v[a+60>>2],d+16|0,2,d+12|0)|0)){e=v[d+12>>2];if((e|0)>0){break b}}v[a>>2]=v[a>>2]|e&48^16;break a}g=v[d+20>>2];if(g>>>0>=e>>>0){break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}e=c}gb=d+32|0;return e|0}function W7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Bb(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[pc(b,0)|0]==43){break b}if(w[pc(b,0)|0]==45){break b}}i=d,j=Ld(b),v[i+8>>2]=j;i=d,j=Ne(d+8|0,e-c|0),v[i+16>>2]=j;Sd(d+24|0,d+16|0);Ex(b,v[d+24>>2],1,g)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function mE(a,b){a=a|0;b=b|0;var c=0,d=0;c=uc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){VD(a,c);break c}b=wb(a);b=tp(d+8|0,Jk(a,uc(a)+c|0),uc(a),b);v[23048]=0;S(394,b|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(365,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}zh(b)}gb=d+32|0;break a}a=P()|0;O()|0;zh(b);R(a|0);L()}return}if(b>>>0<c>>>0){pn(a,v[a>>2]+(b<<1)|0)}}function Vv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb+-64|0;gb=e;OY(e+40|0,c);v[23048]=0;T(213,e+52|0,e+24|0,d|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[23048]=0;Ci(e+16|0,e+40|0);c=v[23048];v[23048]=0;if((c|0)!=1){v[23048]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;T(78,a|0,b|0,e+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jf(e+40|0);break b}a=P()|0;O()|0;vb(e+40|0)}R(a|0);L()}Jf(e+40|0);gb=e- -64|0}function woa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,15);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function fG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-32|0;gb=d;v[d+16>>2]=c;v[d+24>>2]=b;j=d,k=Ld(a),v[j+8>>2]=k;h=Hk(d+24|0,d+8|0);f=h;b=Hk(d+16|0,d+24|0);e=gb-16|0;gb=e;v[e+12>>2]=b;a:{c=Bb(a);if(f>>>0<=c>>>0){if(b){i=Ob(a);g=c-f|0;v[e+8>>2]=g;b=v[Gb(e+12|0,e+8|0)>>2];v[e+12>>2]=b;g=g-b|0;if(g){f=f+i|0;mn(f,b+f|0,g);b=v[e+12>>2]}f=a;a=c-b|0;yh(f,a);t[e+7|0]=0;Qd(a+i|0,e+7|0)}gb=e+16|0;break a}Sn();L()}Ne(d+8|0,h);gb=d+32|0}function Ez(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;g=e;if(d?y[c+20>>2]>=2:0){f=v[b+480180>>2]==1}else{f=0}t[g+15|0]=f;d=!v[c+52>>2]|d;t[e+14|0]=d;if(!(!x[b+480188>>1]|(!d|v[b+480180>>2]!=2))){d=0;while(1){v[(B(d,880)+c|0)+1384>>2]=0;d=d+1|0;if(d>>>0<x[b+480188>>1]){continue}break}}v[c+24>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+48>>2]=v[c+52>>2];u[c+72>>1]=x[c+74>>1];t[a|0]=w[e+15|0];t[a+1|0]=w[e+14|0];gb=e+16|0}function jZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;d=-1;a:{if(!Qf(a,7)){break a}d=0;if(!LD(a,16712)){break a}c=gb-32|0;gb=c;d=f;zD(c+24|0,f);h=xb(c+24|0);e=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=e;v[c>>2]=g;v[c+4>>2]=e;e=a;md(c+16|0,e,c);g=xb(c+16|0);if((g|0)==(h|0)){bd(e,xb(c+24|0))}gb=c+32|0;e=(g|0)==(h|0);if(!e){yD(d)}d=-1;if(!e){break a}d=0;if(!KD(f)){break a}d=Qe(a,b,JD(f),jb)}gb=f+16|0;return d|0}function bj(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=b;a:{if(Zj(a,f+8|0)){v[c>>2]=v[c>>2]|6;b=0;break a}b=fl(a);if(!fh(d,2048,b)){v[c>>2]=v[c>>2]|4;b=0;break a}b=Jn(d,b);el(a);b=b-48|0;b:{if(!_j(a,f+8|0)|(e|0)<2){break b}while(1){g=fl(a);if(!fh(d,2048,g)){break a}g=Jn(d,g);el(a);b=(g+B(b,10)|0)-48|0;g=_j(a,f+8|0);if((e|0)<3){break b}e=e-1|0;if(g){continue}break}}if(!Zj(a,f+8|0)){break a}v[c>>2]=v[c>>2]|2}gb=f+16|0;return b}function aj(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=b;a:{if(al(a,f+8|0)){v[c>>2]=v[c>>2]|6;b=0;break a}b=km(a);if(!bl(d,2048,b)){v[c>>2]=v[c>>2]|4;b=0;break a}b=In(d,b);jm(a);b=b-48|0;b:{if(!lm(a,f+8|0)|(e|0)<2){break b}while(1){g=km(a);if(!bl(d,2048,g)){break a}g=In(d,g);jm(a);b=(g+B(b,10)|0)-48|0;g=lm(a,f+8|0);if((e|0)<3){break b}e=e-1|0;if(g){continue}break}}if(!al(a,f+8|0)){break a}v[c>>2]=v[c>>2]|2}gb=f+16|0;return b}function T_(a,b){a=a|0;b=b|0;var c=0;a=Jb(a);a:{if(w[b+16|0]){v[23048]=0;Q(222,a|0,11216)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[23048]=0;Q(222,a|0,11223)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}}if(hd(a)){v[23048]=0;Q(222,a|0,11230)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[23048]=0;Q(222,a|0,11236)|0;b=v[23048];v[23048]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;vb(a);R(b|0);L()}function TS(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a=Jb(a);d=Bb(b);v[23048]=0;S(111,a|0,d|0);d=v[23048];v[23048]=0;if((d|0)!=1){a:{e=c,f=Ld(b),v[e+8>>2]=f;e=c,f=hf(b),v[e>>2]=f;if(Fb(c+8|0,c)){while(1){b=w[v[c+8>>2]];b:{if((b|0)==13){v[23048]=0;S(110,a|0,10);break b}v[23048]=0;S(110,a|0,b<<24>>24)}b=v[23048];v[23048]=0;if((b|0)==1){break a}Se(c+8|0);if(Fb(c+8|0,c)){continue}break}}gb=c+16|0;return}}b=P()|0;O()|0;vb(a);R(b|0);L()}function IT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;g=v[c>>2];v[d+8>>2]=6553600;e=b+4|0;h=d,i=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h+4>>2]=i;f=+(g>>>0)*1.52587890625e-7;e=lr(f*+y[Gb(d+8|0,d+4|0)>>2]);v[d+12>>2]=e;v[d+4>>2]=6553600;b=b+8|0;h=d,i=Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),v[h>>2]=i;h=d,i=lr(f*+y[Gb(d+4|0,d)>>2]),v[h+8>>2]=i;v[d+4>>2]=v[c>>2]-e;Ou(a,d+12|0,Gb(d+4|0,d+8|0));gb=d+16|0}function eN(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(nl(a)>>>0<=Pf(a)>>>0){break b}b=wb(a);d=Pf(a);e=Pf(a);v[23048]=0;b=ba(1549,c+8|0,d|0,e|0,b|0)|0;d=v[23048];v[23048]=0;c:{d:{if((d|0)!=1){v[23048]=0;S(1550,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}St(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;St(b)}Z(a|0)|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[23048]=0;_(1943,a|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[23048]=0;b=ba(1958,e|0,b|0,c|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53326,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function cN(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(Ce(a)>>>0<=Lb(a)>>>0){break b}b=wb(a);d=Lb(a);e=Lb(a);v[23048]=0;b=ba(1551,c+8|0,d|0,e|0,b|0)|0;d=v[23048];v[23048]=0;c:{d:{if((d|0)!=1){v[23048]=0;S(1552,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}Rg(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Rg(b)}Z(a|0)|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23048]=0;_(2016,a|0);c=v[23048];v[23048]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[23048]=0;S(e|0,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,56116,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function K8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23048]=0;_(2016,a|0);c=v[23048];v[23048]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[23048]=0;S(e|0,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55844,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function J8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23048]=0;_(2016,a|0);c=v[23048];v[23048]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[23048]=0;S(e|0,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55826,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function mK(a,b,c,d,e){var f=0,g=0,h=0,i=0;if((e|0)!=10){f=c;while(1){a:{if((b|0)==(f|0)){f=b;break a}g=d&65535;d=(g|0)/(e|0)|0;f=f-1|0;t[f|0]=w[(g-B(d,e)|0)+10274|0];if(d&65535){continue}}break}b:{if(!(d&65535)){d=c-f|0;if(d){break b}}v[a+4>>2]=61;v[a>>2]=c;return}b=kh(b,f,d);v[a+4>>2]=0;v[a>>2]=b+d;return}e=a;c:{d:{f=c-b|0;if((f|0)<=4){if((wy(d)|0)>(f|0)){break d}}h=a,i=uy(d,b),v[h>>2]=i;a=0;break c}v[a>>2]=c;a=61}v[e+4>>2]=a}function X9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[23048]=0;_(1943,a|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[23048]=0;b=ba(1964,e|0,b|0,c|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53498,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function W9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[23048]=0;_(1943,a|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[23048]=0;b=ba(1965,e|0,b|0,c|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53537,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function V9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[23048]=0;_(1943,a|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[23048]=0;b=ba(1966,e|0,b|0,c|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53574,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function U9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[23048]=0;_(1943,a|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[23048]=0;b=ba(1967,e|0,b|0,c|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53619,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function P8(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23048]=0;_(2016,a|0);c=v[23048];v[23048]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[23048]=0;ta(e|0,c|0,+b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[23048]=0;Y(1920,55930,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23048]=0;X(20);d=v[23048];v[23048]=0;if((d|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function N8(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23048]=0;_(2016,a|0);c=v[23048];v[23048]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[23048]=0;ta(e|0,c|0,+b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[23048]=0;Y(1920,55896,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23048]=0;X(20);d=v[23048];v[23048]=0;if((d|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function L8(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23048]=0;_(2016,a|0);c=v[23048];v[23048]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[23048]=0;ta(e|0,c|0,+b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[23048]=0;Y(1920,55862,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23048]=0;X(20);d=v[23048];v[23048]=0;if((d|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function $9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[23048]=0;_(1943,a|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[23048]=0;b=ba(1961,e|0,b|0,c|0,d|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53403,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function S8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23048]=0;_(2016,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[23048]=0;d=+Ua(e|0,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55985,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Oaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=vj(C(C(yf(v[a+16>>2])>>>0)*C(.04500000178813934)));c=vj(C(C(b>>>0)*C(1.1892070770263672)));d=vj(C(C(c>>>0)*C(1.1892070770263672)));g=vj(C(C(d>>>0)*C(1.1892070770263672)));e=vj(C(C(b+d>>>0)*C(.11546666920185089)));f=vj(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;VL(a);TL(a)}function H8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Ic(a,b);v[23048]=0;T(137,d+8|0,b|0,c|0);e=v[23048];v[23048]=0;a:{if((e|0)==1){break a}Xb(d+8|0);v[23048]=0;e=v[b+24>>2];f=v[23048];v[23048]=0;if((f|0)==1){break a}if(e){v[23048]=0;b=v[b+24>>2];e=v[23048];v[23048]=0;if((e|0)==1){break a}v[23048]=0;T(138,d|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}Xb(d)}gb=d+16|0;return}b=P()|0;O()|0;Xb(a);R(b|0);L()}function s$(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;v[23048]=0;a=wG(1934,a,b,c,d,e,f);b=v[23048];v[23048]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;ia(1931,52615,g|0,h|0,i|0,j|0,k|0,l|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function kr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[lc(a,0)|0]&15)<<8|w[lc(a,1)|0];a:{if((d|0)==4095|!d){break a}e=108;while(1){f=x[(c<<1)+33840>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+33838>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[lc(a,2)|0];g=b,h=w[lc(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[lc(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[lc(a,3)|0],t[g+5|0]=h}function W8(a,b){a=a|0;b=b|0;var c=0,d=0;v[23048]=0;_(2016,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[23048]=0;b=Q(d|0,c|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,56079,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function U8(a,b){a=a|0;b=b|0;var c=0,d=0;v[23048]=0;_(2016,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[23048]=0;b=Q(d|0,c|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,56028,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function cP(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){a=gb-16|0;gb=a;f=a,g=Rb(c),v[f+8>>2]=g;f=a,g=Ub(c),v[f>>2]=g;if(Fb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[23048]=0;_(b|0,d|0);b=v[23048];v[23048]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;sl(c);Ab();L()}Hb(b+20|0);Hb(b+8|0);Zb(b);Ag(a+8|0);if(Fb(a+8|0,a)){continue}break}}sl(c);gb=a+16|0;Zb(c)}}}function Rp(a,b){a=a|0;b=b|0;var c=0,d=0;c=qc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){mr(a,c);break c}b=wb(a);b=Zg(d+8|0,qh(a,qc(a)+c|0),qc(a),b);v[23048]=0;S(201,b|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(199,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}ee(b)}gb=d+32|0;break a}a=P()|0;O()|0;ee(b);R(a|0);L()}return}if(b>>>0<c>>>0){Tm(a,v[a>>2]+b|0)}}function JV(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(jg(a)>>>0<=qc(a)>>>0){break b}b=wb(a);d=qc(a);e=qc(a);v[23048]=0;b=ba(45,c+8|0,d|0,e|0,b|0)|0;d=v[23048];v[23048]=0;c:{d:{if((d|0)!=1){v[23048]=0;S(37,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break d}ee(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;ee(b)}Z(a|0)|0;v[23048]=0;X(20);a=v[23048];v[23048]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function sk(a,b){a=a|0;b=b|0;var c=0,d=0;c=qc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){mr(a,c);break c}b=wb(a);b=Zg(d+8|0,qh(a,qc(a)+c|0),qc(a),b);v[23048]=0;S(46,b|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(37,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}ee(b)}gb=d+32|0;break a}a=P()|0;O()|0;ee(b);R(a|0);L()}return}if(b>>>0<c>>>0){Tm(a,v[a>>2]+b|0)}}function r9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[23048]=0;_(1943,a|0);f=v[23048];v[23048]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[23048]=0;b=At(f,b,c,d,e);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54668,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function pl(a,b){var c=0,d=0;c=Lb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){oN(a,c);break c}b=wb(a);b=Vy(d+8|0,Tg(a,Lb(a)+c|0),Lb(a),b);v[23048]=0;S(1515,b|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(1514,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Rg(b)}gb=d+32|0;break a}a=P()|0;O()|0;Rg(b);R(a|0);L()}return}if(b>>>0<c>>>0){Ui(a,v[a>>2]+(b<<2)|0)}}function n5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+28>>2];g=v[a+24>>2];b:{if(d>>>0<=g>>>0){if(((i=a,j=ah(t[b|0]),h=v[v[a>>2]+52>>2],kb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0;break b}v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[sd(e+12|0,e+8|0)>>2];fi(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=d+f|0;b=b+d|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;d=Q(250,b|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}if(!d){break c}v[23048]=0;S(1185,c|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(1186,a|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}ae(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);R(b|0);L()}function cga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;d=Q(250,b|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}if(!d){break c}v[23048]=0;S(1192,c|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(1193,a|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}ae(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);R(b|0);L()}function PY(){var a=0,b=0;a=gb-16|0;gb=a;a:{if(bb(a+12|0,a+8|0)|0){break a}b=Ad((v[a+12>>2]<<2)+4|0);v[116332]=b;if(!b){break a}b=Ad(v[a+8>>2]);if(!b){v[116332]=0;break a}v[v[116332]+(v[a+12>>2]<<2)>>2]=0;if(!(ab(v[116332],b|0)|0)){break a}v[116332]=0}gb=a+16|0;b:{if(t[465312]&1){break b}if(!Ud(465312)){break b}v[23048]=0;X(2297);a=v[23048];v[23048]=0;if((a|0)!=1){Td(465312);break b}a=P()|0;O()|0;af(465312);R(a|0);L()}lO()}function Cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;EW(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;gb=c+16|0}return a|0}function ypa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;d=Q(250,b|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}if(!d){break c}v[23048]=0;S(493,c|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(494,a|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}ae(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);R(b|0);L()}function nla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;d=Q(250,b|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}if(!d){break c}v[23048]=0;S(861,c|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(862,a|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}ae(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);R(b|0);L()}function _ma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;d=Q(250,b|0,6)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}if(!d){break c}v[23048]=0;S(723,c|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(724,a|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}ae(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);R(b|0);L()}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ti(a,b,c,d);v[a>>2]=48368;c=nc(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[23048]=0;W(1545,a+44|0,2,2)|0;d=v[23048];v[23048]=0;a:{if((d|0)==1){break a}v[23048]=0;Oh(b);d=v[23048];v[23048]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Qc(c);nf(b);R(a|0);L()}function Ska(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;d=Q(250,b|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}if(!d){break c}v[23048]=0;S(900,c|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(901,a|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}ae(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);R(b|0);L()}function Aoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=_g(a);a:{b:{c:{d:{while(1){v[23048]=0;d=Q(250,b|0,8)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}if(!d){break c}v[23048]=0;S(575,c|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(576,a|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break d}ae(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;ae(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);R(b|0);L()}function rz(a,b,c,d){var e=0,f=0,g=0;f=gb-48|0;gb=f;a:{if(!c){c=Tc(a,b);a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;break a}e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;g=v[d+4>>2];e=f;v[e+16>>2]=v[d>>2];v[e+20>>2]=g;g=c>>>1|0;rz(a,b,g,e+16|0);yi(e+32|0,d,Tc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;rz(a,b|c,g,e)}gb=f+48|0}function l4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;$s(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Ob(c)+Bb(c)|0,v[d+44>>2]=e;Wn(a,Ob(c),Ob(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Bb(c);d=a,e=b+Ob(c)|0,v[d+44>>2]=e;lq(c,Nc(c));Tx(a,Ob(c),Ob(c)+Bb(c)|0);if(!(w[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b-2147483647|0;while(1){b=c;et(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}et(a,b)}}function gQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=jd(f|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[g>>1]=h;f=zb(w[b+4|0]);g=a,h=jd(f|zb(w[b+5|0])<<8|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function fQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+3|0]);g=a,h=jd(f|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+7|0]);g=a,h=jd(f|zb(w[b+6|0])<<8|zb(w[b+5|0])<<16|zb(w[b+4|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function daa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23048]=0;_(1943,a|0);d=v[23048];v[23048]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23048]=0;T(1957,d|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53294,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function qoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){qp(a,b);return}f=gb-32|0;gb=f;e=wb(a);g=Rl(a,Je(a)+1|0);i=Je(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=f+8|0;vd(c+12|0,e);if(g){d=g;if(d>>>0>=153391690){xc(17449);L()}d=jc(B(d,28),4)}v[c>>2]=d;e=B(i,28)+d|0;v[c+8>>2]=e;v[c+4>>2]=e;j=bc(c),k=B(g,28)+d|0,v[j>>2]=k;gb=h+16|0;Sl(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;en(a,c);Ql(c);gb=f+32|0}function npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){qp(a,b);return}f=gb-32|0;gb=f;e=wb(a);g=Rl(a,Je(a)+1|0);i=Je(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=f+8|0;vd(c+12|0,e);if(g){d=g;if(d>>>0>=153391690){xc(17033);L()}d=jc(B(d,28),4)}v[c>>2]=d;e=B(i,28)+d|0;v[c+8>>2]=e;v[c+4>>2]=e;j=bc(c),k=B(g,28)+d|0,v[j>>2]=k;gb=h+16|0;Sl(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;en(a,c);Ql(c);gb=f+32|0}function ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){qp(a,b);return}f=gb-32|0;gb=f;e=wb(a);g=Rl(a,Je(a)+1|0);i=Je(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=f+8|0;vd(c+12|0,e);if(g){d=g;if(d>>>0>=153391690){xc(25493);L()}d=jc(B(d,28),4)}v[c>>2]=d;e=B(i,28)+d|0;v[c+8>>2]=e;v[c+4>>2]=e;j=bc(c),k=B(g,28)+d|0,v[j>>2]=k;gb=h+16|0;Sl(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;en(a,c);Ql(c);gb=f+32|0}function eea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){qp(a,b);return}f=gb-32|0;gb=f;e=wb(a);g=Rl(a,Je(a)+1|0);i=Je(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=f+8|0;vd(c+12|0,e);if(g){d=g;if(d>>>0>=153391690){xc(44938);L()}d=jc(B(d,28),4)}v[c>>2]=d;e=B(i,28)+d|0;v[c+8>>2]=e;v[c+4>>2]=e;j=bc(c),k=B(g,28)+d|0,v[j>>2]=k;gb=h+16|0;Sl(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;en(a,c);Ql(c);gb=f+32|0}function Jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){qp(a,b);return}f=gb-32|0;gb=f;e=wb(a);g=Rl(a,Je(a)+1|0);i=Je(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=f+8|0;vd(c+12|0,e);if(g){d=g;if(d>>>0>=153391690){xc(25852);L()}d=jc(B(d,28),4)}v[c>>2]=d;e=B(i,28)+d|0;v[c+8>>2]=e;v[c+4>>2]=e;j=bc(c),k=B(g,28)+d|0,v[j>>2]=k;gb=h+16|0;Sl(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;en(a,c);Ql(c);gb=f+32|0}function kJ(a){var b=C(0),c=0,d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;j=a-24|0;b=z[j>>2];c=a-8|0;d=z[c>>2];e=C(b+d);k=a-16|0;f=z[k>>2];l=z[a>>2];g=C(f+l);z[a>>2]=e+g;z[c>>2]=g-e;c=a-28|0;g=z[c>>2];h=a-12|0;m=z[h>>2];e=C(g+m);p=h;h=a-20|0;i=z[h>>2];a=a-4|0;n=z[a>>2];o=C(i+n);z[p>>2]=o-e;i=C(n-i);b=C(d-b);z[c>>2]=i+b;d=C(m-g);f=C(l-f);z[k>>2]=d+f;z[j>>2]=f-d;z[a>>2]=o+e;z[h>>2]=i-b}function gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23048]=0;_(1943,a|0);d=v[23048];v[23048]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23048]=0;e=+oa(1953,d|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53224,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function cR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){qp(a,b);return}f=gb-32|0;gb=f;e=wb(a);g=Rl(a,Je(a)+1|0);i=Je(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=f+8|0;vd(c+12|0,e);if(g){d=g;if(d>>>0>=153391690){xc(30917);L()}d=jc(B(d,28),4)}v[c>>2]=d;e=B(i,28)+d|0;v[c+8>>2]=e;v[c+4>>2]=e;j=bc(c),k=B(g,28)+d|0,v[j>>2]=k;gb=h+16|0;Sl(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;en(a,c);Ql(c);gb=f+32|0}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;u[e+12>>1]=c;u[e+14>>1]=b;og(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=gb-16|0;gb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Gg(a)>>>0>=d>>>0){g=b,h=uc(a),v[g+8>>2]=h;kv(v[a>>2],v[Gb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){up(a,d-f|0,c);break a}pn(a,v[a>>2]+(d<<1)|0);break a}wS(a);OB(a,Jk(a,d));up(a,d,c)}gb=b+16|0;gb=e+16|0}function wd(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Al(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Tb(d,28120);v[23048]=0;Q(355,a+43|0,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){vb(b);CS(a);gb=d+16|0;return}a=P()|0;O()|0;vb(b);R(a|0);L()}function r$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[23048]=0;a=Ka(1935,a|0,b|0,c|0,d|0)|0;b=v[23048];v[23048]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;ia(1931,52641,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=b;d=gb-16|0;gb=d;v[d>>2]=c;v[d+8>>2]=b;b=lv(d,d+8|0);gb=d+16|0;a:{b=Ik(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[23048]=0;$o(c,d,f);c=v[23048];v[23048]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;Ag(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}$c(b);gb=e+32|0;return}a=P()|0;O()|0;$c(b);R(a|0);L()}function kw(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=gb-16|0;gb=i;if((b^-1)-17>>>0>=c>>>0){j=Ob(a);a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=$l(v[Jc(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=Tj(k);if(e){fi(c,j,e)}if(g){fi(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){fi((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){Rk(a,j,b)}_e(a,c);ch(a,k);b=a;a=d+(e+g|0)|0;Ae(b,a);t[i+7|0]=0;Qd(a+c|0,i+7|0);gb=i+16|0;return}Og();L()}function Wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Q8(a){a=a|0;var b=0,c=0,d=0;v[23048]=0;_(2016,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[23048]=0;c=+pa(d|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55948,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function O8(a){a=a|0;var b=0,c=0,d=0;v[23048]=0;_(2016,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[23048]=0;c=+pa(d|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55913,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function M8(a){a=a|0;var b=0,c=0,d=0;v[23048]=0;_(2016,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[23048]=0;c=+pa(d|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55879,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function IC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Nb(a,b)){break a}if(b>>>0<=3){c=gb-16|0;gb=c;if(Nb(a,b)){while(1){t[c+11|0]=0;b:{if(b>>>0>d>>>0){Ig(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;c=d;break a}c=_f(a);Vb(a,b-4|0)}t[f|0]=c}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){YO(a,b);return}f=gb-32|0;gb=f;e=wb(a);g=Jl(a,Lb(a)+1|0);i=Lb(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=f+8|0;vd(c+12|0,e);if(g){d=g;if(d>>>0>=1073741824){xc(32984);L()}d=jc(d<<2,4)}v[c>>2]=d;e=(i<<2)+d|0;v[c+8>>2]=e;v[c+4>>2]=e;j=bc(c),k=(g<<2)+d|0,v[j>>2]=k;gb=h+16|0;Eq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;Ji(a,c);Jz(c);gb=f+32|0}function yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;bf(b);Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;c=Wd(d+40|0);e=v[23048];v[23048]=0;b:{if((e|0)==1){break b}c=zb(c);v[23048]=0;Xe(d+8|0,1,c,a);a=v[23048];v[23048]=0;if((a|0)==1){break b}v[23048]=0;S(398,d+24|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Eb(b,d+24|0);vb(d+24|0);Ac(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;Ac(d+40|0);R(a|0);L()}}function Zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=Rb(b);f=Ub(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;if(Fb(c+24|0,c+16|0)){while(1){e=v[c+24>>2];if(v[v[c+8>>2]>>2]!=(w[e|0]|w[e+1|0]<<8)){np(c+24|0);if(Fb(c+24|0,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[d+8>>2]=e;g=d,h=Ub(b),v[g>>2]=h;a:{if(Fb(d+8|0,d)){Me(a,wb(v[d+8>>2]));break a}Ah(a)}gb=d+16|0}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=gb-32|0;gb=d;e=gb-16|0;gb=e;f=e,g=Ib(w[c|0]|w[c+1|0]<<8),u[f+14>>1]=g;qL(d+16|0,e+14|0);gb=e+16|0;v[23048]=0;tj(d+8|0,d+16|0);c=v[23048];v[23048]=0;b:{if((c|0)==1){break b}v[23048]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;T(78,a|0,b|0,d|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);R(a|0);L()}}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b>>2];f=SC(b);d=gb-16|0;gb=d;e=nr(c,f);a:{if(e>>>0<=Ce(a)>>>0){if(Lb(a)>>>0<e>>>0){v[d+12>>2]=c;UV(d+12|0,Lb(a));b=v[d+12>>2];vg(c,b,v[a>>2]);TV(a,b,f,e-Lb(a)|0);break a}Ui(a,vg(c,f,v[a>>2]));break a}SV(a);b=a;g=Tg(a,e);if(g>>>0>Ut(a)>>>0){Mc();L()}wb(b);h=IE(g);v[b>>2]=h;v[b+4>>2]=h;i=wb(b),j=(g<<2)+h|0,v[i>>2]=j;ol(b,0);TV(a,c,f,e)}gb=d+16|0}function Fm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=Rb(b);f=Ub(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Fb(c+24|0,c+16|0)){break a}while(1){if(SX(c+8|0,v[c+24>>2])){break a}v[c+24>>2]=v[c+24>>2]+28;if(Fb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=Ub(b),v[g>>2]=h;b:{if(Fb(d+8|0,d)){Me(a,wb(v[d+8>>2]));break b}Ah(a)}gb=d+16|0}function Zx(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!mt(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}ec(a,32);return 0}ha(69814,69696,1549,69835);L()}function L3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){g=v[115529];v[115529]=0;d=BH(a,e+12|0,d,Be());a=jb;f=v[115529];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[115529]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if((a|0)>0?1:(a|0)>=0?d>>>0>=1:0){d=-1;a=2147483647;break a}d=0;a=-2147483648}gb=e+16|0;jb=a;return d|0}function DB(a,b,c){var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;a:{if(w[a+20|0]){break a}b=(-1-b>>>0<c>>>0?-1-b|0:c)+b|0;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=HB(b,4096);AU(a,b-c|0);b=_d(d+16|0,oc(a+4|0,v[a+16>>2]),b-v[a+16>>2]|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;kb[c|0](d+24|0,a,d+8|0);f=a,g=xb(d+24|0)+v[a+16>>2]|0,v[f+16>>2]=g;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}gb=d+32|0}function Lu(a,b){var c=0;c=gb-32|0;gb=c;oT(c+16|0,a,a+1|0,a+2|0,a+3|0);oT(c,b,b+1|0,b+2|0,b+3|0);gb=c+32|0;b=c+16|0;a=c;c=1;a:{if(w[v[b>>2]]<w[v[a>>2]]){break a}c=0;if(w[v[a>>2]]<w[v[b>>2]]){break a}c=1;b:{if(t[v[b+4>>2]]<t[v[a+4>>2]]){break b}c=0;if(t[v[a+4>>2]]<t[v[b+4>>2]]){break b}c=1;c:{if(w[v[b+8>>2]]<w[v[a+8>>2]]){break c}c=0;if(w[v[a+8>>2]]<w[v[b+8>>2]]){break c}c=w[v[b+12>>2]]<w[v[a+12>>2]]}}}return c}function S7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[23048]=0;c=Q(91,f|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,2);c=zy(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=f+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function P7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[23048]=0;c=Q(91,f|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,2);c=yy(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=f+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=ti(a,b,c,d);v[a>>2]=47876;d=nc(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[23048]=0;W(1545,a+44|0,2,2)|0;b=v[23048];v[23048]=0;a:{if((b|0)==1){break a}v[23048]=0;Oh(c);b=v[23048];v[23048]=0;if((b|0)==1){break a}Lt(a);return a|0}a=P()|0;O()|0;Qc(d);nf(c);R(a|0);L()}function naa(a,b){a=a|0;b=b|0;var c=0,d=0;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;S(1946,c|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,52986,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Haa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;a:{b:{if(!a){break b}a=wc(b+8|0,a);v[23048]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=aL(b);c=v[23048];v[23048]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;Y(1920,52236,0,0,0);a=v[23048];v[23048]=0;if((a|0)!=1){$();break b}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}a=0}gb=b+16|0;return a|0}function l2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;d=v[dc(a)>>2];i=v[b>>2];g=v[a>>2];f=(d|0)==2402;j=f?0:g;d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}h=d?d:4;d=Yp(j,h);if(d){if(!f){Bd(a)}v[e+4>>2]=2350;d=ge(e+8|0,d,e+4|0);Ge(a,Bd(d));f=v[dc(d)>>2];k=dc(a),l=f,v[k>>2]=l;Hc(d);v[b>>2]=v[a>>2]+(i-g|0);v[c>>2]=v[a>>2]+(h&-4);gb=e+16|0;return}Ns();L()}function vna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;v[e+24>>2]=d;g=$f(a,c);we(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(nd(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=gb-16|0;gb=f;d=Jb(f);v[23048]=0;ba(671,b|0,h|0,d|0,i|0)|0;b=v[23048];v[23048]=0;b:{if((b|0)!=1){vb(d);gb=f+16|0;break b}a=P()|0;O()|0;vb(d);R(a|0);L()}}Rf(a,g,c,e+16|0);gb=e+32|0}function ofa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=gb-880|0;gb=d;b=Pb(a,0,76);v[b+84>>2]=0;v[b+88>>2]=0;v[b+80>>2]=256;u[b+76>>1]=65535;v[b+92>>2]=0;v[b+96>>2]=0;t[b+100|0]=1;e=b+225896|0;c=b+616|0;a=c;while(1){a=uB(a)+880|0;if((e|0)!=(a|0)){continue}break}d=Pb(d,0,880);e=uB(d);a=c;c=((a+225280|0)-a|0)/880|0;if((c|0)>=1){while(1){lu(a,e);a=a+880|0;f=(c|0)>1;c=c-1|0;if(f){continue}break}}gb=d+880|0;return b|0}function Uz(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074364|0]=b;qO(a+1074328|0,b);f=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;d=b;if(kb[v[v[b>>2]+136>>2]](b)|0){e=v[b+16>>2];b=e+1074328|0;c=C(C(c*C(y[e+480232>>2]))/C(z[b+8>>2]*z[b+20>>2]))}z[d+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function vD(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;bf(b);Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;e=Wd(d+40|0);f=v[23048];v[23048]=0;a:{if((f|0)==1){break a}e=zb(e);v[23048]=0;Xe(d+8|0,3,e,a);e=v[23048];v[23048]=0;if((e|0)==1){break a}v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break a}Eb(b,d+24|0);vb(d+24|0);Ac(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Ac(d+40|0);R(a|0);L()}function b9(a){a=a|0;var b=0;v[23048]=0;_(2016,a|0);b=v[23048];v[23048]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){kb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Zb(b);v[a+20>>2]=0}Zb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55293,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function K9(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;d=LK(c,b);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53973,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function J9(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;d=KK(c,b);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54016,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Ix(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-160|0;gb=e;Pb(e+16|0,0,144);v[e+92>>2]=-1;v[e+60>>2]=b;v[e+24>>2]=-1;v[e+20>>2]=b;oi(e+16|0,0,0);MI(e,e+16|0,d,1);d=v[e+8>>2];g=v[e+12>>2];h=v[e>>2];i=v[e+4>>2];if(c){j=c;f=b;b=v[e+20>>2]-v[e+24>>2]|0;k=b;c=b+v[e+136>>2]|0;b=v[e+140>>2]+(b>>31)|0;b=c>>>0<k>>>0?b+1|0:b;v[j>>2]=!(b|c)?f:f+c|0}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=g;gb=e+160|0}function I9(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;d=JK(c,b);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54059,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function H9(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;d=IK(c,b);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54103,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function G9(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;d=HK(c,b);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54151,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function BY(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;bf(b);Ue(d+40|0,a,c);a=v[d+40>>2];v[23048]=0;e=Wd(d+40|0);f=v[23048];v[23048]=0;a:{if((f|0)==1){break a}e=zb(e);v[23048]=0;Xe(d+8|0,2,e,a);e=v[23048];v[23048]=0;if((e|0)==1){break a}v[23048]=0;S(398,d+24|0,d+8|0);e=v[23048];v[23048]=0;if((e|0)==1){break a}Eb(b,d+24|0);vb(d+24|0);Ac(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Ac(d+40|0);R(a|0);L()}function kQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=jd(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;f=zb(w[b+3|0]);g=a,h=jd(zb(w[b+4|0])<<16|f<<8|zb(w[b+5|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function jQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=jd(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+5|0]);g=a,h=jd(zb(w[b+4|0])<<16|f<<8|zb(w[b+3|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function lJ(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){ec(a,21);return-1}if(v[a+1396>>2]<=9){hl(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=rm(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!((c|0)>-1|(v[a+1384>>2]?!w[a+1376|0]:0))){ec(a,21)}return c}ha(70024,69696,1778,70046);L()}function laa(a,b){a=a|0;b=b|0;var c=0,d=0;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;WK(c,b);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53052,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function iaa(a,b){a=a|0;b=+b;var c=0;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;b=+Xa(1951,c|0,+b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;Z(c|0)|0;v[23048]=0;Y(1920,53152,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;if((c|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function fV(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)>>>0<512|(w[b|0]|w[b+1|0]<<8)>>>0>767){break a}b=a+112|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;return(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return 0}function NJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((ao(a+8|0)|0)>(b|0)){break d}}b=aa(8)|0;v[23048]=0;c=Q(91,c|0,59689)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}rc(b,c);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}gb=c+16|0;return+(+v[(v[a+32>>2]+B(b,880)|0)+1075732>>2]*.015625)}a=P()|0;O()|0;ca(b|0)}R(a|0)}L()}function Oe(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Up(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(xG(a,b)&3){case 0:c=Up(A[b>>3],A[b+8>>3]);break a;case 1:c=-Vp(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Up(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Vp(A[b>>3],A[b+8>>3],1)}a=c;gb=b+16|0;return a}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=Sc(c+8|0,16,1,1,0);v[c+4>>2]=0;wd(a,0);yc(b);a:{if(Pr(b,26592)){Rc(b,12);if(!Lv(b)){Bp(d,2)}Rc(b,24);break a}if(xh(b,26600)){yc(b);v[c+4>>2]=4;break a}Li(d,8)}e=a,f=(Bf(b)>>>0)/(B(Zm(d),w[d|0])>>>3>>>0)|0,v[e>>2]=f;b=ug(d,a,b);if(!(!b|!v[c+4>>2])){d=v[a+20>>2];e=c,f=Oi(a),v[e>>2]=f;Pb(d,0,v[Gb(c+4|0,c)>>2])}gb=c+16|0;return(b|0)!=0|0}function j5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;a:{if((c|0)<1){break a}while(1){e=v[a+24>>2];g=v[a+28>>2];b:{if(e>>>0>=g>>>0){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}f=f+1|0;b=b+4|0;break b}v[d+12>>2]=g-e>>2;v[d+8>>2]=c-f;e=v[sd(d+12|0,d+8|0)>>2];ej(v[a+24>>2],b,e);g=e<<2;v[a+24>>2]=g+v[a+24>>2];f=f+e|0;b=b+g|0}if((c|0)>(f|0)){continue}break}}gb=d+16|0;return f|0}function Nv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=Rb(b);f=Ub(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;if(Fb(c+24|0,c+16|0)){while(1){if((uY(v[c+24>>2])|0)!=v[v[c+8>>2]>>2]){np(c+24|0);if(Fb(c+24|0,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[d+8>>2]=e;g=d,h=Ub(b),v[g>>2]=h;a:{if(Fb(d+8|0,d)){Me(a,wb(v[d+8>>2]));break a}Ah(a)}gb=d+16|0}function LQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+8>>2]=c;v[d+4>>2]=v[a>>2];e=v[Gb(d+8|0,d+4|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){j=d,k=Kh(w[b|0]),t[j+15|0]=k;t[d+14|0]=192;t[d+13|0]=63;h=d+13|0;i=gb-16|0;gb=i;f=d+15|0;g=d+14|0;if(!zj(f,g)){g=zj(h,f)?h:f}gb=i+16|0;t[a|0]=w[g|0]<<1;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function LJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((ao(a+8|0)|0)>(b|0)){break d}}b=aa(8)|0;v[23048]=0;c=Q(91,c|0,59689)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}rc(b,c);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}gb=c+16|0;return(w[(v[a+32>>2]+B(b,880)|0)+1075073|0]&4)>>>2|0}a=P()|0;O()|0;ca(b|0)}R(a|0)}L()}function upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+28>>2]=c;a:{if(!Nb(b,c<<1)){break a}tc(d+28|0,65535);Cf(a,x[d+28>>1]);e=d,f=Rb(a),v[e+16>>2]=f;e=d,f=Ub(a),v[e+8>>2]=f;if(!Fb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];c=d+24|0;if(!Dp(b,c)){pD(c)}c=Ib(w[d+24|0]|w[d+25|0]<<8);u[a>>1]=c;if((c|0)==65535){u[a>>1]=65535}sf(d+16|0);if(Fb(d+16|0,d+8|0)){continue}break}}gb=d+32|0}function Tt(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function T7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[23048]=0;c=Q(91,e|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,1);c=zy(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function Sfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=c;e=b;if(pp(b,c+24|0)){d=-1;a:{if(!Wb(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))){break a}d=Wb(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))}}td(f,e,d);e=Tl(a,c+24|0,c);yb(c);b:{a=d&1;if(!a){break b}v[23048]=0;Q(370,b|0,2-a|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break b}a=P()|0;O()|0;ae(e);R(a|0);L()}gb=c+32|0}function Q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[23048]=0;c=Q(91,e|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,1);c=yy(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function F9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=U(1983,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54200,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Eka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=vU(a,b);v[23048]=0;e=Q(907,a+12|0,b+12|0)|0;d=v[23048];v[23048]=0;b:{c:{if((d|0)!=1){v[23048]=0;Q(908,a+24|0,b+24|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;gc(e)}gc(c);R(a|0);L()}}function o_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+24>>2]=d;v[e+28>>2]=c;f=e+8|0;c=gb-48|0;gb=c;d=ms(c+24|0,jc(32,4),_c(c+16|0,c+40|0,1));g=v[d>>2];v[23048]=0;ba(279,g|0,b|0,e+28|0,e+24|0)|0;b=v[23048];v[23048]=0;a:{if((b|0)!=1){yw(f,bc(v[d>>2]),Bd(d));oF(d);gb=c+48|0;break a}a=P()|0;O()|0;oF(d);R(a|0);L()}vw(e+16|0,e+8|0);Uj(a,e+16|0);Bc(e+16|0);Bc(e+8|0);gb=e+32|0}function jaa(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;c=+pa(1950,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53116,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function us(a){var b=0,c=0;co(a,1,15124);v[23048]=0;b=fa(215)|0;c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[23048]=0;b=fa(216)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}t[a+16|0]=b;v[23048]=0;b=fa(217)|0;c=v[23048];v[23048]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[23048]=0;_(218,a+20|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;vb(a);R(b|0);L()}function t9(a,b){a=a|0;b=b|0;var c=0;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;b=AK(c,b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54599,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function s9(a,b){a=a|0;b=b|0;var c=0;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23048]=0;b=zK(c,b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54632,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function maa(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=v[b+8>>2];c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53016,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function _7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-32|0;gb=b;c=_d(b+24|0,c,d);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;a:{a=Sz(a,b,0);if(a+1>>>0>=3){a=aa(8)|0;v[23048]=0;b=Q(91,b+8|0,56799)|0;c=v[23048];v[23048]=0;b:{if((c|0)!=1){rc(a,b);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;ca(a|0)}R(c|0);L()}gb=b+32|0;return a|0}L()}function Mma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;YV(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;md(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){XV(g)}d=-1;a:{if(!c){break a}d=0;if(!eW(e+8|0)){break a}d=Qe(a,b,dW(e+8|0),jb)}gb=e- -64|0;return d|0}function Eca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;OM(c+8|0,a,0);if(xb(c+8|0)){a=v[a+20>>2];v[a+148>>2]=-1;d=gb-16|0;gb=d;b=v[c+8>>2];f=v[c+12>>2];e=_h(b,f);a=a+4|0;a:{if(e>>>0<=jg(a)>>>0){if(qc(a)>>>0<e>>>0){v[d+12>>2]=b;FO(d+12|0,qc(a));g=b;b=v[d+12>>2];vg(g,b,v[a>>2]);ur(a,b,f,e-qc(a)|0);break a}Tm(a,vg(b,f,v[a>>2]));break a}xv(a);Wo(a,qh(a,e));ur(a,b,f,e)}gb=d+16|0}gb=c+16|0}function noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-112|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;uX(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;md(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){tX(g)}d=-1;a:{if(!c){break a}d=0;if(!yX(e+8|0)){break a}d=Qe(a,b,xX(e+8|0),jb)}gb=e+112|0;return d|0}function haa(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;c=A[b+16>>3];b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53188,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function N7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[23048]=0;c=Q(91,e|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,2);c=cL(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function M7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[23048]=0;c=Q(91,e|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,4);c=cL(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function L7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[23048]=0;c=Q(91,e|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,2);c=bL(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function K7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[23048]=0;c=Q(91,e|0,56856)|0;b=v[23048];v[23048]=0;if((b|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}nj(a,b,4);c=bL(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}R(b|0)}L()}function GZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-512|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;xE(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;md(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){wE(g)}d=-1;a:{if(!c){break a}d=0;if(!BE(e+8|0)){break a}d=Qe(a,b,AE(e+8|0),jb)}gb=e+512|0;return d|0}
function AR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a+4>>2]=0;a:{if(b){b:{if($u(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}wb(a);e=av(d+16|0);v[23048]=0;f=Q(867,a|0,b|0)|0;g=v[23048];v[23048]=0;if((g|0)==1){break a}v[23048]=0;S(868,e|0,f|0);f=v[23048];v[23048]=0;if((f|0)==1){break a}v[e+4>>2]=b;KB(a,e);Ee(e)}rk(d,a);yp(d,b,w[c|0])}gb=d+32|0;return}a=P()|0;O()|0;Ee(e);R(a|0);L()}function Yy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;i=f+8|0;d=gb-16|0;gb=d;c=a;j=b;e=$d(a);g=dc(a);h=gb-16|0;gb=h;if(e){wb(c);while(1){c=kN(e+16|0,j);g=c?g:e;e=v[(c?4:0)+e>>2];if(e){continue}break}}c=v[Cc(h+8|0,g)>>2];gb=h+16|0;v[d+8>>2]=c;k=d,l=rh(a),v[k>>2]=l;a:{if(Nl(d+8|0,d)){if(!lN(wb(a),b,se(d+8|0))){break a}}c=rh(a)}gb=d+16|0;a=v[Cc(i,c)>>2];gb=f+16|0;return a}function O0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[e>>2]=c;c=2;a=cx(f+12|0,0,b,v[a+8>>2]);a:{if(a+1>>>0<2){break a}c=1;b=v[e>>2];g=d-b|0;d=a-1|0;if(g>>>0<d>>>0){break a}c=0;if(!d){break a}d=w[f+12|0];v[e>>2]=b+1;t[b|0]=d;a=a-2|0;if(!a){break a}b=f+12|0;while(1){d=w[b+1|0];g=v[e>>2];v[e>>2]=g+1;t[g|0]=d;b=b+1|0;a=a-1|0;if(a){continue}break}}gb=f+16|0;return c|0}function ji(a){var b=0,c=0;b=gb-16|0;gb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Vp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(xG(a,b)&3){case 0:a=Vp(A[b>>3],A[b+8>>3],1);break a;case 1:a=Up(A[b>>3],A[b+8>>3]);break a;case 2:a=-Vp(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Up(A[b>>3],A[b+8>>3])}gb=b+16|0;return a}function kaa(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=VK(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53084,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ie(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>5>>>0){TA(a,d,c);break c}b=wb(a);b=fS(e+8|0,fr(a,Ie(a)+d|0),Ie(a),b);v[23048]=0;T(1128,b|0,d|0,c|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}eS(a,b);QA(b)}gb=e+32|0;break a}a=P()|0;O()|0;QA(b);R(a|0);L()}return}if(b>>>0<d>>>0){pS(a,v[a>>2]+(b<<5)|0)}}function DZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-48|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;_D(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;md(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){ZD(g)}d=-1;a:{if(!c){break a}d=0;if(!rE(e+8|0)){break a}d=Qe(a,b,qE(e+8|0),jb)}gb=e+48|0;return d|0}function oo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;a:{while(1){g=h&255;if(dz(b,c,g>>>0>1)){t[f+15|0]=0;t[f+14|0]=0;RN(a,f+15|0,f+14|0);break a}th(b,d);th(c,e);h=h+1|0;if(g>>>0<3){continue}break}h=f;g=w[b|0];if(po(g)>>>0>po(w[d|0])>>>0){th(b,d);th(c,e);g=w[b|0]}t[h+11|0]=g;RN(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}gb=f+16|0}function bna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=gb-16|0;gb=e;d=-1;a:{if(!Qj(a,e+8|0)){break a}b:{c:{c=e+8|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(qn(19319)|0)){break c}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>259){break c}c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>255;break b}c=0}d=0;if(!c){break a}d=Qe(a,b,36,0)}c=d;gb=e+16|0;return c|0}function Q9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=SK(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53764,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function P9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=RK(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53797,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function O9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=QK(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53830,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function N9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=OK(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53863,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function M9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=NK(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53898,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function L9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=MK(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53929,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function E9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=ao(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54232,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function D9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=GK(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54264,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-1968|0;gb=f;c=gb-32|0;gb=c;g=f+8|0;JY(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=a;md(c+16|0,d,c);e=xb(c+16|0);if((e|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){IY(g)}d=-1;a:{if(!c){break a}d=0;if(!NY(f+8|0)){break a}d=Qe(a,b,1024,0)}gb=f+1968|0;return d|0}function C9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=FK(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54294,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function B9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=kl(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54326,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function A9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;b=kq(b);c=v[23048];v[23048]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,54361,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function LB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=nc(a);f=d,g=Rb(b),v[f+8>>2]=g;f=d,g=Ub(b),v[f>>2]=g;a:{if(Fb(d+8|0,d)){while(1){a=v[d+8>>2];if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){v[23048]=0;S(577,e|0,wb(a)|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}}np(d+8|0);if(Fb(d+8|0,d)){continue}break}}gb=d+16|0;return}a=P()|0;O()|0;kd(e);R(a|0);L()}function bB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-32|0;gb=f;v[f+8>>2]=c;g=f,h=Bf(b),v[g+28>>2]=h;Ue(f+8|0,b,v[Gb(f+8|0,f+28|0)>>2]);v[23048]=0;b=Wd(f+8|0);c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[23048]=0;a=ga(422,a|0,b|0,c|0,d|0,e|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break a}Ac(f+8|0);gb=f+32|0;return a|0}a=P()|0;O()|0;Ac(f+8|0);R(a|0);L()}function UJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){a=aa(8)|0;v[23048]=0;c=Q(91,c|0,59625)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=oh(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;Gq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}R(d|0)}L()}function SJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){a=aa(8)|0;v[23048]=0;c=Q(91,c|0,59646)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=oh(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;Gq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}R(d|0)}L()}function R9(a){a=a|0;var b=0,c=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23048]=0;c=TK(b);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,53723,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function nV(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function MB(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Ly(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(yf(v[a+16>>2])>>>0);c=C(C(kb[v[v[a>>2]+204>>2]](a))*b);d=a,e=C(C(c*C(2.0480000972747803))*C(kb[v[v[a>>2]+196>>2]](a))),z[d+4248>>2]=e;d=a,f=Bi(C(C(c*C(4.0960001945495605))+C(8192))),v[d+4256>>2]=f;c=C(kb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(kb[v[v[a>>2]+192>>2]](a)|0)){b=yG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function s0(){var a=0;a:{if(t[466040]&1){break a}if(!Ud(466040)){break a}a=465872;while(1){a=Jb(a)+12|0;if((a|0)!=466040){continue}break}Td(466040)}Zc(465872,88880);Zc(465884,88887);Zc(465896,88894);Zc(465908,88902);Zc(465920,88912);Zc(465932,88921);Zc(465944,88928);Zc(465956,88937);Zc(465968,88941);Zc(465980,88945);Zc(465992,88949);Zc(466004,88953);Zc(466016,88957);Zc(466028,88961)}function p0(){var a=0;a:{if(t[466216]&1){break a}if(!Ud(466216)){break a}a=466048;while(1){a=Jb(a)+12|0;if((a|0)!=466216){continue}break}Td(466216)}od(466048,88968);od(466060,88996);od(466072,89024);od(466084,89056);od(466096,89096);od(466108,89132);od(466120,89160);od(466132,89196);od(466144,89212);od(466156,89228);od(466168,89244);od(466180,89260);od(466192,89276);od(466204,89292)}function dda(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[23048]=0;S(488,b+4|0,8);b=v[23048];v[23048]=0;if((b|0)!=1){c=v[v[a+20>>2]+4>>2];b=v[a+4264>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(90496)|0;if((O()|0)==(da(90496)|0)){Z(b|0)|0;Cr(v[a+20>>2]+4|0);$();return}R(b|0);L()}function ama(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;a:{if(!d){break a}a=(e<<1)+a|0;e=c<<1;c=1;while(1){z[f+12>>2]=z[b>>2];le(f+12|0,C(-1));g=C(z[f+12>>2]*C(32768));z[f+12>>2]=g;i=a;g=Fe(g);b:{if(C(D(g))<C(2147483648)){h=~~g;break b}h=-2147483648}j=i,k=Uc(h),u[j>>1]=k;if((c|0)==(d|0)){break a}b=b+4|0;a=a+e|0;c=c+1|0;continue}}gb=f+16|0}function Moa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;c=gb-32|0;gb=c;g=f+8|0;wD(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=a;md(c+16|0,d,c);e=xb(c+16|0);if((e|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){Pv(g)}d=-1;a:{if(!c){break a}d=0;if(!LX(f+8|0)){break a}d=Qe(a,b,72,0)}gb=f+32|0;return d|0}function K$(){var a=0,b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;a:{a=v[116852];if(a){c=a+48|0;if(GG(c)){d=b;if(v[c>>2]==1126902529&v[c+4>>2]==1129074247){c=v[a+44>>2]}else{c=a+80|0}v[d+44>>2]=c;a=v[a>>2];c=v[a+4>>2];if(CG(90472,a,b+44|0)){break a}v[b+20>>2]=c;v[b+16>>2]=90254;L()}v[b+32>>2]=90254;L()}L()}a=v[b+44>>2];e=b,f=kb[v[v[a>>2]+8>>2]](a)|0,v[e+8>>2]=f;v[b+4>>2]=c;v[b>>2]=90254;L()}function C3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0;e=gb-16|0;gb=e;a:{if((a|0)!=(b|0)){g=v[115529];v[115529]=0;Be();d=gb-16|0;gb=d;Ix(d,a,e+12|0,0);f=KI(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115529];b:{if(a){if(v[e+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}v[c>>2]=4;break a}v[115529]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;f=C(0)}gb=e+16|0;return C(f)}function TF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-48|0;gb=d;f=v[b>>2];g=v[b+8>>2];e=v[c+4>>2];c=v[c>>2];v[d+16>>2]=c;v[d+20>>2]=e;v[d+24>>2]=c;v[d+28>>2]=e;Ch(d+32|0,d+16|0);c=v[v[f>>2]+28>>2];e=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=e;kb[c|0](d+40|0,f,g,d+8|0);c=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=c;Ch(a,d);h=b,i=xb(a)+v[b+8>>2]|0,v[h+8>>2]=i;gb=d+48|0}function Is(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}b=c&16384;a:{b:{if((d|0)!=256){if((d|0)!=4){break b}c=b?70:102;break a}c=b?69:101;break a}c=b?65:97;if((d|0)==260){break a}c=b?71:103}t[a|0]=c;return(d|0)!=260}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=b;wb(b);d=a;f=Jg(a);b:{c:{e=uc(b);if(e){v[23048]=0;S(850,d|0,e|0);g=v[23048];v[23048]=0;if((g|0)==1){break c}gS(d,v[c>>2],v[c+4>>2],e)}break b}a=P()|0;O()|0;_r(f);R(a|0);L()}v[23048]=0;Q(4,a+12|0,b+12|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}a=P()|0;O()|0;Ze(d);R(a|0);L()}}function vaa(a){a=a|0;var b=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Zb(Ct(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Zb(b);v[a+20>>2]=0}Zb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,52780,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function oZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;if(!Nb(b,c)){c=Bf(b)}v[a>>2]=c;e=v[b>>2];a:{if(kb[v[v[e>>2]+16>>2]](e)|0){c=a;a=v[b>>2];f=c,g=(kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[f+4>>2]=g;break a}e=a+8|0;sk(e,v[a>>2]);if(cd(e)){break a}a=_d(d+24|0,oc(e,0),c);c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;fc(d+16|0,b,d+8|0)}gb=d+32|0}function hoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-576|0;gb=f;c=gb-32|0;gb=c;e=f;fX(c+24|0,f);h=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;md(c+16|0,d,c);g=xb(c+16|0);if((g|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){eX(e)}e=-1;a:{if(!d){break a}e=0;if(!iX(f)){break a}e=Qe(a,b,hX(f),jb)}gb=f+576|0;return e|0}function eF(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}return Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>27}return 0}function OH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;c=Tb(d,c);v[23048]=0;T(2329,d+16|0,b|0,c|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){v[23048]=0;Q(2330,a|0,d+16|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break b}vb(d+16|0);vb(c);v[a>>2]=79848;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;gb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d+16|0)}vb(c);R(a|0);L()}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-608|0;gb=f;c=gb-32|0;gb=c;e=f;oU(c+24|0,f);h=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;md(c+16|0,d,c);g=xb(c+16|0);if((g|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){nU(e)}e=-1;a:{if(!d){break a}e=0;if(!qU(f)){break a}e=Qe(a,b,pU(f),jb)}gb=f+608|0;return e|0}function $na(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-192|0;gb=f;c=gb-32|0;gb=c;e=f;Mr(c+24|0,f);h=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;md(c+16|0,d,c);g=xb(c+16|0);if((g|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){JW(e)}e=-1;a:{if(!d){break a}e=0;if(!cX(f)){break a}e=Qe(a,b,bX(f),jb)}gb=f+192|0;return e|0}function AI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;h=c;d=gb-16|0;gb=d;c=a;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){Gf(c,b);e=c;break b}f=Qn(b)+1|0;e=om(f);_e(c,e);ch(c,f);Ae(c,b)}c=e;f=b;c:{d:{if(b){v[23048]=0;SI(c,h,f);c=v[23048];v[23048]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Ab();L()}v[d+12>>2]=0;je((b<<2)+e|0,d+12|0);gb=d+16|0;break a}Og();L()}gb=g+16|0;return a}function mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-80|0;gb=f;c=gb-32|0;gb=c;e=f;VV(c+24|0,f);h=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;md(c+16|0,d,c);g=xb(c+16|0);if((g|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){kC(e)}e=-1;a:{if(!d){break a}e=0;if(!fT(f)){break a}e=Qe(a,b,eT(f),jb)}gb=f+80|0;return e|0}function Jla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;c=a;if(!w[c+8|0]){if(w[c+24|0]){t[c+24|0]=0;e=c+40|0;while(1){f=Um(e,b),g=0,t[f+8|0]=g;b=b+1|0;if((b|0)!=16){continue}break}b=c+28|0;sk(b,0);JV(b)}b=c+12|0;sk(b,v[c+4>>2]);me(d+24|0,b);b=v[v[c>>2]+40>>2];e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;kb[b|0](d+16|0,c,0,d+8|0);t[c+8|0]=1}gb=d+32|0;return v[a+12>>2]}function iX(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function Vka(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!YC(a,b+16|0)){break a}c=0;if(!HU(b+16|0)){break a}c=-1;if(!Qj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+8|0;c=(c|0)==((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))&2139062143)}a=c;gb=b+32|0;return a|0}function Ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-128|0;gb=f;c=gb-32|0;gb=c;e=f;dV(c+24|0,f);h=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;md(c+16|0,d,c);g=xb(c+16|0);if((g|0)==(h|0)){bd(d,xb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){cV(e)}e=-1;a:{if(!d){break a}e=0;if(!fV(f)){break a}e=Qe(a,b,256,0)}gb=f+128|0;return e|0}function HJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[23048]=0;c=Q(91,c|0,59689)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}rc(b,c);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=v[a+32>>2]+B(b,880)|0;v[a+1075e3>>2]=0;v[a+1075060>>2]=0;gb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}R(a|0)}L()}function GJ(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+60016>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+60016>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+60016>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+60016>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+60016>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function paa(a,b){a=a|0;b=b|0;var c=0;v[23048]=0;_(1943,a|0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Zb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,52929,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;wb(a);v[c+12>>2]=268435455;v[23048]=0;v[c+8>>2]=2147483647;d=Gb(c+12|0,c+8|0);e=v[23048];v[23048]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){Mc();L()}wb(a);c=b;if(c>>>0>268435455){xc(30724);L()}c=jc(c<<4,8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+(b<<4)|0,v[f>>2]=g;jG(a,0)}function hA(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=Ug(d,a,1);wb(a);je(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;_b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=EN(d+8|0,Tg(a,Lb(a)+1|0),Lb(a),c);je(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;v[23048]=0;S(100,a|0,c|0);a=v[23048];v[23048]=0;a:{if((a|0)!=1){Rg(c);gb=d+32|0;break a}a=P()|0;O()|0;Rg(c);R(a|0);L()}}function dI(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=gb-16|0;gb=c;b=aa(16)|0;a=gb-16|0;gb=a;a:{if(t[462200]&1){break a}if(!Ud(462200)){break a}Td(462200)}_c(a+8|0,1,91868);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;gb=a+16|0;v[23048]=0;Q(2249,b|0,c|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){ja(b|0,78480,2250);L()}a=P()|0;O()|0;ca(b|0);R(a|0);L()}}function $G(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=gb-16|0;gb=f;e=(c+e|0)-c|0;a:{if(!e){b=d;break a}g=b-d|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=vp(d,g+i|0,f+15|0);if(!d){break a}if(!lo(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((g|0)>=(e|0)){continue}break}}gb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function Mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ti(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=48604;v[23048]=0;W(1545,a+44|0,2,2)|0;c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;Oh(b);c=v[23048];v[23048]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;nf(b);R(a|0);L()}function YQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){XG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=RQ(c+8|0,bx(a,Gc(a)+1|0),Gc(a),d);f=v[a+8>>2];v[23048]=0;Gn(d,f,b);b=v[23048];v[23048]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[23048]=0;Fn(e,a);b=v[23048];v[23048]=0;if((b|0)==1){break b}su(a);gb=c+32|0;break a}b=P()|0;O()|0;su(a);R(b|0);L()}}function I2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){XG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=RG(c+8|0,bx(a,Gc(a)+1|0),Gc(a),d);f=v[a+8>>2];v[23048]=0;Gn(d,f,b);b=v[23048];v[23048]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[23048]=0;Fn(e,a);b=v[23048];v[23048]=0;if((b|0)==1){break b}zs(a);gb=c+32|0;break a}b=P()|0;O()|0;zs(a);R(b|0);L()}}function A3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{if((a|0)!=(b|0)){g=v[115529];v[115529]=0;Be();d=gb-16|0;gb=d;Ix(d,a,e+12|0,1);f=Xx(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115529];b:{if(a){if(v[e+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}v[c>>2]=4;break a}v[115529]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;f=0}gb=e+16|0;return+f}function lca(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[v[a+20>>2]+148>>2]=-1;v[23048]=0;jn(c+8|0,a+4228|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){b=v[a+20>>2];d=v[c+8>>2];e=v[c+12>>2];v[23048]=0;T(1677,b+4|0,d|0,e|0);b=v[23048];v[23048]=0;if((b|0)!=1){break b}}b=V(90496)|0;if((O()|0)!=(da(90496)|0)){break a}Z(b|0)|0;Cr(v[a+20>>2]+4|0);$()}gb=c+16|0;return}R(b|0);L()}function lU(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;if(!w[a+20|0]){if(!(kb[v[v[a>>2]+40>>2]](a)|0)){d=a+4|0;while(1){AU(a,65536);c=_d(b+16|0,oc(d,v[a+16>>2]),65536);e=v[v[a>>2]+44>>2];f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;kb[e|0](b+24|0,a,b+8|0);g=a,h=xb(b+24|0)+v[a+16>>2]|0,v[g+16>>2]=h;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){continue}break}}t[a+20|0]=1}gb=b+32|0}function Oca(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function Yq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=gb-16|0;gb=b;e=Rb(a);f=Ub(a);c=gb-16|0;gb=c;v[c>>2]=f;v[c+8>>2]=e;if(Fb(c+8|0,c)){while(1){d=A[v[c+8>>2]>>3]+d;zu(c+8|0);if(Fb(c+8|0,c)){continue}break}}gb=c+16|0;g=b,h=Rb(a),v[g+8>>2]=h;g=b,h=Ub(a),v[g>>2]=h;if(Fb(b+8|0,b)){d=-d;while(1){a=v[b+8>>2];d=A[a>>3]+d;A[a>>3]=d;zu(b+8|0);if(Fb(b+8|0,b)){continue}break}}gb=b+16|0}function cna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[23048]=0;sC(f,b,c);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}$c(d);gb=e+16|0;return}a=P()|0;O()|0;$c(d);R(a|0);L()}function cB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+8>>2]=c;f=e,g=Bf(b),v[f+28>>2]=g;Ue(e+8|0,b,v[Gb(e+8|0,e+28|0)>>2]);v[23048]=0;b=Wd(e+8|0);c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[23048]=0;ba(943,a|0,b|0,c|0,d|0)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Ac(e+8|0);gb=e+32|0;return 1}a=P()|0;O()|0;Ac(e+8|0);R(a|0);L()}function lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;a:{a=v[a+1300464>>2];b:{if(a){kb[v[v[a>>2]+8>>2]](a,b,c);break b}v[d+8>>2]=0;if(!MF(eu(d+8|0),b)){break b}v[d+8>>2]=0;eu(d+8|0);v[d+24>>2]=0;a=eu(d+24|0);aP(d+8|0,32367,32388,132,42);v[23048]=0;ea(33,a|0,d+8|0,b|0,32358,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}}gb=d+32|0;return}a=P()|0;O()|0;R(a|0);L()}function lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;d=wf(64);v[23048]=0;f=U(1333,d|0)|0;g=v[23048];v[23048]=0;a:{if((g|0)!=1){d=ns(e+8|0,f);f=v[d>>2];v[23048]=0;b=W(1543,f|0,b|0,c|0)|0;c=v[23048];v[23048]=0;b:{c:{if((c|0)!=1){if((b|0)==1){break c}Oz(a);break b}a=P()|0;O()|0;yg(d);break a}gi(a,d)}yg(d);gb=e+16|0;return}a=P()|0;O()|0;Zb(d)}R(a|0);L()}function fA(a,b,c,d){a:{if(v[a+1074384>>2]!=(c|0)){break a}b:{if(d){c=B(b,880)+a|0;v[c+1075680>>2]=0;d=c+1074992|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075072|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,880)+a|0;v[c+1075672>>2]=0;c=v[c+1075072>>2]}d=B(b,880)+a|0;v[d+1075072>>2]=c|2097152;tl(a,b,255,0);if(!(w[d+1075073|0]&2)){break a}a=a+1300300|0;if(!Fd(a)){break a}Qh(v[a>>2],b,0)}}function Qka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;CU(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))!=1414807888){d=c+12|0}else{CU(a,c+11|0);t[b|0]=1;d=c+11|0}b=gb-16|0;gb=b;a:{b:{if(d){a=Tb(b,d);v[23048]=0;e=U(903,a|0)|0;d=v[23048];v[23048]=0;if((d|0)==1){break b}vb(a)}gb=b+16|0;break a}b=P()|0;O()|0;vb(a);R(b|0);L()}gb=c+16|0;return e|0}function Nma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,20);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[23048]=0;S(401,e|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[c>>2]+20|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}$c(c);gb=d+16|0;return}a=P()|0;O()|0;$c(c);R(a|0);L()}function zU(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|(w[a+65|0]!=1?w[a+65|0]!=16:0))){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}c=gb-16|0;gb=c;d=$D(b,a);gb=c+16|0;a=d?a:b;return(w[a|0]|w[a+1|0]<<8)!=0}return 0}function pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-1120|0;gb=e;c=gb-32|0;gb=c;TU(c+24|0,e+8|0);g=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;md(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(g|0)){bd(d,xb(c+24|0))}gb=c+32|0;d=-1;a:{if((f|0)!=(g|0)){break a}d=0;if(!WU(e+8|0)){break a}d=Qe(a,b,VU(e+8|0),jb)}gb=e+1120|0;return d|0}function oaa(a){a=a|0;var b=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Zb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,52959,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=ti(a,b,c,d);v[a>>2]=46248;d=nc(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=yf(c),v[e+4232>>2]=f;DY(a+4260|0,80,150,80,255);v[23048]=0;W(1545,a+44|0,2,2)|0;c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;Oh(b);c=v[23048];v[23048]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Qc(d);nf(b);R(a|0);L()}function R6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=gb-32|0;gb=b;v[b+24>>2]=c;c=v[b+24>>2];d=v[c+12>>2];v[b+16>>2]=v[c+8>>2];v[b+20>>2]=d;d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;qr(a);v[a>>2]=1420;nc(a+4|0);t[a+20|0]=0;v[a+16>>2]=0;v[a>>2]=1528;c=v[b+12>>2];v[a+24>>2]=v[b+8>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+32>>2]=v[b+16>>2];v[a+36>>2]=c;t[a+40|0]=0;gb=b+32|0;return a|0}function $la(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;a:{if(!d){break a}a=a+e|0;e=1;while(1){z[f+12>>2]=z[b>>2];le(f+12|0,C(-1));g=C(z[f+12>>2]*C(128));z[f+12>>2]=g;i=a;g=Fe(g);b:{if(C(D(g))<C(2147483648)){h=~~g;break b}h=-2147483648}j=i,k=DV(h),t[j|0]=k;if((d|0)==(e|0)){break a}a=a+c|0;b=b+4|0;e=e+1|0;continue}}gb=f+16|0}function sN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!Sf(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;uk(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}pl(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;rq(a,c+8|0);f=z[c+8>>2];g=Mb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=Sf(v[v[a>>2]-12>>2]+a|0)}d=e;gb=c+16|0;return d}function rN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!Sf(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;Yf(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}pl(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;rq(a,c+8|0);f=z[c+8>>2];g=Mb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=Sf(v[v[a>>2]-12>>2]+a|0)}a=e;gb=c+16|0;return a}function il(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=gb-32|0;gb=c;f=wc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Kc(c+8|0,c);gb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=e+16|0;return a}function QJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(!(b<=1?!(b<0):0)){a=aa(8)|0;v[23048]=0;c=Q(91,c|0,59667)|0;d=v[23048];v[23048]=0;if((d|0)==1){break c}rc(a,c);v[23048]=0;T(84,a|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=oh(b*256);v[v[a+32>>2]+1074448>>2]=d;gb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}R(d|0)}L()}function sm(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return t[a+69856|0]}if((a|0)<=511){return t[(a>>>5|0)+69856|0]+5|0}return t[(a>>>10|0)+69856|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return t[(a>>>15|0)+69856|0]+15|0}return t[(a>>>20|0)+69856|0]+20|0}if((a|0)<=536870911){return t[(a>>>25|0)+69856|0]+25|0}a=t[(a>>>30|0)+69856|0]+30|0}else{a=0}return a}function qaa(a){a=a|0;var b=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return ie(a)|0}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,52891,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();return 0}return ie(52181)|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function eka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Od(a)){break a}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break a}Al(b);Uo(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Mm(b)){break a}if(v[a>>2]!=(d|0)){as(b+68|0)}hc(zb(v[b+20>>2]),zb(v[a+20>>2])+c|0,d);a=x[b+34>>1];if(e){v[b+8>>2]=d;v[b+4>>2]=0;u[b+34>>1]=a|2;return}v[b+4>>2]=0;v[b+8>>2]=0;u[b+34>>1]=a&65533}}function t2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[dc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=Yp((f|0)==2402?0:v[a>>2],d);if(g){if((f|0)!=2402){Bd(a)}v[e+4>>2]=2350;f=ge(e+8|0,g,e+4|0);gH(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);gb=e+16|0;return}Ns();L()}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+f;a:{a=v[d>>2];if((a|0)!=v[d+4>>2]){while(1){v[23048]=0;S(1502,a|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}a=v[d>>2]+52|0;v[d>>2]=a;if(v[d+4>>2]!=(a|0)){continue}break}}$c(d);gb=e+16|0;return}a=P()|0;O()|0;$c(d);R(a|0);L()}function ZV(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;v[f+12>>2]=a;d=B(B(a,d),2500);a:{if(!(!c|b)){break a}if(!(!a|!b)){tc(f+12|0,10);d=B(w[v[f+12>>2]+19827|0],1e4);break a}e=+(a>>>0);b:{if(a-1>>>0<=9){e=7338401.379310345/e;if(!(e<4294967296&e>=0)){break b}d=~~e>>>0;break a}e=e*37878.78787878787;if(!(e<4294967296&e>=0)){break b}d=~~e>>>0;break a}d=0}gb=f+16|0;return d}function AF(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=119304647;v[23048]=0;v[b+8>>2]=2147483647;e=Gb(b+12|0,b+8|0);f=v[23048];v[23048]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>=d>>>0){a=am(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function XX(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=89478485;v[23048]=0;v[b+8>>2]=2147483647;e=Gb(b+12|0,b+8|0);f=v[23048];v[23048]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>=d>>>0){a=dn(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function Oq(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+812|0]=w[b+812|0]&15|c<<4;break a}c=w[b+812|0]>>>4|0;break a}if(d){if(c){t[b+836|0]=c;break a}c=w[b+836|0];break a}if(c){t[b+812|0]=c;break a}c=w[b+812|0]}b:{if(!(t[b+853|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function u2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[dc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=Yp((f|0)==2402?0:v[a>>2],d);if(g){if((f|0)!=2402){Bd(a)}v[e+4>>2]=2350;f=ge(e+8|0,g,e+4|0);gH(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];gb=e+16|0;return}Ns();L()}function dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=477218588;v[23048]=0;v[c+8>>2]=2147483647;d=Gb(c+12|0,c+8|0);e=v[23048];v[23048]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){Mc();L()}c=b;if(c>>>0>=477218589){xc(26316);L()}c=jc(B(c,9),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,9)|0,v[f>>2]=g}function Toa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=715827882;v[23048]=0;v[c+8>>2]=2147483647;d=Gb(c+12|0,c+8|0);e=v[23048];v[23048]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){Mc();L()}c=b;if(c>>>0>=715827883){xc(17250);L()}c=jc(B(c,6),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,6)|0,v[f>>2]=g}function Foa(a){a=a|0;var b=0,c=0,d=0;b=Jg(a);v[23048]=0;_(556,a|0);d=v[23048];v[23048]=0;if((d|0)!=1){d=gb-16|0;gb=d;b=d;v[b>>2]=a;c=v[a+4>>2];v[b+4>>2]=c;v[b+8>>2]=c+32768;c=v[b+4>>2];if((c|0)!=v[b+8>>2]){while(1){u[c>>1]=0;u[c+2>>1]=0;c=v[b+4>>2]+4|0;v[b+4>>2]=c;if(v[b+8>>2]!=(c|0)){continue}break}}_b(b);gb=d+16|0;return a|0}a=P()|0;O()|0;VC(b);R(a|0);L()}function Aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=4880644;v[23048]=0;v[c+8>>2]=2147483647;d=Gb(c+12|0,c+8|0);e=v[23048];v[23048]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){Mc();L()}c=b;if(c>>>0>=4880645){xc(26612);L()}c=jc(B(c,880),8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,880)|0,v[f>>2]=g}function kL(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=Lf(e);if((f|0)==(Bb(c)|0)){v[23048]=0;c=ga(592,c|0,0,-1,e|0,f|0)|0;e=v[23048];v[23048]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Ab();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=d+16|0;return a}function bJ(a,b){a:{if((b|0)>=128){a=C(a*C(1.7014118346046923e38));if((b|0)<255){b=b-127|0;break a}a=C(a*C(1.7014118346046923e38));b=((b|0)<381?b:381)-254|0;break a}if((b|0)>-127){break a}a=C(a*C(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=C(a*C(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return C(a*(l(2,(b<<23)+1065353216|0),q()))}function Cja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=134217727;v[23048]=0;v[c+8>>2]=2147483647;d=Gb(c+12|0,c+8|0);e=v[23048];v[23048]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){Mc();L()}c=b;if(c>>>0>=134217728){xc(26612);L()}c=jc(c<<5,4);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+(b<<5)|0,v[f>>2]=g}function VJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-32>>>0>=481){b=aa(8)|0;v[23048]=0;c=Q(91,c|0,59611)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}rc(b,c);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074412>>2]=B(b,1e4);gb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}R(a|0)}L()}function AY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=2147483647;v[23048]=0;v[b+8>>2]=2147483647;e=Gb(b+12|0,b+8|0);f=v[23048];v[23048]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>=d>>>0){a=Gg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-224|0;gb=e;c=gb-32|0;gb=c;mX(c+24|0,e);g=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;md(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(g|0)){bd(d,xb(c+24|0))}gb=c+32|0;d=-1;a:{if((f|0)!=(g|0)){break a}d=0;if(!qX(e)){break a}d=Qe(a,b,pX(e),jb)}gb=e+224|0;return d|0}function Rl(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=153391689;v[23048]=0;v[b+8>>2]=2147483647;e=Gb(b+12|0,b+8|0);f=v[23048];v[23048]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>=d>>>0){a=Mi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function BO(a,b){var c=0,d=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,880)+a|0;d=w[c+1075777|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}c=t[c+1075779|0];if((c|0)>=0){rP(a,b,(d|0)==32,((w[(B(b,880)+a|0)+1075830|0]<<5)+a|0)+901692|0,c&255);return}rP(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function AB(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=357913941;v[23048]=0;v[b+8>>2]=2147483647;e=Gb(b+12|0,b+8|0);f=v[23048];v[23048]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>=d>>>0){a=pg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function at(a,b,c,d){var e=0,f=0;e=gb-160|0;gb=e;hc(e+8|0,75176,144);a:{b:{if(b-1>>>0>=2147483647){if(b){break b}b=1;a=e+159|0}v[e+52>>2]=a;v[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;v[e+56>>2]=b;a=a+b|0;v[e+36>>2]=a;v[e+24>>2]=a;a=gJ(e+8|0,c,d,2216,2217);if(!b){break a}b=v[e+28>>2];t[b-((b|0)==v[e+24>>2])|0]=0;break a}v[115529]=61;a=-1}gb=e+160|0;return a}function uz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=F(c,.999);c=d*32768;h=d*3.141592653589793;i=xq(b);while(1){j=a;k=c;g=((e<<12^-1)&28672)+(e>>>3|0)|0;if((g|0)!=16384){f=+(g-16384|0);d=f*.000244140625;f=xq(K(f*-152587890625e-16*d+1)*b);d=h*d;d=f*ji(d)/(d*i)}else{d=1}l=j,m=HT(k*d),u[l>>1]=m;a=a+2|0;e=e+1|0;if((e|0)!=32768){continue}break}}function _K(a,b,c){var d=0;d=gb-48|0;gb=d;zL(d,b,v[c>>2]&2?16:10);Et(d+16|0,d,c);v[23048]=0;T(139,d+32|0,d+16|0,c|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){v[23048]=0;T(140,a|0,d+32|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}vb(d+32|0);vb(d+16|0);vb(d);gb=d+48|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+32|0)}vb(d+16|0);vb(d);R(c|0);L()}function XK(a,b,c){var d=0;d=gb-48|0;gb=d;xL(d,b,v[c>>2]&2?16:10);Et(d+16|0,d,c);v[23048]=0;T(139,d+32|0,d+16|0,c|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){v[23048]=0;T(140,a|0,d+32|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}vb(d+32|0);vb(d+16|0);vb(d);gb=d+48|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+32|0)}vb(d+16|0);vb(d);R(c|0);L()}function JD(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=Fpa(w[a+3|0],0,18,0);d=d+c|0;b=jb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}jb=a;return b}function Ay(a,b,c){var d=0;d=gb-48|0;gb=d;AL(d,b,v[c>>2]&2?16:10);Et(d+16|0,d,c);v[23048]=0;T(139,d+32|0,d+16|0,c|0);b=v[23048];v[23048]=0;a:{b:{if((b|0)!=1){v[23048]=0;T(140,a|0,d+32|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}vb(d+32|0);vb(d+16|0);vb(d);gb=d+48|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+32|0)}vb(d+16|0);vb(d);R(c|0);L()}function cz(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if((f|0)!=10|(e|0)!=20|w[b|0]!=159){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function _y(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=a;f=v[a+4>>2];v[d+4>>2]=f;v[d+8>>2]=B(b,52)+f;a:{if(v[d+4>>2]!=v[d+8>>2]){while(1){wb(a);b=v[d+4>>2];v[23048]=0;S(1502,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[d+4>>2]+52|0;v[d+4>>2]=b;if((b|0)!=v[d+8>>2]){continue}break}}_b(d);gb=e+16|0;return}a=P()|0;O()|0;_b(d);R(a|0);L()}function Pma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c;e=b;if(hW(b,c+24|0)){b=c+26|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}else{b=0}td(d,e,b);b=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;b=w[c+28|0]|w[c+29|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8;Lk(a+8|0,c);yb(c);gb=c+32|0}function BT(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=kb[a|0](b)|0;d=jb;f=d;if((d|0)<0){break b}if((kb[c|0](b,0,0,0)|0)<=-1){break a}if((kb[c|0](b,0,0,2)|0)<=-1){break a}d=kb[a|0](b)|0;a=jb;kb[c|0](b,e,f,0)|0;if((a|0)<0){break b}g=LU(d,a)}return g}kb[c|0](b,e,f,0)|0;return 0}function yfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=b;e=a+4|0;d=e;f=b+1074368|0;c=hc(wf(225896),f,614);b=0;while(1){g=B(b,880);lu((c+g|0)+616|0,(f+g|0)+616|0);b=b+1|0;if((b|0)!=256){continue}break}Ai(d,c);b=vk(a+8|0);c=dd(a+20|0);v[23048]=0;_(1277,a|0);d=v[23048];v[23048]=0;if((d|0)!=1){return a|0}a=P()|0;O()|0;qP(c);pP(b);oP(e);R(a|0);L()}function WJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-1>>>0>=65535){b=aa(8)|0;v[23048]=0;c=Q(91,c|0,59592)|0;a=v[23048];v[23048]=0;if((a|0)==1){break c}rc(b,c);v[23048]=0;T(84,b|0,56328,1945);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074408>>2]=b;gb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}R(a|0)}L()}function Tca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<11)+e;a:{if(v[c>>2]!=v[c+4>>2]){while(1){a=v[c>>2];v[23048]=0;Py(a);a=v[23048];v[23048]=0;if((a|0)==1){break a}a=v[c>>2]+2048|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}$c(c);gb=d+16|0;return}a=P()|0;O()|0;$c(c);R(a|0);L()}function $q(a,b){var c=0,d=0;a:{if(a-1>>>0<=268435455){a=a+208|0;Fpa(b,0,a,0);a=jb?0:B(a,b);break a}a=0}b:{if(!a){break b}v[23048]=0;b=U(2328,a|0)|0;c=v[23048];v[23048]=0;c:{d:{if((c|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;X(20);c=v[23048];v[23048]=0;b=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Ab();L()}if(!b){break b}d=Pb(b,0,a)- -64|0}return d}function saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23048]=0;_(1943,a|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,52831,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function fU(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if(w[a+30|0]!=2|((b|0)!=2?(b|0)!=26:0)){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if((b|0)!=88?b>>>0>=65:0){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function Ida(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;u[a>>1]=0;c=nc(a+4|0);d=nc(a+16|0);v[a+36>>2]=0;e=Jb(a+40|0);f=vk(a+52|0);xg(c);u[a+28>>1]=65472;v[23048]=0;v[b+12>>2]=1065353216;S(1511,c|0,b+12|0);g=v[23048];v[23048]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;xg(d);gb=b+16|0;return a|0}a=P()|0;O()|0;NW(f);vb(e);Qc(d);Qc(c);R(a|0);L()}function qQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Gb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b|0])+g|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+2|0])+d|0)+(zb(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function nQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Gb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b+1|0])+g|0)+(zb(w[b|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+3|0])+d|0)+(zb(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function Zaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ti(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=49984;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[23048]=0;W(1545,a+44|0,2,2)|0;c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;Oh(b);c=v[23048];v[23048]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;nf(b);R(a|0);L()}function Ah(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;f=a;b=gb-16|0;gb=b;g=b+8|0;c=gb-48|0;gb=c;d=ms(c+24|0,jc(16,4),_c(c+16|0,c+40|0,1));e=v[d>>2];v[23048]=0;U(272,e|0)|0;e=v[23048];v[23048]=0;a:{if((e|0)!=1){yw(g,bc(v[d>>2]),Bd(d));wF(d);gb=c+48|0;break a}a=P()|0;O()|0;wF(d);R(a|0);L()}Uj(f,b+8|0);Bc(b+8|0);gb=b+16|0;v[a+8>>2]=0;Xd(a+12|0);return a|0}function x5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=Bb(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Gb(f+12|0,f)>>2],v[g+4>>2]=h;b=lo(Ob(a)+b|0,d,v[Gb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}gb=f+16|0;return b|0}Sn();L()}function qna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b>>2];e=v[b>>2]+xb(b)|0;f=Bg(a);v[23048]=0;b=_h(d,e);c=v[23048];v[23048]=0;a:{b:{if((c|0)==1){break b}if(!b){break a}v[23048]=0;S(42,a|0,b|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;Y(708,a|0,d|0,e|0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;$m(f);R(a|0);L()}}function d8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=Ld(b),v[g+8>>2]=h;b:{if(!Bb(b)){break b}if(w[pc(b,0)|0]==43){c=c+1|0;Se(d+8|0);break b}if(w[pc(b,0)|0]!=45){break b}c=c+1|0;Se(d+8|0)}if(Bb(b)>>>0>=c>>>0){break a}e=Sd(d,d+8|0);f=Bb(b);Ex(b,v[e>>2],c-f|0,48)}Dc(a,b);gb=d+16|0}function cda(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((qc(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}My(a,b)}Tt(a)}function Ln(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;Ic(d+8|0,b);v[23048]=0;b=U(2376,d+8|0)|0;e=v[23048];v[23048]=0;a:{if((e|0)==1){break a}v[23048]=0;e=U(2385,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break a}v[c>>2]=e;v[23048]=0;S(2386,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}Xb(d+8|0);gb=d+16|0;return}a=P()|0;O()|0;Xb(d+8|0);R(a|0);L()}function uoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=nc(a);e=d,f=Rb(b),v[e+8>>2]=f;e=d,f=Ub(b),v[e>>2]=f;a:{if(Fb(d+8|0,d)){while(1){b=v[d+8>>2];if((uY(b)|0)==(c|0)){v[23048]=0;S(577,a|0,wb(b)|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}}np(d+8|0);if(Fb(d+8|0,d)){continue}break}}gb=d+16|0;return}b=P()|0;O()|0;kd(a);R(b|0);L()}function Nq(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+812|0];if(c){t[b+812|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+836|0]=c;break a}c=w[b+836|0];break a}if(c){t[b+812|0]=c;break a}c=w[b+812|0]}b:{if(!(t[b+853|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function Nn(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;Ic(d+8|0,b);v[23048]=0;b=U(2346,d+8|0)|0;e=v[23048];v[23048]=0;a:{if((e|0)==1){break a}v[23048]=0;e=U(2358,b|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break a}t[c|0]=e;v[23048]=0;S(2359,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}Xb(d+8|0);gb=d+16|0;return}a=P()|0;O()|0;Xb(d+8|0);R(a|0);L()}function opa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-48|0;gb=d;Di(d+32|0,d+24|0,c);v[23048]=0;tj(d+16|0,d+32|0);c=v[23048];v[23048]=0;b:{if((c|0)==1){break b}v[23048]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;T(498,a|0,b|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Hb(d+32|0);gb=d+48|0;break a}a=P()|0;O()|0;Hb(d+32|0);R(a|0);L()}}function rQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+2|0])|zb(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function oQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+3|0])|zb(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function Uw(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1|v[a+48>>2]!=1){break a}t[a+54|0]=1;return}if((b|0)==(c|0)){b=v[a+24>>2];if((b|0)==2){v[a+24>>2]=d}else{d=b}if((d|0)!=1|v[a+48>>2]!=1){break a}t[a+54|0]=1;return}t[a+54|0]=1;v[a+36>>2]=v[a+36>>2]+1}}function Kna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-48|0;gb=d;rA(d+32|0,d+24|0,c);v[23048]=0;tj(d+16|0,d+32|0);c=v[23048];v[23048]=0;b:{if((c|0)==1){break b}v[23048]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;T(78,a|0,b|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Hb(d+32|0);gb=d+48|0;break a}a=P()|0;O()|0;Hb(d+32|0);R(a|0);L()}}function zZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-48|0;gb=d;bw(d+32|0,d+24|0,c);v[23048]=0;tj(d+16|0,d+32|0);c=v[23048];v[23048]=0;b:{if((c|0)==1){break b}v[23048]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;T(78,a|0,b|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Hb(d+32|0);gb=d+48|0;break a}a=P()|0;O()|0;Hb(d+32|0);R(a|0);L()}}function qS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-48|0;gb=d;Di(d+32|0,d+24|0,c);v[23048]=0;tj(d+16|0,d+32|0);c=v[23048];v[23048]=0;b:{if((c|0)==1){break b}v[23048]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;T(78,a|0,b|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Hb(d+32|0);gb=d+48|0;break a}a=P()|0;O()|0;Hb(d+32|0);R(a|0);L()}}function f8(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;a=nc(a);v[23048]=0;S(2072,b+16|0,0);c=v[23048];v[23048]=0;a:{b:{if((c|0)!=1){c=Rb(b+16|0);d=Ub(b+16|0);e=v[Cc(b+8|0,a)>>2];v[23048]=0;T(2073,c|0,d|0,e|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}Qc(b+16|0);gb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;Qc(b+16|0)}yd(a);R(c|0);L()}function Wla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,24);a:{b=v[c+4>>2];if((b|0)!=v[c+8>>2]){while(1){v[23048]=0;_(815,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}b=v[c+4>>2]+24|0;v[c+4>>2]=b;if(v[c+8>>2]!=(b|0)){continue}break}}_b(c);gb=d+16|0;return}a=P()|0;O()|0;_b(c);R(a|0);L()}function XU(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=Fpa(w[a+30|0],0,37,0);c=jb;d=b;b=a+24|0;b=Fpa(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=jb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;e=d;a=w[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;if(b>>>0<192){a=a+1|0}jb=a;return b}function Saa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ti(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=50216;v[23048]=0;W(1545,a+44|0,2,2)|0;c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;Oh(b);c=v[23048];v[23048]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;nf(b);R(a|0);L()}function zja(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,880);a:{b=v[c+4>>2];if((b|0)!=v[c+8>>2]){while(1){v[23048]=0;CT(b);a=v[23048];v[23048]=0;if((a|0)==1){break a}b=v[c+4>>2]+880|0;v[c+4>>2]=b;if(v[c+8>>2]!=(b|0)){continue}break}}_b(c);gb=d+16|0;return}a=P()|0;O()|0;_b(c);R(a|0);L()}function taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23048]=0;_(1943,a|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1928;return}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,52803,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function H4(a){a=a|0;a:{v[23048]=0;U(2303,464456)|0;a=v[23048];v[23048]=0;b:{if((a|0)==1){break b}v[23048]=0;U(2304,464540)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}v[23048]=0;U(2303,464792)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}v[23048]=0;U(2304,464876)|0;a=v[23048];v[23048]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Ab();L()}}function CG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb+-64|0;gb=d;e=1;a:{if(Kg(a,b,0)){break a}e=0;if(!b){break a}b=Ww(b,91048,91096);e=0;if(!b){break a}Pb(d+8|4,0,52);v[d+56>>2]=1;v[d+20>>2]=-1;v[d+16>>2]=a;v[d+8>>2]=b;kb[v[v[b>>2]+28>>2]](b,d+8|0,v[c>>2],1);a=v[d+32>>2];if((a|0)==1){v[c>>2]=v[d+24>>2]}e=(a|0)==1}a=e;gb=d- -64|0;return a|0}function Bh(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=e;e=0;i=e;f=c;c=0;e=Fpa(h,e,f,c);j=jb;g=b;k=Fpa(d,0,b,0);b=jb;d=Fpa(d,l,f,c);c=b+d|0;b=jb;b=c>>>0<d>>>0?b+1|0:b;f=b;d=b+e|0;b=j;b=d>>>0<f>>>0?b+1|0:b;f=d;e=b;b=Fpa(g,m,h,i)+c|0;d=jb;d=b>>>0<c>>>0?d+1|0:d;g=d;d=d+f|0;v[a+8>>2]=d;v[a+12>>2]=d>>>0<g>>>0?e+1|0:e;v[a>>2]=k;v[a+4>>2]=b}function kpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-624|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;nY(c+24|0,f);g=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(g|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){mY(f)}if(a){e=pY(b+8|0)}gb=b+624|0;return e|0}function X7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-48|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+16>>2]=b;v[d+20>>2]=e;v[d+32>>2]=b;v[d+36>>2]=e;Ch(d+40|0,d+16|0);b=Uj(d+24|0,c);v[23048]=0;c=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=c;W(254,a|0,d+8|0,b|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){Bc(b);gb=d+48|0;return}a=P()|0;O()|0;Bc(b);R(a|0);L()}function Ika(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;sU(c+24|0,f);g=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(g|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){rU(f)}if(a){e=zU(b+8|0)}gb=b+160|0;return e|0}function y5(a,b){a=a|0;b=b|0;var c=0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(Ke(b,-1)){Wn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return _s(b)|0}if(!(w[a+48|0]&16)){if(!Ke(Kh(b),t[v[a+12>>2]-1|0])){break a}}Wn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=Kh(b);t[v[a+12>>2]]=c;return b|0}return-1}function op(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=gb-16|0;gb=h;if(-17-b>>>0>=c>>>0){i=Ob(a);a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=$l(v[Jc(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=Tj(j);if(e){fi(c,i,e)}d=d-(e+f|0)|0;if(d){fi((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){Rk(a,i,b)}_e(a,c);ch(a,j);gb=h+16|0;return}Og();L()}function Qi(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if((b|0)<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}l(0,0);l(1,b+1023<<20);return a*+n()}function Oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+24>>2]=d;f=$f(a,c);we(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!f){if(nd(a,5)){break a}}g=v[a+28>>2];d=0;mE(b,v[e+24>>2]);if(v[e+24>>2]){while(1){PA(g,sc(b,d));d=d+1|0;if(d>>>0<y[e+24>>2]){continue}break}}}Rf(a,f,c,e+16|0);gb=e+32|0}function Dla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-48|0;gb=d;bV(d+32|0,c);v[23048]=0;tj(d+16|0,d+32|0);c=v[23048];v[23048]=0;b:{if((c|0)==1){break b}v[23048]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;T(498,a|0,b|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Hb(d+32|0);gb=d+48|0;break a}a=P()|0;O()|0;Hb(d+32|0);R(a|0);L()}}function e_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;a:{if(y[b+16>>2]<=c>>>0){Gj(a,d,0);break a}f=v[b+4>>2];g=v[b+12>>2];h=e,i=xb(d),v[h+20>>2]=i;v[e+16>>2]=v[b+16>>2]-c;Gj(e+24|0,d,v[Gb(e+20|0,e+16|0)>>2]);b=v[v[f>>2]+28>>2];d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;kb[b|0](a,f,c+g|0,e+8|0)}gb=e+32|0}function ana(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-16|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;Rv(c+24|0,f);g=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(g|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){Sv(f)}if(a){e=uW(b+8|0)}gb=b+16|0;return e|0}function IA(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Coa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;wv(c+24|0,f);g=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(g|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){EX(f)}if(a){e=GX(b+8|0)}gb=b+32|0;return e|0}function iY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-48|0;gb=d;OY(d+32|0,c);v[23048]=0;tj(d+16|0,d+32|0);c=v[23048];v[23048]=0;b:{if((c|0)==1){break b}v[23048]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;T(78,a|0,b|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Hb(d+32|0);gb=d+48|0;break a}a=P()|0;O()|0;Hb(d+32|0);R(a|0);L()}}function Ir(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;t[d+15|0]=b;a:{b:{c:{d:{if($e(a)){c=Sk(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}op(a,c,1,c,c,0,0);b=c;if($e(a)){break b}}c=a;Gf(a,b+1|0);break a}c=v[a>>2];Ae(a,b+1|0)}a=b+c|0;Qd(a,d+15|0);t[d+14|0]=0;Qd(a+1|0,d+14|0);gb=d+16|0}function vu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=d+8|0;b=gb-16|0;gb=b;v[23048]=0;c=a;VQ(c+4|0);f=v[23048];v[23048]=0;a:{b:{c:{if((f|0)!=1){v[23048]=0;v[b+12>>2]=0;gf(c+8|0,b+12|0,e);e=v[23048];v[23048]=0;if((e|0)!=1){break c}break b}break b}g=c,h=dc(c),v[g>>2]=h;gb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}gb=d+16|0;return a}function t5(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{b:{c:{d:{if($e(a)){c=Sk(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=1;b=w[a+11|0];if((b|0)!=1){break c}}CI(a,c,1,c,c);b=c;if($e(a)){break b}}c=a;Gf(a,b+1|0);break a}c=v[a>>2];Ae(a,b+1|0)}a=(b<<2)+c|0;je(a,d+12|0);v[d+8>>2]=0;je(a+4|0,d+8|0);gb=d+16|0}function ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;e=v[b>>2];f=v[b+8>>2];b=v[c+4>>2];c=v[c>>2];v[d+16>>2]=c;v[d+20>>2]=b;v[d+24>>2]=c;v[d+28>>2]=b;Ch(d+32|0,d+16|0);b=v[v[e>>2]+28>>2];c=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=c;kb[b|0](d+40|0,e,f,d+8|0);b=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=b;Ch(a,d);gb=d+48|0}function n_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-48|0;gb=e;Kp(a);v[a>>2]=15916;g=Jp(e+40|0);f=e+24|0;_e(f,b);_e(f+4|0,c);_e(f+8|0,d);v[e+16>>2]=v[e+32>>2];v[23048]=0;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;W(281,a+12|0,g|0,e+8|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){gb=e+48|0;return a|0}a=P()|0;O()|0;R(a|0);L()}function mA(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e|0]=0;v[a>>2]=w[(b&15)+33824|0];t[a+4|0]=w[e|0];break a}t[e+15|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+15|0]=1;f=f<<1}Db(e,b+1074308|0,66);if(!(!d|!Cb(e))){v[e>>2]=0;Xh(a,e,e+15|0);break a}v[e>>2]=f<<4;Xh(a,e,e+15|0)}gb=e+16|0}function CI(a,b,c,d,e){var f=0,g=0,h=0;f=gb-16|0;gb=f;if(1073741807-b>>>0>=c>>>0){g=Ob(a);a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=Qn(v[Jc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=om(h);if(e){ej(c,g,e)}d=d-e|0;if(d){e=e<<2;ej(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){Ph(a,g,b)}_e(a,c);ch(a,h);gb=f+16|0;return}Og();L()}function RH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;e=b+16|0;a:{while(1){c=v[a+36>>2];f=kb[v[v[c>>2]+20>>2]](c,v[a+40>>2],b+8|0,e,b+4|0)|0;c=-1;d=v[b+4>>2]-(b+8|0)|0;if((d|0)!=(xk(b+8|0,1,d,v[a+32>>2])|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}c=jt(v[a+32>>2])?-1:0}gb=b+16|0;return c|0}function m_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+24>>2]=b;JF(v[d+24>>2]);v[d+16>>2]=v[c+8>>2];b=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=b;b=gb-16|0;gb=b;c=d+8|0;e=Xi(b+8|0,v[c>>2]);f=v[v[c+4>>2]>>2];c=v[v[c+8>>2]>>2];qr(a);v[a>>2]=16044;Xi(a+4|0,e);v[a+16>>2]=c;v[a+12>>2]=f;Bc(e);gb=b+16|0;gb=d+32|0;return a|0}function Xr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;d=Ob(b);e=Ob(b);g=c,h=Bb(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;vg(d,e+v[Gb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];g=c,h=Bb(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;b=v[Gb(c+12|0,c+8|0)>>2];e=v[a+4>>2];f=v[a>>2];t[c+7|0]=0;Fy(b+d|0,e+f|0,c+7|0);gb=c+16|0;return a|0}function pka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-208|0;gb=b;e=-1;c=gb-32|0;gb=c;h=b;YT(c+24|0,b);f=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(f|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){XT(h)}if(a){e=dU(b)}gb=b+208|0;return e|0}function joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;e=-1;c=gb-32|0;gb=c;h=b;kX(c+24|0,b);f=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(f|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){jX(h)}if(a){e=lX(b)}gb=b+160|0;return e|0}function fja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;cc(c+24|0,b,40);gb=d+16|0;d=xb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;fc(c+16|0,a,c);e=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Pb(b,0,40);gb=c+16|0}return a|0}function bla(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-48|0;gb=c;a:{if($u(a)>>>0<b>>>0){wb(a);d=av(c+32|0);v[23048]=0;S(871,d|0,b|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}rk(c+16|0,a);Dl(c+8|0,a);v[23048]=0;T(872,d|0,c+16|0,c+8|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}KB(a,d);Ee(d)}gb=c+48|0;return}a=P()|0;O()|0;Ee(d);R(a|0);L()}function QN(a,b,c,d){var e=0,f=0,g=0;e=gb-32|0;gb=e;g=v[a+20>>2];f=x[a+34>>1];v[23048]=0;f=f&65;v[e+16>>2]=f;v[e+8>>2]=f^65;ka(1486,d|0,a|0,b|0,c|0,e+16|0,e+8|0);d=v[23048];v[23048]=0;a:{if((d|0)==1){break a}v[a>>2]=c;v[a+20>>2]=b;v[23048]=0;ar(g);a=v[23048];v[23048]=0;if((a|0)==1){break a}gb=e+32|0;return}a=P()|0;O()|0;R(a|0);L()}function sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=Nb(a,6);a:{if(e){d=gb-16|0;gb=d;cc(c+24|0,b,6);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=gb-16|0;gb=d;f=b+6|0;while(1){Re(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0}gb=c+32|0;return e|0}function aX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;cc(c+24|0,b,80);gb=d+16|0;d=xb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;fc(c+16|0,a,c);e=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Pb(b,0,80);gb=c+16|0}return a|0}function sQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+2|0])|zb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function pQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+3|0])|zb(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function BZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-48|0;gb=b;e=-1;c=gb-32|0;gb=c;h=b;YD(c+24|0,b);f=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(f|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){XD(h)}if(a){e=oE(b)}gb=b+48|0;return e|0}function vc(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[23048]=0;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=Zu(c+24|0,c+8|0);b=v[23048];v[23048]=0;a:{if((b|0)==1){break a}v[23048]=0;a=JB(c+16|0,a);b=v[23048];v[23048]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function kna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;bf(b);v[d+12>>2]=0;a:{if(!uk(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!Dh(a,d+11|0)){break b}Ir(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}gb=d+16|0;return e|0}function hM(a){var b=C(0),c=0,d=C(0),e=0;b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);c=a;d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){e=~~b>>>0;break a}e=0}v[c+4248>>2]=e;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;bf(b);t[d+15|0]=0;a:{if(!Dh(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!Dh(a,d+14|0)){break b}Ir(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}gb=d+16|0;return e|0}function Rt(a){var b=0,c=0,d=0,e=0;b=wg(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){e=a;if(b<=45e-5){b=0}else{b=Wp(b)*1.4426950408889634;d=H(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=.5849625007211562;if(b<.792481250360578){break a}c=1}b=wg(c+d)*.5}A[e+4248>>3]=b}Ot(a)}function pM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=(yf(v[a+16>>2])|0)/5|0;b=vc(b,b>>31);v[a+4272>>2]=b;v[23048]=0;v[c+12>>2]=0;T(1553,a+4256|0,b<<1,c+12|0);b=v[23048];v[23048]=0;a:{if((b|0)==1){b=V(90496)|0;if((O()|0)!=(da(90496)|0)){break a}Z(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;gb=c+16|0;return}R(b|0);L()}function mQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=jd(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function lQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=jd(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function Sx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-240|0;gb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((kb[b|0](a,f)|0)>=0){if((kb[b|0](a,e)|0)>-1){break a}}j=f;f=(kb[b|0](f,e)|0)>-1;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}XI(g,h);gb=g+240|0}function M6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=a;c=Jg(a);v[23048]=0;_(2117,a|0);d=v[23048];v[23048]=0;a:{if((d|0)!=1){v[23048]=0;jK(e);d=v[23048];v[23048]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;sl(c);R(a|0);L()}v[23048]=0;b=U(2112,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){v[a+12>>2]=b;return a|0}a=P()|0;O()|0;sl(e);R(a|0);L()}function wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;a:{if(!v[b+300>>2]){break a}if((kb[v[b+304>>2]](v[b+296>>2],c,0,0)|0)<0){break a}c=v[d>>2];f=xb(d);if(!f){break a}while(1){b:{e=kb[v[b+300>>2]](v[b+296>>2],c,f)|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;if(!e){break b}c=c+e|0;f=f-e|0;if(f){continue}}break}e=g}Gj(a,d,e)}function lX(a){a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>9){break a}return(w[a|0]|w[a+1|0]<<8)!=0}return 0}function kf(a,b,c,d){var e=0,f=0;a:{if(!Bb(a)|(c-b|0)<5){break a}Gs(b,c);e=Ob(a);f=Bb(a);a=c-4|0;if(a>>>0>b>>>0){c=e+f|0;while(1){f=w[e|0];if(!((f-1&255)>>>0>125|(f|0)==v[b>>2])){v[d>>2]=4;return}e=(c-e|0)>1?e+1|0:e;b=b+4|0;if(a>>>0>b>>>0){continue}break}}b=w[e|0];if((b-1&255)>>>0>125|b>>>0>v[a>>2]-1>>>0){break a}v[d>>2]=4}}function kO(){var a=0,b=0;a=gb-240|0;gb=a;a:{b:{if(t[92352]&1){break b}if(!Ud(92352)){break b}v[23048]=0;X(105);b=v[23048];v[23048]=0;if((b|0)==1){break a}v[23048]=0;_(106,a+120|0);b=v[23048];v[23048]=0;if((b|0)==1){break a}hc(92232,hc(a,a+120|0,120),116);Td(92352)}gb=a+240|0;return 92232}a=P()|0;O()|0;af(92352);R(a|0);L()}function ju(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;if(b){Db(f+8|0,a+1074308|0,73);j=Cb(f+8|0)?c- -64|0:c;e=so(a);k=e^1;c=120;l=e^-1;g=1;while(1){e=c>>>1|0;i=e+g|0;h=Vg(a,i,j,d);a:{if(!((h|0)!=0&k|b>>>0<=h>>>0?!(h>>>0>b>>>0&l):0)){g=i+1|0;c=(e^-1)+c|0;break a}c=e}if(c){continue}break}}gb=f+16|0;return g}function cH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);c=b+4|0;u[a+4>>1]=w[c|0]|w[c+1|0]<<8;c=b+6|0;u[a+6>>1]=w[c|0]|w[c+1|0]<<8;b=b+8|0;d=a,e=Yz(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24),w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),v[d+8>>2]=e;v[a+12>>2]=jb;return a|0}function XI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=gb-256|0;gb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;hc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;hc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=v[h>>2];continue}}gb=e+256|0}function iQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=jd(zb(w[b|0])|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function hQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=jd(zb(w[b+3|0])|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function Ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=cg(d,b);v[23048]=0;T(1198,d+16|0,b|0,c|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){v[23048]=0;T(120,a|0,d+16|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);R(c|0);L()}function GT(a){var b=0,c=0,d=0,e=0,f=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=kb[a|0](b)|0;d=jb;if((d|0)<0){break b}if((kb[c|0](b,0,0,0)|0)<=-1){break a}if((kb[c|0](b,0,0,2)|0)<=-1){break a}kb[a|0](b)|0;a=jb;kb[c|0](b,e,d,0)|0;f=(a|0)>-1}return f}kb[c|0](b,e,d,0)|0;return 0}function jE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;wb(b);f=bE(a,c+8|0);a:{d=Lb(b);if(!d){break a}v[23048]=0;S(388,a|0,d|0);e=v[23048];v[23048]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[23048]=0;Y(392,a|0,b|0,e|0,d|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;bu(f);R(a|0);L()}gb=c+16|0;return a|0}function Cca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=33;c=v[Gb(d+44|0,d+24|0)>>2];if(!Nb(a,c)){c=Bf(a)}qC(d+24|0,b);e=_d(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);qC(d+24|0,b);Pb(v[d+24>>2]+c|0,0,33-c|0);Vb(a,v[d+44>>2]);gb=d+48|0;return c|0}function uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Ik(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[23048]=0;qq(d,f,c);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}$c(b);gb=e+16|0;return}a=P()|0;O()|0;$c(b);R(a|0);L()}function gna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Ik(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[23048]=0;_v(d,f,c);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}$c(b);gb=e+16|0;return}a=P()|0;O()|0;$c(b);R(a|0);L()}function dna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=_A(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[23048]=0;Ml(d,f,c);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}$c(b);gb=e+16|0;return}a=P()|0;O()|0;$c(b);R(a|0);L()}function aG(a,b,c){var d=0;d=gb-48|0;gb=d;Bn(d+32|0,d+24|0,c);v[23048]=0;tj(d+16|0,d+32|0);c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;T(78,a|0,b|0,d+8|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}Hb(d+32|0);gb=d+48|0;return}a=P()|0;O()|0;Hb(d+32|0);R(a|0);L()}function D7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Bg(a);a:{c=v[b+4>>2];if(!c){break a}v[23048]=0;S(2090,a|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[23048]=0;Y(2091,a|0,c|0,e+f|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;hF(d);R(a|0);L()}return a|0}function y$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Kg(a,v[b+8>>2],e)){Tw(b,c,d);return}a:{if(!Kg(a,v[b>>2],e)){break a}if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function EZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=tn(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[23048]=0;on(d,f,c);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}$c(b);gb=e+16|0;return}a=P()|0;O()|0;$c(b);R(a|0);L()}function up(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=di(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=wb(a);f=v[b+4>>2];v[23048]=0;on(d,f,c);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b+4>>2]+2|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}_b(b);gb=e+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function sn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Jj(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=wb(a);f=v[b+4>>2];v[23048]=0;Ml(d,f,c);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b+4>>2]+1|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}_b(b);gb=e+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function eE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Ug(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=wb(a);f=v[b+4>>2];v[23048]=0;_v(d,f,c);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b+4>>2]+4|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}_b(b);gb=e+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function Pn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=rt(a+60|0);v[a>>2]=10864;v[d>>2]=10884;v[23048]=0;e=a+8|0;W(167,a|0,10896,e|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){a:{v[a>>2]=10864;v[d>>2]=10884;v[23048]=0;W(168,e|0,b|0,c|8)|0;b=v[23048];v[23048]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;gh(d);R(a|0);L()}function Mz(a,b){var c=0,d=0,e=0;SV(a);gp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function K_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=cg(d,b);v[23048]=0;T(245,d+16|0,b|0,c|0);e=v[23048];v[23048]=0;a:{b:{if((e|0)!=1){v[23048]=0;T(5,a|0,d+16|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);R(c|0);L()}function FC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Er(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=wb(a);f=v[b+4>>2];v[23048]=0;sC(d,f,c);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b+4>>2]+6|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}_b(b);gb=e+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function EK(a,b,c,d,e){var f=0,g=0,h=0;if((e|0)!=10){f=c;while(1){a:{if((b|0)==(f|0)){f=b;g=d;break a}f=f-1|0;g=(d>>>0)/(e>>>0)|0;t[f|0]=w[(d-B(g,e)|0)+10274|0];h=d>>>0>=e>>>0;d=g;if(h){continue}}break}b:{if(!g){d=c-f|0;if(d){break b}}v[a+4>>2]=61;v[a>>2]=c;return}b=kh(b,f,d);v[a+4>>2]=0;v[a>>2]=b+d;return}BK(a,b,c,d)}function EE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a:{if(!b){break a}if(!Nb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Ig(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;return d}function BE(a){var b=0,c=0,d=0;a:{if(w[a+110|0]>64|((w[a|0]|w[a+1|0]<<8)!=20042?(w[a|0]|w[a+1|0]<<8)!=26217:0)|(t[a+112|0]<0|w[a+111|0]>128)){break a}while(1){b=a+c|0;d=t[b+113|0];if(!(((d&255)>>>0<254?(d|0)<=-1:0)|(w[b+241|0]?0:(d|0)>=0)|w[b+369|0]>=64)){b=1;c=c+1|0;if((c|0)!=128){continue}break a}break}b=0}return b}function dE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;a:{b=QD(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=wb(a);e=v[b+4>>2];v[23048]=0;S(401,c|0,e|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}c=v[b+4>>2]+20|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}_b(b);gb=d+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function SL(a){var b=0;v[a+4116>>2]=0;v[a+4132>>2]=0;v[a+4136>>2]=0;u[a+4128>>1]=0;v[a+4104>>2]=0;v[a+4108>>2]=0;b=a+4140|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4148|0;v[b>>2]=0;v[b+4>>2]=0;RL(a+4164|0);RL(a+4156|0);Jq(a+54060|0);Jq(a+62252|0);Jq(a+70444|0);Jq(a+78636|0);Pb(a+4332|0,0,32768);dB(a+37100|0);Pb(a+37612|0,0,16384)}function $ba(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=yf(v[a+16>>2]);b=vc(Gpa(Fpa(b,b>>31,3840,0),jb,1e3,0),jb);v[a+4276>>2]=b;v[23048]=0;v[c+12>>2]=0;T(1553,a+4260|0,b|0,c+12|0);b=v[23048];v[23048]=0;a:{if((b|0)==1){b=V(90496)|0;if((O()|0)!=(da(90496)|0)){break a}Z(b|0)|0;v[a+4276>>2]=0;$()}gb=c+16|0;return}R(b|0);L()}function ika(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+12;QT(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+12;_b(c);gb=c+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=CB(d+8|0,AB(a,Gc(a)+1|0),Gc(a),c);QT(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;$T(a,c);_T(c);gb=d+32|0}function od(a,b){var c=0,d=0,e=0,f=0,g=0;d=b;b=DI(b);e=gb-16|0;gb=e;c=Zs(a);a:{if(c>>>0>=b>>>0){f=Ob(a);g=f;c=b;b:{c:{if(b){v[23048]=0;RI(g,d,c);d=v[23048];v[23048]=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Ab();L()}v[e+12>>2]=0;je((b<<2)+f|0,e+12|0);yh(a,b);break a}f=a;a=Bb(a);EI(f,c,b-c|0,a,0,a,b,d)}gb=e+16|0}function hla(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;a:{if(!Qf(a,8)){break a}c=0;if(!Qv(a,25561,8)){break a}c=-1;if(!Qj(a,b+8|0)){break a}a=b+8|4;c=0;if(!Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=!(Wb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))&-2139062144)}a=c;gb=b+16|0;return a|0}function dU(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>3999){break a}b=a+140|0;if(!Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;return(Ib(w[a|0]|w[a+1|0]<<8)|0)==50}return 0}function cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=4896;c=v[Gb(d+44|0,d+24|0)>>2];if(!Nb(a,c)){c=Bf(a)}uC(d+24|0,b);e=_d(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);uC(d+24|0,b);Pb(v[d+24>>2]+c|0,0,4896-c|0);Vb(a,v[d+44>>2]);gb=d+48|0}function KE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=a;a=b+18|0;d=b+46|0;b=Sc(e,w[a|0]&2?16:8,1,0,(w[d|0]^-1)&1);if(!(!(w[a|0]&4)|c>>>0<532)){Bp(b,3)}if(w[a|0]&8){tf(b,w[d|0]&4?5:4);return}if(!(w[a|0]&2|w[d|0]!=255)){tf(b,11);return}if(w[d|0]&2){t[b+2|0]=1}if(w[d|0]&4){tf(b,2)}if(!(!(w[d|0]&8)|!(w[a|0]&2))){tf(b,9)}}function eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{b:{c:{d:{e:{f:{if((b|0)<=28590){if((b|0)==437){break c}if((b|0)==1252){break b}if((b|0)!=20127){break f}e=1;break a}if((b|0)==28591){break e}if((b|0)==28605){break d}e=0;if((b|0)==65001){break a}}e=c;break a}e=2;break a}e=3;break a}e=5;break a}e=8}Kt(a,e,d)}function e8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{a=Fl(a);d=Fl(b);b=gb-32|0;gb=b;v[b+24>>2]=c;b:{if((a|0)!=(d|0)){while(1){c=Tb(b+8|0,v[a>>2]);v[23048]=0;S(2119,b+24|0,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break b}vb(c);a=a+4|0;if((d|0)!=(a|0)){continue}break}}gb=b+32|0;break a}a=P()|0;O()|0;vb(c);R(a|0);L()}}function $X(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=Er(c,a,b);b=v[a+4>>2];if((b|0)!=v[a+8>>2]){while(1){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4;b=v[a+4>>2]+6|0;v[a+4>>2]=b;if(v[a+8>>2]!=(b|0)){continue}break}}_b(a);gb=c+16|0}function jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=263;c=v[Gb(d+44|0,d+24|0)>>2];if(!Nb(a,c)){c=Bf(a)}aT(d+24|0,b);e=_d(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);aT(d+24|0,b);Pb(v[d+24>>2]+c|0,0,263-c|0);Vb(a,v[d+44>>2]);gb=d+48|0}function LX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=320012546|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=184619540|w[a+8|0]>1){break a}b=a+9|0;if(!w[b|0]|w[b|0]>8){break a}b=a+10|0;if((w[b|0]|w[b+1|0]<<8)>>>0>4096){break a}a=a+12|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4097}return c}function uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}f=v[c>>2];e=xb(c);if(!e){break a}while(1){b:{d=kb[v[b+28>>2]](v[b+24>>2],f,e)|0;if(!d){t[b+40|0]=1;break b}f=d+f|0;g=d+g|0;h=g>>>0<d>>>0?h+1|0:h;e=e-d|0;if(e){continue}}break}d=g}Gj(a,c,d)}function nC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;cW(a,b);e=b+8|0;Rc(a,Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+504|0);bW(a,d);a:{b=b+32|0;if(!Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}if(!Rc(a,Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){break a}oC(a,c);return}Pb(c,0,80)}function hpa(a,b){a=a|0;b=b|0;var c=0;gv(a,b);Mf(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function Hma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=22;c=v[Gb(d+44|0,d+24|0)>>2];if(!Nb(a,c)){c=Bf(a)}wv(d+24|0,b);e=_d(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);wv(d+24|0,b);Pb(v[d+24>>2]+c|0,0,22-c|0);Vb(a,v[d+44>>2]);gb=d+48|0}function Ema(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=40;c=v[Gb(d+44|0,d+24|0)>>2];if(!Nb(a,c)){c=Bf(a)}gC(d+24|0,b);e=_d(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);gC(d+24|0,b);Pb(v[d+24>>2]+c|0,0,40-c|0);Vb(a,v[d+44>>2]);gb=d+48|0}function oS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 3:PA(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;u[d+26>>1]=0;v[d+12>>2]=2;Zi(d+16|0,a,d+26|0,v[Gb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=2;Gb(d+28|0,d+16|0);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[d+16|0]|w[d+17|0]<<8;gb=d+32|0}function _ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=gb-16|0;gb=e;d=gb-16|0;gb=d;Gf(c,1);Ov(c,1,b<<24>>24);t[d+15|0]=0;Qd(c+1|0,d+15|0);gb=d+16|0;gb=e+16|0;b=c;d=Ob(c);e=Bb(c);v[23048]=0;W(187,a|0,d|0,e|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){vb(b);gb=c+16|0;return a|0}a=P()|0;O()|0;vb(b);R(a|0);L()}function HS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=vk(a);a=b+236|0;b=Ku(a);a:{if((a|0)!=(b|0)){while(1){d=x[a>>1];u[c+14>>1]=d;if(d){v[23048]=0;T(1110,c|0,e|0,c+14|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}gb=c+16|0;return}a=P()|0;O()|0;pr(e);R(a|0);L()}function raa(a){a=a|0;var b=0;v[23048]=0;_(1943,a|0);b=v[23048];v[23048]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,52861,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function io(a,b,c){var d=0,e=0;a=Jb(a);d=Bb(b);v[23048]=0;S(113,a|0,d|0);d=v[23048];v[23048]=0;if((d|0)!=1){a:{if(Bb(b)){while(1){d=v[(w[pc(b,e)|0]<<2)+c>>2];v[23048]=0;S(112,a|0,d|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}e=e+1|0;if(Bb(b)>>>0>e>>>0){continue}break}}return}}b=P()|0;O()|0;Pc(a);R(b|0);L()}function LU(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[23048]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=Zu(c+24|0,c+8|0);b=v[23048];v[23048]=0;a:{if((b|0)==1){break a}v[23048]=0;a=JB(c+16|0,a);b=v[23048];v[23048]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function XB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-1024|0;gb=f;d=gb-32|0;gb=d;SB(d+24|0,f);g=xb(d+24|0);e=v[d+28>>2];h=v[d+24>>2];v[d+8>>2]=h;v[d+12>>2]=e;v[d>>2]=h;v[d+4>>2]=e;fc(d+16|0,a,d);e=xb(d+16|0);if((e|0)==(g|0)){Vb(a,xb(d+24|0))}gb=d+32|0;if((e|0)==(g|0)){i=UB(f,c)>>>0<=b>>>0}gb=f+1024|0;return i}function MN(a,b){var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){d=gb-16|0;gb=d;c=v[b>>2];e=v[b+4>>2];b=nr(c,e);a:{if(b>>>0<=Ce(a)>>>0){if(Lb(a)>>>0<b>>>0){v[d+12>>2]=c;UV(d+12|0,Lb(a));f=c;c=v[d+12>>2];vg(f,c,v[a>>2]);cw(a,c,e,b-Lb(a)|0);break a}Ui(a,vg(c,e,v[a>>2]));break a}KN(a);fE(a,Tg(a,b));cw(a,c,e,b)}gb=d+16|0}}function bN(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[23048]=0;v[c+12>>2]=0;T(1553,a+4208|0,b<<1,c+12|0);b=v[23048];v[23048]=0;a:{if((b|0)==1){b=V(90496)|0;if((O()|0)!=(da(90496)|0)){break a}Z(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;gb=c+16|0;return}R(b|0);L()}function a9(a){a=a|0;var b=0;v[23048]=0;_(2016,a|0);b=v[23048];v[23048]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[23048]=0;Y(1920,55320,a|0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Oo(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];if(e|v[d>>2]){if(!b){break a}while(1){e=jd((jd(0-e|0,31)&255)+e|0,8);f=v[d>>2];f=jd((jd(0-f|0,31)&255)+f|0,8);v[c>>2]=v[c>>2]-e;v[d>>2]=v[d>>2]-f;e=g<<3;v[e+a>>2]=v[c>>2];v[(e|4)+a>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}e=v[c>>2];continue}}PS(a,b<<1)}}function Kaa(){var a=0,b=0;v[23048]=0;a=v[23048];v[23048]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;Y(1920,52156,0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();a=0}else{a=19922997}return a|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function A2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=gb-128|0;gb=c;v[c+12>>2]=c+116;lH(a+8|0,c+16|0,c+12|0,e,f,g);e=v[c+12>>2];a=gb-16|0;gb=a;v[a+8>>2]=b;d=c+16|0;if((e|0)!=(d|0)){while(1){gI(a+8|0,t[d|0]);d=d+1|0;if((e|0)!=(d|0)){continue}break}b=v[a+8>>2]}gb=a+16|0;gb=c+128|0;return b|0}function Vna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;uC(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Pb(b,0,4896);gb=c+16|0}return a|0}function MM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=a;d=gb-96|0;gb=d;YM(b,d,d+96|0);b=0;while(1){e=b<<3;f=e+c|0;g=v[d+e>>2];e=v[(e|4)+d>>2];v[f>>2]=g;v[f+4>>2]=e&65535;b=b+1|0;if((b|0)!=12){continue}break}v[c+104>>2]=0;v[c+96>>2]=!(v[c+88>>2]|v[c+92>>2]);v[c+100>>2]=0;gb=d+96|0;v[a+112>>2]=0;return a|0}function G2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=v[21079];v[g+24>>2]=v[21078];v[g+28>>2]=h;h=v[21077];v[g+16>>2]=v[21076];v[g+20>>2]=h;h=v[21075];v[g+8>>2]=v[21074];v[g+12>>2]=h;h=v[21073];v[g>>2]=v[21072];v[g+4>>2]=h;a=Vj(a,b,c,d,e,f,g,g+32|0);gb=g+32|0;return a|0}function kca(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{if((qc(v[a+20>>2]+4|0)|0)!=7){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=Rb(v[a+20>>2]+4|0);c=Ub(v[a+20>>2]+4|0);jn(d+8|0,a+4228|0);Hi(b,c,v[d+8>>2]);break a}My(a,b)}Lt(a);gb=d+16|0}function dw(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(Nb(a,256)){d=gb-16|0;gb=d;cc(c+24|0,b,256);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=gb-16|0;gb=d;e=b+256|0;while(1){Re(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0}gb=c+32|0}function Pg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);Uf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[h>>2]=b;v[g+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;gb=d+16|0}function Maa(){var a=0,b=0;v[23048]=0;a=v[23048];v[23048]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;Y(1920,52128,0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();a=0}else{a=393216}return a|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{b=wT(d,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){v[23048]=0;S(1116,a|0,c|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}$c(b);gb=d+16|0;return}a=P()|0;O()|0;$c(b);R(a|0);L()}function yga(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b=Pp(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(a);c=v[b+4>>2];v[23048]=0;ER(c);c=v[23048];v[23048]=0;if((c|0)==1){break a}c=v[b+4>>2]+16|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}_b(b);gb=d+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function kE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=Nb(a,3);a:{if(d){sE(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;e=gb-16|0;gb=e;f=b+3|0;while(1){Re(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=e+16|0;gb=a+16|0}gb=c+32|0;return d|0}function GQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;f=a,g=zb(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function FQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Gb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=zb(w[b|0])+g|0;t[a|0]=g;d=zb(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function EY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=Nb(a,8);a:{if(d){qY(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;e=gb-16|0;gb=e;f=b+8|0;while(1){Re(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=e+16|0;gb=a+16|0}gb=c+32|0;return d|0}function Aaa(){var a=0,b=0;v[23048]=0;a=v[23048];v[23048]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;Y(1920,52568,0,0,0);a=v[23048];v[23048]=0;if((a|0)==1){break a}$();a=0}else{a=2048}return a|0}a=P()|0;O()|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;if((b|0)!=1){R(a|0);L()}V(0)|0;O()|0;Ab();L()}function AU(a,b){var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;c=a+4|0;a:{if(qc(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!qc(c)){sk(c,HB(v[a+16>>2]+b|0,65536));break a}f=d,g=qc(c),v[f+12>>2]=g;e=Bj(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){sk(c,HB(a,65536));break a}f=d,g=qc(c),v[f+8>>2]=g;sk(c,Bj(d+8|0))}gb=d+16|0}function Ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;b=-1;a:{if(!Qf(a,1084)){break a}Gl(a,1080);BV(a,c+60|0);d=AV(c+40|0);b=0;if(!zV(c+60|0,d)){break a}Gl(a,20);b=1;while(1){yV(a,c+8|0);e=ZB(c+8|0)+e|0;f=b&65535;b=b+1|0;if(f>>>0<31){continue}break}b=y[d+4>>2]>=e>>>0}gb=c- -64|0;return b|0}function TA(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;a:{b=Nu(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(a);d=v[b+4>>2];v[23048]=0;S(1116,d|0,c|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b+4>>2]+32|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}_b(b);gb=e+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function Mda(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-48|0;gb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;rn(c+16|0,c+40|0);b=zb(v[c+16>>2]);rn(c+8|0,c+40|0);b=pj(c+24|0,b,zb(v[c+8>>2]+2|0));v[23048]=0;Q(1127,a|0,b|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);R(a|0);L()}function AP(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=v[a+1074408>>2];a=v[a+1074384>>2];t[b+853|0]=w[b+853|0]|8;g=b;d=a?w[b+815|0]:0;h=v[b+856>>2]+((c|0)>-1?0-d|0:d)|0;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[g+856>>2]=h+d;c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+815|0]=a^a+c}function mr(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b=Jj(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(a);c=v[b+4>>2];v[23048]=0;Re(c);c=v[23048];v[23048]=0;if((c|0)==1){break a}c=v[b+4>>2]+1|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}_b(b);gb=d+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function fv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=Rb(a);c=Ub(a);a=gb-16|0;gb=a;v[a>>2]=c;v[a+8>>2]=b;if(Fb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}sf(a+8|0);if(Fb(a+8|0,a)){continue}break}}gb=a+16|0}gb=d+16|0}function Wy(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Ug(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=wb(a);f=v[b+4>>2];v[23048]=0;qq(d,f,c);d=v[23048];v[23048]=0;if((d|0)==1){break a}d=v[b+4>>2]+4|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}_b(b);gb=e+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function VD(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b=di(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(a);c=v[b+4>>2];v[23048]=0;$v(c);c=v[23048];v[23048]=0;if((c|0)==1){break a}c=v[b+4>>2]+2|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}_b(b);gb=d+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function Sr(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;tc(f+12|0,256);tc(f+12|0,65535);h=x[f+12>>1];Cf(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Si(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}gb=f+16|0}function Nfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;e=wf(1);v[23048]=0;c=Q(91,b|0,1992)|0;d=v[23048];v[23048]=0;a:{b:{if((d|0)!=1){v[23048]=0;d=Q(92,e|0,c|0)|0;f=v[23048];v[23048]=0;if((f|0)==1){break b}Ai(a,d);vb(c);gb=b+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c)}Zb(e);R(a|0);L()}function zH(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=nr(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){Gf(a,e);d=a;break a}g=Qn(e)+1|0;d=om(g);_e(a,d);ch(a,g);Ae(a,e)}if((b|0)!=(c|0)){while(1){je(d,b);d=d+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f+12>>2]=0;je(d,f+12|0);gb=f+16|0;return}Og();L()}function BL(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=_h(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){Gf(a,e);d=a;break a}g=$l(e)+1|0;d=Tj(g);_e(a,d);ch(a,g);Ae(a,e)}if((b|0)!=(c|0)){while(1){Qd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Qd(d,f+15|0);gb=f+16|0;return}Og();L()}function tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(jg(a)>>>0>=b>>>0){f=d,g=qc(a),v[f+8>>2]=g;bi(v[a>>2],v[Gb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){sn(a,b-e|0,c);break a}Tm(a,b+v[a>>2]|0);break a}xv(a);Wo(a,qh(a,b));sn(a,b,c)}gb=d+16|0}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){tG(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=Zg(d+8|0,qh(a,qc(a)+1|0),qc(a),c);Qp(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+1;v[23048]=0;S(37,a|0,c|0);a=v[23048];v[23048]=0;a:{if((a|0)!=1){ee(c);gb=d+32|0;break a}a=P()|0;O()|0;ee(c);R(a|0);L()}}function t_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;uF(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-36|0;tF(h,e-36|0,c);e=v[d>>2]-36|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}mc(a,f);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];Mk(a);am(a);am(a)}function s3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Jb(a);e=Bb(b);f=Bb(c);b=Ob(b);v[23048]=0;Y(186,a|0,b|0,e|0,e+f|0);b=v[23048];v[23048]=0;a:{if((b|0)!=1){b=Ob(c);v[23048]=0;W(187,a|0,b|0,f|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);R(b|0);L()}gb=d+16|0}function XQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;hT(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-28|0;tu(h,e-28|0,c);e=v[d>>2]-28|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}mc(a,f);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];Je(a);Mi(a);Mi(a)}function Rf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=gb-48|0;gb=c;a:{if(!b){b=1;if(nd(a,5)){break a}b=rG(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;we(c,v[a+28>>2]);sG(c+16|0,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[c+24>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}gb=c+48|0;return b|0}function PQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Gb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=zb(w[b|0])+d|0;d=g+zb(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function w7(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;a:{b:{if(mj(a)){lh(b+24|0);break b}fo(b+8|0,a);v[23048]=0;S(2087,b+24|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}Tf(b+8|0)}c=a+36|0;c:{if(mj(a)){break c}c=v[b+24>>2]}a=bo(c);ll(b+24|0);gb=b+32|0;return a|0}a=P()|0;O()|0;Tf(b+8|0);R(a|0);L()}function lR(a,b,c){var d=0,e=0,f=0;d=$d(a);e=dc(a);a:{if(d){f=wb(a);b:{while(1){c:{a=d+16|0;d:{if(yl(f,c,a)){if(!v[d>>2]){break a}a=d;break d}if(!yl(f,a,c)){break b}a=d+4|0;if(!v[d+4>>2]){break c}d=a;a=d}e=a;d=v[d>>2];continue}break}v[b>>2]=d;return a}v[b>>2]=d;return e}d=dc(a)}v[b>>2]=d;return d}function Hr(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,128);tc(d+12|0,65535);f=x[d+12>>1];Cf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==65535){e=65535;break a}if((e|0)!=65535){break a}e=65534}g=Si(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function HI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;d=Bb(a);f=Nc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=Ob(a);h=e;f=d;if(d){mn(c+e|0,e,f);b=b>>>0>=e>>>0?d+e>>>0>b>>>0?b+c|0:b:b}mn(h,b,c);b=c+d|0;yh(a,b);t[g+15|0]=0;Qd(b+e|0,g+15|0);break a}kw(a,f,(c+d|0)-f|0,d,0,0,c,b)}gb=g+16|0;return a}function vv(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-20|0;v[b+8>>2]=d;v[23048]=0;S(409,c|0,d|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){PD(v[a+16>>2],v[a>>2],(v[bc(a)>>2]-v[a>>2]|0)/20|0)}}function ks(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-36|0;v[b+8>>2]=d;v[23048]=0;S(269,c|0,d|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){js(v[a+16>>2],v[a>>2],(v[bc(a)>>2]-v[a>>2]|0)/36|0)}}function yN(a){var b=0,c=0,d=0,e=0;c=a;d=v[a+4>>2];a:{while(1){b=v[c+8>>2];if((b|0)==(d|0)){break a}e=v[c+16>>2];b=b-52|0;v[c+8>>2]=b;v[23048]=0;S(1342,e|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}c=v[a>>2];if(c){Kz(v[a+16>>2],c,(v[bc(a)>>2]-v[a>>2]|0)/52|0)}}function mM(a,b,c){var d=0,e=0,f=0,g=0;g=(b|0)<1;if(C(D(a))<C(2147483648)){d=~~a}else{d=-2147483648}f=d&-2147483648;e=f?0-d|0:d;a:{if(!(g|(e|0)<0)){while(1){d=b-1|0;e=e<<1;if((b|0)<2){break a}b=d;if((e|0)>-1){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=d;e=b;if(pp(b,d+24|0)){f=Qm(d+24|0)}td(g,e,f);e=Tl(a,d+24|0,d);yb(d);a:{a=(f>>>0)%(c>>>0)|0;if(!a){break a}v[23048]=0;Q(370,b|0,c-a|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ae(e);R(a|0);L()}gb=d+32|0}function bm(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;nc(a+32|0);dd(a+44|0);v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function HQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Kh(w[b|0]),t[f|0]=g;f=a,g=Kh(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function ym(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{c:{d:{e:{switch(c|0){case 1:break b;case 3:break c;case 0:break d;case 2:break e;default:break a}}e=KP(a,b,d);if(e-251>>>0<5){break d}if(e){break a}}return JP(a,b,d)}e=JP(a,b,d);if(e-251>>>0<5){break b}if(e){break a}}e=KP(a,b,d)}return e}function pna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 2:Eh(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;t[d+27|0]=0;v[d+12>>2]=1;Zi(d+16|0,a,d+27|0,v[Gb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=1;Gb(d+28|0,d+16|0);t[d+16|0]=w[d+27|0];t[b|0]=w[d+16|0];gb=d+32|0}function NP(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}Mo(b,e,a);Db(f+8|0,a+1074308|0,10);if(!Cb(f+8|0)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}gb=f+16|0}function Fe(a){var b=C(0),c=C(0),d=0,e=0;d=(p(a),j(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return C(a*C(0))}a=(d|0)>-1?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){c=C(C(a+b)+C(-1));break a}a=C(a+b);c=a;if(!(b<=C(-.5))){break a}c=C(a+C(1))}a=c;a=(d|0)>-1?a:C(-a)}return a}function CD(a,b,c){var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=192;c=v[Gb(d+44|0,d+24|0)>>2];if(!Nb(a,c)){c=Bf(a)}Mr(d+24|0,b);e=_d(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);Mr(d+24|0,b);Pb(v[d+24>>2]+c|0,0,192-c|0);Vb(a,v[d+44>>2]);gb=d+48|0}function zE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,128);tc(d+12|0,65535);f=x[d+12>>1];Cf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=Si(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function wX(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,256);tc(d+12|0,65535);f=x[d+12>>1];Cf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=Si(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function be(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;zn(a);a=Ai(d+8|0,a);a:{if(Lb(467232)>>>0<=b>>>0){v[23048]=0;_(2456,b+1|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}}c=v[Mb(467232,b)>>2];if(c){yn(c)}c=Bd(a);e=Mb(467232,b),f=c,v[e>>2]=f;_G(a);gb=d+16|0;return}b=P()|0;O()|0;_G(a);R(b|0);L()}function GX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<14){break a}if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>256){break a}a=a+8|0;return!Ib(w[a|0]|w[a+1|0]<<8)}return 0}function DE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a:{if(!b){break a}if(!Nb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Ig(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}gb=c+16|0;return d}function qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ti(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=49464;v[23048]=0;W(1545,a+44|0,2,2)|0;c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;Oh(b);c=v[23048];v[23048]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;nf(b);R(a|0);L()}function kK(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;v[b+12>>2]=-1;v[23048]=0;v[b+8>>2]=2147483647;c=Gb(b+12|0,b+8|0);d=v[23048];v[23048]=0;a:{if((d|0)!=1){gb=b+16|0;b=v[c>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0<=3){Mc();L()}b=jc(4,1);v[a>>2]=b;v[a+4>>2]=b;e=wb(a),f=b+4|0,v[e>>2]=f}function fB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=c,f=Bb(a),v[e+4>>2]=f;v[c>>2]=v[c+12>>2];a=lo(Ob(a),v[c+8>>2],v[Gb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=v[c>>2];d=v[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}gb=c+16|0;return a|0}function Fn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;cq(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;Gn(h,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}mc(a,f);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];$w(a,Gc(a))}function BI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Jb(a);e=Lf(b);f=Bb(c);v[23048]=0;Y(2227,a|0,b|0,e|0,e+f|0);b=v[23048];v[23048]=0;a:{if((b|0)!=1){b=Ob(c);v[23048]=0;W(2228,a|0,b|0,f|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);R(b|0);L()}gb=d+16|0}function ica(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){v[d+8>>2]=0;v[d+4>>2]=1065353216;h=(a+b|0)+4232|0;b=d+4|0;g=gb-16|0;gb=g;e=d+12|0;f=d+8|0;if(!Mt(e,f)){f=Mt(b,e)?b:e}gb=g+16|0;i=h,j=aA(C(z[f>>2]*C(127))),t[i|0]=j;Lt(a)}gb=d+16|0}function Nr(a){var b=0,c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;b=gb-32|0;gb=b;ds(b+24|0,d+15|0);e=xb(b+24|0);c=v[b+28>>2];f=v[b+24>>2];v[b+8>>2]=f;v[b+12>>2]=c;v[b>>2]=f;v[b+4>>2]=c;md(b+16|0,a,b);c=xb(b+16|0);if((c|0)==(e|0)){bd(a,xb(b+24|0))}gb=b+32|0;gb=d+16|0;return((c|0)==(e|0)?w[d+15|0]:0)&255}function wO(a){var b=0,c=0,d=0;b=v[a+2496>>2];c=(b+1>>>0)%624|0;d=v[(c<<2)+a>>2];b=B(d&1,-1727483681)^(v[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|v[(b<<2)+a>>2]&-2147483648)>>>1);v[(v[a+2496>>2]<<2)+a>>2]=b;v[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function jz(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function gM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[23048]=0;v[c+12>>2]=0;T(1553,a+4208|0,b<<2,c+12|0);b=v[23048];v[23048]=0;a:{if((b|0)==1){b=V(90496)|0;if((O()|0)!=(da(90496)|0)){break a}Z(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;gb=c+16|0;return}R(b|0);L()}function ez(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{c=a-12|0;d:{if(c>>>0>31){break d}a=1;d=1<<c;if(d&-2145904587){break b}if(d&65792){break c}if((c|0)!=7){break d}b=b&240;if(!b|(b|0)==96|(b|0)==224){break b}}return 0}a=0;b=(b&240)-96|0;if(b>>>0<144){break a}}return a|0}return 297>>>(b>>>4)&1}function EX(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Dz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[Yb(a+484344|0,x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;Db(d+8|0,a+1074308|0,63);if(!Cb(d+8|0)){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}gb=d+16|0}function DQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function AQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function oN(a,b){var c=0,d=0;d=gb-16|0;gb=d;a:{b=Ug(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(a);c=v[b+4>>2];v[23048]=0;Qo(c);c=v[23048];v[23048]=0;if((c|0)==1){break a}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}_b(b);gb=d+16|0;return}a=P()|0;O()|0;_b(b);R(a|0);L()}function nf(a){a=a|0;var b=0,c=0;v[a>>2]=46784;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=a+44|0;Qc(b+36|0);Qc(b+24|0);Nt(b+12|0);Nt(b);return a|0}function zQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Gb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b+1|0])+d|0)+(zb(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function fna(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Ik(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[23048]=0;Bk(b);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}$c(a);gb=c+16|0;return}b=P()|0;O()|0;$c(a);R(b|0);L()}function CQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Gb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b|0])+d|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function qZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=tn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[23048]=0;$v(b);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}$c(a);gb=c+16|0;return}b=P()|0;O()|0;$c(a);R(b|0);L()}function nZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=tn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[23048]=0;Dk(b);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}$c(a);gb=c+16|0;return}b=P()|0;O()|0;$c(a);R(b|0);L()}function nN(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Ik(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[23048]=0;Qo(b);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}$c(a);gb=c+16|0;return}b=P()|0;O()|0;$c(a);R(b|0);L()}function Tn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=E(b);Uf(c,d,0,0,0,b+81|0);d=0+v[c+8>>2]|0;b=(v[c+12>>2]^65536)+(16414-b<<16)|0;b=d>>>0<f>>>0?b+1|0:b;f=d;d=b;b=v[c+4>>2];e=v[c>>2]}v[h>>2]=e;v[g+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=d;gb=c+16|0}function Mn(a,b){var c=0,d=0;c=gb-16|0;gb=c;Ic(c+8|0,a);v[23048]=0;a=U(2375,c+8|0)|0;d=v[23048];v[23048]=0;a:{b:{if((d|0)==1){break b}v[23048]=0;Y(2387,a|0,84064,84090,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Xb(c+8|0);gb=c+16|0;break a}a=P()|0;O()|0;Xb(c+8|0);R(a|0);L()}return b}function MZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Ik(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[23048]=0;Ur(b);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}$c(a);gb=c+16|0;return}b=P()|0;O()|0;$c(a);R(b|0);L()}function $g(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;e=gb-16|0;gb=e;d=a;a:{if(b>>>0<=4294967279){b:{if(b>>>0<=10){Gf(d,b);f=d;break b}h=$l(b)+1|0;f=Tj(h);_e(d,f);ch(d,h);Ae(d,b)}Ov(f,b,c);t[e+15|0]=0;Qd(b+f|0,e+15|0);gb=e+16|0;break a}Og();L()}gb=g+16|0;return a|0}function $A(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=_A(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[23048]=0;Re(b);b=v[23048];v[23048]=0;if((b|0)==1){break a}b=v[a>>2]+1|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}$c(a);gb=c+16|0;return}b=P()|0;O()|0;$c(a);R(b|0);L()}function tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,1030);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pb(b,0,1030)}return a|0}function apa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,3);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0}}function aI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=Ys(a);v[a+32>>2]=b;v[a>>2]=79336;Ps(d+8|0,e);v[23048]=0;b=U(2301,d+8|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){Xb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=On(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Xb(d+8|0);nm(e);R(a|0);L()}function N0(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[23048]=0;b=U(2472,b|0)|0;c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}b:{if(b){a=-1}else{a=v[a+8>>2];if(a){break b}a=1}return a|0}v[23048]=0;a=U(2473,a|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break a}return(a|0)==1|0}V(0)|0;O()|0;Ab();L()}function Lc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}e=b;d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=e-d|0;jb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function $H(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=uI(a);v[a+32>>2]=b;v[a>>2]=79440;Ps(d+8|0,e);v[23048]=0;b=U(2302,d+8|0)|0;f=v[23048];v[23048]=0;if((f|0)!=1){Xb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=On(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Xb(d+8|0);eq(e);R(a|0);L()}function yF(a){a=a|0;var b=0,c=0;b=Jb(a);v[23048]=0;U(270,a+12|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){b=gb-16|0;gb=b;v[b+12>>2]=0;v[23048]=0;gf(a+32|0,b+12|0,b+8|0);c=v[23048];v[23048]=0;a:{if((c|0)!=1){gb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a|0}a=P()|0;O()|0;vb(b);R(a|0);L()}function qma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,422);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pb(b,0,422)}return a|0}function mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,225);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pb(b,0,225)}return a|0}function kma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,826);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pb(b,0,826)}return a|0}function jea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,326);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pb(b,0,326)}return a|0}function Sga(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=Nu(d,a,1);wb(a);RA(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;_b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=fS(d+8|0,fr(a,Ie(a)+1|0),Ie(a),c);RA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;eS(a,c);QA(c);gb=d+32|0}function QC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;aE(a);wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-20|0;Lk(e-20|0,c);e=v[d>>2]-20|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}mc(a,f);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];RD(a,cf(a))}function oea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,73);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pb(b,0,73)}return a|0}function hea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,60);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pb(b,0,60)}return a|0}function Yma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,91);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pb(b,0,91)}return a|0}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,71);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pb(b,0,71)}return a|0}function We(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;yE(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];gb=b+32|0}function VY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Nb(a,120);a:{if(d){cc(c+24|0,b,120);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;e=b+120|0;while(1){Re(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0;return d|0}function Lf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function EQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function BQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function w8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=Jg(a);a:{b=b+4|0;c=vf(b);if(!c){break a}v[23048]=0;S(2048,a|0,c|0);d=v[23048];v[23048]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[23048]=0;Y(2049,a|0,b|0,d|0,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Ht(e);R(a|0);L()}}function t8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-48|0;gb=d;v[d+44>>2]=b;dk(d+8|0,0,c);b=d+24|0;v[b>>2]=v[d+44>>2];Dc(b+4|0,d+8|0);v[23048]=0;S(2051,a+4|0,d+24|0);a=v[23048];v[23048]=0;if((a|0)!=1){Ll(d+24|0);vb(d+8|0);gb=d+48|0;return}a=P()|0;O()|0;Ll(d+24|0);vb(d+8|0);R(a|0);L()}function f4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[b>>2]){if(!hd(c)){Jw(c,79836)}e=v[b+4>>2];kb[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[23048]=0;Q(1201,c|0,d|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break a}vb(d)}Dc(a,c);gb=d+16|0;return}a=P()|0;O()|0;vb(d);R(a|0);L()}function bX(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function aga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Nb(b,8)){Hp(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}u[c+16>>1]=0;b=4;while(1){d=w[c+16|0]|w[c+17|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;a=a+2|0;b=b-1|0;if(b){continue}break}}gb=c+32|0}function Y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=_h(b,c);d=Nc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=Bb(a);op(a,g,h,d,0,d,0)}d=Ob(a);if((b|0)!=(c|0)){while(1){Qd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;Qd(d,e+15|0);yh(a,f);gb=e+16|0}function GO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=_h(b,c);a:{if(e>>>0<=jg(a)>>>0){if(qc(a)>>>0<e>>>0){v[d+12>>2]=b;FO(d+12|0,qc(a));vg(b,v[d+12>>2],v[a>>2]);ur(a,v[d+12>>2],c,e-qc(a)|0);break a}Tm(a,vg(b,c,v[a>>2]));break a}xv(a);Wo(a,qh(a,e));ur(a,b,c,e)}gb=d+16|0}function Fea(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){d=gb-16|0;gb=d;c=Fq(d,a);wb(a);je(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;_b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=eO(d+8|0,Jl(a,Lb(a)+1|0),Lb(a),c);je(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;dO(a,c);tz(c);gb=d+32|0}function Ch(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;d=gb-16|0;gb=d;b=c+8|0;e=v[b>>2];b=v[b>>2]+xb(b)|0;v[23048]=0;Dn(a,e,b);a=v[23048];v[23048]=0;a:{if((a|0)!=1){gb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}gb=c+32|0}function zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Nb(a,64);a:{if(d){eD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;e=b- -64|0;while(1){Dk(b);b=b+2|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0;return d|0}function w4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if(((g=a,h=ah(t[b|0]),f=v[v[a>>2]+52>>2],kb[f](g|0,h|0)|0)|0)==-1){return d|0}b=b+1|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return xk(b,1,c,v[a+32>>2])|0}function ut(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;v[b+12>>2]=12;v[b+8>>2]=32;a:{if(!v[Gb(b+12|0,b+8|0)>>2]){break a}d=15;while(1){e=Lq(a);v[b+8>>2]=32;c=c^e;if(y[Gb(b+12|0,b+8|0)>>2]<=d>>>0){break a}c=c<<15;d=d+15|0;continue}}gb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function de(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=(a|0)>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function Uc(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[23048]=0;v[b+4>>2]=32767;a=sd(b+12|0,b+4|0);c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;a=Wf(b+8|0,a);c=v[23048];v[23048]=0;if((c|0)==1){break a}gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Ab();L()}function pv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;g=$f(a,c);we(e+8|0,v[a+28>>2]);f=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=f;a:{b:{if(!g){f=-1;if(!nd(a,5)){break b}break a}f=v[g+8>>2]}kb[d|0](v[a+28>>2],b,f)}a=Rf(a,g,c,e+24|0);gb=e+32|0;return a|0}function Et(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;a:{if(!(w[c|0]&32)){break a}f=d,g=Ld(b),v[f+8>>2]=g;f=d,g=hf(b),v[f>>2]=g;if(!Fb(d+8|0,d)){break a}while(1){c=v[d+8>>2];e=w[c|0];if((e-97&255)>>>0<=25){t[c|0]=e-32}Se(d+8|0);if(Fb(d+8|0,d)){continue}break}}Dc(a,b);gb=d+16|0}function aka(a,b){a=a|0;b=b|0;var c=0,d=0;b=gb-16|0;gb=b;c=-1;a:{if(!Qj(a,b+8|0)){break a}c=0;if(!PT(b+8|0)){break a}c=-1;if(!Qf(a,4)){break a}c=gb-16|0;gb=c;if(AT(a,c+8|0)){a=c+8|0;d=Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=c+16|0;c=d>>>31|0}gb=b+16|0;return c|0}function Xn(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1){d=a;break a}while(1){d=Ipa(a,b,10,0);e=jb;f=e;e=Fpa(d,e,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function zA(a){var b=0,c=0,d=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=dc(a);if(w[a+4|0]){c=v[a>>2];v[23048]=0;d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;S(1161,c|0,b+16|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}}if(b){js(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function CM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[v[a+16>>2]+1074396>>2];v[23048]=0;v[c+12>>2]=0;T(1553,a+4208|0,B(b,254)|0,c+12|0);b=v[23048];v[23048]=0;a:{if((b|0)==1){b=V(90496)|0;if((O()|0)!=(da(90496)|0)){break a}Z(b|0)|0;$()}v[a+4220>>2]=0;gb=c+16|0;return}R(b|0);L()}function $oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;d=Jg(a);a:{if(!b){break a}v[23048]=0;S(530,c|0,b|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;$X(c,b);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;$C(d);R(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function tl(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,880)+a|0)+1075640>>2];if(!f){break a}if(!uj(f)){break a}e=w[f+34|0];if(e-251>>>0<5|!e){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}kb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,880)+a|0)+1075828>>1]=65535}}function jN(a){var b=0,c=0,d=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=dc(a);if(w[a+4|0]){c=v[a>>2];v[23048]=0;d=v[23048];v[23048]=0;if((d|0)==1){break b}v[23048]=0;S(700,c|0,b+16|0);c=v[23048];v[23048]=0;if((c|0)==1){break b}}if(b){_l(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function XE(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;u[(v[a+1068>>2]<<1)+d>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=ld(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function Fga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;RR(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){IA(b)}return a|0}function zs(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[23048]=0;S(197,c|0,d|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){dm(v[a+16>>2],v[a>>2],_p(a))}}function xba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){le(d+12|0,C(0));c=z[d+12>>2];a:{if(!((b|0)!=1|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(Fe(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;Ly(a)}gb=d+16|0}function v6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;d=gi(f+8|0,d);v[23048]=0;ga(1942,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){mf(d);ZJ(a);b=YJ(a+88|0);v[a>>2]=59432;v[b>>2]=59520;gb=f+16|0;return a|0}a=P()|0;O()|0;mf(d);R(a|0);L()}function su(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[23048]=0;S(332,c|0,d|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){dm(v[a+16>>2],v[a>>2],_p(a))}}function nE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;YD(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){XD(b)}return a|0}function jc(a,b){var c=0,d=0;if(ZE(b)){c=gb-16|0;gb=c;a:{b:{b=b>>>0>4?b:4;a=a?a:1;if(AG(c+12|0,b,a)){while(1){d=v[116854];if(!d){break b}kb[d|0]();if(AG(c+12|0,b,a)){continue}break}}gb=c+16|0;a=v[c+12>>2];break a}a=aa(4)|0;cm(a);ja(a|0,90496,1937);L()}return a}return wf(a)}function bca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){le(d+12|0,C(0));c=z[d+12>>2];a:{if(!((b|0)!=3|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(Fe(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;Ly(a)}gb=d+16|0}function _u(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;JU(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){KU(b)}return a|0}function Xv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;zD(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){yD(b)}return a|0}function WQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-28|0;v[b+8>>2]=d;v[23048]=0;S(984,c|0,d|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){iB(v[a+16>>2],v[a>>2],vY(a))}}function VF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;FF(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){EF(b)}return a|0}function DV(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[23048]=0;v[b+4>>2]=127;a=sd(b+12|0,b+4|0);c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;a=Wf(b+8|0,a);c=v[23048];v[23048]=0;if((c|0)==1){break a}gb=b+16|0;return t[a|0]}V(0)|0;O()|0;Ab();L()}function pR(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-12|0;v[b+8>>2]=c;v[23048]=0;S(1159,e|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}b=v[a>>2];if(b){dm(v[a+16>>2],b,_p(a))}}function m8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;fo(c,a);a=b;if(v[a>>2]){Rd(a);sy(v[a>>2],hv(a));d=wb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=wb(c);d=wb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Tf(c);gb=c+16|0}
function eS(a,b){var c=0,d=0,e=0,f=0,g=0;ev(a);wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;RA(e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}zc(a,f);zc(a+4|0,b+8|0);zc(wb(a),bc(b));v[b>>2]=v[b+4>>2];SA(a,Ie(a))}function QA(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-32|0;v[b+8>>2]=c;v[23048]=0;S(1129,e|0,c|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}b=v[a>>2];if(b){_l(v[a+16>>2],b,oB(a))}}function Lga(a,b){a=a|0;b=b|0;var c=0;c=gb-48|0;gb=c;t[c+40|0]=w[b|0];ds(c+16|0,c+40|0);b=zb(v[c+16>>2]);ds(c+8|0,c+40|0);b=pj(c+24|0,b,zb(v[c+8>>2]+1|0));v[23048]=0;Q(1127,a|0,b|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);R(a|0);L()}function Bj(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;b=gb-16|0;gb=b;d=2;e=v[a>>2];if((e|0)!=1){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Gb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Gb(b+12|0,b+8|0)>>2]}gb=b+16|0;gb=c+16|0;return d|0}function vU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;wb(b);d=Jg(a);a:{c=qc(b);if(c){v[23048]=0;S(532,a|0,c|0);e=v[23048];v[23048]=0;if((e|0)==1){break a}d=v[b>>2];e=v[b+4>>2];b=gb-16|0;gb=b;c=Jj(b,a,c);wb(a);Pl(d,e,c+4|0);_b(c);gb=b+16|0}return a|0}a=P()|0;O()|0;$m(d);R(a|0);L()}function Rj(a,b){var c=0,d=0,e=0,f=0,g=0;if(b){c=v[a>>2];while(1){g=a;a:{if(c){d=v[a+4>>2];c=c-1|0;break a}v[a>>2]=8;c=v[a+12>>2];if((c|0)!=v[a+8>>2]){c=c-1|0;v[a+12>>2]=c}d=w[c|0];c=7}v[g>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function lM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-16|0;gb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Ob(d);pj(b,a,Bb(d)+a|0);break c}yM(e,c,d);v[23048]=0;T(115,a|0,b|0,e|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Pc(e)}gb=e+16|0;break a}a=P()|0;O()|0;Pc(e);R(a|0);L()}}function fe(a){var b=0,c=0,d=0,e=0;o(+a);b=j(1)|0;j(0)|0;e=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(e|0)>-1?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){d=a+c+-1;break a}a=a+c;d=a;if(!(c<=-.5)){break a}d=a+1}a=d;a=(e|0)>-1?a:-a}return a}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(!Od(b)){break a}if(v[b+20>>2]==(zb(v[a+20>>2])|0)){v[a+20>>2]=0}tc(a,v[b>>2]);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=x[b+34>>1]&64|c&65471;if(!Mm(a)){break a}hc(zb(v[a+20>>2]),v[b+20>>2],Oi(a));d=1}return d|0}function Vx(a){var b=0,c=0;a:{if(y[a+20>>2]<=y[a+28>>2]){break a}kb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break a}return-1}b=v[a+4>>2];c=v[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;kb[v[a+40>>2]](a,b,b>>31,1)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;return 0}function Ki(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[23048]=0;v[b+4>>2]=255;a=sd(b+12|0,b+4|0);c=v[23048];v[23048]=0;a:{if((c|0)==1){break a}v[23048]=0;a=Wf(b+8|0,a);c=v[23048];v[23048]=0;if((c|0)==1){break a}gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Ab();L()}function yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,106);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Pb(b,0,106)}}function jla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c;e=b;if(pp(b,c+24|0)){b=c+28|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>=9){b=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-8|0}else{b=0}}else{b=0}td(d,e,b);Tl(a,c+24|0,c);yb(c);gb=c+32|0}function jh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(!(b?0:!(v[a+480180>>2]&1))){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function Ela(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,274);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Pb(b,0,274)}}function bW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,284);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Pb(b,0,284)}}function WE(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=ld(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function Vp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(e*.16666666666666632+(d*(b*.5-e*f)-b))}function Vf(a,b){var c=0,d=0,e=0,f=0;c=Bb(a);a:{if((c|0)!=(Bb(b)|0)){break a}d=Ob(a);b=Ob(b);b:{if(!$e(a)){if(c){break b}return 1}return!lo(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function Hy(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Ld(b);e=hf(b);f=Ld(b);c=gb-32|0;gb=c;v[c+16>>2]=e;v[c+24>>2]=d;v[c+8>>2]=f;if(Fb(c+24|0,c+16|0)){while(1){d=pq(t[v[c+24>>2]]);t[v[c+8>>2]]=d;Se(c+24|0);Se(c+8|0);if(Fb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;Dc(a,b)}function xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,72);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Pb(b,0,72)}}function voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,34);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Pb(b,0,34)}}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=Du(a+8|0,d);v[23048]=0;Q(1662,a+20|0,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Hb(b);R(a|0);L()}function em(a){var b=0,c=0,d=0,e=0;cq(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=wb(d);v[23048]=0;b=b-12|0;S(197,c|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;dm(wb(a),v[a>>2],pg(a))}}function Vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=c;d=b;if(pp(b,c+24|0)){e=xY(c+24|0)}td(f,d,e);d=Tl(a,c+24|0,c);yb(c);a:{if(!(e&1)){break a}v[23048]=0;Q(370,b|0,1)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ae(d);R(a|0);L()}gb=c+32|0}function S3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{if((d|0)!=(e|0)){while(1){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}b=b+4|0;d=d+4|0;if((e|0)!=(d|0)){continue}break}}a=(b|0)!=(c|0)}return a|0}function Lt(a){var b=0,c=C(0),d=0;if(w[a+4232|0]>=5){t[a+4232|0]=0}if(t[a+4233|0]<=-1){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<=-1){t[a+4234|0]=127;b=127}d=a;a:{if((EM(a)|0)==3){c=C(C(1)-re(C(2),C(-C((b&255)+1|0))));break a}c=re(C(2),C(-C((b&255)>>>0)))}z[d+4224>>2]=c}function Bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,42);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Pb(b,0,42)}}function GY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,50);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Pb(b,0,50)}}function dP(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;c=b+8|0;e=c;d=gb-16|0;gb=d;Cc(d+8|0,a+116|0);v[23048]=0;a=Na(189,a|0)|0;O()|0;a=a|0;f=v[23048];v[23048]=0;a:{if((f|0)!=1){gb=d+16|0;break a}a=P()|0;O()|0;R(a|0);L()}v[e>>2]=a;Lq(c);gb=b+16|0;return v[c>>2]}function V3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{if((d|0)!=(e|0)){while(1){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}b=b+1|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}a=(b|0)!=(c|0)}return a|0}function Bga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Jg(a);a:{d=zf(b);if(d){v[23048]=0;S(1143,a|0,d|0);e=v[23048];v[23048]=0;if((e|0)==1){break a}c=gb-16|0;gb=c;e=v[b>>2];f=v[b+4>>2];b=gs(c,a,d);Pl(e,f,b+4|0);_b(b);gb=c+16|0}return a|0}a=P()|0;O()|0;Kf(c);R(a|0);L()}function cO(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){Je(c);gT(c);Mi(c);Je(c);iB(wb(c),v[c>>2],Mi(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}gp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function aD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[Ff(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=((a+b|0)-2|0)/(b-1|0);a=w[Ff(d+13|0,d+12|0)|0]}gb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function RF(a,b){var c=0,d=0;c=gb-16|0;gb=c;Ic(c+8|0,a);v[23048]=0;a=U(21,c+8|0)|0;d=v[23048];v[23048]=0;a:{if((d|0)==1){break a}v[23048]=0;a=Q(22,a|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break a}Xb(c+8|0);gb=c+16|0;return a}a=P()|0;O()|0;Xb(c+8|0);R(a|0);L()}function NQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function LK(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,880);c=C(C(w[(b+v[a>>2]|0)+1075829|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075828|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function IR(a,b){var c=0,d=0,e=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;e=a;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[e+16>>2]=b;b=JT(c-+(b<<2));v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=b;v[a+12>>2]=jb}function $k(a,b,c,d){var e=0;if(d&2048){t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}t[a|0]=b}function cX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148?(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297:0){break a}b=a+34|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+36|0;return(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return 0}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Nb(a,4);a:{if(d){dC(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}t[c+16|0]=0;a=4;while(1){t[b|0]=w[c+16|0];b=b+1|0;a=a-1|0;if(a){continue}break}}gb=c+32|0;return d|0}function zG(a,b,c){var d=0;d=gb-32|0;gb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;Zi(d+16|0,a,d+24|0,v[Gb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=4;Gb(d+28|0,d+16|0);v[d+16>>2]=v[d+24>>2];a=d+16|0;v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);gb=d+32|0}function Y1(){var a=0;a=gb-16|0;gb=a;v[116808]=0;v[116809]=0;v[a+12>>2]=0;Qo(467248);t[467376]=0;gb=a+16|0;v[23048]=0;X(2453);a=v[23048];v[23048]=0;a:{if((a|0)!=1){v[23048]=0;gx(28);a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;fx(467232);R(a|0);L()}}function VM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){d=b;if(b>>>0>2097151){xc(46476);L()}f=jc(d<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<11)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function UM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){xc(46476);L()}f=jc(d<<2,4)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function B_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;v[d>>2]=c;v[d+8>>2]=b;JF(v[d+8>>2]);b=gb-32|0;gb=b;v[b+24>>2]=v[d>>2];e=v[b+24>>2];c=v[e+4>>2];e=v[e>>2];v[b+8>>2]=e;v[b+12>>2]=c;v[b+16>>2]=e;v[b+20>>2]=c;GF(a,b+8|0);gb=b+32|0;gb=d+16|0;return a|0}function hF(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(e);v[23048]=0;b=b-12|0;S(332,c|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;dm(wb(a),v[a>>2],pg(a))}}function _q(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=zl(a,b);if((e|0)==255){break a}if(ok(a)){break a}b=Um(a+314|0,e);e=WR(e);if(!(f=0,g=!(t[lc(b,10)|0]&1),h=d,h?f:g)){Rh(v[a>>2],e- -64&65535,VR(c,w[lc(b,2)|0]))}if(d){break a}Rh(v[a>>2],e+67&65535,VR(c,w[lc(b,3)|0]))}}function UQ(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=dc(a);if(w[a+4|0]){a=v[a>>2];v[23048]=0;c=v[23048];v[23048]=0;if((c|0)==1){break b}v[23048]=0;S(1207,a|0,b+16|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}}if(b){uA(b)}break a}V(0)|0;O()|0;Ab();L()}}}function hl(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=nt(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Nb(a,64)){eD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b- -64|0;while(1){Re(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function Zy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!Nf(a)){break a}while(1){if(!ai(ef(a,e))){break a}d=d+1|0;e=d&65535;if(Nf(a)>>>0>e>>>0){continue}break}}if(!(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0?c:0)){return(Sg(a,d&65535,b)?d:-1)&65535}return 65535}function OQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Gb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Kh(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function MQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Gb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=zb(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f|0}function yma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;MV(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Dk(b)}}function yV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;mV(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){nV(b)}return a}function qG(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;v[b>>2]=0;t[c+15|0]=0;Dh(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;a:{e=d&3;if(!e){break a}d=1;while(1){t[c+15|0]=0;Dh(a,c+15|0);v[b>>2]=v[b>>2]|w[c+15|0]<<(d<<3)-2;if((d|0)==(e|0)){break a}d=d+1|0;continue}}gb=c+16|0}function lY(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Bv(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){_C(b)}return a}function iK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=Bi(C(d*C(65536)));if((e|0)==65536){break a}f=B(b,c);if(!f){break a}c=e;e=e>>31;b=1;while(1){g=v[a>>2];h=a,i=vc(Gpa(Fpa(g,g>>31,c,e),jb,65536,0),jb),v[h>>2]=i;if((b|0)==(f|0)){break a}a=a+4|0;b=b+1|0;continue}}}function gU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;rX(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){sX(b)}return a}function cW(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;YV(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){XV(b)}return a}function YC(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;OX(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){XC(b)}return a}function Qs(a,b){var c=0,d=0,e=0;c=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{d=v[b+4>>2];c:{if(!d){PI(b);d=v[b+4>>2];if(!d){break c}}if(v[b+44>>2]-8>>>0<d>>>0){break b}}if(!e){break a}return-1}c=d-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;c=a}return c}function Qj(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Hp(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Sj(b)}return a}function OU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;JU(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){bd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){KU(b)}return a}function NC(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;rX(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){sX(b)}return a}function MH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=aa(16)|0;PH();a=_c(c+8|0,a,92168);v[23048]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2331,d|0,c|0,b|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){ja(d|0,79884,2332);L()}a=P()|0;O()|0;ca(d|0);R(a|0);L()}function vka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Nb(a,32)){NB(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b+32|0;while(1){Re(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function dv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;NB(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){MB(b)}}function _B(a){var b=0,c=0,d=0;if(v[a>>2]){c=a;b=v[a+4>>2];d=v[a>>2];if((b|0)!=(d|0)){while(1){b=b-24|0;yb(b);if((b|0)!=(d|0)){continue}break}}v[c+4>>2]=d;c=v[a>>2];a=hv(a);v[23048]=0;Oc(c,B(a,24),4);a=v[23048];v[23048]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function Tga(a){a=a|0;var b=0,c=0,d=0;c=gb-32|0;gb=c;b=255;a:{if(Ei(a)>>>0<=49){b=UA(c,v[a+12>>2]);v[23048]=0;S(1117,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)==1){break a}Km(b);Fi(a,Ei(a)-1&255);b=Ei(a)-1|0}gb=c+32|0;return b&255}a=P()|0;O()|0;Km(b);R(a|0);L()}function Ega(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Nb(a,27)){RR(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b+27|0;while(1){Re(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function B$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Kg(a,v[b+8>>2],0)){Vw(b,c,d);return}e=v[a+12>>2];f=a+16|0;BG(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){BG(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function Av(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-48;v[23048]=0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){UX(v[a+16>>2],v[a>>2],(v[bc(a)>>2]-v[a>>2]|0)/48|0)}}function u5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=Zs(a);e=Bb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Ob(a);ej(d+(e<<2)|0,b,c);b=c+e|0;yh(a,b);v[f+12>>2]=0;je(d+(b<<2)|0,f+12|0);break a}EI(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function pO(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=c;b=v[b>>2];v[a+16>>2]=b;v[a+20>>2]=f;v[a+8>>2]=e;v[a+12>>2]=d;v[a>>2]=b;v[a+4>>2]=f;d=!PL(a+8|0,a)}gb=c+32|0;return d}function lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;cc(c+24|0,b,1100);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;zM(a,b,c,d);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=49204;return a|0}function ov(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-6;v[23048]=0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){wC(v[a+16>>2],v[a>>2],(v[bc(a)>>2]-v[a>>2]|0)/6|0)}}function mma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Nb(a,2)){MV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b+2|0;while(1){Re(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function gd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;e=v[b>>2];g=v[b+8>>2];f=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=f;h=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=f;kb[h|0](a,e,g,d);i=b,j=xb(a)+v[b+8>>2]|0,v[i+8>>2]=j;gb=d+16|0}function UG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=84440;b=v[a+8>>2];v[23048]=0;c=fa(2371)|0;d=v[23048];v[23048]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=v[a+8>>2];v[23048]=0;tx(b);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Ab();L()}return a|0}function St(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-2048;v[23048]=0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){RM(v[a+16>>2],v[a>>2],v[bc(a)>>2]-v[a>>2]>>11)}}function Qu(a){var b=0,c=0;a:{if(w[a+4|0]|(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1414687062){break a}b=a+6|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>1){break a}b=a+12|0;if(Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+16|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==20}return c}function pE(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;cc(c+24|0,b,37);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Pb(b,0,37)}}function aJ(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=aJ(a*0x10000000000000000,b);b=v[b>>2]+-64|0}v[c>>2]=b;return a}v[b>>2]=c-1022;l(0,d|0);l(1,e&-2146435073|1071644672);a=+n()}return a}function JP(a,b,c){var d=0,e=0;d=(c|0)==1;c=v[(B(b,880)+a|0)+1075072>>2];a:{if(d&(c&134218752)!=0|c&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,880)+a|0)+1075772>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function GD(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;e=c;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}jb=a;return b}function E2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Ic(g,d);v[23048]=0;b=U(2375,g|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){Xb(g);oH(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Xb(g);R(a|0);L()}function D2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Ic(g,d);v[23048]=0;b=U(2375,g|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){Xb(g);nH(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Xb(g);R(a|0);L()}function nz(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;d=vf(a);e=b,f=Rb(a),v[e+8>>2]=f;e=b,f=Ub(a),v[e>>2]=f;if(Fb(b+8|0,b)){c=+(d>>>0);while(1){a=v[b+8>>2];A[a>>3]=A[a>>3]/c;A[a+8>>3]=A[a+8>>3]/c;Ro(b+8|0);if(Fb(b+8|0,b)){continue}break}}gb=b+16|0}function ffa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-2496|0;gb=c;YM(b,c,c+2496|0);b=hc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<=-1){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}gb=c+2496|0;return a|0}function Uv(a,b,c){var d=0,e=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-4;e=d|a<<1&2;if(a&2){t[b+12|0]=e|4;return}t[b+12|0]=e&251;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function mla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;gC(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function _w(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[23048]=0;c=fa(2371)|0;d=v[23048];v[23048]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[23048]=0;tx(b);b=v[23048];v[23048]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Ab();L()}return a|0}function Vt(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;a:{if(!(!b|!c)){e=Tb(d,b);v[23048]=0;T(1489,d+16|0,e|0,c|0);f=v[23048];v[23048]=0;if((f|0)==1){break a}Eb(a+36|0,d+16|0);vb(d+16|0);vb(e)}gb=d+32|0;return(b|0)!=0&(c|0)!=0}a=P()|0;O()|0;vb(e);R(a|0);L()}function Tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;f=$f(a,c);we(d+8|0,v[a+28>>2]);e=v[d+20>>2];v[d+24>>2]=v[d+16>>2];v[d+28>>2]=e;a:{b:{if(!f){e=-1;if(!nd(a,5)){break b}break a}e=v[f+8>>2]}LO(v[a+28>>2],b,e)}Rf(a,f,c,d+24|0);gb=d+32|0}function Qfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Nb(a,16);a:{if(d){aw(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=b+16|0;while(1){t[b|0]=0;b=b+1|0;if((a|0)!=(b|0)){continue}break}}gb=c+32|0;return d|0}function L2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Ic(g,d);v[23048]=0;b=U(21,g|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){Xb(g);rH(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Xb(g);R(a|0);L()}function K2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Ic(g,d);v[23048]=0;b=U(21,g|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){Xb(g);qH(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Xb(g);R(a|0);L()}function Cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Bg(a);a:{if(!b){break a}v[23048]=0;S(850,a|0,b|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;T(851,a|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;_r(d);R(a|0);L()}return a|0}function xZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Bg(a);a:{if(!b){break a}v[23048]=0;S(388,a|0,b|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;T(389,a|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;bu(d);R(a|0);L()}return a|0}function tT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<8)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){nB(a);a=v[c>>2]+256|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}$c(c);gb=d+16|0}function oW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,33)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){lW(a);a=v[c>>2]+33|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}$c(c);gb=d+16|0}function ZW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Bg(a);a:{if(!b){break a}v[23048]=0;S(659,a|0,b|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;T(660,a|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;qv(d);R(a|0);L()}return a|0}function Ev(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Bg(a);a:{if(!b){break a}v[23048]=0;S(532,a|0,b|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;T(533,a|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;$m(d);R(a|0);L()}return a|0}function Bz(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=gw(f,c);d=a+1074308|0;Db(e+8|0,d,31);a=0;if(!Cb(e+8|0)){Db(e,d,93);a=Cb(e)^1}if(!(t[uO(b,c)+6|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=cd(f)^1}gb=e+16|0;return d}function BD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Bg(a);a:{if(!b){break a}v[23048]=0;S(447,a|0,b|0);e=v[23048];v[23048]=0;if((e|0)!=1){v[23048]=0;T(448,a|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;$m(d);R(a|0);L()}return a|0}function ee(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-1;v[23048]=0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Rk(v[a+16>>2],v[a>>2],v[bc(a)>>2]-v[a>>2]|0)}}function dk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Ob(c);pj(b,a,Bb(c)+a|0);break c}uM(d,c);v[23048]=0;T(115,a|0,b|0,d|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Pc(d)}gb=d+16|0;break a}a=P()|0;O()|0;Pc(d);R(a|0);L()}}function Rm(a){var b=0,c=0,d=0,e=0;ev(a);if(v[a>>2]){c=a;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}wb(c);v[23048]=0;b=b-32|0;e=v[23048];v[23048]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[c+4>>2]=d;jV(wb(a),v[a>>2],nh(a))}}function PI(a){var b=0,c=0;b=w[a+74|0];t[a+74|0]=b-1|b;if(y[a+20>>2]>y[a+28>>2]){kb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function HW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,48)+e;if(v[c>>2]!=v[c+4>>2]){while(1){GW(v[c>>2]);a=v[c>>2]+48|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}$c(c);gb=d+16|0}function Gpa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=b^d;h=e>>31;f=b>>31;a=a^f;i=a-f|0;g=b;b=b>>31;g=(g^b)-((a>>>0<f>>>0)+b|0)|0;a=d>>31;b=c^a;c=d>>31;e=e>>31;a=Ipa(i,g,b-a|0,(c^d)-((a>>>0>b>>>0)+c|0)|0)^e;b=a-e|0;jb=(h^jb)-((a>>>0<e>>>0)+h|0)|0;return b}function $U(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<3)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){Sj(a);a=v[c>>2]+8|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}$c(c);gb=d+16|0}function en(a,b){var c=0,d=0,e=0,f=0,g=0;f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-28|0;Sl(e-28|0,c);e=v[d>>2]-28|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}zc(a,f);zc(a+4|0,b+8|0);zc(wb(a),bc(b));v[b>>2]=v[b+4>>2]}function UB(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;if((d|0)!=(a|0)){f=b?224:240;while(1){a=c;b=a+16|0;if((a|0)!=(b|0)){while(1){e=((f&w[lc(a,0)|0])!=0)+e|0;a=a+4|0;if((b|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return e}function Kt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Ob(c);pj(b,a,Bb(c)+a|0);break c}yM(d,b,c);v[23048]=0;S(116,a|0,d|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}Pc(d)}gb=d+16|0;break a}a=P()|0;O()|0;Pc(d);R(a|0);L()}}function una(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=$f(a,c);we(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(nd(a,5)){break a}}VW(v[a+28>>2],b,v[e+24>>2],0)}Rf(a,d,c,e+16|0);gb=e+32|0}function sY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=tn(d+8|0,a+8|0,fD(b,c));c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){Gv(c,v[d+24>>2]);v[a>>2]=v[a>>2]+2;jD(d+24|0);c=v[a>>2];if((c|0)!=v[a+4>>2]){continue}break}}$c(a);gb=d+32|0}function sO(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(!b){break a}g=c;h=c>>31;c=1;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=vc(Gpa(Fpa(d,d>>31,g,h),jb,256,0),jb);v[a+4>>2]=f-d;v[a>>2]=d+f;if((b|0)==(c|0)){break a}a=a+8|0;c=c+1|0;continue}}}function s4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;e=Ys(a);v[a>>2]=10716;f=Jb(a+32|0);v[a+48>>2]=c;v[a+44>>2]=0;v[23048]=0;S(173,a|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){gb=d+16|0;return a|0}a=P()|0;O()|0;vb(f);nm(e);R(a|0);L()}function Yja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;Om(a,b);d=c,e=Rb(a),v[d+8>>2]=e;d=c,e=Ub(a),v[d>>2]=e;if(Fb(c+8|0,c)){b=0;while(1){a=v[c+8>>2];b=zb(w[a|0])+b&255;d=a,e=zb(b),t[d|0]=e;Se(c+8|0);if(Fb(c+8|0,c)){continue}break}}gb=c+16|0}function MY(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(Nb(a,512)){mD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b+512|0;while(1){Bk(b);b=b+4|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function Dma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,256);tc(d+12|0,65535);e=x[d+12>>1];Cf(a,e);if(e){c=0;while(1){f=w[b+c|0];g=Si(a,c),h=f,u[g>>1]=h;c=c+1|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0}function vO(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=7;v[b+8>>2]=32;c=0;a:{if(!v[Gb(b+12|0,b+8|0)>>2]){break a}c=15;while(1){d=Lq(a);v[b+12>>2]=7;v[b+8>>2]=32;if(c>>>0<y[Gb(b+12|0,b+8|0)>>2]){c=c+15|0;continue}break}c=d&127}gb=b+16|0;return c}function sV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;mV(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){nV(b)}}function Ep(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=Nc(a);e=Bb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Ob(a);fi(d+e|0,b,c);b=c+e|0;yh(a,b);t[f+15|0]=0;Qd(b+d|0,f+15|0);break a}kw(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function Ct(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[23048]=0;U(1313,c|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){yd(a+68|0);Tf(a+36|0);mq(a+32|0);ri(b);qi(a+4|0);mf(a);return a}V(0)|0;O()|0;yd(a+68|0);Tf(a+36|0);mq(a+32|0);ri(b);qi(a+4|0);mf(a);Ab();L()}function TP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a=Uc(Cm(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=lk(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,880)+c|0)+1392>>1];a=Uc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,880)+c|0)+1392>>1]=a}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=$f(a,c);we(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(nd(a,5)){break a}}qN(v[a+28>>2],b,v[e+24>>2])}Rf(a,d,c,e+16|0);gb=e+32|0}function $O(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=zb(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+2080|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function t4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}b=b+4|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return xk(b,4,c,v[a+32>>2])|0}function CC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=nc(a+8|0);v[23048]=0;d=U(511,b|0)|0;e=v[23048];v[23048]=0;b:{if((e|0)==1){break b}v[23048]=0;T(404,a|0,b|0,d|0);a=v[23048];v[23048]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;gc(c);R(a|0);L()}}function C2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Ic(a,d);v[23048]=0;b=U(2375,a|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){Xb(a);mH(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Xb(a);R(b|0);L()}function Poa(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!YC(a,b+16|0)){break a}c=0;if(!QX(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!bd(a,4)){break a}}c=-1;if(!Qj(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}gb=b+32|0;return c|0}function LA(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(w[a+530|0]){while(1){d=c&65535;Qh(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;bi(a+4|0,18,b+15|0);kv(a+22|0,18,29690);t[b+14|0]=255;bi(a+58|0,256,b+14|0);gb=b+16|0}function Ju(a){a=a|0;var b=0,c=0,d=0,e=0;c=WS(a);if((c|0)!=(a|0)){while(1){b=0;e=a;UW(a);a:{while(1){d=b+e|0;if(w[d|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Pb(d,0,32-b|0)}a=a+32|0;if((c|0)!=(a|0)){continue}break}}}function rF(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function gx(a){a=a|0;var b=0,c=0,d=0;c=gb-16|0;gb=c;b=c;v[b>>2]=467232;d=v[116809];v[b+4>>2]=d;v[b+8>>2]=(a<<2)+d;a=v[b+4>>2];if((a|0)!=v[b+8>>2]){while(1){Qo(a);a=v[b+4>>2]+4|0;v[b+4>>2]=a;if(v[b+8>>2]!=(a|0)){continue}break}}_b(b);gb=c+16|0}function Up(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function J2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Ic(a,d);v[23048]=0;b=U(21,a|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){Xb(a);pH(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Xb(a);R(b|0);L()}function hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;b=(b-a|0)/160|0;if((b|0)>=1){while(1){f=a;d=c;v[a>>2]=v[d>>2];e=a+4|0;if((e|0)!=(d+4|0)){GO(e,v[d+4>>2],v[d+8>>2])}hc(f+16|0,d+16|0,144);a=a+160|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function CB(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;vd(a+12|0,d);if(b){d=b;if(b>>>0>=357913942){xc(26316);L()}f=jc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function $2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=ni(e,e+12|0);v[23048]=0;a=W(2392,a|0,c|0,v[e+8>>2])|0;c=v[23048];v[23048]=0;if((c|0)!=1){jf(b);gb=e+16|0;return a|0}a=P()|0;O()|0;jf(b);R(a|0);L()}function zF(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){d=b;if(b>>>0>119304647){xc(15392);L()}f=jc(B(d,36),4)}v[a>>2]=f;c=B(c,36)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=B(b,36)+f|0,v[g>>2]=h;gb=e+16|0;return a}function sF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;cc(c+24|0,b,20);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function ima(a,b){a=a|0;b=b|0;var c=0,d=0;c=Jg(a);a:{if(!b){break a}v[23048]=0;S(811,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(812,a|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;_B(c);R(a|0);L()}return a|0}function gW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;cc(c+24|0,b,18);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function bk(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;e=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=v[d+4>>2];v[a>>2]=v[d>>2];v[a+4>>2]=b;b=v[d+12>>2];v[a+8>>2]=v[d+8>>2];v[a+12>>2]=b;v[a+16>>2]=c;gb=d+16|0}function ZP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Jc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=OP(c&255),v[e+44>>2]=f}gb=d+16|0}function RG(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){d=b;if(b>>>0>357913941){xc(11047);L()}f=jc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Jd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>=2048){break a}c=c+1|0;if((g|0)!=(c|0)){continue}break}}return}u[a+20>>1]=c-d}function Be(){var a=0,b=0;a:{b:{if(t[465588]&1){break b}if(!Ud(465588)){break b}v[23048]=0;a=W(2373,2147483647,84357,0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break a}v[116396]=a;Td(465588)}return v[116396]}a=P()|0;O()|0;af(465588);R(a|0);L()}function uZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=Bg(a);a:{if(!b){break a}v[23048]=0;S(390,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(391,a|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;cE(c);R(a|0);L()}return a|0}function tH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){Gf(a,c);d=a;break a}f=$l(d)+1|0;d=Tj(f);_e(a,d);ch(a,f);Ae(a,c)}fi(d,b,c);t[e+15|0]=0;Qd(c+d|0,e+15|0);gb=e+16|0;return}Og();L()}function jK(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=c;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+16;a=v[b+4>>2];if((a|0)!=v[b+8>>2]){while(1){v[a>>2]=0;yk(a);a=v[b+4>>2]+4|0;v[b+4>>2]=a;if(v[b+8>>2]!=(a|0)){continue}break}}_b(b);gb=c+16|0}function WX(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){d=b;if(b>>>0>89478485){xc(17250);L()}f=jc(B(d,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=B(b,48)+f|0,v[g>>2]=h;gb=e+16|0;return a}function CE(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;cc(c+24|0,b,1);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function $W(a,b){a=a|0;b=b|0;var c=0,d=0;c=Bg(a);a:{if(!b){break a}v[23048]=0;S(532,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(647,a|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;$m(c);R(a|0);L()}return a|0}function vma(a,b){a=a|0;b=b|0;var c=0,d=0;c=Bg(a);a:{if(!b){break a}v[23048]=0;S(42,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(43,a|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;$m(c);R(a|0);L()}return a|0}function bR(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;vd(a+12|0,d);if(b){d=b;if(b>>>0>=613566757){xc(30917);L()}f=jc(B(d,7),1)}v[a>>2]=f;c=B(c,7)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=B(b,7)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Ue(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=nc(a+8|0);v[23048]=0;T(404,a|0,b|0,c|0);c=v[23048];v[23048]=0;a:{if((c|0)!=1){a=v[a>>2];v[23048]=0;Q(370,b|0,a|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;gc(d);R(a|0);L()}}function SQ(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function xD(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;wD(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function oD(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;jn(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function lV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;kV(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function is(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;ii(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function hW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;BX(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function fs(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Hp(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function eO(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;vd(a+12|0,d);if(b){d=b;if(b>>>0>=1073741824){xc(43937);L()}f=jc(d<<2,4)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function cF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;bs(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function aO(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;$N(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function _X(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Bv(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function WV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;VV(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Uq(a,b){var c=0;a:{if(b){Uq(a,v[b>>2]);Uq(a,v[b+4>>2]);a=dc(a);v[23048]=0;c=v[23048];v[23048]=0;if((c|0)==1){break a}v[23048]=0;S(1161,a|0,b+16|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}js(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function RX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;aw(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function RI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function NX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;OX(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function NV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;dC(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function MX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;eD(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Ig(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;ds(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function IX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=_A(d+8|0,a+8|0,JX(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){Qp(v[a>>2],v[d+24>>2]);v[a>>2]=v[a>>2]+1;Se(d+24|0);if(v[a>>2]!=v[a+4>>2]){continue}break}}$c(a);gb=d+32|0}function FM(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;vd(a+12|0,d);if(b){d=b;if(b>>>0>=1073741824){xc(47798);L()}f=jc(d<<2,4)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Dp(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;rn(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function CF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;DF(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function AT(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;dC(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;md(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){bd(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function AD(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Rv(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Vb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function yC(a,b){var c=0;a:{if(b){yC(a,v[b>>2]);yC(a,v[b+4>>2]);a=dc(a);v[23048]=0;c=v[23048];v[23048]=0;if((c|0)==1){break a}v[23048]=0;S(700,a|0,b+16|0);c=v[23048];v[23048]=0;if((c|0)==1){break a}_l(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function Xq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-fe(A[qe(a,c)>>3]*131072*f);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Dj(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function DA(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;vd(a+12|0,d);if(b){d=b;if(b>>>0>=536870912){xc(30794);L()}f=jc(d<<3,8)}v[a>>2]=f;c=(c<<3)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<3)+f|0,v[g>>2]=h;gb=e+16|0;return a}function y_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[b+8>>2];if(f>>>0>c>>>0){v[e+12>>2]=f-c;h=e,i=xb(d),v[h+8>>2]=i;f=Gb(e+12|0,e+8|0);b=v[b+4>>2]+c|0;g=v[f>>2];vg(b,b+g|0,v[d>>2])}Gj(a,d,g);gb=e+16|0}function Mp(a,b){var c=0;c=b+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a:{b:{b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b>>>0>=qc(a)>>>0){break b}if(qc(a)>>>0<c>>>0){break b}a=c>>>0<=qc(a)-b>>>0;break a}a=0}return a}function tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=0;a:{if(!Lb(a)){break a}while(1){cg(d,v[Mb(a,e)>>2]+40|0);c=zr(d,b);vb(d);if(c){c=v[Mb(a,e)>>2];break a}e=e+1|0;if(Lb(a)>>>0>e>>>0){continue}break}c=0}gb=d+16|0;return c|0}function dba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=12){le(d+12|0,C(0));c=z[d+12>>2];if((b|0)==12){c=C(Fe(C(c*C(3)))*C(.3333333432674408));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}gb=d+16|0}function aca(a){a=a|0;var b=0;kb[v[v[a>>2]+128>>2]](a);Ly(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=kb[v[v[a>>2]+192>>2]](a)|0;v[a+4272>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4292>>2]=b;v[a+4288>>2]=b;v[a+4284>>2]=b;v[a+4280>>2]=b}function Qoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;VX(a);wb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}mc(a,c);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];Lj(a);dn(a);dn(a)}function vA(a,b){var c=0;a:{if(b){vA(a,v[b>>2]);vA(a,v[b+4>>2]);a=dc(a);v[23048]=0;c=v[23048];v[23048]=0;if((c|0)==1){break a}v[23048]=0;S(1207,a|0,b+16|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}uA(b)}return}V(0)|0;O()|0;Ab();L()}function nG(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-16;v[23048]=0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}b=v[a>>2];if(b){Op(v[a+16>>2],b,Kw(a))}}function lma(a,b){a=a|0;b=b|0;var c=0,d=0;c=Jg(a);a:{if(!b){break a}v[23048]=0;S(809,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;Wm(a,b);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Vh(c);R(a|0);L()}return a|0}function gja(a,b){a=a|0;b=b|0;var c=0,d=0;c=Bg(a);a:{if(!b){break a}v[23048]=0;S(388,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;cT(a,b);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;bu(c);R(a|0);L()}return a|0}function A5(a){a=a|0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<y[a+44>>2]){Wn(a,v[a+8>>2],v[a+12>>2],v[a+44>>2])}if(y[a+12>>2]>=y[a+16>>2]){break a}return ah(t[v[a+12>>2]])|0}return-1}function sma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(jg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,qc(a),d);v[23048]=0;S(349,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}ee(b)}gb=c+32|0;return}a=P()|0;O()|0;ee(b);R(a|0);L()}function Lg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function BA(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-8;v[23048]=0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}b=v[a>>2];if(b){AA(v[a+16>>2],b,ZU(a))}}function AO(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;v[b>>2]=(B(a,v[b>>2])|0)/65536;return}if(v[a+696>>2]){break a}v[b>>2]=0}}function _V(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Gg(a)>>>0<b>>>0){d=wb(a);b=tp(c+8|0,b,uc(a),d);v[23048]=0;S(365,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}zh(b)}gb=c+32|0;return}a=P()|0;O()|0;zh(b);R(a|0);L()}function Voa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(jg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,qc(a),d);v[23048]=0;S(37,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}ee(b)}gb=c+32|0;return}a=P()|0;O()|0;ee(b);R(a|0);L()}function B8(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;b=b+4|0;d=v[b+48>>2];a:{if(d&16){if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}pj(a,v[b+20>>2],v[b+44>>2]);break a}if(d&8){pj(a,v[b+8>>2],v[b+16>>2]);break a}Jb(a)}gb=c+32|0}function zY(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;vd(a+12|0,d);if(b){d=b;if((b|0)<=-1){xc(17033);L()}f=jc(d<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function jP(a,b){a=a|0;b=b|0;eP(a);eP(a+368680|0);if(b){nO(a,1);return a|0}lO();$t(223472,289008,a+131112|0);$t(289008,354544,a+196648|0);$t(354544,420080,a+262184|0);$t(92384,223472,a+24|0);hc(a+327720|0,420080,40960);return a|0}function dg(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[Dj(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function cG(){var a=0,b=0,c=0;b=gb-16|0;gb=b;a=Tb(b,15177);a:{if(!Bb(a)){break a}c=1;if((ng(a,15183)|0)!=-1){break a}if((ng(a,11241)|0)!=-1){break a}if((ng(a,15187)|0)!=-1){break a}c=(ng(a,15189)|0)!=-1}vb(a);gb=b+16|0;return c|0}function tU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=PU(c+8|0,c);gb=c+32|0;return a}function dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;Hp(c+24|0,b);e=xb(c+24|0);b=v[c+28>>2];d=v[c+24>>2];v[c+8>>2]=d;v[c+12>>2]=b;v[c>>2]=d;v[c+4>>2]=b;fc(c+16|0,a,c);if((xb(c+16|0)|0)==(e|0)){Vb(a,xb(c+24|0))}gb=c+32|0}function Ud(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;a=Yw(c,a);d=gb-16|0;gb=d;if(!w[v[Cc(d+8|0,v[a+4>>2])>>2]]){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}L()}b=a}gb=d+16|0;gb=c+16|0;return b}function RB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);h=b,i=xb(a)+v[b+12>>2]|0,v[h+12>>2]=i;gb=d+16|0}function NR(a,b){var c=0,d=0;c=Bg(a);a:{if(!b){break a}v[23048]=0;S(1145,a|0,b|0);d=v[23048];v[23048]=0;if((d|0)!=1){v[23048]=0;S(1146,a|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;GR(c);R(a|0);L()}return a}function xu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;if(b){e=Nc(a);d=Bb(a);g=d+b|0;if(e-d>>>0<b>>>0){op(a,e,g-e|0,d,d,0,0)}e=d;d=Ob(a);Ov(e+d|0,b,c);yh(a,g);t[f+15|0]=0;Qd(d+g|0,f+15|0)}gb=f+16|0;return a|0}function jA(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[a+104>>2];if(d){v[a+88>>2]=v[a+88>>2]&-131|128;d=v[d>>2];v[a+76>>2]=d;v[c+12>>2]=b<<8;v[c+8>>2]=d-1;b=d+(v[Gb(c+12|0,c+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}gb=c+16|0}function QX(a){if(!((w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1179472708?(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179011410:0)){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}return 1}function Jea(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(pg(a)>>>0<b>>>0){d=wb(a);b=RQ(c+8|0,b,Gc(a),d);v[23048]=0;Fn(a,b);a=v[23048];v[23048]=0;if((a|0)==1){break a}su(b)}gb=c+32|0;return}a=P()|0;O()|0;su(b);R(a|0);L()}function IK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,880);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075828|0])*C(.0078125))}return C(c)}function HK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,880);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075829|0])*C(.0078125))}return C(c)}function PN(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=Rb(a),v[e+8>>2]=f;b=b+B(Wt(d+24|0,d+8|0),6)|0;if(Fb(d+24|0,d+16|0)){EC(a,bz(b+B(Wt(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}Uh(b);gb=d+32|0}function W3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=at(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=Ad(c);v[f>>2]=a;if(!a){break a}e=at(a,c,b,v[d+12>>2])}gb=d+16|0;return e|0}function N6(a){a=a|0;var b=0,c=0,d=0;b=a;c=Jg(a);v[23048]=0;_(2115,a|0);d=v[23048];v[23048]=0;a:{if((d|0)!=1){v[23048]=0;yt(b);b=v[23048];v[23048]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;$n(c);R(a|0);L()}Xd(a+12|0);return a|0}function Zea(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[a+480180>>2]=b;Vz(c,Hq(a));d=v[c+12>>2];b=a+1074316|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074308>>2]=v[c>>2];v[a+1074312>>2]=b;du(a+8|0,Hq(a));gb=c+16|0}function KK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,880);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075828|0])*C(.0078125))}return C(c)}function JK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,880);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075829|0])*C(.0078125))}return C(c)}function FI(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;if(c>>>0<=1073741807){a:{if(c>>>0<=1){Gf(a,c);e=a;break a}f=Qn(c)+1|0;e=om(f);_e(a,e);ch(a,f);Ae(a,c)}ej(e,b,c);v[d+12>>2]=0;je((c<<2)+e|0,d+12|0);gb=d+16|0;return}Og();L()}function NO(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function nt(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!Zx(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Pe(a)}return b}ha(69778,69696,1563,69798);L()}function mP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a=gs(d,a,b);b=v[a+4>>2];if((b|0)!=v[a+8>>2]){while(1){e=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=e;b=v[a+4>>2]+8|0;v[a+4>>2]=b;if(v[a+8>>2]!=(b|0)){continue}break}}_b(a);gb=d+16|0}function GU(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){yY(c);hD(v[c>>2],Mi(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);d=wb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function uG(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(jg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,qc(a),d);v[23048]=0;S(199,a|0,b|0);a=v[23048];v[23048]=0;if((a|0)==1){break a}ee(b)}gb=c+32|0;return}a=P()|0;O()|0;ee(b);R(a|0);L()}function ku(a,b){var c=0,d=0;c=B(b,880)+a|0;a:{if(v[c+1075072>>2]&134218752){break a}if(!kk(c+1074984|0)){break a}b=w[v[(B(b,880)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function hU(a,b,c){var d=0;d=gb-16|0;gb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|b>>>0>=c>>>0|b>>>0>=109|c>>>0>=109)){t[d+14|0]=(x[(b<<1)+33790>>1]-x[(c<<1)+33790>>1]|0)/5;a=w[$b(d+15|0,d+14|0)|0]}gb=d+16|0;return a&255}function eT(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function LV(a){var b=0;a:{if(zd(a,24315,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}return w[a+3|0]<6}return 0}function II(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Bb(a);if(d>>>0<b>>>0){xu(a,b-d|0,c);return}c=gb-16|0;gb=c;a:{if($e(a)){d=v[a>>2];t[c+15|0]=0;Qd(b+d|0,c+15|0);Ae(a,b);break a}t[c+14|0]=0;Qd(a+b|0,c+14|0);Gf(a,b)}gb=c+16|0}function m1(){var a=0;a:{b:{if(t[465612]&1){break b}if(!Ud(465612)){break b}v[23048]=0;X(2461);a=v[23048];v[23048]=0;if((a|0)==1){break a}v[116402]=465604;Td(465612)}return v[116402]}a=P()|0;O()|0;af(465612);R(a|0);L()}function fW(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function bD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=0;a:{if(!a){break a}e=a|-16;if(!(a>>>0<16&c?0:b>>>0>=2)){break a}t[d+15|0]=1;t[d+14|0]=(a|0)/(b-1|0);e=w[Ff(d+15|0,d+14|0)|0]}a=e;gb=d+16|0;return a&255}function aH(){var a=0;a:{b:{if(t[465600]&1){break b}if(!Ud(465600)){break b}v[23048]=0;X(2458);a=v[23048];v[23048]=0;if((a|0)==1){break a}v[116399]=465592;Td(465600)}return v[116399]}a=P()|0;O()|0;af(465600);R(a|0);L()}function JT(a){a=+a;a=a*4294967296;if(D(a)<0x8000000000000000){jb=D(a)>=1?a>0?~~F(H(a*2.3283064365386963e-10),4294967295)>>>0:~~I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10)>>>0:0;return~~a>>>0|0}jb=-2147483648;return 0}function t0(a){a=a|0;a:{b:{if(t[465688]&1){break b}if(!Ud(465688)){break b}v[23048]=0;X(2477);a=v[23048];v[23048]=0;if((a|0)==1){break a}v[116421]=465872;Td(465688)}return v[116421]}a=P()|0;O()|0;af(465688);R(a|0);L()}function q0(a){a=a|0;a:{b:{if(t[465696]&1){break b}if(!Ud(465696)){break b}v[23048]=0;X(2479);a=v[23048];v[23048]=0;if((a|0)==1){break a}v[116423]=466048;Td(465696)}return v[116423]}a=P()|0;O()|0;af(465696);R(a|0);L()}function oA(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=(v[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(Wp(b)+-4.8737671609324025),A[d+8>>3]=e;hg(c+8|0,0,127);a=Xm(A[c+8>>3]);gb=c+16|0;return a|0}function n0(a){a=a|0;a:{b:{if(t[465704]&1){break b}if(!Ud(465704)){break b}v[23048]=0;X(2481);a=v[23048];v[23048]=0;if((a|0)==1){break a}v[116425]=466224;Td(465704)}return v[116425]}a=P()|0;O()|0;af(465704);R(a|0);L()}function kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Fb(d+16|0,d+24|0)){while(1){v[d+12>>2]=v[v[d+16>>2]>>2];hA(a,d+12|0);Qg(d+16|0);if(Fb(d+16|0,d+24|0)){continue}break}}gb=d+32|0}function kU(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function k0(a){a=a|0;a:{b:{if(t[465712]&1){break b}if(!Ud(465712)){break b}v[23048]=0;X(2483);a=v[23048];v[23048]=0;if((a|0)==1){break a}v[116427]=466528;Td(465712)}return v[116427]}a=P()|0;O()|0;af(465712);R(a|0);L()}function h0(a){a=a|0;a:{b:{if(t[465720]&1){break b}if(!Ud(465720)){break b}v[23048]=0;X(2485);a=v[23048];v[23048]=0;if((a|0)==1){break a}v[116429]=466832;Td(465720)}return v[116429]}a=P()|0;O()|0;af(465720);R(a|0);L()}function eY(a,b,c){var d=0;d=gb-32|0;gb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;if(Fb(d+24|0,d+16|0)){while(1){if(!SX(d+8|0,v[d+24>>2])){np(d+24|0);if(Fb(d+24|0,d+16|0)){continue}}break}a=v[d+24>>2]}gb=d+32|0;return a}function e0(a){a=a|0;a:{b:{if(t[465728]&1){break b}if(!Ud(465728)){break b}v[23048]=0;X(2487);a=v[23048];v[23048]=0;if((a|0)==1){break a}v[116431]=466864;Td(465728)}return v[116431]}a=P()|0;O()|0;af(465728);R(a|0);L()}function du(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=45012;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=45380;break a;case 2:c=45288;break a;case 1:break b;case 0:break c}}c=45196;break a}c=45104}v[a>>2]=c}function YR(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function Sp(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){Gf(a,c);e=a;break a}f=$l(c)+1|0;e=Tj(f);_e(a,e);ch(a,f);Ae(a,c)}fi(e,b,c);t[d+15|0]=0;Qd(c+e|0,d+15|0);gb=d+16|0;return}Og();L()}function E5(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{if(Br(b,74891)){BI(c,74904,b);a=Ob(c);v[23048]=0;S(2220,44,a|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);R(a|0);L()}gb=c+16|0;return a|0}L()}function wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=dd(a);e=vk(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[23048]=0;S(1150,a|0,1);b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;yR(e);CR(d);R(a|0);L()}function pk(a){a=a|0;tc(a+16|0,v[a>>2]);tc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function gT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[23048]=0;b=b-28|0;S(984,c|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function aU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;u[a+34>>1]=0;d=gb-16|0;gb=d;e=gb-16|0;gb=e;c=a+43|0;f=c+22|0;while(1){Re(c);c=c+1|0;if((f|0)!=(c|0)){continue}break}gb=e+16|0;gb=d+16|0;v[a+20>>2]=0;wd(a,b);return a|0}function WF(a){var b=0;a:{b=a+2|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}a=a+4|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<2147483649}return 0}function SF(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[23048]=0;b=b-36|0;S(269,c|0,b|0);c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function Nz(a,b,c){var d=0;a:{if(x[a+480192>>1]){if(!ue(b)|x[a+480192>>1]<c>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[ud(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function Lca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a=ek(a);d=1;a:{if(!a){break a}d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;d=kb[e|0](a,c)|0}gb=c+16|0;return d|0}function Fpa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;jb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=Te(b);c=kT(d+8|0,c);v[23048]=0;Y(983,a|0,b|0,e-1&65535,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){Ee(c);gb=d+32|0;return}a=P()|0;O()|0;Ee(c);R(a|0);L()}function _x(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!mt(a)){break a}if(!(t[a+1375|0]&1)){continue}break}ec(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function Mo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;Db(d+8|0,c+1074308|0,102);a:{if(!Cb(d+8|0)){break a}c=x[a+692>>1]+1|0;u[a+786>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+786>>1]=c|32768}v[a+692>>2]=b;gb=d+16|0}function KR(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=c*A[a+8>>3]+A[a>>3]*b+e*A[a+16>>3]-(f*A[a+32>>3]+d*A[a+24>>3]);A[a+56>>3]=b;return b}function Vn(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return C(b?-1/a:a)}function FX(a){var b=0,c=0,d=0;b=v[a>>2];c=SC(a);d=gb-16|0;gb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=Nd(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}gb=d+16|0;return v[b>>2]}function fI(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=kb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!Ke(b,-1)){break a}v[a>>2]=0}return a|0}function eR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=tn(d,a+8|0,hp(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){Gu(v[a>>2],b);c=v[a>>2]+2|0;v[a>>2]=c;b=b+2|0;if(v[a+4>>2]!=(c|0)){continue}break}}$c(a);gb=d+16|0}function YP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;e=c&15;if(e){t[b+826|0]=e}c=c&240;if(c){t[b+825|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;Db(d+8|0,a+1074308|0,80);if(!(!e|!Cb(d+8|0))){t[b+826|0]=w[b+826|0]<<2}gb=d+16|0}function XG(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=$p(d,a,1);a=wb(a);e=v[c+4>>2];v[23048]=0;Gn(a,e,b);a=v[23048];v[23048]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;_b(c);gb=d+16|0;return}a=P()|0;O()|0;_b(c);R(a|0);L()}function X6(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;Kp(a);v[a>>2]=58060;d=qk(c+8|0);b=qk(b);v[23048]=0;W(2110,a+12|0,d|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;R(a|0);L()}function X$(a){a=a|0;a:{b:{if(t[465792]&1){break b}if(!Ud(465792)){break b}v[23048]=0;Q(2490,465780,84680)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(465792)}return 465780}a=P()|0;O()|0;af(465792);R(a|0);L()}function W6(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;Kp(a);v[a>>2]=58204;d=qk(c+8|0);b=qk(b);v[23048]=0;W(2111,a+12|0,d|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;R(a|0);L()}function T$(a){a=a|0;a:{b:{if(t[465824]&1){break b}if(!Ud(465824)){break b}v[23048]=0;Q(2490,465812,84740)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(465824)}return 465812}a=P()|0;O()|0;af(465824);R(a|0);L()}function Sna(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Nb(a,12);a:{if(d){EW(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}t[c+16|0]=0;bi(b,12,c+16|0)}gb=c+32|0;return d|0}function P$(a){a=a|0;a:{b:{if(t[465856]&1){break b}if(!Ud(465856)){break b}v[23048]=0;Q(2490,465844,84836)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(465856)}return 465844}a=P()|0;O()|0;af(465856);R(a|0);L()}function $$(a){a=a|0;a:{b:{if(t[465760]&1){break b}if(!Ud(465760)){break b}v[23048]=0;Q(2490,465748,84632)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(465760)}return 465748}a=P()|0;O()|0;af(465760);R(a|0);L()}function iW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Ug(d,a,1);a=wb(a);e=v[c+4>>2];v[23048]=0;$o(a,e,b);a=v[23048];v[23048]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;_b(c);gb=d+16|0;return}a=P()|0;O()|0;_b(c);R(a|0);L()}function Yz(a,b){var c=0,d=0,e=0,f=0;c=a<<8&16711680|a<<24;d=b<<24|a>>>8;e=d&65280;d=b<<8|a>>>24;c=d&255|e|c;a=((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|f;jb=c;return a}function Iz(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}hc(a+24604|0,b,40);DO(a,c)}function C_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;Kp(a);v[a>>2]=15468;d=Jp(c+8|0);b=Jp(b);v[23048]=0;W(268,a+12|0,d|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;R(a|0);L()}function lk(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=v[a+24>>2];d=v[a+40>>2];v[23048]=0;v[b+12>>2]=1;a=Jc(a+20|0,b+12|0);e=v[23048];v[23048]=0;if((e|0)!=1){gb=b+16|0;return B(v[a>>2],c+d|0)}V(0)|0;O()|0;Ab();L()}function b0(a){a=a|0;a:{b:{if(t[465744]&1){break b}if(!Ud(465744)){break b}v[23048]=0;Q(91,465732,84620)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(465744)}return 465732}a=P()|0;O()|0;af(465744);R(a|0);L()}function Z$(a){a=a|0;a:{b:{if(t[465776]&1){break b}if(!Ud(465776)){break b}v[23048]=0;Q(91,465764,84668)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(465776)}return 465764}a=P()|0;O()|0;af(465776);R(a|0);L()}function V$(a){a=a|0;a:{b:{if(t[465808]&1){break b}if(!Ud(465808)){break b}v[23048]=0;Q(91,465796,84716)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(465808)}return 465796}a=P()|0;O()|0;af(465808);R(a|0);L()}function R$(a){a=a|0;a:{b:{if(t[465840]&1){break b}if(!Ud(465840)){break b}v[23048]=0;Q(91,465828,84824)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(465840)}return 465828}a=P()|0;O()|0;af(465840);R(a|0);L()}function Hz(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;CO(a+24648|0);TO(a)}function wU(a){var b=0,c=0,d=0;c=a;b=v[a+8>>2];d=v[a+4>>2];if((b|0)!=(d|0)){while(1){b=b-56|0;v[c+8>>2]=b;Yu(b);b=v[c+8>>2];if((d|0)!=(b|0)){continue}break}}c=v[a>>2];if(c){IB(c,(v[bc(a)>>2]-v[a>>2]|0)/56|0)}}function mS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e>>2]=c;v[e+8>>2]=b;if(Fb(e+8|0,e)){while(1){on(a,v[d>>2],v[e+8>>2]);sf(e+8|0);v[d>>2]=v[d>>2]+2;if(Fb(e+8|0,e)){continue}break}}gb=e+16|0}function jt(a){var b=0;if(a){if(v[a+76>>2]<=-1){return Vx(a)}return Vx(a)}if(v[23040]){b=jt(v[23040])}a=v[115528];if(a){while(1){if(y[a+20>>2]>y[a+28>>2]){b=Vx(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}function co(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{if(c){Tb(d,c);break a}Jb(d)}v[23048]=0;T(13,a|0,b|0,d|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);R(a|0);L()}function Zg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){f=Tj(b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=b+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function Vw(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function Un(a,b,c){var d=0,e=0;d=Nd(b,a);e=Nd(c,b);a:{b:{if(!d){d=0;if(!e){break a}mc(b,c);d=1;if(!Nd(b,a)){break a}mc(a,b);break b}if(e){mc(a,c);return 1}mc(a,b);d=1;if(!Nd(c,b)){break a}mc(b,c)}d=2}return d}function E1(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=a;b=v[a+112>>2];a:{if((b|0)<=10){c=b+1|0;break a}e=a;b=378;while(1){bH(e);c=f-(b>>>0<1)|0;b=b-1|0;f=c;if(b|c){continue}break}c=1}v[d+112>>2]=c;a=bH(a);return a|0}function $ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;kb[g|0](a,b,e,d);gb=e+16|0}function Ng(a){var b=0;v[23048]=0;a=U(1312,a|0)|0;b=v[23048];v[23048]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;X(20);b=v[23048];v[23048]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Ab();L()}function HR(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;a=gs(c,a,2048);b=v[a+4>>2];if((b|0)!=v[a+8>>2]){while(1){v[b>>2]=0;v[b+4>>2]=0;b=v[a+4>>2]+8|0;v[a+4>>2]=b;if(v[a+8>>2]!=(b|0)){continue}break}}_b(a);gb=c+16|0}function B7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=$p(e,a,d);wb(a);v[23048]=0;T(2092,b|0,c|0,d+4|0);a=v[23048];v[23048]=0;if((a|0)!=1){_b(d);gb=e+16|0;return}a=P()|0;O()|0;_b(d);R(a|0);L()}function lP(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function cD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=d,f=eY(Rb(b),Ub(b),d+12|0),v[e+8>>2]=f;e=d,f=Ub(b),v[e>>2]=f;a:{if(Fb(d+8|0,d)){Me(a,wb(v[d+8>>2]));break a}Ah(a)}gb=d+16|0}function VB(a,b,c){var d=0;d=gb-16|0;gb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Fb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}sf(d+8|0);if(Fb(d+8|0,d)){continue}break}}gb=d+16|0;return v[d+8>>2]}function TO(a){var b=0,c=0;b=gb-544|0;gb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){IR(b,yf(a));c=a+1300264|0;a=a+1074984|0;while(1){hc(a+112|0,b,538);a=a+880|0;if((c|0)!=(a|0)){continue}break}}gb=b+544|0}function Pv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function NE(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;if(!((f-1^e-1)>>>0<32?e:0)){g=v[a>>2];v[(f>>>0<33?g:(f-1>>>3&536870908)+g|0)>>2]=0}zp(d+8|0,a,e);yp(d+8|0,b,c);gb=d+16|0}function Hx(a){a=a|0;var b=0;v[a>>2]=78400;v[23048]=0;S(2229,a|0,0);b=v[23048];v[23048]=0;if((b|0)!=1){Xb(a+28|0);Zb(v[a+32>>2]);Zb(v[a+36>>2]);Zb(v[a+48>>2]);Zb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Ab();L()}function rR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[23048]=0;c=c-12|0;S(1159,d|0,c|0);d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function lH(a,b,c,d,e,f){var g=0,h=0,i=0;g=gb-16|0;gb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){th(g+13|0,g+14|0)}h=c,i=($a(b|0,vX(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;gb=g+16|0}function jS(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[23048]=0;c=c-32|0;S(1129,d|0,c|0);d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function HO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[23048]=0;c=c-52|0;S(1342,d|0,c|0);d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Cv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=ac(128/(B(v[Wf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[Ff(c+7|0,c+6|0)|0];gb=c+16|0;return a|b<<4&240}function qca(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){YO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=FM(d+8|0,Jl(a,Lb(a)+1|0),Lb(a),c);Eq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;Ji(a,c);Jz(c);gb=d+32|0}function p_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;b=Xi(e+8|0,b);v[23048]=0;Y(278,a|0,b|0,c|0,d|0);a=v[23048];v[23048]=0;if((a|0)!=1){Bc(b);gb=e+16|0;return}a=P()|0;O()|0;Bc(b);R(a|0);L()}function lu(a,b){a=hc(a,b,88);v[a+88>>2]=v[b+88>>2];hc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];hc(a+672|0,b+672|0,52);to(a+724|0,b+724|0);to(a+732|0,b+732|0);to(a+740|0,b+740|0);hc(a+748|0,b+748|0,127)}function i1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){while(1){a=d;if(y[b>>2]<=127){e=x[aq()+(v[b>>2]<<1)>>1]}else{e=0}u[a>>1]=e;d=d+2|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function OA(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){Ho(d);ZR(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function ND(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[23048]=0;c=c-20|0;S(409,d|0,c|0);d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function tp(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){f=tE(v[a+16>>2],b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function oi(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;d=v[a+8>>2];g=v[a+4>>2];e=d-g|0;f=e>>31;v[a+120>>2]=e;v[a+124>>2]=f;v[a+104>>2]=b|c?((c|0)<(f|0)?1:(c|0)<=(f|0)?b>>>0<e>>>0:0)?b+g|0:d:d}function jba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;b=vc(Gpa(Fpa(d,d>>31,b,0),jb,1e3,0),jb);v[a+16>>2]=0;v[a+12>>2]=b+c;bM(a,e);b=v[a+12>>2];v[f+12>>2]=0;tN(a,b,f+12|0);gb=f+16|0}function bg(a,b,c,d,e){var f=0;f=gb-256|0;gb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Pb(f,b&255,d?c:256);if(!d){while(1){xf(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}xf(a,f,c)}gb=f+256|0}function NA(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;d=Nc(a);a:{if(d>>>0>=c>>>0){d=Ob(a);mn(d,b,c);t[e+15|0]=0;Qd(c+d|0,e+15|0);yh(a,c);break a}f=d;g=c-d|0;d=Bb(a);kw(a,f,g,d,0,d,c,b)}gb=e+16|0;return a}function LL(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;Mh(c+24|0,a);Mh(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=PL(c+8|0,c);gb=c+32|0;return a|0}function mU(a){var b=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;if((w[a|0]|w[a+1|0]<<8)!=2?(w[a|0]|w[a+1|0]<<8)!=1:0){break a}b=1}return b}function hX(a){var b=0,c=0;b=a+36|0;c=Fpa(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}jb=a;return b}function ce(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Ad(b)}return c}function cT(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Ug(c,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(a);Qo(v[b+4>>2]);d=v[b+4>>2]+4|0;v[b+4>>2]=d;if(v[b+8>>2]!=(d|0)){continue}break}}_b(b);gb=c+16|0}function XF(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1129474426&(w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24))==1634291279){a=a+8|0;return(w[a|0]|w[a+1|0]<<8)==14}return 0}function Ut(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=1073741823;v[23048]=0;v[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function UE(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=2147483647;v[23048]=0;v[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function LN(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Er(c,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){wb(a);$h(v[b+4>>2]);d=v[b+4>>2]+6|0;v[b+4>>2]=d;if(v[b+8>>2]!=(d|0)){continue}break}}_b(b);gb=c+16|0}function IN(a){var b=0,c=0,d=0;if(Nf(a)){while(1){b=a;d=c&65535;if(Nf(b)>>>0>d>>>0){b=ef(b,d);v[b+20>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;ON(b);bf(b+36|0)}c=c+1|0;if(Nf(a)>>>0>(c&65535)>>>0){continue}break}}}function u8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=Pp(e,a,d);v[23048]=0;T(2050,b|0,c|0,a+4|0);b=v[23048];v[23048]=0;if((b|0)!=1){_b(a);gb=e+16|0;return}b=P()|0;O()|0;_b(a);R(b|0);L()}function q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=v[a+24>>2];Kt(d,0,c);v[23048]=0;T(601,a|0,b|0,d|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);R(a|0);L()}function lO(){var a=0;a:{b:{if(t[461064]&1){break b}if(!Ud(461064)){break b}v[23048]=0;Q(1430,92360,1)|0;a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(461064)}return}a=P()|0;O()|0;af(461064);R(a|0);L()}function g1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]>127){break a}if(!(x[aq()+(v[c>>2]<<1)>>1]&b)){break a}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function cs(a,b,c){a:{if(y[a+12>>2]<=b>>>0){a=aa(8)|0;v[23048]=0;U(336,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);R(b|0);L()}t[v[a+8>>2]+b|0]=c;return}ja(a|0,16160,259);L()}function SD(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=214748364;v[23048]=0;v[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function OG(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=357913941;v[23048]=0;v[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function CW(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=715827882;v[23048]=0;v[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function cla(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=HE(a);if(d>>>0>=b>>>0){a=$u(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Jc(c+12|0,c+8|0)>>2]}gb=c+16|0;return d|0}Mc();L()}function an(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=1073741823;v[23048]=0;v[a+8>>2]=2147483647;b=Gb(a+12|0,a+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Ab();L()}function MU(a){var b=0,c=0,d=0,e=0;jb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function M0(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=ni(b+8|0,b+12|0);v[23048]=0;c=JI(0,0,4);d=v[23048];v[23048]=0;if((d|0)!=1){jf(a);gb=b+16|0;return c|0}b=P()|0;O()|0;jf(a);R(b|0);L()}function xT(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=134217727;v[23048]=0;v[a+8>>2]=2147483647;b=Gb(a+12|0,a+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Ab();L()}function mR(a){var b=0,c=0,d=0;c=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[23048]=0;b=b-8|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=c}function lG(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=268435455;v[23048]=0;v[a+8>>2]=2147483647;b=Gb(a+12|0,a+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Ab();L()}function hs(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=536870911;v[23048]=0;v[a+8>>2]=2147483647;b=Gb(a+12|0,a+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Ab();L()}function UO(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break a}kb[v[v[b>>2]+96>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function CV(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=178956970;v[23048]=0;v[a+8>>2]=2147483647;b=Gb(a+12|0,a+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Ab();L()}function LO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=gb-16|0;gb=c;Yf(a,c+14|0);GC(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){uk(a,Mb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}Lz(b);gb=c+16|0}function CN(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=82595524;v[23048]=0;v[a+8>>2]=2147483647;b=Gb(a+12|0,a+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Ab();L()}function LR(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function Kd(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function kj(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Z1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;c=gb-16|0;gb=c;b=a;a:{if(!$e(f)){v[b+8>>2]=v[f+8>>2];a=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=a;break a}FI(a,v[f>>2],v[f+4>>2])}gb=c+16|0}function Rs(a){var b=0;if(v[a+76>>2]<0){b=v[a+4>>2];if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return Kx(a)}b=v[a+4>>2];a:{if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=Kx(a)}return a}function KP(a,b,c){var d=0,e=0;d=v[(B(b,880)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,880)+a|0)+1075088>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function zv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function rS(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[a+16|0]=0;c=UA(b,v[a+12>>2]);v[23048]=0;S(1115,a|0,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){Km(c);gb=b+32|0;return}a=P()|0;O()|0;Km(c);R(a|0);L()}function bh(a,b){a:{if(y[a+4>>2]<=b>>>0){a=aa(8)|0;v[23048]=0;U(336,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);R(b|0);L()}return w[v[a>>2]+b|0]}ja(a|0,16160,259);L()}function Xc(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[23048]=0;v[c>>2]=-1;v[c+4>>2]=0;a=Wl(c+8|0,c);b=v[23048];v[23048]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function RQ(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){f=QQ(b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Q3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if((b|0)==(c|0)){a=0;break a}a=0;while(1){a=v[b>>2]+a|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;if((c|0)==(b|0)){break a}a=a<<4;continue}}return a|0}function L0(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=ni(b+8|0,b+12|0);v[23048]=0;c=DH();d=v[23048];v[23048]=0;if((d|0)!=1){jf(a);gb=b+16|0;return c|0}b=P()|0;O()|0;jf(a);R(b|0);L()}function FW(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=-1;v[23048]=0;v[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function CX(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){f=OD(b)}v[a>>2]=f;c=B(c,20)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=B(b,20)+f|0,v[g>>2]=h;gb=e+16|0;return a}function tS(a,b,c){var d=0,e=0,f=0;$r(a);e=v[b+4>>2];d=b+4|0;Ym(wb(a),v[a>>2],c,d);wb(a);f=c;c=b+8|0;Pl(f,v[a+4>>2],c);mc(a,d);mc(a+4|0,c);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];nw(a,uc(a));return e}function pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<qc(a)>>>0){a=En(d,oc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=Pw(c,a);Hb(a);e=b^1}gb=d+16|0;return e|0}function Vr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(HE(a)>>>0<b>>>0){Mc();L()}wb(a);b=(b-1>>>5|0)+1|0;c=b;if(b>>>0>1073741823){xc(16348);L()}c=jc(c<<2,4);v[a+4>>2]=0;v[a>>2]=c;d=wb(a),e=b,v[d>>2]=e}function TG(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=e;e=ni(f+8|0,f+12|0);v[23048]=0;a=dq(a,b,c,d);b=v[23048];v[23048]=0;if((b|0)!=1){jf(e);gb=f+16|0;return a}a=P()|0;O()|0;jf(e);R(a|0);L()}function T3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if((b|0)==(c|0)){a=0;break a}a=0;while(1){a=t[b|0]+a|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;if((c|0)==(b|0)){break a}a=a<<4;continue}}return a|0}function OK(a){a=a|0;var b=0;a=a+24|0;b=PK(v[a>>2]);if(Gi(Qb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074438>>1]}b=x[sc(Qb(v[a>>2]+484360|0),b)>>1];return(Ul(v[a>>2]+484344|0,b)?b:-1)|0}function HX(a,b,c){var d=0,e=0,f=0;TC(a);e=v[b+4>>2];d=b+4|0;Ym(wb(a),v[a>>2],c,d);wb(a);f=c;c=b+8|0;Pl(f,v[a+4>>2],c);mc(a,d);mc(a+4|0,c);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];BC(a,qc(a));return e}function xw(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0}function rg(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb+-64|0;gb=c;d=$y(c+8|0,a);v[23048]=0;T(1503,a|0,b|0,d|0);a=v[23048];v[23048]=0;if((a|0)!=1){xm(d);gb=c- -64|0;return}a=P()|0;O()|0;xm(d);R(a|0);L()}function pga(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=ST(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){oR(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}$c(b);gb=c+16|0}function nba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=1){le(d+12|0,C(0));c=z[d+12>>2];if((b|0)==1){c=Fe(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;cM(a)}gb=d+16|0}function h1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]<=127){if(x[aq()+(v[c>>2]<<1)>>1]&b){break a}}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function fS(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;vd(a+12|0,d);if(b){f=hS(b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<5)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Yf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;u[c+30>>1]=0;Zi(c+16|0,a,c+30|0,2);a=xb(c+16|0);u[c+14>>1]=x[c+30>>1];d=b;b=c+14|0;u[d>>1]=w[b|0]|w[b+1|0]<<8;gb=c+32|0;return(a|0)==2|0}function Wm(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=Ug(c,a,b);b=v[a+4>>2];if((b|0)!=v[a+8>>2]){while(1){Bk(b);b=v[a+4>>2]+4|0;v[a+4>>2]=b;if(v[a+8>>2]!=(b|0)){continue}break}}_b(a);gb=c+16|0}function Vy(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){f=pN(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Hh(a,b){var c=0,d=0;a=v[a>>2];b=Yd(b);c=b;d=a+16|0;if(Lb(d)>>>0>b>>>0){c=v[Mb(d,c)>>2]!=0}else{c=0}if(!c){a=aa(4)|0;go(a);v[a>>2]=90940;ja(a|0,91e3,2460);L()}return v[Mb(a+16|0,b)>>2]}function EN(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){f=dN(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Cw(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=gs(c,a,b);b=v[a+4>>2];if((b|0)!=v[a+8>>2]){while(1){Sj(b);b=v[a+4>>2]+8|0;v[a+4>>2]=b;if(v[a+8>>2]!=(b|0)){continue}break}}_b(a);gb=c+16|0}function Cba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){le(d+12|0,C(0));c=z[d+12>>2];if((b|0)==4){c=Fe(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;hM(a)}gb=d+16|0}function Ap(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){f=IE(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function AW(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Zf(a+12|0,d);if(b){f=BW(b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=bc(a),h=B(b,6)+f|0,v[g>>2]=h;gb=e+16|0;return a}function zT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=wT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){MB(a);a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}$c(b);gb=c+16|0}function vT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=kG(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){zv(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}$c(b);gb=c+16|0}function toa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Nb(b,6)){BX(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;bi(a,6,c+16|0)}gb=c+32|0}function r8(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=v[a+24>>2];Kt(c,0,b);v[23048]=0;T(601,a|0,1,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);R(a|0);L()}function oG(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=kG(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){iG(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}$c(b);gb=c+16|0}function Xka(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Nb(b,5)){Rv(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;bi(a,5,c+16|0)}gb=c+32|0}function UT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=ST(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){RT(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}$c(b);gb=c+16|0}function $T(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}zc(a,c);zc(a+4|0,b+8|0);zc(wb(a),bc(b));v[b>>2]=v[b+4>>2]}function wp(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Nb(b,3)){sE(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;bi(a,3,c+16|0)}gb=c+32|0}function sC(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function nn(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Nb(b,4)){ii(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;bi(a,4,c+16|0)}gb=c+32|0}function lF(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-9&255)>>>0>6|((w[a+5|0]-9&255)>>>0>6|(w[a+6|0]-9&255)>>>0>6))){return(w[a+7|0]-9&255)>>>0<7}return 0}function iD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function fc(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=v[b>>2];f=v[b+8>>2];b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;g=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=b;kb[g|0](a,e,f,d);gb=d+16|0}function cg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=a;a:{if(!$e(b)){v[c+8>>2]=v[b+8>>2];e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;break a}Sp(a,v[b>>2],v[b+4>>2])}gb=d+16|0;return a|0}function Yo(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Ik(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Bk(a);a=v[b>>2]+4|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}$c(b);gb=c+16|0}function Taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(86224);if(!d){return 0}v[23048]=0;a=ba(1896,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function OV(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=tn(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Dk(a);a=v[b>>2]+2|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}$c(b);gb=c+16|0}function IG(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Ik(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Qo(a);a=v[b>>2]+4|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}$c(b);gb=c+16|0}function zba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4296);if(!d){return 0}v[23048]=0;a=ba(1810,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function rba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4228);if(!d){return 0}v[23048]=0;a=ba(1823,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4236);if(!d){return 0}v[23048]=0;a=ba(1675,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4268);if(!d){return 0}v[23048]=0;a=ba(1544,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function iba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(5048);if(!d){return 0}v[23048]=0;a=ba(1846,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function eca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4296);if(!d){return 0}v[23048]=0;a=ba(1706,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function cx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=ni(e+8|0,e+12|0);v[23048]=0;a=gl(a,b,c);b=v[23048];v[23048]=0;if((b|0)!=1){jf(d);gb=e+16|0;return a}a=P()|0;O()|0;jf(d);R(a|0);L()}function _aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4276);if(!d){return 0}v[23048]=0;a=ba(1873,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function YS(a){var b=0,c=0;a:{b:{b=a&240;if((b|0)!=192){if((b|0)==240){break b}c=3;if((b|0)!=208){break a}}c=2;break a}c=1;a=a+15&255;if(a>>>0>2){break a}return 131842>>>(a<<3)&255}return c}function Vba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4280);if(!d){return 0}v[23048]=0;a=ba(1739,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function TM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[23048]=0;c=c-2048|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Rca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4304);if(!d){return 0}v[23048]=0;a=ba(1607,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function Oy(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){b=Lq(d)^b;if(a>>>0<=16){a=a+15|0;b=b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function Nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4276);if(!d){return 0}v[23048]=0;a=ba(1763,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function Gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ng(4268);if(!d){return 0}v[23048]=0;a=ba(1786,d|0,a|0,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);R(a|0);L()}function BR(a,b){var c=0,d=0;c=v[a+24>>2];v[23048]=0;c=oe(c+484344|0,b);d=v[23048];v[23048]=0;if((d|0)!=1){if(c){a=v[Yb(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}V(0)|0;O()|0;Ab();L()}function $Q(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-7|0,7)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}zc(a,c);zc(a+4|0,b+8|0);zc(wb(a),bc(b));v[b>>2]=v[b+4>>2]}function sea(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;a:{if(!Qj(a,b+8|0)){break a}c=0;if(!XN(b+8|0)){break a}c=b;a=AT(a,b);if(!a){Bk(c)}c=-1;if(!a){break a}c=WN(b)}gb=b+16|0;return c|0}function sG(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function qX(a){var b=0,c=0;a:{if(zd(a,17587,11)){break a}b=a+215|0;a=a+63|0;while(1){if(w[a+16|0]>3|w[a+17|0]>3|w[a+18|0]>=16){break a}a=a+19|0;if((b|0)!=(a|0)){continue}break}c=1}return c}function fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((xb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4228|0,c,xb(b));Lt(a)}}function dp(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Nb(a,4);a:{if(d){ii(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}xW(b)}gb=c+32|0;return d|0}function ak(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;v[d+8>>2]=v[b+8>>2];e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=v[d+4>>2];v[a>>2]=v[d>>2];v[a+4>>2]=b;v[a+8>>2]=v[d+8>>2];v[a+12>>2]=c;gb=d+16|0}function Zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((xb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4260|0,c,xb(b));Tt(a)}}function Yca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=gb-16|0;gb=d;e=d,f=C(C(kb[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;le(d+12|0,C(0));kb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);gb=d+16|0}function Rr(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Nb(b,2)){rn(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;WD(a,c+16|0)}gb=c+32|0}function KH(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function ox(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function mG(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[23048]=0;c=c-16|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function e1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Bs()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function c1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[As()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function ZX(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[23048]=0;c=c-48|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Tea(){var a=0;a:{b:{if(t[92228]&1){break b}if(!Ud(92228)){break b}v[23048]=0;X(103);a=v[23048];v[23048]=0;if((a|0)==1){break a}Td(92228)}return}a=P()|0;O()|0;af(92228);R(a|0);L()}function Ii(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[23048]=0;v[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function Hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;OT(b,c);if(Nb(a,c<<8)){cc(d+24|0,v[b>>2],Wg(b)<<8);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;gd(d+16|0,a,d+8|0)}gb=d+32|0}function eG(a){var b=0;a:{b:{a=v[a>>2];if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a|0)!=(a&-256)}return b}function av(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[23048]=0;gf(a+8|0,b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function _W(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[23048]=0;c=c-1|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function VN(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[23048]=0;c=c-4|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function VE(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[23048]=0;c=c-2|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function LW(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[23048]=0;c=c-6|0;d=v[23048];v[23048]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Bi(a){var b=0;a=Fe(a);b=2147483647;a:{if(!(a<C(2147483648))){break a}b=-2147483648;if(!(a>C(-2147483648))){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function Bg(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[23048]=0;rf(a+8|0,b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function zaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=EL(f,b,c,d,0,0,0,0,e);gb=f+16|0;return a|0}function vm(a,b){var c=0,d=C(0),e=0;e=u[a+28>>1];c=a+4|0;Lb(c);d=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Lb(c)<<16)-65536>>16<(b|0)){break a}d=z[Mb(c,b-u[a+28>>1]|0)>>2]}return d}function hj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function b4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=kt(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;hc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function ZS(a){var b=0,c=0;c=v[a+4>>2];a:{while(1){b=v[a+8>>2];if((b|0)==(c|0)){break a}v[a+8>>2]=b-4;v[23048]=0;b=v[23048];v[23048]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}}function Uy(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-4;v[23048]=0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}}function TT(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-12|0;v[b+8>>2]=c;VT(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){Vu(b,_p(a))}}function TE(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-2;v[23048]=0;c=v[23048];v[23048]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}}function Ql(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-28|0;v[b+8>>2]=c;ae(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){hD(b,vY(a))}}function xi(a){var b=0,c=0,d=0,e=0;d=Hd(a);b=d&63;a:{if(!(d&64)){break a}c=6;while(1){e=Hd(a);b=(e&127)<<c|b;if(c>>>0>24){break a}c=c+7|0;if(e&128){continue}break}}return d&128?0-b|0:b}function te(a,b){var c=0;a:{c=Lf(b);if((c|0)==(Bb(a)|0)){v[23048]=0;a=ga(592,a|0,0,-1,b|0,c|0)|0;b=v[23048];v[23048]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Ab();L()}function OL(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=Oe(31415.926535897932/+b);d=Ko((32768-(K((1-c)*+C(a+a)+(c*c-1)*+C(a*a))+c*e)*32768)/(1-e))}return d}function Joa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;sk(b,c);c=Nb(a,c);if(c){qD(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;gd(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function fR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}Sc(a,8,1,0,11);return}d=a;a=b+31|0;Sc(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function aR(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=gb-16|0;gb=b;xL(b,c,10);v[23048]=0;T(13,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break a}a=P()|0;O()|0;vb(b);R(a|0);L()}}function Px(a,b,c,d,e){var f=0;f=Qx(a,b,c,d);if(Nd(e,d)){mc(d,e);if(!Nd(d,c)){return f+1|0}mc(c,d);if(!Nd(c,b)){return f+2|0}mc(b,c);if(!Nd(b,a)){return f+3|0}mc(a,b);f=f+4|0}return f}function Jx(a,b,c,d,e,f,g,h,i){var j=0;j=gb-16|0;gb=j;qg(j,b,c,d,e,f,g,h,i^-2147483648);b=v[j+4>>2];v[a>>2]=v[j>>2];v[a+4>>2]=b;b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;gb=j+16|0}function wN(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[23048]=0;v[b+8>>2]=32767;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Ab();L()}function Y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Bs()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(CV()>>>0<b>>>0){Mc();L()}c=b;if(c>>>0>=178956971){xc(24319);L()}c=jc(B(c,24),4);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=c+B(b,24)|0,v[d>>2]=e}function W0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[As()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Fv(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[23048]=0;v[b+8>>2]=65535;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return x[a>>1]}V(0)|0;O()|0;Ab();L()}function $Z(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a=xn(c+8|0,a);v[23048]=0;a=W(325,a|0,b|0,16132)|0;b=v[23048];v[23048]=0;if((b|0)!=1){gb=c+32|0;return a|0}a=P()|0;O()|0;R(a|0);L()}function yv(a){var b=0,c=0;b=gb-16|0;gb=b;u[b+14>>1]=a;v[23048]=0;u[b+12>>1]=255;a=Vc(b+14|0,b+12|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Ab();L()}function rC(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=CW(a);if(d>>>0<=b>>>0){a=Kj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function qh(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=FW(a);if(d>>>0<=b>>>0){a=jg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function md(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);gb=d+16|0}function hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=kb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Gb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function g0(){var a=0;a:{if(t[466856]&1){break a}if(!Ud(466856)){break a}a=466832;while(1){a=Jb(a)+12|0;if((a|0)!=466856){continue}break}Td(466856)}Zc(466832,89960);Zc(466844,89963)}function d0(){var a=0;a:{if(t[466888]&1){break a}if(!Ud(466888)){break a}a=466864;while(1){a=Jb(a)+12|0;if((a|0)!=466888){continue}break}Td(466888)}od(466864,89968);od(466876,89980)}function bx(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=OG(a);if(d>>>0<=b>>>0){a=pg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function Tg(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=Ut(a);if(d>>>0<=b>>>0){a=Ce(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function Jk(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=UE(a);if(d>>>0<=b>>>0){a=Gg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function JL(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=IL(f,b,c,d,e,0,0,0,0);gb=f+16|0;return+c}function DX(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=SD(a);if(d>>>0<=b>>>0){a=Vl(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function fr(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=xT();if(d>>>0<=b>>>0){a=nh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function cv(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=hs();if(d>>>0<=b>>>0){a=mg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function bE(a,b){var c=0;c=gb-16|0;gb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[23048]=0;rf(a+8|0,c+12|0,b);b=v[23048];v[23048]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function ZO(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;XO(c,b+80|0);v[23048]=0;T(13,a|0,0,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);R(a|0);L()}function WN(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function QO(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function O6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){v[d>>2]=v[a>>2];cg(d+4|0,a+4|0);d=v[c>>2]+16|0;v[c>>2]=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}}function Mw(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=lG();if(d>>>0<=b>>>0){a=hi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function Jna(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;YW(b,c,32);XW(a,c);gb=c+32|0}function Jl(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=an();if(d>>>0<=b>>>0){a=Ce(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function GN(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=CN();if(d>>>0<=b>>>0){a=hk(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Mc();L()}function Fs(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=Bb(b);if(d>>>0<c>>>0){Sn();L()}b=Ob(b);v[e+4>>2]=d-c;Sp(a,b+c|0,v[Gb(e+12|0,e+4|0)>>2]);gb=e+16|0}function Bn(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=gb-16|0;gb=b;Ey(b,c);v[23048]=0;T(13,a|0,0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(b);gb=b+16|0;break a}a=P()|0;O()|0;vb(b);R(a|0);L()}}function BG(a,b,c,d){var e=0,f=0,g=0,h=0;f=v[a+4>>2];a=v[a>>2];g=a;h=b;e=0;a:{if(!c){break a}b=f>>8;e=b;if(!(f&1)){break a}e=v[b+v[c>>2]>>2]}kb[v[v[a>>2]+28>>2]](g,h,e+c|0,f&2?d:2)}function yt(a){a=a|0;var b=0,c=0,d=0;c=gb-16|0;gb=c;b=Fq(c,a);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){a=a+1|0;if((d|0)!=(a|0)){continue}break}v[b+4>>2]=d}_b(b);gb=c+16|0}function xS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=di(e,a,d);a=wb(a);v[23048]=0;mS(a,b,c,d+4|0);a=v[23048];v[23048]=0;if((a|0)!=1){_b(d);gb=e+16|0;return}a=P()|0;O()|0;_b(d);R(a|0);L()}function _o(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[23048]=0;v[b+8>>2]=255;a=Gb(b+12|0,b+8|0);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Ab();L()}function ZG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=84368;b=a+16|0;if(Lb(b)){while(1){d=v[Mb(b,c)>>2];if(d){yn(d)}c=c+1|0;if(Lb(b)>>>0>c>>>0){continue}break}}vb(a+176|0);fx(b);return a|0}function Yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(an()>>>0<b>>>0){Mc();L()}c=b;if(c>>>0>=1073741824){xc(24319);L()}c=jc(c<<2,1);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=c+(b<<2)|0,v[d>>2]=e}function Gy(a){a=a|0;var b=0;a:{if(!a){a=aa(8)|0;v[23048]=0;U(1956,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);R(b|0);L()}return}ja(a|0,55668,1945);L()}function CL(a){a=a|0;var b=0;a:{if(!a){a=aa(8)|0;v[23048]=0;U(1944,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);R(b|0);L()}return}ja(a|0,55612,1945);L()}function Ab(){var a=0;v[23048]=0;a=v[23048];v[23048]=0;a:{if((a|0)!=1){a=v[116852];if(!a){break a}if(!GG(a+48|0)){break a}FG(v[a+12>>2]);L()}V(0)|0;O()|0;Ab();L()}FG(v[23043]);L()}function zJ(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=z[c>>2];g=z[e>>2];z[e>>2]=f+g;z[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}function s_(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;Kp(a);v[a>>2]=15692;v[23048]=0;vF(a+12|0,b+8|0,b);c=v[23048];v[23048]=0;if((c|0)!=1){gb=b+16|0;return a|0}a=P()|0;O()|0;R(a|0);L()}function mt(a){var b=0;a:{b:{b=a;if((Pe(b)|0)!=79){break b}if((Pe(b)|0)!=103){break b}if((Pe(b)|0)!=103){break b}b=(Pe(b)|0)==83;break a}b=0}if(!b){ec(a,30);return 0}return oJ(a)}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(hs()>>>0<b>>>0){Mc();L()}c=b;if(c>>>0>=536870912){xc(30724);L()}c=jc(c<<3,8);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=c+(b<<3)|0,v[d>>2]=e}function az(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Er(e,a,d);wb(a);a=c-b|0;if((a|0)>=1){hc(v[d+4>>2],b,a);v[d+4>>2]=v[d+4>>2]+B((a>>>0)/6|0,6)}_b(d);gb=e+16|0}function NU(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>32){break a}return w[a+4|0]>95}return 0}function N2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;a=Wj(a,b,c,d,e,f,g+8|0,g+16|0);gb=g+16|0;return a|0}function LS(a,b){var c=0;c=w[a+802|0];a:{if(c){break a}c=Ki(w[a+799|0]-u[a+772>>1]|0);if(!b|(!v[a+656>>2]|!c|c>>>0>=129)){break a}c=w[lc(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function GL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wf(12);c=v[c>>2];b=v[b>>2];v[23048]=0;b=FL(d,b,c);c=v[23048];v[23048]=0;if((c|0)!=1){Ai(a,b);return}a=P()|0;O()|0;Zb(d);R(a|0);L()}function E_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(hs()>>>0<b>>>0){Mc();L()}c=b;if(c>>>0>=536870912){xc(15392);L()}c=jc(c<<3,1);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=c+(b<<3)|0,v[d>>2]=e}function $i(a,b){var c=0,d=0;c=gb-16|0;gb=c;if($e(a)){Ph(a,v[a>>2],Sk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Gf(b,0);v[c+12>>2]=0;je(b,c+12|0);gb=c+16|0}function uk(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;Zi(c,a,c+12|0,4);a=xb(c);v[c>>2]=v[c+12>>2];v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);gb=c+16|0;return(a|0)==4}function o4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;kb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=d+8|0;if(Ke(v[a+4>>2],v[c+4>>2])){a=v[a>>2]==v[c>>2]}else{a=0}gb=d+16|0;return a|0}function n2(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;dk(b,0,a);v[23048]=0;a=U(193,b|0)|0;c=v[23048];v[23048]=0;if((c|0)!=1){vb(b);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(b);R(a|0);L()}function Ow(a,b){var c=0,d=0;c=gb-16|0;gb=c;u[b>>1]=0;t[c+15|0]=0;Dh(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;Dh(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}gb=c+16|0}function Eb(a,b){var c=0,d=0;c=gb-16|0;gb=c;if($e(a)){Rk(a,v[a>>2],Sk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Gf(b,0);t[c+15|0]=0;Qd(b,c+15|0);gb=c+16|0}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;DB(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Gb(d+8|0,d+12|0)>>2]}gb=d+16|0;return c|0}function Gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Lb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=vN(a,b,c,d+8|0);gb=d+16|0;return a|0}function FN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!oe(a,b)){break a}c=Zy(a,v[ef(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=ef(a,b);NN(ef(a,c),b);d=c}return d|0}function nR(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;if(c){a=wb(a);while(1){f=yl(a,c+16|0,b);d=f?d:c;c=v[(f?4:0)+c>>2];if(c){continue}break}}a=v[Cc(e+8|0,d)>>2];gb=e+16|0;return a}function gi(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=Bd(b),v[d+12>>2]=e;v[23048]=0;gf(a,c+12|0,b);b=v[23048];v[23048]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function Vaa(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=Ao(C(C(C(yf(v[a+16>>2])>>>0)*C(20938023226335645e-21))+C(-.005025125574320555)),C(0),C(1)),z[b+4272>>2]=c;XL(a);WL(a)}function ZA(a,b,c,d,e){var f=0;a:{if(!d){break a}f=1;while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;if((d|0)==(f|0)){break a}c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;continue}}}function Xp(a){var b=0,c=0;b=v[23044];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(Rw()>>>0<a>>>0){if(!(va(a|0)|0)){break a}}v[23044]=a;return b}v[115529]=48;return-1}function O4(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;OH(a,c,78408);v[a>>2]=78380;gb=c+16|0;return a|0}function Ht(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-16|0;Ll(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;oK(v[a>>2],hi(a))}}function BU(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-56|0;Yu(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;IB(v[a>>2],yU(a))}}function yX(a){a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(zd(a+44|0,17568,3)){break a}a=a+47|0;return(w[a|0]|w[a+1|0]<<8)>>>0>97}return 0}function Tv(a,b,c){var d=0;a:{d=gb-16|0;gb=d;_K(d,b,c);v[23048]=0;T(13,a|0,0,d|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(d);gb=d+16|0;break a}a=P()|0;O()|0;vb(d);R(a|0);L()}}function Js(a,b,c){var d=0;a:{d=gb-16|0;gb=d;Ay(d,b,c);v[23048]=0;T(13,a|0,0,d|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(d);gb=d+16|0;break a}a=P()|0;O()|0;vb(d);R(a|0);L()}}function Iw(a,b,c){var d=0;a:{d=gb-16|0;gb=d;XK(d,b,c);v[23048]=0;T(13,a|0,0,d|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(d);gb=d+16|0;break a}a=P()|0;O()|0;vb(d);R(a|0);L()}}function Fma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+8>>2]=b;d=c,e=Rb(a),v[d>>2]=e;b=lv(c+8|0,c);b=v[a>>2]+(b<<2)|0;Ui(a,vg(b+4|0,v[a+4>>2],b));Uh(b);gb=c+16|0}
function zla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Nb(a,32)){NB(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}aV(b)}gb=c+32|0}function yr(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){tm(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ig(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;tm(a,c)}function xr(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){tm(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ig(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;tm(a,c)}function ip(a,b){var c=0,d=0,e=0;xv(a);gp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;return a}function fJ(a){var b=0,c=0,d=0;a:{if(!Lh(t[v[a>>2]])){break a}while(1){c=v[a>>2];d=t[c|0];v[a>>2]=c+1;b=(b+d|0)-48|0;if(!Lh(t[c+1|0])){break a}b=B(b,10);continue}}return b}function wA(a,b){var c=0;c=gb-16|0;gb=c;Mh(c+8|0,b);v[23048]=0;a=fB(a,c+8|0);b=v[23048];v[23048]=0;a:{if((b|0)!=1){gb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}return a>>>31|0}function oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=kb[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Zp(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=Fpa(a,0,b,0);e=jb;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=Ad(b);if(!(!a|!(w[a-4|0]&3))){Pb(a,0,b)}return a}function Vga(a,b){a=a|0;b=b|0;var c=0;c=dd(a);t[a+16|0]=0;v[a+12>>2]=b;v[23048]=0;_(1114,a|0);b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Eu(c);R(a|0);L()}function bv(a){var b=0,c=0,d=0;d=a+32|0;a:{while(1){c=w[a|0];if(!((c-1&255)>>>0<=30|((b^1)&1?0:c))){b=!c|b;a=a+1|0;if((d|0)!=(a|0)){continue}break a}break}b=0}return b&1}function Tl(a,b,c){var d=0;d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a>>2]=d;v[a+4>>2]=b;Lk(a+8|0,c);return a}function DT(a){var b=0;if(v[a>>2]){Rd(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/880|0;v[23048]=0;Oc(b,B(a,880),8);a=v[23048];v[23048]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function $0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function nW(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-33>>>0)/33^-1,33)+c}b=v[a>>2];if(b){mW(b,(v[bc(a)>>2]-v[a>>2]|0)/33|0)}}function lA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[b+56>>2]=0;d=b,e=Cm(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(v[a+480180>>2]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function KO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];hA(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}gb=d+16|0}function AJ(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}
function T0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=t[b|0];t[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function PZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;gf(a+8|0,d+12|0,d+8|0);if(b){Vr(a,b);NE(a,b,w[c|0])}gb=d+16|0;return a|0}function M4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=bq(d,a);YG(a,c);v[23048]=0;S(2229,b|0,1);a=v[23048];v[23048]=0;if((a|0)==1){a=P()|0;O()|0;Xb(d);R(a|0);L()}}function Dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=Ii(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Gm(c+12|0,c+8|0,46024)>>2],v[d+36>>2]=e;sq(a);gb=c+16|0}function AK(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((Gi(Qb(v[a>>2]+484360|0))|0)<=(b|0)){break a}c=x[sc(Qb(v[a>>2]+484360|0),b)>>1]}return c|0}function zd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function tL(a,b){var c=0;c=gb-16|0;gb=c;zL(c,b,10);v[23048]=0;T(13,a|0,0,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);R(a|0);L()}function qj(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function qL(a,b){var c=0;c=gb-16|0;gb=c;yL(c,b,10);v[23048]=0;T(13,a|0,0,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);R(a|0);L()}function Laa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}ML(a,i,h,g,e,f,b,c,d)}function wf(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Ad(a);if(!b){b=v[116854];if(!b){break a}kb[b|0]();continue}break}return b|0}a=aa(4)|0;cm(a);ja(a|0,90496,1937);L()}function dZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Ig(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=tD(a,b,v[Gb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function c_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Gb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=nc(a+8|0);v[23048]=0;T(404,a|0,b|0,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;gc(d);R(a|0);L()}}function Vk(a,b,c){var d=0;d=gb-16|0;gb=d;Wk(d+8|0,a+24|0,b);a=v[d+12>>2];a:{if(c){b=v[d+8>>2];v[b>>2]=a|v[b>>2];break a}b=v[d+8>>2];v[b>>2]=v[b>>2]&(a^-1)}gb=d+16|0}function PT(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1299020115){a=a+4|0;a=(Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)==1}else{a=0}return a}function Ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;DB(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ID(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Ig(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=vD(a,b,v[Gb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function BB(a){var b=0;if(v[a>>2]){Rd(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/9|0;v[23048]=0;Oc(b,B(a,9),1);a=v[23048];v[23048]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function w_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Gb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function pX(a){var b=0,c=0;c=Fpa(w[a+217|0],0,9,0);b=w[a+216|0];a=b>>>31|0;b=b<<1;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;if(b>>>0<11){a=a+1|0}jb=a;return b}function fC(a,b){var c=0;a:{if(b){fC(a,v[b>>2]);fC(a,v[b+4>>2]);a=dc(a);v[23048]=0;c=v[23048];v[23048]=0;if((c|0)==1){break a}Op(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function bfa(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[23048]=0;a=Q(1331,a|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;R(a|0);L()}function _Q(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-7>>>0)/7^-1,7)+c}b=v[a>>2];if(b){TQ(b,(v[bc(a)>>2]-v[a>>2]|0)/7|0)}}function VS(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function M5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=dt(Pa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);gb=e+16|0;jb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function HU(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function Ge(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[dc(a)>>2];v[23048]=0;_(a|0,c|0);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Bx(a,b){var c=0;c=rt(a+4|0);v[a>>2]=78212;v[c>>2]=78232;v[23048]=0;S(2299,c|0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){return}a=P()|0;O()|0;gh(c);R(a|0);L()}function Ax(a,b){var c=0;c=YH(a+4|0);v[a>>2]=78260;v[c>>2]=78280;v[23048]=0;S(2300,c|0,b|0);a=v[23048];v[23048]=0;if((a|0)!=1){return}a=P()|0;O()|0;gh(c);R(a|0);L()}function wt(a,b,c,d){var e=0;a:{if(d==C(1)){break a}c=B(b,c);if(!c){break a}e=+d;b=1;while(1){A[a>>3]=A[a>>3]*e;if((b|0)==(c|0)){break a}a=a+8|0;b=b+1|0;continue}}}function vI(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=ah(b),d=v[v[a>>2]+52>>2],kb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return ah(b)}function so(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(!(v[a+480208>>2]&16)){break a}Db(b+8|0,a+1074308|0,7);if(!Cb(b+8|0)){break a}c=v[a+480180>>2]!=4}gb=b+16|0;return c}function qm(a){a=a>>>1&1431655765|a<<1&-1431655766;a=a>>>2&858993459|a<<2&-858993460;a=a>>>4&252645135|a<<4&-252645136;return Jpa(a>>>8&16711935|a<<8&-16711936,16)}function BK(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=9){if((wy(d)|0)>(e|0)){break b}}g=a,h=uy(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function uB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;IR(a+112|0,48e3);v[a+668>>2]=0;tB(a+724|0);tB(a+732|0);tB(a+740|0);Pi(a+790|0);return a}function rfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=wf(2500);v[23048]=0;b=Q(97,c|0,b|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){Ai(a,b);return}a=P()|0;O()|0;Zb(c);R(a|0);L()}function pt(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Pb(a+32|0,0,40);ex(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function Vb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Nb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function Gga(a,b){a=a|0;b=b|0;var c=0;c=lh(a);t[a+530|0]=0;v[23048]=0;S(1130,a|0,b|0);b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Dm(c);R(a|0);L()}function GB(a,b){var c=0,d=0,e=0;wb(b);c=Jg(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[wb(b)>>2];d=wb(c),e=a,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function FS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=lp(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function u$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=v[c>>2];a=kb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}gb=d+16|0;return a|0}function oE(a){var b=0,c=0;a:{if(zd(a,16605,3)){break a}b=a+3|0;if(w[b|0]<8|w[b|0]>14){break a}a=a+40|0;if(w[b|0]>9?!(w[a|0]<33?w[a|0]:0):0){break a}c=1}return c}function dr(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function rla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-80|0;gb=d;c=-1;a:{if(!lY(a,d+8|0)){break a}c=0;if(!YU(d+8|0)){break a}c=Qe(a,b,XU(d+8|0),jb)}gb=d+80|0;return c|0}function S1(){var a=0,b=0;a:{Zd(466944);v[116736]=84440;v[23048]=0;a=fa(2371)|0;b=v[23048];v[23048]=0;if((b|0)!=1){v[116738]=a;break a}a=P()|0;O()|0;R(a|0);L()}}function Dh(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+31|0]=0;Zi(c+16|0,a,c+31|0,1);a=xb(c+16|0);t[c+8|0]=w[c+31|0];t[b|0]=w[c+8|0];gb=c+32|0;return(a|0)==1|0}function sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=nc(a);v[23048]=0;T(96,a|0,b|0,c|0);b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Qc(d);R(a|0);L()}function sT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-256>>>8^-1)<<8)+c}b=v[a>>2];if(b){pB(b,v[bc(a)>>2]-v[a>>2]>>8)}}function oV(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878){return(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165}return 0}function g4(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){PH();c=92168;break a}b:{if(t[465316]&1){break b}if(!Ud(465316)){break b}Td(465316)}c=92164}_c(a,b,c)}function JM(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Gb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])*C(-.007874015718698502))+C(1);gb=c+16|0}function Fj(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!ig(a)){while(1){a=v[a+8>>2];if(!ig(a)){continue}break}}a=v[a+8>>2];break a}a=PV(b)}v[c>>2]=a}function De(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function uy(a,b){var c=0,d=0;a:{if(a>>>0<=99999999){a=Nx(b,a);break a}c=(a>>>0)/1e8|0;d=a-B(c,1e8)|0;a=(d>>>0)/1e4|0;a=gj(gj(VI(b,c),a),d-B(a,1e4)|0)}return a}function rL(a){a=a|0;var b=0,c=0,d=0;b=wf(1300472);v[23048]=0;c=U(2054,b|0)|0;d=v[23048];v[23048]=0;if((d|0)!=1){Ai(a,c);return}a=P()|0;O()|0;Zb(b);R(a|0);L()}function ns(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[23048]=0;gf(a,c+12|0,c+8|0);b=v[23048];v[23048]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function lK(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function kF(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=zb((kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0);a=v[b>>2];_d(c,d,(kb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function c4(a,b){a=a|0;b=b|0;go(a);v[a>>2]=90536;b=Ob(b);v[23048]=0;Q(2341,a+4|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;R(a|0);L()}function Hpa(a,b,c){var d=0,e=0;d=b>>31;e=a^d;a=b>>31;Dpa(e-d|0,(b^a)-((d>>>0>e>>>0)+a|0)|0,c,0);jb=ib;b=d^hb;c=b-d|0;jb=(a^jb)-((b>>>0<d>>>0)+a|0)|0;return c}function zB(a,b){var c=0,d=0,e=0,f=0;d=Jg(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);e=wb(d),f=v[c>>2],v[e>>2]=f;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function WL(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function Uca(a,b){a=a|0;b=b|0;var c=0;SM(a);c=b+4|0;Ym(wb(a),v[a>>2],v[a+4>>2],c);mc(a,c);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];Pf(a);nl(a);nl(a)}function Es(a){a=a|0;var b=0;b=aa(8)|0;v[23048]=0;Q(1990,b|0,a|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){ja(b|0,90844,259);L()}a=P()|0;O()|0;ca(b|0);R(a|0);L()}function BV(a,b){var c=0;c=gb-32|0;gb=c;a:{if(Qf(a,4)){ii(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;RB(c+16|0,a,c+8|0);break a}xW(b)}gb=c+32|0}function xd(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(!b){break a}if(!Nb(a,b)){break a}t[c+15|0]=0;Ig(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}gb=c+16|0;return d}function x6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){Fo(d,a);d=v[c>>2]+12|0;v[c>>2]=d;a=a+12|0;if((b|0)!=(a|0)){continue}break}}}function ms(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[23048]=0;Lp(a,d+12|0,c);b=v[23048];v[23048]=0;if((b|0)!=1){gb=d+16|0;return a}V(0)|0;O()|0;Ab();L()}function GE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(!b){break a}if(!Nb(a,b)){break a}t[c+15|0]=0;Ig(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}gb=c+16|0;return d}function F2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return Vj(g,b,c,d,e,f,Ob(a),Ob(a)+(Bb(a)<<2)|0)|0}function m7(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=cg(a,b);v[23048]=0;Q(119,a+12|0,c|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);R(a|0);L()}}function Zl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[$b(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;gb=d+16|0}function Yl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[$b(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;gb=d+16|0}function zK(a,b){a=a|0;b=b|0;var c=0;a:{if(!Bt(b)){break a}a=a+24|0;if(!oe(v[a>>2]+484344|0,b&65535)){break a}c=v[Yb(v[a>>2]+484344|0,b)+12>>2]}return c|0}function vj(a){var b=0;a=Fe(a);b=-1;a:{if(!(a<C(4294967296))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function li(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function kA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=Cm(a,x[b+70>>1],v[b+48>>2],c,0)}return d|0}function d_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Waa(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){le(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];XL(a)}gb=d+16|0}function Rba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=5){le(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];qM(a)}gb=d+16|0}function Paa(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=3){le(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];VL(a)}gb=d+16|0}function Oz(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;v[23048]=0;gf(a,b+12|0,b+8|0);a=v[23048];v[23048]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function Jba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){le(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];kM(a)}gb=d+16|0}function HT(a){var b=0;a=fe(a);b=32767;a:{if(!(a<32767)){break a}b=-32768;if(!(a>-32768)){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b}function ES(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}QW(v[dc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function zna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Nb(a,b)){break a}if(b>>>0<=1){c=DE(a,1);break a}c=Fg(a);Vb(a,b-2|0)}u[d>>1]=c}function xk(a,b,c,d){var e=0,f=0;e=B(b,c);f=e;a:{if(v[d+76>>2]<=-1){a=UC(a,e,d);break a}a=UC(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function x_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function s5(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];if(c){while(1){c=c-1|0;d=c<<2;kb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);if(c){continue}break}}}function gy(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(C(z[((c&3)<<2)+62768>>2]*a)*C(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function eg(a,b,c){a:{switch(b-1|0){case 0:if(c){return sj(a,1)}return sj(a,0);case 1:if(c){return sj(a,3)}return sj(a,2);default:break a}}return sj(a,4)}function KX(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;wp(b+8|0,a);a=w[lc(b+8|0,0)|0];c=w[lc(b+8|0,1)|0];d=lc(b+8|0,2);gb=b+16|0;return c<<9|a<<1|w[d|0]<<17}function Cna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Nb(a,b)){break a}if(b>>>0<=3){c=EE(a,b);break a}c=_f(a);Vb(a,b-4|0)}v[d>>2]=c}function rv(a){var b=0;b=gb-16|0;gb=b;_c(b+8|0,a,0);v[23048]=0;yp(b+8|0,112,0);a=v[23048];v[23048]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function jJ(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];h=g+(c<<2)|0;a:{if(!w[a+23|0]){break a}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;b=c;h=f+g|0}v[h>>2]=b}function Yn(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Ad(b)}return c}function G4(a,b){a=a|0;b=b|0;var c=0,d=0;b=zx(b);v[a+36>>2]=b;c=a,d=ro(b),v[c+44>>2]=d;c=a,d=On(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Es(79188);L()}}function C4(a,b){a=a|0;b=b|0;var c=0,d=0;b=yx(b);v[a+36>>2]=b;c=a,d=ro(b),v[c+44>>2]=d;c=a,d=On(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Es(79188);L()}}function Bc(a){var b=0;a=v[a+4>>2];if(a){if(yn(a)){a:{b=a+8|0;if(!v[b>>2]){kb[v[v[a>>2]+16>>2]](a);break a}if((Aw(b)|0)==-1){kb[v[v[a>>2]+16>>2]](a)}}}}}function UR(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function Rc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(kb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function M2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return Wj(g,b,c,d,e,f,Ob(a),Ob(a)+Bb(a)|0)|0}function J0(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[23048]=0;a=U(2473,a|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Ab();L()}function vE(a,b){a=a|0;b=b|0;var c=0;$r(a);c=b+4|0;Ym(wb(a),v[a>>2],v[a+4>>2],c);mc(a,c);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];nw(a,uc(a))}function v3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=d;b=ni(c,c+12|0);a=JH(a,84097,v[c+8>>2]);jf(b);gb=c+16|0;return a|0}function tq(a,b){a=a|0;b=b|0;var c=0;ik(a);c=b+4|0;Ym(wb(a),v[a>>2],v[a+4>>2],c);mc(a,c);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];ol(a,Lb(a))}function tk(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=a;d=v[v[a>>2]>>2];if(d){v[b>>2]=d}QW(v[dc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function ZC(a,b){a=a|0;b=b|0;var c=0;TC(a);c=b+4|0;Ym(wb(a),v[a>>2],v[a+4>>2],c);mc(a,c);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];BC(a,qc(a))}function Td(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;a=Yw(b,a);c=gb-16|0;gb=c;d=v[Cc(c+8|0,v[a+4>>2])>>2],e=1,t[d|0]=e;t[v[a+8>>2]]=1;gb=c+16|0;gb=b+16|0}function LH(a,b){a=a|0;b=b|0;go(a);v[a>>2]=90536;v[23048]=0;Q(2341,a+4|0,b|0)|0;b=v[23048];v[23048]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;R(a|0);L()}function vt(a){var b=0,c=0,d=0;b=v[a+4>>2];c=((b<<2)+(fK(v[a>>2],1)^270549120)|0)+2019860093|0;v[a>>2]=c;d=a;a=B(fK(c,16),5)+b|0;v[d+4>>2]=a;return a}function sZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(SD(a)>>>0<b>>>0){Mc();L()}wb(a);c=OD(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,20)+c|0,v[d>>2]=e;RD(a,0)}function rpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(CE(a,d+8|0)){v[d+4>>2]=w[d+8|0];BY(a,b,v[Gb(d+4|0,d+12|0)>>2])}gb=d+16|0}function d4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Lf(b);d=wf(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=hc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function _6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Pb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Y6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Pb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Nj(a,b){var c=0;c=v[v[b>>2]-12>>2];v[23048]=0;b=v[(b+c|0)+24>>2];c=v[23048];v[23048]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Ab();L()}function Cn(a){var b=0;b=aa(8)|0;v[23048]=0;Q(203,b|0,a|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){ja(b|0,90776,24);L()}a=P()|0;O()|0;ca(b|0);R(a|0);L()}function C7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(OG(a)>>>0<b>>>0){Mc();L()}wb(a);c=QQ(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,12)+c|0,v[d>>2]=e;$w(a,0)}function Bla(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=_f(b);_f(b);break a}a=Fg(b);Fg(b)}if(a){while(1){if(a&1){Vb(b,260)}a=a>>>1|0;if(a){continue}break}}}function zka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!OU(a,d)){break a}c=0;if(!mU(d)){break a}c=Qe(a,b,kU(d),jb)}gb=d+96|0;return c|0}function xc(a){var b=0;b=aa(8)|0;v[23048]=0;Q(23,b|0,a|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){ja(b|0,90724,24);L()}a=P()|0;O()|0;ca(b|0);R(a|0);L()}function x1(){var a=0;a:{Zd(467168);v[23048]=0;U(2457,467176)|0;a=v[23048];v[23048]=0;if((a|0)!=1){v[116792]=87244;break a}a=P()|0;O()|0;R(a|0);L()}}function v1(){var a=0;a:{Zd(467184);v[23048]=0;U(2457,467192)|0;a=v[23048];v[23048]=0;if((a|0)!=1){v[116796]=87400;break a}a=P()|0;O()|0;R(a|0);L()}}function tja(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!gU(a,d)){break a}c=0;if(!nT(d)){break a}c=Qe(a,b,mT(d),jb)}gb=d+48|0;return c|0}function rka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!gU(a,d)){break a}c=0;if(!fU(d)){break a}c=Qe(a,b,eU(d),jb)}gb=d+48|0;return c|0}function fE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ut(a)>>>0<b>>>0){Mc();L()}wb(a);c=dN(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e;ol(a,0)}function cZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Ig(a,d+8|0)){v[d+4>>2]=w[d+8|0];sD(a,b,v[Gb(d+4|0,d+12|0)>>2])}gb=d+16|0}function bf(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if($e(a)){c=v[a>>2];t[b+15|0]=0;Qd(c,b+15|0);Ae(a,0);break a}t[b+14|0]=0;Qd(a,b+14|0);Gf(a,0)}gb=b+16|0}function aA(a){var b=0;a=Fe(a);b=255;a:{if(!(a<C(255))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function ZB(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;a=a+22|0;return c+(Ib(w[b|0]|w[b+1|0]<<8)>>>0>Ib(w[a|0]|w[a+1|0]<<8)<<1>>>0)|0}function WW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(CW(a)>>>0<b>>>0){Mc();L()}wb(a);c=BW(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,6)+c|0,v[d>>2]=e;tC(a,0)}function WO(a){if(w[a+480224|0]==2){return+y[a+1074412>>2]*1e-4}return+y[a+24620>>2]*60/(+y[a+1074396>>2]*+(B(v[a+1074400>>2],v[a+1074408>>2])>>>0))}function OB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(UE(a)>>>0<b>>>0){Mc();L()}c=tE(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<1)+c|0,v[d>>2]=e;nw(a,0)}function Kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c;e=b;if(pp(b,c+24|0)){b=Qm(c+24|0)}else{b=0}td(d,e,b);Tl(a,c+24|0,c);yb(c);gb=c+32|0}function $ka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!OU(a,d)){break a}c=0;if(!NU(d)){break a}c=Qe(a,b,MU(d),jb)}gb=d+96|0;return c|0}function w$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Kg(a,v[b+8>>2],f)){Uw(b,c,d,e);return}a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function GR(a){var b=0;if(v[a>>2]){TW(a);wb(a);b=v[a>>2];a=hi(a);v[23048]=0;Oc(b,a<<4,8);a=v[23048];v[23048]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function CY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c;e=b;if(pp(b,c+24|0)){b=xY(c+24|0)}else{b=0}td(d,e,b);Tl(a,c+24|0,c);yb(c);gb=c+32|0}function xn(a,b){var c=0;v[a>>2]=1848;v[a>>2]=15596;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function k7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-32|0;gb=h;xK(h+8|0,b,c,d,e,f,g);Dc(a,h+20|0);Bo(h+8|0);gb=h+32|0}function iJ(a,b){a:{b:{if(w[a+23|0]){a=1;if((b|0)!=255){break b}ha(71390,69696,1165,71405);L()}if((b|0)!=255){break a}a=0}return a}return b>>>0>10}function ey(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=d&1?a*c:c;if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function a7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Sp(a,v[c+8>>2],v[c+12>>2]);gb=c+32|0;return a|0}function XC(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0}function KA(a,b,c){var d=0,e=0,f=0;d=zl(a,b);if((d|0)!=255){e=ud(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=lc(a,b),f=255,t[e|0]=f;e=lc(a,c),f=d,t[e|0]=f}}function yD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function l7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-32|0;gb=h;xK(h+8|0,b,c,d,e,f,g);Dc(a,h+8|0);Bo(h+8|0);gb=h+32|0}function hx(a,b,c){a:{if((a|0)==(b|0)){break a}c=v[c>>2];while(1){if((c|0)==v[a>>2]){break a}a=a+4|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function cM(a){var b=0;b=(yf(v[a+16>>2])>>>0)/(vj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;tc(a+4224|0,b)}function b1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function _T(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-12>>>0)/12^-1,12)+c}b=v[a>>2];if(b){Vu(b,_p(a))}}function YN(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){Sc(a,8,1,0,11);return}c=a;a=b+14|0;Sc(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function Qx(a,b,c,d){var e=0;e=Un(a,b,c);if(Nd(d,c)){mc(c,d);if(!Nd(c,b)){return e+1|0}mc(b,c);if(!Nd(b,a)){return e+2|0}mc(a,b);e=e+3|0}return e}function yE(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=gb-16|0;gb=c;d=a+20|0;while(1){Re(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}gb=c+16|0;gb=b+16|0}function i5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Sf(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){Vs(b)}t[a|0]=1}return a|0}function hq(a,b){var c=0;a:{if(!AJ(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function ex(a){var b=0,c=0;v[23048]=0;c=fa(2462)|0;b=v[23048];v[23048]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;zn(a);return}V(0)|0;O()|0;Ab();L()}function aV(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=gb-16|0;gb=c;d=a+32|0;while(1){Re(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}gb=c+16|0;gb=b+16|0}function V4(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Sf(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){oI(b)}t[a|0]=1}return a|0}function V0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Kx(a){var b=0,c=0;b=gb-16|0;gb=b;c=-1;a:{if(PI(a)){break a}if((kb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}gb=b+16|0;return c}function CA(a,b){var c=0;wR(a);wb(a);c=b+4|0;Tk(v[a>>2],v[a+4>>2],c);zc(a,c);zc(a+4|0,b+8|0);zc(wb(a),bc(b));v[b>>2]=v[b+4>>2];zf(a);mg(a);mg(a)}function xW(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=gb-16|0;gb=c;d=a+4|0;while(1){Re(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}gb=c+16|0;gb=b+16|0}function nk(a,b){var c=0,d=0;a:{b=zl(a,b);if((b|0)==255){break a}if(ok(a)){break a}c=lc(a+4|0,b);d=w[c|0]&223;t[c|0]=d;Rh(v[a>>2],Bu(b)|176,d)}}function jW(a,b,c){var d=0;cl(b,zb(v[c>>2]),xb(c));d=gb-16|0;gb=d;v[d+12>>2]=v[b+4>>2];v[d+8>>2]=0;b=v[Wf(d+8|0,d+12|0)>>2];gb=d+16|0;Gj(a,c,b)}function ho(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function fm(a,b){a:{if((a|0)==(b|0)){break a}b=b-1|0;if(b>>>0<=a>>>0){break a}while(1){th(a,b);a=a+1|0;b=b-1|0;if(a>>>0<b>>>0){continue}break}}}function bpa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;u[b+14>>1]=1;c=b,d=Ol(a),u[c+12>>1]=d;a=x[Le(b+14|0,b+12|0)>>1];gb=b+16|0;return a-1&65535}function Xm(a){a=+a;var b=0;a=fe(a);b=255;a:{if(!(a<255)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function Wo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(FW(a)>>>0<b>>>0){Mc();L()}wb(a);c=Tj(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=b+c|0,v[d>>2]=e;BC(a,0)}function Sw(a,b,c,d,e,f){var g=0,h=0,i=0;g=v[a+4>>2];h=g>>8;a=v[a>>2];i=a;if(g&1){h=v[v[d>>2]+h>>2]}kb[v[v[a>>2]+20>>2]](i,b,c,d+h|0,g&2?e:2,f)}function Gs(a,b){a:{if((a|0)==(b|0)){break a}b=b-4|0;if(b>>>0<=a>>>0){break a}while(1){mc(a,b);a=a+4|0;b=b-4|0;if(a>>>0<b>>>0){continue}break}}}function FA(a){var b=0,c=0,d=0;c=w[a+32|0];d=Ei(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Qb(b)}return Ej(b,w[a+32|0])}function B4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;pt(v[v[a>>2]-12>>2]+a|0,c);return a|0}function $C(a){var b=0;if(v[a>>2]){Rd(a);b=v[a>>2];a=Kj(a);v[23048]=0;Oc(b,B(a,6),1);a=v[23048];v[23048]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function xR(a,b){var c=0,d=0,e=0;d=x[a>>1];e=x[b>>1];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=y[a+4>>2]<y[b+4>>2]}return c}function yT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-32>>>5^-1)<<5)+c}b=v[a>>2];if(b){sB(b,oB(a))}}function vB(a){var b=0;if(v[a>>2]){Rd(a);b=v[a>>2];a=nh(a);v[23048]=0;Oc(b,a<<5,4);a=v[23048];v[23048]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function uT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-16>>>4^-1)<<4)+c}b=v[a>>2];if(b){rB(b,Kw(a))}}function ZL(a){a=a|0;var b=0,c=0;v[a>>2]=49696;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;Qc(b);if((b|0)!=(c|0)){continue}break}nf(a);return a|0}function VC(a){var b=0;if(v[a>>2]){Rd(a);b=v[a>>2];a=Ce(a);v[23048]=0;Oc(b,a<<2,2);a=v[23048];v[23048]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function Lv(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(is(a,b+8|0)){c=Wb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))}gb=b+16|0;return c|0}function Kf(a){var b=0;if(v[a>>2]){Rd(a);b=v[a>>2];a=mg(a);v[23048]=0;Oc(b,a<<3,8);a=v[23048];v[23048]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function B5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=v[a+20>>2];d=v[a+16>>2]-e|0;d=c>>>0<d>>>0?c:d;hc(e,b,d);v[a+20>>2]=d+v[a+20>>2];return c|0}function rp(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-2>>>1^-1)<<1)+c}b=v[a>>2];if(b){tY(b,ow(a))}}function kP(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function _U(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-8>>>3^-1)<<3)+c}b=v[a>>2];if(b){qF(b,ZU(a))}}function Wr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=ho(d,d+e|0,c+15|0);pj(a,v[b>>2],d);gb=c+16|0}function Qy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function AE(a){var b=0,c=0;c=Fpa(w[a+111|0],0,1536,0);b=jb;a=Fpa(w[a+110|0],0,25,0);c=c+a|0;b=jb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;jb=b;return a}function xs(a,b,c,d,e){var f=0,g=0,h=0;f=v[a+4>>2];g=f>>8;a=v[a>>2];h=a;if(f&1){g=v[v[c>>2]+g>>2]}kb[v[v[a>>2]+24>>2]](h,b,c+g|0,f&2?d:2,e)}function rda(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!nd(a,4)){Nw(a)}c=b,d=Rb(a+44|0),v[c>>2]=d;a=v[Sd(b+8|0,b)>>2];gb=b+16|0;return a|0}function qda(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!nd(a,4)){Nw(a)}c=b,d=Ub(a+44|0),v[c>>2]=d;a=v[Sd(b+8|0,b)>>2];gb=b+16|0;return a|0}function YU(a){a:{if(zd(a,25420,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>32){break a}return w[a|0]!=0}return 0}function Ot(a){var b=0;b=A[a+4248>>3]/+(yf(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*.016666666666666666*A[a+4288>>3]}}function Lm(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function yY(a){var b=0,c=0;c=a;b=v[a+4>>2];a=v[a>>2];if((b|0)!=(a|0)){while(1){b=b-28|0;ae(b);if((a|0)!=(b|0)){continue}break}}v[c+4>>2]=a}function vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(mg(a)>>>0<b>>>0){d=wb(a);e=a;a=DA(c+8|0,b,zf(a),d);CA(e,a);BA(a)}gb=c+32|0}function jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(pg(a)>>>0<b>>>0){d=wb(a);e=a;a=CB(c+8|0,b,Gc(a),d);$T(e,a);_T(a)}gb=c+32|0}function fga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(tA(a)>>>0<b>>>0){d=wb(a);e=a;a=bR(c+8|0,b,xA(a),d);$Q(e,a);_Q(a)}gb=c+32|0}function dO(a,b){var c=0;ik(a);wb(a);c=b+4|0;Tk(v[a>>2],v[a+4>>2],c);mc(a,c);mc(a+4|0,b+8|0);mc(wb(a),bc(b));v[b>>2]=v[b+4>>2];ol(a,Lb(a))}function _S(a,b){var c=0;ik(a);wb(a);c=b+4|0;Tk(v[a>>2],v[a+4>>2],c);zc(a,c);zc(a+4|0,b+8|0);zc(wb(a),bc(b));v[b>>2]=v[b+4>>2];ol(a,Lb(a))}function S0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=gb-16|0;gb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Gb(a+12|0,a+8|0);gb=a+16|0;return v[b>>2]}function Gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(Ce(a)>>>0<b>>>0){d=wb(a);e=a;a=eO(c+8|0,b,Lb(a),d);dO(e,a);tz(a)}gb=c+32|0}function $n(a){var b=0;if(v[a>>2]){Rd(a);b=v[a>>2];a=jg(a);v[23048]=0;Oc(b,a,1);a=v[23048];v[23048]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function s6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=At(a+8|0,b,c,d,2);if(a>>>0<=15){a=w[a+45856|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function r6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=At(a+8|0,b,c,d,3);if(a>>>0<=44){a=w[a+45808|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function ki(a){var b=0;a=a*a;b=a*a;return C(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+-.001388676377460993))}function bga(a){a=a|0;var b=0;b=v[a>>2];if(kb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=kb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Qh(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((zl(a,b)|0)==255){break a}nk(a,b);_q(a,b,0,0);if(!c){break a}a=lc(a+58|0,b);t[a|0]=w[a|0]|128}}function OP(a){a=50-(B(w[(a>>>4|0)+32240|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return vc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function MT(a){var b=0,c=0;b=gb-16|0;gb=b;if(NV(a,b+8|0)){a=b+8|0;c=Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=b+16|0;return c}function J5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+15&-16;v[c>>2]=b+16;d=a,e=Xx(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function x3(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Js(a,b,c);gb=c+32|0}
function ppa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;XK(a,b,c);gb=c+32|0}function n7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;yK(g+8|0,b,c,d,e,f);Dc(a,g+20|0);Bo(g+8|0);gb=g+32|0}function k1(a){a=a|0;var b=0,c=0,d=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;d=b;if(c&1){a=v[a+v[b>>2]>>2]}kb[a|0](d)}function iE(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=gb-16|0;gb=a;Rx(v[c+8>>2],v[c>>2],a+8|0);gb=a+16|0;gb=c+16|0}function aja(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;GV(a,b,c);gb=c+32|0}function TI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function QL(a){var b=0,c=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=C(wg(b-J(b+.5)))}else{c=C(0)}return c}function Fna(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Js(a,b,c);gb=c+32|0}function Fda(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;Js(a,b,c);gb=c+32|0}function Bka(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Tv(a,b,c);gb=c+32|0}function xpa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;Tv(a,b,c);gb=c+32|0}function xca(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=0;c=b+12|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;HM(a,b+12|0);gb=b+16|0}function o7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;yK(g+8|0,b,c,d,e,f);Dc(a,g+8|0);Bo(g+8|0);gb=g+32|0}function iv(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;_K(a,b,c);gb=c+32|0}function bd(a,b){var c=0,d=0,e=0;c=Qf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function aC(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;GV(a,b,c);gb=c+32|0}function a$(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Iw(a,b,c);gb=c+32|0}function WY(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Tv(a,b,c);gb=c+32|0}function Mx(a,b){var c=0;if(b>>>0<=99){return VI(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return bt(UI(c,a),b-B(a,100)|0)}return gj(a,b)}function Kk(a){var b=0;b=a+28|0;a=b;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[b|0]^-128}else{a=255}return a&255}function Kb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(b>>>0>=112){Cn(16896);L()}Db(d+8|0,a,b);Ef(d+8|0,c);gb=d+16|0;return a|0}function G3(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;Js(a,b,c);gb=c+32|0}function ht(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function b$(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;Iw(a,b,c);gb=c+32|0}function Wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(an()>>>0<b>>>0){Mc();L()}c=IU(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function Ms(a,b){go(a);v[a>>2]=90516;v[23048]=0;Q(2341,a+4|0,b|0)|0;a=v[23048];v[23048]=0;if((a|0)!=1){return}a=P()|0;O()|0;R(a|0);L()}function Jb(a){var b=0,c=0;b=gb-16|0;gb=b;v[23048]=0;c=v[23048];v[23048]=0;if((c|0)!=1){yA(a);gb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Hca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!ue(c&255))){QM(a,8,C(0))}a=ek(a);if(a){kb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function G5(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;Iw(a,b,c);gb=c+32|0}function v8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(lG()>>>0<b>>>0){Mc();L()}c=nK(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<4)+c|0,v[d>>2]=e}function dG(){var a=0,b=0,c=0;a=gb-16|0;gb=a;b=Tb(a,15177);c=0;a:{if(!Bb(b)){break a}c=(ng(b,15185)|0)!=-1}vb(b);gb=a+16|0;return c|0}function bG(a){a=a|0;var b=0;a=Jb(a);v[23048]=0;Q(225,a|0,11243)|0;b=v[23048];v[23048]=0;if((b|0)==1){b=P()|0;O()|0;vb(a);R(b|0);L()}}function _f(a){var b=0,c=0;b=gb-16|0;gb=b;if(is(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=b+16|0;return c}function Pz(a,b){a=a|0;b=b|0;var c=0;c=32397;a:{if(b>>>0>255){break a}a=v[((b<<2)+a|0)+900380>>2];if(!a){break a}c=a+492|0}return c|0}function GI(a){var b=0,c=0,d=0;c=Ob(a);b=Bb(a);a=gb-16|0;gb=a;t[a+15|0]=0;d=-1;if(b){b=vp(c,b,a+15|0);d=b?b-c|0:-1}gb=a+16|0;return d}function Vd(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)<(b|0)){v[a>>2]=b;return}if((c|0)>=(d|0)){break a}v[a>>2]=c}}function T6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=0-(d&65535)&65535;b=b+1|0}mK(a,b,c,d&65535,10)}function Or(a,b){return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function If(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=ni(f,f+12|0);a=at(a,b,d,v[f+8>>2]);jf(c);gb=f+16|0;return a}function Fp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0<b>>>0){v[a>>2]=b;return}if(c>>>0>=d>>>0){break a}v[a>>2]=c}}function xb(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[23048]=0;a=_h(a,b);b=v[23048];v[23048]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function wu(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[23048]=0;a=Tq(a,b);b=v[23048];v[23048]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function wB(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[23048]=0;a=hp(a,b);b=v[23048];v[23048]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function q6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];pt(v[v[a>>2]-12>>2]+a|0,c);return a|0}function ft(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function R_(){var a=0,b=0;a=gb-16|0;gb=a;v[a+8>>2]=19922997;a:{if(eG(a+8|0)){break a}if(dG()){break a}b=cG()^1}gb=a+16|0;return b|0}function Fx(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return ah(t[b|0])|0}function Doa(a){a=a|0;var b=0,c=0,d=0;if(an()>>>0<=8191){Mc();L()}b=jc(32768,2);v[a>>2]=b;v[a+4>>2]=b;c=wb(a),d=b+32768|0,v[c>>2]=d}function kY(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179468868){return(w[a+4|0]-1&255)>>>0<10}return 0}function _M(a){a=a|0;a=gb-16|0;gb=a;v[a+12>>2]=1869112133;gb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function tca(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;if(Ce(a)>>>0<=11){c=wb(a);d=a;a=FM(b+8|0,12,Lb(a),c);Ji(d,a);Jz(a)}gb=b+32|0}function jw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=Jpa(0-Jpa(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function Wh(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;je(a,d+12|0);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;gb=d+16|0;return a}function FB(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=wb(b),d=0,v[c>>2]=d}function qH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Ls(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function nH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Ks(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function ek(a){var b=0,c=0;b=Kk(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function ay(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}hc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function NS(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=Fpa(b,b>>31,a,a>>31)+5e5|0;a=jb;return vc(Gpa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function MS(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=Fpa(b,b>>31,a,a>>31)+5e5|0;a=jb;return vc(Gpa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function Cg(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;if(b>>>0>=112){Cn(17140);L()}Db(c+8|0,a,b);Ef(c+8|0,0);gb=c+16|0;return a|0}function vk(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;Ar(a+4|0);v[b+12>>2]=0;je(a+8|0,b+12|0);c=a,d=dc(a),v[c>>2]=d;gb=b+16|0;return a}function dS(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){Ae(b,a)}if(c){Ae(c,a)}if(d){Ae(d,a)}if(e){Ae(e,a)}}function wl(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];_c(a,c,v[Gb(d+12|0,d+8|0)>>2]);gb=d+16|0}function o5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return ah(t[a|0])|0}function cu(a,b){a=a|0;b=b|0;var c=0;c=b>>>0>126;if(!c){We(((b<<5)+a|0)+480280|0);No((B(b,880)+a|0)+1074984|0,a,b)}return c|0}function Gl(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(kb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function C$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Kg(a,v[b+8>>2],0)){Vw(b,c,d);return}a=v[a+8>>2];kb[v[v[a>>2]+28>>2]](a,b,c,d)}function uI(a){v[a>>2]=78056;ex(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function rH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Ls(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function oH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Ks(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function lg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=bh(d,a);return((bh(d,a+1|0)<<8|e<<16|bh(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function eU(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;jb=c;return a}function Zi(a,b,c,d){var e=0;e=gb-16|0;gb=e;cc(e+8|0,zb(c),d);c=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=c;jW(a,b,e);gb=e+16|0}function Ys(a){v[a>>2]=77992;ex(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function W5(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}kb[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}function Sb(a,b){var c=0,d=0,e=0;c=a;d=v[b>>2];e=d+v[a>>2]|0;a=v[a+4>>2]+v[b+4>>2]|0;v[c>>2]=e;v[c+4>>2]=e>>>0<d>>>0?a+1|0:a}function xq(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function uq(a){a=a|0;var b=0,c=0;b=Te(a);while(1){c=b;if(c&65535){b=c-1|0;if(!oe(a,b&65535)){continue}}break}return c&65535}function jf(a){a:{a=v[a>>2];if(a){v[23048]=0;sx(a);a=v[23048];v[23048]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function mO(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function YA(a){a=a|0;v[a+700>>2]=0;u[a+844>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function WT(a,b){var c=0;c=v[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-12|0;VT(c);if((b|0)!=(c|0)){continue}break}}v[a+4>>2]=b}function SI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function PB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function EF(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0}function y7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=0-d|0;b=b+1|0}EK(a,b,c,d,e)}function uP(a,b){var c=0;c=gb-16|0;gb=c;Db(c+8|0,a+1074308|0,7);a=Cb(c+8|0);gb=c+16|0;return v[(b<<2)+(a?38176:38240)>>2]}function tP(a,b){var c=0;c=gb-16|0;gb=c;Db(c+8|0,a+1074308|0,7);a=Cb(c+8|0);gb=c+16|0;return v[(b<<2)+(a?38240:38176)>>2]}function ke(a,b){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))}function ej(a,b,c){a:{if(c){v[23048]=0;TI(a,b,c);a=v[23048];v[23048]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function cA(a,b){var c=0;c=gb-16|0;gb=c;Db(c+8|0,a+1074308|0,7);a=Cb(c+8|0);gb=c+16|0;return v[(b<<2)+(a?38304:39328)>>2]}function bA(a,b){var c=0;c=gb-16|0;gb=c;Db(c+8|0,a+1074308|0,7);a=Cb(c+8|0);gb=c+16|0;return v[(b<<2)+(a?39328:38304)>>2]}function FG(a){v[23048]=0;X(a|0);a=v[23048];v[23048]=0;if((a|0)!=1){v[23048]=0;L()}a=V(0)|0;O()|0;Z(a|0)|0;v[23048]=0;L()}function $S(a,b){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function rl(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;pz(a,c)}function rZ(a){a=a|0;var b=0;a:{if(!Ke(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=RF(a,32);v[b+76>>2]=a}return a<<24>>24}function k5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function jI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function fT(a){var b=0;b=a+68|0;if(!(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>127)){return!zd(a,27325,17)}return 0}function XN(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179011410){return Qm(a)>>>0>80}return 0}function BS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){zS(a,1);zS(a,0)}}function AS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){yS(a,1);yS(a,0)}}function uW(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1279544644){return w[a+4|0]<32}return 0}function pY(a){var b=0;a:{if(zd(a,17211,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>8){break a}return t[a+47|0]>-1}return 0}function le(a,b){var c=C(0);a:{if(b>C(1)){break a}c=z[a>>2];if(!(c>=b)){z[a>>2]=b;return}if(c<=C(1)){break a}z[a>>2]=1}}function Fy(a,b,c){var d=0;b=b-a|0;if((b|0)>=1){while(1){t[a|0]=w[c|0];a=a+1|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function gma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Dp(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}gb=b+16|0;return c|0}function Pe(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function rc(a,b){var c=0;go(a);v[a+4>>2]=0;v[a>>2]=56280;c=a;a=Ad(Bb(b)+1|0);v[c+4>>2]=a;if(a){hc(a,Ob(b),Bb(b)+1|0)}}function Zv(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){cc(a,c,v[b>>2]);return}b=b+8|0;if(!cd(b)){me(a,b);return}Xd(a)}function L6(a){a=a|0;var b=0,c=0,d=0;if(an()>>>0<=3){Mc();L()}b=DS();v[a>>2]=b;v[a+4>>2]=b;c=wb(a),d=b+16|0,v[c>>2]=d}function HY(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==810369604){return w[a+4|0]<4}return 0}function po(a){var b=0;a:{while(1){if(w[b+45872|0]==(a|0)){break a}b=b+1|0;if((b|0)!=45){continue}break}b=0}return b}function gV(a){var b=0,c=0;b=gb-16|0;gb=b;c=a+512|0;while(1){Re(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}gb=b+16|0}function VU(a){var b=0;a=a+1104|0;a=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+8|0;b=a>>>0<8?1:b;jb=b;return a}function ur(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Jj(e,a,d);MD(wb(a),b,c,d+4|0);_b(d);gb=e+16|0}function tfa(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;if(b>>>0>=250){Cn(32324);L()}Db(c+8|0,a,b);ir(c+8|0);gb=c+16|0}function tG(a,b){var c=0,d=0;d=gb-16|0;gb=d;c=Jj(d,a,1);wb(a);Qp(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+1;_b(c);gb=d+16|0}function cw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Ug(e,a,d);MD(wb(a),b,c,d+4|0);_b(d);gb=e+16|0}function OI(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function kda(a,b){a=a|0;b=b|0;var c=0;a:{if(Lb(a)>>>0>511){break a}if(!Fd(b)){break a}c=v[b>>2];gN(a,b)}return c|0}function js(a,b,c){a:{v[23048]=0;Oc(b,B(c,36),4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function iB(a,b,c){a:{v[23048]=0;Oc(b,B(c,28),4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function dm(a,b,c){a:{v[23048]=0;Oc(b,B(c,12),4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function ada(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=aA(C(c*C(255))),t[d|0]=e;Tt(a)}}function UX(a,b,c){a:{v[23048]=0;Oc(b,B(c,48),4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function PD(a,b,c){a:{v[23048]=0;Oc(b,B(c,20),4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Oh(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function Kz(a,b,c){a:{v[23048]=0;Oc(b,B(c,52),4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Ji(a,b){var c=0;c=b+4|0;Tk(v[a>>2],v[a+4>>2],c);zc(a,c);zc(a+4|0,b+8|0);zc(wb(a),bc(b));v[b>>2]=v[b+4>>2]}function DY(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function xv(a){var b=0,c=0;if(v[a>>2]){Cr(a);Rk(wb(a),v[a>>2],jg(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function wS(a){var b=0,c=0;if(v[a>>2]){fn(a);pw(wb(a),v[a>>2],Gg(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function wC(a,b,c){a:{v[23048]=0;Oc(b,B(c,6),1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function ul(a,b){var c=0;c=b&15;if(c){t[a+826|0]=c<<2}b=b&240;if(b){t[a+825|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function jM(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function gI(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!Ke(vI(c,b),-1)){break a}v[a>>2]=0}return a|0}function XP(a,b){var c=0;c=b&15;if(c){t[a+829|0]=c<<2}b=b&240;if(b){t[a+828|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function SV(a){var b=0,c=0;if(v[a>>2]){xg(a);hw(wb(a),v[a>>2],Ce(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function KN(a){var b=0,c=0;if(v[a>>2]){xg(a);Ph(wb(a),v[a>>2],Ce(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function JN(a){var b=0,c=0;if(v[a>>2]){ON(a);wC(wb(a),v[a>>2],Kj(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function sy(a,b){a:{v[23048]=0;Oc(a,B(b,24),8);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function mW(a,b){a:{v[23048]=0;Oc(a,B(b,33),1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function hg(a,b,c){var d=0;a:{if(b>c){break a}d=A[a>>3];if(!(d>=b)){A[a>>3]=b;return}if(c>=d){break a}A[a>>3]=c}}function hD(a,b){a:{v[23048]=0;Oc(a,B(b,28),4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function cJ(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+(c*c-e+(c+c)*d)}function ZN(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function Vu(a,b){a:{v[23048]=0;Oc(a,B(b,12),4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function RM(a,b,c){a:{v[23048]=0;Oc(b,c<<11,4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function x4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=zx(b);v[a+36>>2]=b;c=a,d=On(b),t[c+44|0]=d}function vC(a,b,c){a:{v[23048]=0;Oc(b,c<<2,1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function uaa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,56189);rc(a,c);vb(c);v[a>>2]=56216;gb=b+16|0;return a|0}function u4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=yx(b);v[a+36>>2]=b;c=a,d=On(b),t[c+44|0]=d}function ru(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function qn(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function pw(a,b,c){a:{v[23048]=0;Oc(b,c<<1,2);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function jV(a,b,c){a:{v[23048]=0;Oc(b,c<<5,8);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function hw(a,b,c){a:{v[23048]=0;Oc(b,c<<2,2);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function eaa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,56228);rc(a,c);vb(c);v[a>>2]=56260;gb=b+16|0;return a|0}function UD(a,b,c){a:{v[23048]=0;Oc(b,c<<1,1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function TQ(a,b){a:{v[23048]=0;Oc(a,B(b,7),1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Ph(a,b,c){a:{v[23048]=0;Oc(b,c<<2,4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Kr(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Dp(a,b+8|0)){c=Ib(w[b+8|0]|w[b+9|0]<<8)}gb=b+16|0;return c|0}function Gh(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function AA(a,b,c){a:{v[23048]=0;Oc(b,c<<3,8);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function vS(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a+4>>2];v[c>>2]=v[b+4>>2];a=Fb(c+8|0,c);gb=c+16|0;return a}function jr(a,b,c){if((Ib(w[a|0]|w[a+1|0]<<8)|0)>=(b|0)){a=(Ib(w[a|0]|w[a+1|0]<<8)|0)<=(c|0)}else{a=0}return a}function Kg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!hj(v[a+4>>2],v[b+4>>2])}function Ef(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function Dv(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=(B(a,b)>>>0)/255;Vd(c+12|0,0,15);gb=c+16|0;return w[c+12|0]}function uO(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function tY(a,b){a:{v[23048]=0;Oc(a,b<<1,1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function tV(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(!(b<0)){A[a+8>>3]=b;v[a+16>>2]=3}return a}function sB(a,b){a:{v[23048]=0;Oc(a,b<<5,1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function rB(a,b){a:{v[23048]=0;Oc(a,b<<4,1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function qF(a,b){a:{v[23048]=0;Oc(a,b<<3,1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function pB(a,b){a:{v[23048]=0;Oc(a,b<<8,1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function oK(a,b){a:{v[23048]=0;Oc(a,b<<4,4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function nP(a,b){a:{v[23048]=0;Oc(a,b<<3,4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function jC(a,b){a:{v[23048]=0;Oc(a,b<<2,1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function dR(a){a:{if(w[a|0]<24){break a}if(!w[a+3|0]){t[a+3|0]=16;return}if(w[a+3|0]!=3){break a}t[a+3|0]=15}}function bT(a,b){var c=0;c=v[a+4>>2]+b|0;v[a+4>>2]=c&31;v[a>>2]=v[a>>2]+(((b|0)>=0?c>>>5|0:(c-31|0)/32|0)<<2)}function G8(a,b){a=a|0;b=b|0;if(a){b=kb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=ie(b);break a}b=ie(52181)}v[a>>2]=b}}function EO(a,b){a:{v[23048]=0;Oc(a,b<<2,4);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function qK(a,b){v[23048]=0;Oc(a,B(b,324),4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function qI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return ah(t[b|0])}function pH(a,b,c,d,e){b=bj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function mH(a,b,c,d,e){b=aj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function lr(a){if(!(a<4294967295)){return-1}if(!(a>0)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function hC(a){var b=0,c=0;c=a;b=v[a+8>>2];a=v[a+4>>2];if((b|0)!=(a|0)){v[c+8>>2]=(((b-a|0)-4>>>2^-1)<<2)+b}}function ZR(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+22>>1]<<4|x[b+20>>1]>>>6)&65535)+29552|0]>>>x[a+68>>1]}function XH(a){a=a|0;var b=0;b=v[v[a>>2]-12>>2]+a|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;return a|0}function Rk(a,b,c){a:{v[23048]=0;Oc(b,c,1);a=v[23048];v[23048]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Io(a,b){a=a|0;b=b|0;if(uc(a)>>>0>b>>>0){a=oe(v[a+24>>2]+484344|0,x[Si(a,b)>>1])}else{a=0}return a|0}function $V(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;if((Ol(a)|0)!=65535){DD(a,c+14|0)}gb=c+16|0}function xU(a,b){v[23048]=0;Oc(a,B(b,56),4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function wJ(a,b,c,d){z[d+4>>2]=c+a;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=a+b}function r1(){var a=0;if(an()>>>0<=27){Mc();L()}a=MG(Zw(467232),28);v[116808]=a;v[116809]=a;v[116812]=a+112}function nq(a){a=a|0;var b=0;b=v[2642];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[2645];lt(a+4|0);gh(a+56|0);return a|0}function ag(a){a=a|0;var b=0;b=v[2723];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[2726];lt(a+8|0);gh(a+60|0);return a|0}function SW(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){NW(c+52|0);vb(c+40|0);Qc(c+16|0);Qc(c+4|0);Zb(c)}}}function Nx(a,b){var c=0;if(b>>>0<=9999){return Mx(a,b)}c=a;a=(b>>>0)/1e4|0;return gj(Mx(c,a),b-B(a,1e4)|0)}function Nh(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Ec(c,(b>>31&a)+b|0)>>2]}function IF(a,b){v[23048]=0;Oc(a,B(b,24),4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function Gm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(!Iu(a,b)){b=Iu(c,a)?c:a}gb=d+16|0;return b|0}function uma(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(Qj(a,b+8|0)){c=LV(b+8|0)}gb=b+16|0;return c|0}function jy(a,b){var c=0;c=(B(B(hy(a),iy(a)),125)>>>0)/(DJ(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function gw(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function fpa(a,b){a=a|0;b=b|0;var c=0;b=gb-80|0;gb=b;c=-1;if(lY(a,b+8|0)){c=kY(b+8|0)}gb=b+80|0;return c|0}function Lq(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=zb(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function DJ(a){var b=0;b=v[(w[a+2|0]&12)+61656>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function D5(a){a=a|0;a=gb-16|0;gb=a;if(fb(a+12|0,4)|0){MH(v[115529],74933);L()}gb=a+16|0;return v[a+12>>2]}function Apa(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(Qj(a,b+8|0)){c=HY(b+8|0)}gb=b+16|0;return c|0}function lI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function gv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;nn(c+8|0,a);v[c+4>>2]=v[c+8>>2];kr(c+4|0,b);gb=c+16|0}function eL(a){var b=0;while(1){if(!v[(b<<2)+a>>2]){return b}b=b+1|0;if((b|0)!=4){continue}break}return 4}function b_(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(Qj(a,b+8|0)){c=lF(b+8|0)}gb=b+16|0;return c|0}function aq(){var a=0;v[23048]=0;a=v[23048];v[23048]=0;if((a|0)!=1){return v[20047]}V(0)|0;O()|0;Ab();L()}function VG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function Fg(a){var b=0,c=0;b=gb-16|0;gb=b;if(Dp(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}gb=b+16|0;return c}function Bs(){var a=0;v[23048]=0;a=v[23048];v[23048]=0;if((a|0)!=1){return v[20628]}V(0)|0;O()|0;Ab();L()}function As(){var a=0;v[23048]=0;a=v[23048];v[23048]=0;if((a|0)!=1){return v[20240]}V(0)|0;O()|0;Ab();L()}function $y(a,b){nc(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Co(a+24|0);Jb(a+36|0);v[a+48>>2]=b;return a}function yi(a,b,c){var d=0,e=0,f=0,g=0;d=A[c>>3];e=A[b>>3];f=A[c+8>>3];g=A[b+8>>3];Im(a,d*e-f*g,e*f+d*g)}function qp(a,b){var c=0;c=gb-16|0;gb=c;a=gD(c,a);Sl(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;_b(a);gb=c+16|0}function oq(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=Bd(b),v[d+12>>2]=e;je(a,c+12|0);gb=c+16|0;return a}function mF(a,b){v[23048]=0;Oc(a,b<<5,4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function hG(a,b){v[23048]=0;Oc(a,b<<4,4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function Hg(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];jb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function zz(a,b){var c=0;c=gb-16|0;gb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];gb=c+16|0}function yw(a,b,c){var d=0;d=gb-16|0;gb=d;a=Xd(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;gb=d+16|0}function mc(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];gb=c+16|0}function YO(a,b){var c=0;c=gb-16|0;gb=c;a=Fq(c,a);Eq(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;_b(a);gb=c+16|0}function VA(a){dd(a);t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=255;return a}function RS(a,b){var c=0;c=y[b>>2]>y[a>>2];a=v[a+4>>2];b=v[b+4>>2];return(a|0)<(b|0)?1:(a|0)<=(b|0)?c:0}function KG(a,b,c){v[23048]=0;JG(a,b,c);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function yB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=v[b>>2]+c|0;if((d|0)==-1){d=xb(b)-c|0}_d(a,e,d)}function sx(a){a=a|0;var b=0;b=v[22953];if(a){v[22953]=(a|0)==-1?462176:a}return((b|0)==462176?-1:b)|0}function Kq(a,b,c){a=lk(a+1074368|0)-v[a+1074384>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function CS(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;v[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function iy(a){var b=0;b=w[a+1|0];return w[(B(b>>>3&1,45)+B(b>>>1&3,15)+(w[a+2|0]>>>4)|0)+61665|0]<<1}function Jg(a){var b=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Qo(a+8|0);gb=b+16|0;return a}function uA(a){v[23048]=0;Oc(a,40,4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function rT(a){v[23048]=0;Oc(a,48,4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function jv(a){v[23048]=0;Oc(a,20,4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function jca(a,b){a=a|0;b=b|0;return C((b|0)<=2?C(C(w[(a+b|0)+4232|0])*C(.007874015718698502)):C(0))}function jO(a){v[23048]=0;Oc(a,28,4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function iT(a){Nm(a+140|0);yb(a+120|0);yb(a+100|0);yb(a+80|0);yb(a+60|0);yb(a+40|0);yb(a+20|0);yb(a)}function bda(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])*C(.003921568859368563)):C(0))}function Sj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function OW(a){v[23048]=0;Oc(a,32,4);a=v[23048];v[23048]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function Lr(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function qE(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}jb=a;return b}function kla(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;UU(c,b);a=Vf(a,c)^1;vb(c);gb=c+16|0;return a|0}function ew(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function Th(a){a=a|0;var b=0;b=a+172|0;a:{if(jB(a)){break a}b=a+156|0}a=b;return w[a|0]|w[a+1|0]<<8}function SR(a,b,c){if((b|0)!=(c|0)){while(1){QR(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Md(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=57088;v[b+8>>2]=57192;Ou(a,b+12|0,b+8|0);gb=b+16|0}function Fca(a,b,c){a=a|0;b=b|0;c=c|0;a=ek(a);if(!a){return 0}return kb[v[v[a>>2]+100>>2]](a,b,c)|0}function k$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return kb[a|0](b,c,d,e,f,g)|0}function j1(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[aq()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function Ola(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(YC(a,b)){c=oV(b)}gb=b+16|0;return c|0}function Mm(a){a=a|0;var b=0;Al(a);b=$q(v[a>>2],Wi(a));v[a+20>>2]=b;if(!b){return 0}return Oi(a)|0}function JZ(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=CE(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function E8(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Ob(b);if(c){kb[c|0](b,v[a+8>>2]);return}Jt(b,a)}function th(a,b){var c=0;c=gb-16|0;gb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];gb=c+16|0}function sr(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;kv(a+236|0,128,c+14|0);gb=c+16|0}function ska(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;UU(c,a);a=Vf(c,b);vb(c);gb=c+16|0;return a|0}function sg(a){a=a|0;var b=0,c=0;while(1){c=b&65535;cu(a,c);b=b+1|0;if(c>>>0<126){continue}break}}function e6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;kb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;bq(d,a);YG(a,c)}function Lp(a,b,c){a=a|0;b=b|0;c=c|0;je(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function Hna(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;ME(c,a);a=Vf(c,b);vb(c);gb=c+16|0;return a|0}function GM(a){a=a|0;var b=0;b=v[a>>2];if(b){kb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Cr(a);JV(a)}function oX(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];nX(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function mT(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}jb=a;return b}function k6(a,b){a=a|0;b=b|0;Ys(a);v[a>>2]=10716;Jb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function eV(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}v[a>>2]=b}}function d5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function b5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function Z4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function X4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function So(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];QV(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function QZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Ye(c+8|0,a);Xr(c+8|0,b);gb=c+16|0;return a|0}function QY(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;rD(c+8|0,a);Xr(c+8|0,b);gb=c+16|0;return a|0}function Ne(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];fw(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function NZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;LE(c+8|0,a);Xr(c+8|0,b);gb=c+16|0;return a|0}function GA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=A[b+8>>3];d=Qw(A[b>>3]);e=ji(c);Im(a,d*Oe(c),d*e)}function EA(a,b){var c=0;c=gb-16|0;gb=c;a=v[Cc(c+8|0,nR(a,b,$d(a),dc(a)))>>2];gb=c+16|0;return a}function $4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function zN(a,b){b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Qo(a+8|0);gb=b+16|0;return a}function v$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Kg(a,v[b+8>>2],f)){Uw(b,c,d,e)}}function rJ(a){var b=0;b=+((a&2097151)>>>0);return C(Qi(+C((a|0)>-1?b:-b),(a>>>21&1023)-788|0))}function lna(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=is(a,b+8|0);gb=b+16|0;return C(a?z[b+8>>2]:C(0))}function kia(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function KZ(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Ig(a,b+8|0)){c=w[b+8|0]}gb=b+16|0;return c|0}function Iea(a,b){a=a|0;b=b|0;xi(a);xi(a);a:{if(b>>>0>=60){Vb(a,4);break a}xi(a)}return xi(a)|0}function Dca(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;me(b,v[a+20>>2]+4|0);NM(a,pe(b+8|0,b),0);gb=b+16|0}function Cq(a,b,c){a=v[a>>2]+1074984|0;return v[(a+B(b,880)|0)+680>>2]>v[(a+B(c,880)|0)+680>>2]}function C5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function Bba(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=yf(v[a+16>>2]),v[b+4256>>2]=c;hM(a);gM(a)}function $ca(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=yf(v[a+16>>2]),v[b+4232>>2]=c;Tt(a);bN(a)}function wy(a){var b=0;b=B(32-E(a|1)|0,1233)>>>12|0;return(b-(y[(b<<2)+10320>>2]>a>>>0)|0)+1|0}function fD(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=sp(c,c+8|0);gb=c+16|0;return a}function dY(a,b){return(ac((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|ac((B(a&15,b)>>>0)/15|0,1,15))&255}function Jo(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=oh(wg(b)*+(c>>>0)),v[d+24>>2]=e}function JX(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=Hk(c,c+8|0);gb=c+16|0;return a}function of(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=a;a=Tb(c,b);Dc(d,a);vb(a);gb=c+16|0}function n4(a,b,c){a=a|0;b=b|0;c=c|0;if(Ke(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function mi(a){var b=0;b=gb-16|0;gb=b;a=v[Cc(b+8|0,Ob(a)+(Bb(a)<<2)|0)>>2];gb=b+16|0;return a}function e$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb[a|0](b,c,d,e)|0;ma(jb|0);return a|0}function ST(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function zr(a,b){var c=0;c=Bb(a);if((c|0)==(Bb(b)|0)){a=!lo(Ob(a),Ob(b),c)}else{a=0}return a}function wT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<5)+d;return a}function tn(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function nL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){sl(c+36|0);$n(c+16|0);$n(c);Zb(c)}}}function kG(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function gE(a){var b=0;b=gb-16|0;gb=b;a=Ig(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function g7(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c+12>>2]=w[b|0];Ey(a,c+12|0);gb=c+16|0}function YI(a){var b=0;b=Epa(v[a>>2]-1|0);if(!b){a=Epa(v[a+4>>2]);return a?a+32|0:0}return b}function WG(a){a=a|0;var b=0;v[a>>2]=84388;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Zb(b)}return a|0}function Vla(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;c=a;a=Ah(b+8|0);KV(c,a,0,0);yb(a);gb=b+32|0}function S4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return kb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function QR(a,b){var c=0,d=0,e=0;c=a;a=v[a>>2];d=c,e=a<<8^v[Dj(29700,a>>>24^b)>>2],v[d>>2]=e}function Ik(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function DI(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function ula(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=fs(a,b+8|0);gb=b+16|0;return+(a?A[b+8>>3]:0)}function sd(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Iu(b,a);gb=c+16|0;return(d?b:a)|0}function iA(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function gS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=di(e,a,d);wb(a);Pl(b,c,d+4|0);_b(d);gb=e+16|0}function eP(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function bw(a,b,c){a=a|0;b=b|0;c=c|0;b=gb-16|0;gb=b;t[b+15|0]=w[c|0];tL(a,b+15|0);gb=b+16|0}function bM(a,b){var c=0;c=v[a+12>>2];if((c|0)>=1){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function Zu(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=RS(b,a);gb=c+16|0;return(d?b:a)|0}function Wl(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=ew(b,a);gb=c+16|0;return(d?b:a)|0}function Wf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Iu(a,b);gb=c+16|0;return(d?b:a)|0}function Vc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=un(b,a);gb=c+16|0;return(d?b:a)|0}function TV(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=Ug(e,a,d);wb(a);Pl(b,c,d+4|0);_b(d);gb=e+16|0}function Nb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return kb[v[v[c>>2]+32>>2]](c,v[a+8>>2],b)|0}function Le(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=un(a,b);gb=c+16|0;return(d?b:a)|0}function Jc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Nd(a,b);gb=c+16|0;return(d?b:a)|0}function JB(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=RS(a,b);gb=c+16|0;return(d?b:a)|0}function Gb(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Nd(b,a);gb=c+16|0;return(d?b:a)|0}function Ff(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=pG(a,b);gb=c+16|0;return(d?b:a)|0}function FL(a,b,c){a=a|0;b=b|0;c=c|0;Cy(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=56136;return a|0}function Baa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ML(a,b,c,d,e,0,0,f,g)}function $b(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=pG(b,a);gb=c+16|0;return(d?b:a)|0}function yW(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function xka(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,26111);Dc(c,a);vb(a);gb=b+16|0}function pma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,23936);Dc(c,a);vb(a);gb=b+16|0}function pj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;BL(a,b,c);gb=d+16|0;return a|0}function oma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,23945);Dc(c,a);vb(a);gb=b+16|0}function iO(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[dc(a)+4|0]){Hb(b+16|0)}if(b){jO(b)}}}function cI(a){var b=0;b=v[a>>2];if(b){if(!Ke(qI(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function bI(a){var b=0;b=v[a>>2];if(b){if(!Ke(lI(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function Zla(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,24070);Dc(c,a);vb(a);gb=b+16|0}function Yg(a){var b=0;b=a+44|0;Lw(b);if(v[b>>2]){TW(b);Op(wb(b),v[b>>2],hi(b))}gc(a+32|0)}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){uk(a,b);return}zG(a,b,c)}function Pna(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,18596);Dc(c,a);vb(a);gb=b+16|0}function Lna(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,18698);Dc(c,a);vb(a);gb=b+16|0}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ek(a);if(a){kb[v[v[a>>2]+76>>2]](a,b,c,d)}}function Jv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;df(c,1,a);RE(c,b);gb=c+16|0;return a|0}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ek(a);if(a){kb[v[v[a>>2]+84>>2]](a,b,c,d)}}function Iv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Jr(c,1,a);RE(c,b);gb=c+16|0;return a|0}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ek(a);if(a){kb[v[v[a>>2]+88>>2]](a,b,c,d)}}function Goa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,17344);Dc(c,a);vb(a);gb=b+16|0}function GF(a,b){var c=0,d=0;qr(a);v[a>>2]=15596;v[a+4>>2]=v[b>>2];c=a,d=xb(b),v[c+8>>2]=d}function Dc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];yA(b)}function $l(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function nd(a,b){var c=0;c=gb-16|0;gb=c;Wk(c+8|0,a+24|0,b);a=Cb(c+8|0);gb=c+16|0;return a}function n$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;kb[a|0](b,c,d,e,f,g)}function lz(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+1272>>2]}else{b=1196}Tb(a,b)}function it(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function PM(a){a=a|0;var b=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074368>>2];A[a+4256>>3]=b-J(b)}function P4(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){xx(a,c);return}Tb(a,78297)}function N_(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,11308);Dc(c,a);vb(a);gb=b+16|0}function M_(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,11312);Dc(c,a);vb(a);gb=b+16|0}function MG(a,b){a:{if(!(w[a+112|0]|b>>>0>28)){t[a+112|0]=1;break a}a=jc(b<<2,4)}return a}function Lx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;a=at(a,b,c,d);gb=e+16|0;return a}function Jpa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function Dy(a){a=a|0;var b=0;v[a>>2]=56280;b=v[a+4>>2];if(b){Zb(b);v[a+4>>2]=0}return a|0}function kv(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function hf(a){var b=0;b=gb-16|0;gb=b;a=v[Cc(b+8|0,Ob(a)+Bb(a)|0)>>2];gb=b+16|0;return a}function ge(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;sH(a,d+12|0,c);gb=d+16|0;return a}function Mca(a,b){a=a|0;b=b|0;a=ek(a);if(!a){return 1}return kb[v[v[a>>2]+68>>2]](a,b)|0}function Hd(a){var b=0;b=gb-16|0;gb=b;a=Ig(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)&255}function zP(a,b){var c=0;c=w[a+853|0];if(c&1){t[a+853|0]=c|8;v[a+856>>2]=v[a+856>>2]+b}}function yn(a){var b=0;b=Aw(a+4|0);if((b|0)==-1){kb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function f_(a){a=a|0;var b=0;b=v[a+4>>2];return(kb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function au(a,b){if(!(v[a+480180>>2]==8?t[b+853|0]&1:0)){Az(a,b,0);Az(a,b,1);Az(a,b,2)}}function _A(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function SX(a,b){return v[v[a>>2]>>2]==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))}function Pi(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function LT(a,b,c){var d=0;d=v[b>>2];if((c|0)==-1){c=gr(b)}v[a>>2]=d;v[a+4>>2]=(c<<2)+d}function IH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;a=JH(a,84320,b);gb=c+16|0;return a}function $o(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function yH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;sH(a,c+12|0,b);gb=c+16|0;return a}function gP(a){Jb(a);Jb(a+12|0);Jb(a+24|0);Jb(a+36|0);Jb(a+48|0);v[a+60>>2]=0;return a}function cU(a){var b=0;b=44325e5/+(a>>>0);if(b<4294967296&b>=0){return~~b>>>0}return 0}function bi(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function ax(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;FI(a,b,DI(b));gb=c+16|0;return a|0}function af(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=v[Yw(b,a)+8>>2],d=0,t[c|0]=d;gb=b+16|0}function ZF(a){var b=0;b=a+48|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function VR(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function Tk(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>=1){hc(c,a,b)}}function Tb(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Sp(a,b,Lf(b));gb=c+16|0;return a|0}function RA(a,b){GB(a,b);Dc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function Qk(a){var b=0;b=a+36|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function KY(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+16880|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function Jf(a){var b=0;b=a+24|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function JG(a,b,c){a=a|0;b=b|0;c=c|0;if((a|0)==(b|0)){t[a+112|0]=0;return}Oc(b,c<<2,4)}function v2(a,b){a=a|0;b=b|0;var c=0;c=Fx(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function t7(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;rD(c+8|0,b);Wr(a,c+8|0);gb=c+16|0}function r0(a){a=a|0;a=466040;while(1){a=vb(a-12|0);if((a|0)!=465872){continue}break}}function o0(a){a=a|0;a=466216;while(1){a=Pc(a-12|0);if((a|0)!=466048){continue}break}}function l0(a){a=a|0;a=466512;while(1){a=vb(a-12|0);if((a|0)!=466224){continue}break}}function i0(a){a=a|0;a=466816;while(1){a=Pc(a-12|0);if((a|0)!=466528){continue}break}}function f0(a){a=a|0;a=466856;while(1){a=vb(a-12|0);if((a|0)!=466832){continue}break}}function c0(a){a=a|0;a=466888;while(1){a=Pc(a-12|0);if((a|0)!=466864){continue}break}}function Xu(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function SE(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Ye(c+8|0,b);Wr(a,c+8|0);gb=c+16|0}function Qn(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function Q5(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function P5(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function Jt(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;v[b>>2]=a;hJ(52267,b);jt(91496);gb=b+16|0}function waa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return DL(a,b,c,d,0,0,0,0,e)|0}function pL(a,b){a=a|0;b=b|0;var c=0;c=wf(8);fL(c);v[c+4>>2]=b;v[c>>2]=58416;Ai(a,c)}function bja(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Sp(a,b,12);gb=c+16|0;return a|0}function Z0(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Bs()+((b&255)<<2)>>2]}return b<<24>>24}function X0(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[As()+((b&255)<<2)>>2]}return b<<24>>24}function QT(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Bf(a){a=a|0;var b=0;b=v[a>>2];return(kb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function Ai(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;Eq(a,c+12|0);gb=c+16|0;return a}function $h(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;Pi(a)}function h$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kb[a|0](b,c,d)|0;ma(jb|0);return a|0}function Uj(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function vq(a,b){a=a|0;b=b|0;if(b>>>0<=44){return w[v[a+84>>2]+b|0]!=63|0}return 0}function sJ(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function qT(a,b,c,d,e,f){Cc(a,b);Cc(a+4|0,c);Cc(a+8|0,d);Cc(a+12|0,e);Cc(a+16|0,f)}function lh(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;Eq(a,b+12|0);gb=b+16|0;return a}function lC(a){var b=0;b=gb-16|0;gb=b;a=v[Cc(b+8|0,v[a>>2])>>2];gb=b+16|0;return a}function hz(a,b){a=a|0;b=b|0;if(b>>>0<=15){return w[v[a+88>>2]+b|0]!=63|0}return 0}function Wd(a){a=a|0;var b=0;b=gb-16|0;gb=b;Qr(b+8|0,a);gb=b+16|0;return v[b+8>>2]}function WP(a,b){var c=0;c=b&15;if(c){t[a+832|0]=c}b=b&240;if(b){t[a+831|0]=b>>>4}}function Si(a,b){a=a|0;b=b|0;if(uc(a)>>>0<=b>>>0){Ox();L()}return v[a>>2]+(b<<1)|0}function Jp(a){var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;HF(c,a);gb=b+16|0;return v[c>>2]}function wF(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=dc(a);Op(v[a>>2],b,v[a+4>>2])}}function vw(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){zn(a)}}function oF(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=dc(a);_l(v[a>>2],b,v[a+4>>2])}}function _n(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+(v[a+16>>2]+c|0)<<1)|0}function YX(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function Uo(a,b){a=hc(a,b,34);u[a+34>>1]=x[b+34>>1];hc(a+36|0,b+36|0,68);return a}function QD(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,20);return a}function $p(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function xY(a){a=a+4|0;return Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function wY(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;Lk(a+8|0,b+8|0)}function tF(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c);Lk(b+12|0,c+12|0);gi(b+32|0,c+32|0)}function rr(a){var b=0;b=gb-16|0;gb=b;a=v[Cc(b+8|0,lC(a))>>2];gb=b+16|0;return a}function rh(a){var b=0;b=gb-16|0;gb=b;a=v[Cc(b+8|0,dc(a))>>2];gb=b+16|0;return a}function iP(a){a=a|0;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;yE(a+9|0);return a|0}function hJ(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;gJ(91496,a,b,0,0);gb=c+16|0}function gs(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function di(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function Xg(a){var b=0;b=gb-16|0;gb=b;a=v[Cc(b+8|0,rh(a))>>2];gb=b+16|0;return a}function Ug(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function Pp(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function Nu(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function Ld(a){var b=0;b=gb-16|0;gb=b;a=v[Cc(b+8|0,Ob(a))>>2];gb=b+16|0;return a}function Er(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function tW(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function mf(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){kb[v[v[b>>2]+4>>2]](b)}}}function g$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[a|0](b,c,d,e,f)}function R3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-16|0;gb=b;zH(a,c,d);gb=b+16|0}function j4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,79685);return}xx(a,c)}function j$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return kb[a|0](b,c,d,e)|0}function h4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,79763);return}xx(a,c)}function fba(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function Vm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function Fu(a,b){return oh(wg((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function $5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return IJ(a-88|0,b,c,d,e)|0}function z6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;wt(b,c,d,z[a+24>>2]);_J(a,b,c,d)}function xB(a){return(+y[a>>2]+ +v[a+4>>2]*4294967296)*2.3283064365386963e-10}function oba(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function nA(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function mo(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function ij(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Zb(b)}function iR(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function iF(a,b){var c=0;c=gb-16|0;gb=c;b=Xi(c+8|0,b);NF(b,a);Bc(b);gb=c+16|0}function cca(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function Xy(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function Xi(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){zn(b)}return a}function Xaa(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function Sba(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function Qaa(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function PF(a,b){var c=0;c=gb-16|0;gb=c;b=Uj(c+8|0,b);NF(b,a);Bc(b);gb=c+16|0}function Kba(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function I6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;iK(b,c,d,z[a+28>>2]);hK(a,b,c,d)}function H6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;wt(b,c,d,z[a+28>>2]);gK(a,b,c,d)}function E6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;wt(b,c,d,z[a+28>>2]);dK(a,b,c,d)}function Dba(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function D6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;iK(b,c,d,z[a+24>>2]);bK(a,b,c,d)}function D$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Kg(a,v[b+8>>2],0)){Vw(b,c,d)}}function C6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;wt(b,c,d,z[a+24>>2]);aK(a,b,c,d)}function vH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function um(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=Mt(b,a);gb=c+16|0;return d?b:a}function uH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function td(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Vb(b,c);Bw(a,b,d,c)}function qk(a){var b=0;b=gb-16|0;gb=b;a=v[pT(b+8|0,a)>>2];gb=b+16|0;return a}function gj(a,b){var c=0;c=a;a=(b>>>0)/100|0;return bt(bt(c,a),b-B(a,100)|0)}function gH(a,b){var c=0,d=0;Ge(a,Bd(b));b=v[dc(b)>>2];c=dc(a),d=b,v[c>>2]=d}function dL(a,b,c,d){v[a+12>>2]=0;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function Ym(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function Uh(a){var b=0;b=gb-16|0;gb=b;a=v[Cc(b+8|0,a)>>2];gb=b+16|0;return a}function Qz(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946300|0:32397)|0}function Qm(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function PH(){a:{if(t[465320]&1){break a}if(!Ud(465320)){break a}Td(465320)}}function Ny(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=Mt(a,b);gb=c+16|0;return d?b:a}function Np(a,b){a=a|0;b=b|0;if((a|0)!=(b|0)){a=NA(a,Ob(b),Bb(b))}return a|0}function MD(a,b,c,d){a=c-b|0;if((a|0)>=1){hc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function Fl(a){var b=0;b=gb-16|0;gb=b;v[b+8>>2]=a;gb=b+16|0;return v[b+8>>2]}function nT(a){if((w[a+14|0]-49&255)>>>0<=3){return!zd(a,26863,14)}return 0}function kT(a,b){uU(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function gz(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function fz(a,b){a=a|0;b=b|0;return(b>>>0<=44?t[v[a+84>>2]+b|0]:63)<<24>>24}function _F(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Di(a,c+8|0,b);gb=c+16|0}function U_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Bn(a,c+8|0,b);gb=c+16|0}function UH(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Tu(a,b,c){var d=0;d=gb-16|0;gb=d;Cc(d+8|0,To(a,b,Fl(c)));gb=d+16|0}function PV(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function Os(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function LY(a,b){a=a|0;b=b|0;a=v[a>>2];return kb[v[v[a>>2]+32>>2]](a,0,b)|0}function Jj(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function ph(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function oe(a,b){a=a|0;b=b|0;if(Ul(a,b)){a=ai(ef(a,b))}else{a=0}return a|0}function kg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function jo(a,b){a=v[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function gR(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;bT(a,c)}function gD(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+28;return a}function f1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Bs()+(b<<2)>>2]}return b|0}function d1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[As()+(b<<2)>>2]}return b|0}function bt(a,b){b=x[(b<<1)+74976>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function Yw(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function Pl(a,b,c){b=b-a|0;if((b|0)>=1){hc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function BF(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+36;return a}function $s(a,b){a=a|0;b=b|0;if((a|0)!=(b|0)){NA(a,Ob(b),Bb(b))}return a|0}function vl(a,b){var c=0;c=gb-16|0;gb=c;Db(c+8|0,a,b);ir(c+8|0);gb=c+16|0}function uV(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function ql(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function kn(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+48>>2]](a,b,c)|0}function jR(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+8;return a}function f$(a,b,c){a=a|0;b=b|0;c=c|0;a=kb[a|0](b,c)|0;ma(jb|0);return a|0}function bl(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+12>>2]](a,b,c)|0}function aF(a){return(v[a+88>>2]&2050)==2?(w[v[a+104>>2]+34|0]&8)>>>3|0:0}function Xda(a,b,c){a=a|0;b=b|0;c=c|0;if(Bb(b)>>>0>c>>>0){lq(b,c)}Dc(a,b)}function W4(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+32>>2]](a,b,c)|0}function Sc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function ME(a,b){var c=0;c=gb-16|0;gb=c;LE(c+8|0,b);Wr(a,c+8|0);gb=c+16|0}function Fq(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+4;return a}function Aca(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function $P(a,b){var c=0;c=gb-16|0;gb=c;Wk(c+8|0,a,b);ir(c+8|0);gb=c+16|0}function yI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ph(a,-1,-1)}function uY(a){return Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function $D(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function wc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Lf(b),v[c+4>>2]=d;return a}function rG(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function id(a,b){PF(a,b);v[a+8>>2]=v[b+8>>2];PF(a+12|0,b+12|0);return a}function fh(a,b,c){return(c|0)>=0?(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0:0}function ed(a){if((a|0)>=-32768){return(a|0)<32767?a:32767}return-32768}function dx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function cS(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function Yx(a){return((hh(a)+(hh(a)<<8)|0)+(hh(a)<<16)|0)+(hh(a)<<24)|0}function WR(a){if(a>>>0<=8){return w[a+29680|0]}return w[a+29671|0]|256}function Tf(a){var b=0;b=a;if(v[b>>2]){Rd(b);sy(v[b>>2],hv(b))}return a}function RJ(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function Me(a,b){Xi(a,b);v[a+8>>2]=v[b+8>>2];Xi(a+12|0,b+12|0);return a}function AV(a){v[a+8>>2]=0;v[a>>2]=0;v[a+4>>2]=40;u[a+12>>1]=0;return a}function xC(a,b){if(b){xC(a,v[b>>2]);xC(a,v[b+4>>2]);Ll(b+16|0);OW(b)}}function to(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function sz(a,b){if(b){sz(a,v[b>>2]);sz(a,v[b+4>>2]);Hb(b+16|0);jO(b)}}function sga(a){a=a|0;Ms(a,1944);v[a>>2]=90556;v[a>>2]=1980;return a|0}function pz(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function pA(a,b,c){a:{if(a<b){break a}b=c;if(b<a){break a}b=a}return b}function jF(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function h5(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){ua();L()}}function bP(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Dm(c);Zb(c)}}}function _k(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function Zn(a,b,c){return v[a>>2]+(B(v[a+4>>2],v[a+12>>2]+c|0)+b<<1)|0}function Tw(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function Ec(a,b){if(Lb(a)>>>0<=b>>>0){Ox();L()}return v[a>>2]+(b<<2)|0}function Ao(a,b,c){a:{if(a<b){break a}b=c;if(b<a){break a}b=a}return b}function tK(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){qK(b,v[dc(a)+4>>2])}}function tE(a,b){if(b>>>0>2147483647){xc(16475);L()}return jc(b<<1,2)}function t$(a){a=a|0;if(!a){return 0}return(Ww(a,91048,91192)|0)!=0|0}function sK(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){IB(b,v[dc(a)+4>>2])}}function qD(a,b){var c=0;c=gb-16|0;gb=c;cc(a,v[b>>2],qc(b));gb=c+16|0}function aP(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function S_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;gG(a,b);gb=c+16|0}function QQ(a){if(a>>>0>357913941){xc(30917);L()}return jc(B(a,12),4)}function OD(a){if(a>>>0>214748364){xc(16609);L()}return jc(B(a,20),4)}function LF(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){IF(b,v[dc(a)+4>>2])}}function It(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;bV(a,b);gb=c+16|0}function GG(a){return(v[a>>2]&-256)==1126902528&v[a+4>>2]==1129074247}function Cj(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function BN(a){if(a>>>0>=82595525){xc(45953);L()}return jc(B(a,52),4)}function vs(a,b,c,d,e){b=Ea(a|0,b|0,c|0,d|0,e|0)|0;jb=O()|0;return b}function tz(a){var b=0;ZS(a);b=v[a>>2];if(b){Ph(v[a+16>>2],b,fk(a))}}function pC(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];Lk(a+8|0,b+8|0)}function l1(a){a=a|0;var b=0;b=v[116404]+1|0;v[116404]=b;v[a+4>>2]=b}function im(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function i$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kb[a|0](b,c,d)|0}function cC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){dc(a);if(b){jv(b)}}}function bz(a,b,c){b=b-a|0;if(b){kh(c,a,b)}return B((b|0)/6|0,6)+c|0}function _1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;cg(a,f)}function UA(a,b){nc(a);Jb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function QF(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Zb(gc(c))}}}function KB(a,b){mc(a,b);mc(a+4|0,b+4|0);mc(wb(a),wb(b));wb(a);wb(b)}function IU(a){if(a>>>0>=1073741824){xc(25639);L()}return jc(a<<2,1)}function HG(a){var b=0;hC(a);b=v[a>>2];if(b){KG(v[a+16>>2],b,fk(a))}}function BW(a){if(a>>>0>715827882){xc(19251);L()}return jc(B(a,6),1)}function wG(a,b,c,d,e,f,g){return La(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function vF(a,b,c){a=a|0;b=b|0;c=c|0;qr(a);v[a>>2]=15820;return a|0}function pN(a){if(a>>>0>1073741823){xc(46078);L()}return jc(a<<2,4)}function om(a){if(a>>>0>1073741823){xc(77913);L()}return jc(a<<2,4)}function oT(a,b,c,d,e){Cc(a,b);Cc(a+4|0,c);Cc(a+8|0,d);Cc(a+12|0,e)}function nK(a){if(a>>>0>=268435456){xc(57827);L()}return jc(a<<4,4)}function hS(a){if(a>>>0>=134217728){xc(28236);L()}return jc(a<<5,4)}function cy(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function XO(a,b){var c=0;c=gb-16|0;gb=c;Jr(c,1,b);Fc(a,c);gb=c+16|0}function Sv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0}function IE(a){if(a>>>0>1073741823){xc(16348);L()}return jc(a<<2,2)}function Gd(a,b,c){if(a>>>0>=b>>>0){return a>>>0>c>>>0?c:a}return b}function Ana(a,b){a=a|0;b=b|0;pj(a,zb(v[b>>2]),zb(v[b>>2])+qc(b)|0)}function yP(a,b){v[a+856>>2]=v[a+856>>2]+b;t[a+853|0]=w[a+853|0]|8}function ll(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Zb(Tf(b))}}}function jT(a,b){FB(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function gB(a){a=a|0;v[a>>2]=1368;gc(a+28|0);gc(a+12|0);return a|0}function dN(a){if(a>>>0>1073741823){xc(2005);L()}return jc(a<<2,4)}function ac(a,b,c){if((a|0)>=(b|0)){return(a|0)>(c|0)?c:a}return b}function a1(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function Wc(a,b,c){a=a|0;b=b|0;c=c|0;return ad(a,B(wi(a),b)+c|0)|0}function OS(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<2)|0}function J6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;mK(a,b,c,d,e)}function G6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;EK(a,b,c,d,e)}function Fia(a,b){a=a|0;b=b|0;if(!v[23048]){v[23049]=b;v[23048]=a}}function CH(a,b,c){a=a|0;b=b|0;c=c|0;return dq(0,a,b,c?c:465344)|0}function xX(a){jb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function wj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function pU(a){a=a+34|0;a=Fpa(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function ni(a,b){var c=0,d=0;c=a,d=sx(v[b>>2]),v[c>>2]=d;return a}function jp(a){a=a|0;return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function hy(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function h_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+12>>2]](a)|0}function g_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+16>>2]](a)|0}function cE(a){if(v[a>>2]){ND(a,v[a>>2]);PD(wb(a),v[a>>2],Vl(a))}}function PJ(a){a=a|0;return+(+v[v[a+32>>2]+1074448>>2]*.00390625)}function oM(a){a=a|0;v[a>>2]=48368;Qc(a+4256|0);nf(a);return a|0}function jd(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function i_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function hu(a){vb(a+48|0);vb(a+36|0);vb(a+24|0);vb(a+12|0);vb(a)}function hR(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function fM(a){a=a|0;v[a>>2]=48976;Qc(a+4208|0);nf(a);return a|0}function aN(a){a=a|0;v[a>>2]=46248;Qc(a+4208|0);nf(a);return a|0}function RP(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Zb(c)}}}function N$(a){a=a|0;var b=0,c=0;b=a,c=Be(),v[b>>2]=c;return a|0}function LM(a){a=a|0;v[a>>2]=46552;gc(a+4208|0);nf(a);return a|0}function Ky(a){a=a|0;v[a>>2]=48108;Qc(a+4260|0);nf(a);return a|0}function Caa(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function BM(a){a=a|0;v[a>>2]=47876;Qc(a+4208|0);nf(a);return a|0}function vx(a,b){a=a|0;b=b|0;return(Lh(a)|0)!=0|(a|32)-97>>>0<6}function vea(a,b){a=a|0;b=b|0;a=RX(a,b);if(!a){zv(b)}return a|0}function tM(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function rE(a){if(!zd(a,16579,25)){return w[a+34|0]<65}return 0}function nx(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+12>>2]](a,b)|0}function m$(a,b){a=a|0;b=b|0;a=kb[a|0](b)|0;ma(jb|0);return a|0}function lf(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function gn(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+28>>2]](a,b)|0}function gga(a,b){a=a|0;b=b|0;a=gW(a,b);if(!a){fW(b)}return a|0}function Zz(a){VX(a);if(v[a>>2]){gY(a);UX(wb(a),v[a>>2],dn(a))}}function Zo(a){ik(a);if(v[a>>2]){wq(a);hw(wb(a),v[a>>2],Ce(a))}}function Yh(a){ik(a);if(v[a>>2]){wq(a);vC(wb(a),v[a>>2],Ce(a))}}function Wz(a){JO(a);if(v[a>>2]){IO(a);Kz(wb(a),v[a>>2],hk(a))}}function Vq(a){wR(a);if(v[a>>2]){mR(a);AA(wb(a),v[a>>2],mg(a))}}function Ss(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+44>>2]](a,b)|0}function Rz(a){uF(a);if(v[a>>2]){SF(a);js(wb(a),v[a>>2],am(a))}}function Pk(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+24>>2]](a)|0}function OR(a,b){b=1/(564505.8718779281/b+1);LR(a,b,0,0,b+-1,0)}function Nt(a){SM(a);if(v[a>>2]){XM(a);RM(wb(a),v[a>>2],nl(a))}}function Nm(a){hT(a);if(v[a>>2]){gT(a);iB(wb(a),v[a>>2],Mi(a))}}function KV(a,b,c,d){Me(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function Hi(a,b,c){a=a|0;b=b|0;c=c|0;return To(Fl(a),Fl(b),c)|0}function Eu(a){ev(a);if(v[a>>2]){kS(a);_l(wb(a),v[a>>2],nh(a))}}function Ek(a){$r(a);if(v[a>>2]){qw(a);UD(wb(a),v[a>>2],Gg(a))}}function CR(a){cq(a);if(v[a>>2]){sR(a);dm(wb(a),v[a>>2],pg(a))}}function zl(a,b){a=t[lc(a+58|0,b)|0];return((a|0)>-1?a:-1)&255}function zh(a){TE(a);if(v[a>>2]){pw(v[a+16>>2],v[a>>2],ow(a))}}function uv(a){a=a|0;a=w[a|0];return ue(a)^1|(a-49&255)>>>0<36}function uC(a,b){var c=0;c=gb-16|0;gb=c;cc(a,b,4896);gb=c+16|0}function tw(a,b){iF(a,b);v[a+8>>2]=v[b+8>>2];iF(a+12|0,b+12|0)}function sL(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function mC(a,b){a=a|0;b=b|0;a=NV(a,b);if(!a){Bk(b)}return a|0}function lt(a){a=a|0;v[a>>2]=10716;vb(a+32|0);nm(a);return a|0}function l$(a,b){a=a|0;b=+b;a=kb[a|0](b)|0;ma(jb|0);return a|0}function dh(a,b){a=a|0;b=b|0;a=fs(a,b);if(!a){Sj(b)}return a|0}function dF(a,b){a=a|0;b=b|0;a=cF(a,b);if(!a){as(b)}return a|0}function bO(a,b){a=a|0;b=b|0;a=aO(a,b);if(!a){jz(b)}return a|0}function Zr(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function Wv(a,b){a=a|0;b=b|0;a=oD(a,b);if(!a){Lr(b)}return a|0}function Wb(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function Ti(a){Uy(a);if(v[a>>2]){hw(v[a+16>>2],v[a>>2],fk(a))}}function TD(a){TE(a);if(v[a>>2]){UD(v[a+16>>2],v[a>>2],ow(a))}}function TB(a,b){a=a|0;b=b|0;a=MX(a,b);if(!a){WC(b)}return a|0}function Rg(a){Uy(a);if(v[a>>2]){Ph(v[a+16>>2],v[a>>2],fk(a))}}function Qf(a,b){return kb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function Lk(a,b){Uj(a,b);v[a+8>>2]=v[b+8>>2];Uj(a+12|0,b+12|0)}function IW(a){Uy(a);if(v[a>>2]){vC(v[a+16>>2],v[a>>2],fk(a))}}function Gp(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function Ew(a,b){a=a|0;b=b|0;a=sF(a,b);if(!a){rF(b)}return a|0}function Dr(a,b){a=a|0;b=b|0;a=NX(a,b);if(!a){XC(b)}return a|0}function zma(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,HI(c,Ob(b),Bb(b)))}function vG(a,b,c){b=Ia(2006,a|0,b|0,c|0)|0;jb=O()|0;return b}function tR(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function r_(a){a=a|0;var b=0;b=gb-16|0;gb=b;hG(a,1);gb=b+16|0}function rO(a){a=a|0;v[a+12>>2]=1065353216;qO(a,4);return a|0}function pe(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function p8(a,b,c){a=a|0;b=b|0;c=c|0;lM(a,0,wk(v[b+24>>2]),c)}function k_(a){a=a|0;var b=0;b=gb-16|0;gb=b;mF(a,1);gb=b+16|0}function ct(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function c$(a,b){a=a|0;b=b|0;Ms(a,b);v[a>>2]=90744;return a|0}function Uda(a,b,c){a=a|0;b=b|0;c=c|0;return pv(a,b,c,1499)|0}function UZ(a,b){a=a|0;b=b|0;Ms(a,b);v[a>>2]=90692;return a|0}function Rn(a,b){if(Bb(a)>>>0<=b>>>0){Sn();L()}return pc(a,b)}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;return pv(a,b,c,1122)|0}function Ou(a,b,c){v[a>>2]=v[b>>2];v[a+4>>2]=v[c>>2];return a}function Hm(a,b,c){u[a>>1]=x[b>>1];v[a+4>>2]=v[c>>2];return a}function HB(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function Gv(a,b){b=w[b|0]|w[b+1|0]<<8;t[a|0]=b;t[a+1|0]=b>>>8}function Fi(a,b){a=a|0;b=b|0;if(Ie(a)>>>0>b>>>0){t[a+16|0]=b}}function A_(a){a=a|0;var b=0;b=gb-16|0;gb=b;IF(a,1);gb=b+16|0}function zc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function xna(a,b,c){a=a|0;b=b|0;c=c|0;return pv(a,b,c,685)|0}function vp(a,b,c){if(!b){return 0}return kt(a,ah(t[c|0]),b)}function hP(a){v[a>>2]=0;nc(a+4|0);Pb(a+16|0,0,144);return a}function fF(a,b){var c=0;c=gb-16|0;gb=c;cc(a,b,36);gb=c+16|0}function TJ(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function Ry(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function Ns(){var a=0;a=aa(4)|0;cm(a);ja(a|0,90496,1937);L()}function Gca(a){a=a|0;a=ek(a);if(a){kb[v[v[a>>2]+96>>2]](a)}}function EW(a,b){var c=0;c=gb-16|0;gb=c;cc(a,b,12);gb=c+16|0}function sE(a,b){var c=0;c=gb-16|0;gb=c;cc(a,b,3);gb=c+16|0}function rn(a,b){var c=0;c=gb-16|0;gb=c;cc(a,b,2);gb=c+16|0}function qY(a,b){var c=0;c=gb-16|0;gb=c;cc(a,b,8);gb=c+16|0}function mB(a,b){if(b){mB(a,v[b>>2]);mB(a,v[b+4>>2]);rT(b)}}function lB(a,b){if(b){lB(a,v[b>>2]);lB(a,v[b+4>>2]);jv(b)}}function iu(a,b){if(b){iu(a,v[b>>2]);iu(a,v[b+4>>2]);jv(b)}}function ii(a,b){var c=0;c=gb-16|0;gb=c;cc(a,b,4);gb=c+16|0}function eC(a,b){if(b){eC(a,v[b>>2]);eC(a,v[b+4>>2]);jv(b)}}function ds(a,b){var c=0;c=gb-16|0;gb=c;cc(a,b,1);gb=c+16|0}function ZT(a){if(v[a>>2]){WT(a,v[a>>2]);Vu(v[a>>2],pg(a))}}function VI(a,b){if(b>>>0<=9){return UI(a,b)}return bt(a,b)}function U0(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function JF(a){var b=0;b=gb-16|0;gb=b;v[b+8>>2]=a;gb=b+16|0}function Aw(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function o8(a){a=a|0;uL(a,2,100);Fi(v[a+24>>2]+484360|0,0)}function me(a,b){a=a|0;b=b|0;_c(a,v[b>>2],v[b>>2]+qc(b)|0)}function lp(a){if((a|0)>=1){return(a|0)<120?a:120}return 1}function jfa(a){a=a|0;Ms(a,32397);v[a>>2]=90636;return a|0}function jB(a){a=a+156|0;return(w[a|0]|w[a+1|0]<<8)==65534}function ir(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function gg(a,b){a=Gpa(v[a>>2],v[a+4>>2],b,b>>31);return a}function gF(a){var b=0;b=gb-16|0;gb=b;Pb(a,0,36);gb=b+16|0}function Wn(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function RK(a){a=a|0;return y[v[a+24>>2]+1074412>>2]/1e4|0}function J4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jb=0;return 0}function EG(a){a=v[a>>2]-12|0;if((Aw(a+8|0)|0)<=-1){Zb(a)}}function Bb(a){if($e(a)){return v[a+4>>2]}return w[a+11|0]}function zp(a,b,c){_c(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function xj(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function ve(a,b,c){_c(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function qv(a){if(v[a>>2]){MW(a);wC(wb(a),v[a>>2],Kj(a))}}function qJ(a){while(1){if((nt(a)|0)!=-1){continue}break}}function pq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function mL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){wL(c)}}function lj(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function kk(a){a=v[a+656>>2];if(!a){return 0}return uj(a)}function fx(a){if(v[a>>2]){Rd(a);KG(Zw(a),v[a>>2],LG(a))}}function by(a,b){return v[((a>>>24^b)<<2)+461072>>2]^a<<8}function bu(a){if(v[a>>2]){wq(a);Ph(wb(a),v[a>>2],Ce(a))}}function _z(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){UN(c)}}function _r(a){if(v[a>>2]){qw(a);pw(wb(a),v[a>>2],Gg(a))}}function Xo(a){var b=0;hC(a);b=v[a>>2];if(b){jC(b,fk(a))}}function VZ(a){a=a|0;OF(a,16172);v[a>>2]=16200;return a|0}function Tx(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function Od(a){if(!v[a+20>>2]){return 0}return v[a>>2]!=0}function Jz(a){var b=0;hC(a);b=v[a>>2];if(b){EO(b,fk(a))}}function GK(a){a=a|0;return Gi(Qb(v[a+24>>2]+484360|0))|0}function Ee(a){if(v[a>>2]){Ph(wb(a),v[a>>2],v[wb(a)>>2])}}function D_(a){a=a|0;OF(a,15328);v[a>>2]=15360;return a|0}function $m(a){if(v[a>>2]){dX(a);Rk(wb(a),v[a>>2],jg(a))}}function zb(a){var b=0;b=gb-16|0;gb=b;gb=b+16|0;return a}function yna(a,b){a=a|0;b=b|0;Tb(a,b?b:19152);return a|0}function xI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ph(a,-1,-1)}function x8(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,HI(c,b,Lf(b)))}function wn(a,b,c){a=Gpa(v[a>>2],v[a+4>>2],b,c);return a}function rK(a){a=a|0;v[a>>2]=58060;gB(a+12|0);return a|0}function pK(a){a=a|0;v[a>>2]=58204;eB(a+12|0);return a|0}function nF(a){a=a|0;v[a>>2]=15916;uw(a+12|0);return a|0}function mv(a){Zo(a+88|0);Zo(a+68|0);Zo(a+48|0);return a}function mba(a){a=a|0;cM(a);t[a+4202|0]=1;v[a+4224>>2]=0}function jj(a){return Pe(a)|Pe(a)<<8|Pe(a)<<16|Pe(a)<<24}function cK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;BK(a,b,c,d)}function Zoa(a,b,c){a=a|0;b=b|0;c=c|0;return tD(a,b,c)|0}function Z5(a,b,c){a=a|0;b=b|0;c=c|0;return Ad(B(b,c))|0}function YG(a,b){zn(v[b>>2]);yn(v[a>>2]);v[a>>2]=v[b>>2]}function Xe(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;uf(a,c,d,b)}function QG(a){a=a|0;v[a>>2]=84488;vb(a+12|0);return a|0}function PG(a){a=a|0;v[a>>2]=84528;vb(a+16|0);return a|0}function KC(a){a=a|0;if(!w[a|0]){return 1}return ne(a)|0}function HA(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function G_(a,b,c){a=a|0;b=b|0;c=c|0;Bw(a,b,v[b+8>>2],c)}function Bk(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function ys(a){a=a|0;v[a>>2]=90536;EG(a+4|0);return a|0}function uw(a){a=a|0;v[a>>2]=16044;Bc(a+4|0);return a|0}function tv(a,b,c){a=a|0;b=b|0;c=c|0;return kt(a,b,c)|0}function oj(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){wL(b)}}function oP(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){UN(b)}}function nm(a){a=a|0;v[a>>2]=77992;Xb(a+4|0);return a|0}function m4(a,b){a=a|0;b=b|0;return UF(a,Ob(b),Bb(b))|0}function lD(a,b,c){a=a|0;b=b|0;c=c|0;return BY(a,b,c)|0}function gf(a,b,c){a=a|0;b=b|0;c=c|0;je(a,b);return a|0}function eq(a){a=a|0;v[a>>2]=78056;Xb(a+4|0);return a|0}function _L(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function _G(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){yn(b)}}function Xw(a){a=a|0;v[a>>2]=90516;EG(a+4|0);return a|0}function To(a,b,c){b=b-a|0;if(b){kh(c,a,b)}return b+c|0}function Nc(a){if($e(a)){a=Sk(a)-1|0}else{a=10}return a}function Hs(a,b,c){return $G(Ob(a),Bb(a),Ob(b),c,Bb(b))}function HD(a){if(w[a+1|0]==2){return w[a|0]<3}return 0}function HC(a,b,c){a=a|0;b=b|0;c=c|0;return vD(a,b,c)|0}function GH(a){return(a|0)!=0&(a|0)!=75744&(a|0)!=75768}function Ft(a){a=a|0;v[a>>2]=57732;Ht(a+4|0);return a|0}function FR(a,b,c){a=a|0;b=b|0;c=c|0;return xu(a,b,c)|0}function CJ(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function BH(a,b,c,d){a=QI(a,b,c,0,-2147483648);return a}function $L(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function tI(a){a=a|0;return Ws(v[v[a>>2]-12>>2]+a|0)|0}function sw(a,b){a=Fpa(v[a>>2],v[a+4>>2],b,0);return a}function rM(a){a=a|0;return vj(C(z[a+4224>>2]*C(4)))|0}function q_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Gj(a,d,0)}function m2(a,b){a=a|0;b=b|0;_c(a,jI(v[b>>2]),v[b>>2])}function lga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function iI(a){a=a|0;return Us(v[v[a>>2]-12>>2]+a|0)|0}function hh(a){var b=0;b=nt(a);v[a+1396>>2]=0;return b}function gq(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function gca(a,b,c){a=a|0;b=b|0;c=c|0;_d(a,b+4228|0,7)}function eB(a){a=a|0;v[a>>2]=1420;gc(a+4|0);return a|0}function a4(a){a=a|0;return ag(v[v[a>>2]-12>>2]+a|0)|0}function _ca(a,b,c){a=a|0;b=b|0;c=c|0;_d(a,b+4260|0,8)}function _R(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;MA(a)}function _P(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function Zs(a){if($e(a)){a=Sk(a)-1|0}else{a=1}return a}function Yj(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function WK(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function U3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pj(a,c,d)}function S5(a){a=a|0;return nq(v[v[a>>2]-12>>2]+a|0)|0}function Qq(a,b){v[a>>2]=b;v[a+4>>2]=b+225280;return a}function Mg(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+20>>2]](a,b)}function Jh(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+24>>2]](a,b)}function Ih(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+28>>2]](a,b)}function vb(a){if($e(a)){Rk(a,v[a>>2],Sk(a))}return a}function uf(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function tj(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function ro(a){a=a|0;return kb[v[v[a>>2]+24>>2]](a)|0}function rf(a,b,c){a=a|0;b=b|0;c=c|0;Qo(a);return a|0}function qs(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function qq(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}
function pD(a){var b=0;b=gb-16|0;gb=b;Dk(a);gb=b+16|0}function eoa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function dj(a){a=a|0;return kb[v[v[a>>2]+12>>2]](a)|0}function cj(a){a=a|0;return kb[v[v[a>>2]+16>>2]](a)|0}function Wba(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function Ul(a,b){a=a|0;b=b|0;return Te(a)>>>0>b>>>0|0}function Pc(a){if($e(a)){Ph(a,v[a>>2],Sk(a))}return a}function Nca(a){a=a|0;t[a+4202|0]=1;Ot(a);Oy(a);PM(a)}function Jn(a,b){return kb[v[v[a>>2]+36>>2]](a,b,0)|0}function In(a,b){return kb[v[v[a>>2]+52>>2]](a,b,0)|0}function FK(a){a=a|0;return uq(v[a+24>>2]+484344|0)|0}function Ci(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function tba(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function sM(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function qP(a){if(v[a>>2]){Rd(a);nP(v[a>>2],mg(a))}}
function on(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function _v(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function Sda(a,b){a=a|0;b=b|0;a=a+24|0;MN(a,b);Lz(a)}function SK(a){a=a|0;return v[v[a+24>>2]+1074408>>2]}function NK(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function Ip(a){a=a|0;a=a+12|0;kb[v[v[a>>2]>>2]](a)|0}function Epa(a){if(a){return 31-E(a-1^a)|0}return 32}function C8(a){a=a|0;a=v[a+4>>2];return(a?a:56292)|0}function zo(a){a=a|0;return nu(w[a+3|0],w[a+5|0])|0}function tB(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function sl(a){if(v[a>>2]){Rd(a);EO(v[a>>2],Ce(a))}}function pF(a,b,c){Xi(a,b);v[a+8>>2]=0;Xi(a+12|0,c)}function lo(a,b,c){if(!c){return 0}return zd(a,b,c)}function kq(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function kl(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function gX(a){a=a|0;return ez(w[a+3|0],w[a+5|0])|0}function g5(a,b){a=a|0;b=b|0;return UF(a,b,Lf(b))|0}function dt(a){if(!a){return 0}v[115529]=a;return-1}function dha(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,Hu(b,c))}function d6(a,b,c){a=a|0;b=b|0;c=c|0;MJ(a-88|0,b,c)}function bq(a,b){b=v[b>>2];v[a>>2]=b;zn(b);return a}function b6(a,b,c){a=a|0;b=b|0;c=c|0;KJ(a-88|0,b,c)}function ap(a){if(v[a>>2]){Rd(a);mW(v[a>>2],kW(a))}}function ao(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function _d(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function Zc(a,b){a=a|0;b=b|0;return NA(a,b,Lf(b))|0}function ZQ(a){if(v[a>>2]){Rd(a);TQ(v[a>>2],tA(a))}}function Yda(a,b){a=a|0;b=b|0;$s(a+36|0,b);return 1}function Vh(a){if(v[a>>2]){Rd(a);jC(v[a>>2],Ce(a))}}function VT(a){if(v[a>>2]){Rd(a);Vu(v[a>>2],pg(a))}}function VK(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function Uu(a){if(v[a>>2]){Rd(a);sB(v[a>>2],nh(a))}}function Su(a){if(v[a>>2]){Rd(a);pB(v[a>>2],qB(a))}}function Ru(a){if(v[a>>2]){Rd(a);rB(v[a>>2],hi(a))}}function Rea(a){a=a|0;Dm(92224);qA(92216);vb(92204)}function Pq(a){a=a|0;return nu(w[a+2|0],w[a+4|0])|0}function Ok(a,b){Me(a,b);Pb(a+20|0,0,1040);return a}function MR(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function MK(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function Hv(a){if(v[a>>2]){Rd(a);tY(v[a>>2],Gg(a))}}function Hu(a,b){a=a|0;b=b|0;return Ep(a,b,Lf(b))|0}function Db(a,b,c){_c(a,(c>>>3&536870908)+b|0,1<<c)}function Cd(a){if(v[a>>2]){yY(a);hD(v[a>>2],Mi(a))}}function Bd(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function An(a){if(v[a>>2]){Rd(a);qF(v[a>>2],mg(a))}}function zm(a){rj(a+724|0);rj(a+732|0);rj(a+740|0)}function yj(a){a=a+158|0;return w[a|0]|w[a+1|0]<<8}function g6(a,b,c){a=a|0;b=b|0;c=+c;OJ(a-88|0,b,c)}function eu(a){v[a>>2]=32964;v[a>>2]=1064;return a}function ep(a){return(v[a+480180>>2]&740327453)!=0}function c6(a,b){a=a|0;b=b|0;return LJ(a-88|0,b)|0}function a6(a,b){a=a|0;b=b|0;return JJ(a-88|0,b)|0}function _t(a){a=a|0;Ah(a);v[a+20>>2]=0;return a|0}function Xh(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function WB(a,b,c){_d(a,v[b+28>>2]+(c<<12)|0,4096)}function VP(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function Qt(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,SG(b,c))}function PC(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function Ml(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function Do(a){a=a+168|0;return w[a|0]|w[a+1|0]<<8}function Bl(a){a=a+170|0;return w[a|0]|w[a+1|0]<<8}function zk(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,12,b)}function yoa(a,b){a=a|0;b=b|0;if(!NX(a,b)){XC(b)}}function yh(a,b){if($e(a)){Ae(a,b);return}Gf(a,b)}function yU(a){return(v[wb(a)>>2]-v[a>>2]|0)/56|0}function xma(a,b){a=a|0;b=b|0;if(!cF(a,b)){as(b)}}function wea(a,b){a=a|0;b=b|0;if(!aO(a,b)){jz(b)}}function vY(a){return(v[bc(a)>>2]-v[a>>2]|0)/28|0}function sW(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,16,b)}function pg(a){return(v[wb(a)>>2]-v[a>>2]|0)/12|0}function ng(a,b){return $G(Ob(a),Bb(a),b,0,Lf(b))}function kW(a){return(v[wb(a)>>2]-v[a>>2]|0)/33|0}function hv(a){return(v[wb(a)>>2]-v[a>>2]|0)/24|0}function hk(a){return(v[wb(a)>>2]-v[a>>2]|0)/52|0}function dn(a){return(v[wb(a)>>2]-v[a>>2]|0)/48|0}function df(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,32,b)}function am(a){return(v[wb(a)>>2]-v[a>>2]|0)/36|0}function _p(a){return(v[bc(a)>>2]-v[a>>2]|0)/12|0}function _c(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function _I(a,b){if(!a){return 0}return gl(a,b,0)}function Yoa(a,b){a=a|0;b=b|0;if(!RX(a,b)){zv(b)}}function Vma(a,b){a=a|0;b=b|0;if(!CF(a,b)){xw(b)}}function Vl(a){return(v[wb(a)>>2]-v[a>>2]|0)/20|0}function Sma(a,b){a=a|0;b=b|0;if(!gW(a,b)){fW(b)}}function OC(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,40,b)}function Mv(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,30,b)}function Mj(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,20,b)}function Mi(a){return(v[wb(a)>>2]-v[a>>2]|0)/28|0}function Ke(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function Jr(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,64,b)}function Ima(a,b){a=a|0;b=b|0;if(!hW(a,b)){Vm(b)}}function Im(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function Fla(a,b){a=a|0;b=b|0;if(!oD(a,b)){Lr(b)}}function Fk(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,22,b)}function Cp(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,26,b)}function Cb(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function Ak(a,b,c){a=a|0;b=b|0;c=c|0;uf(a,c,28,b)}function AH(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function zi(a){return v[a+8>>2]!=0|v[a+12>>2]!=0}function yA(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function xja(a){a=a|0;a=gb-a&-16;gb=a;return a|0}function vba(a){a=a|0;return z[a+4212>>2]<C(1)|0}function uK(a,b,c){a=Xd(a);v[a+4>>2]=c;v[a>>2]=b}function ty(a,b){v[a>>2]=v[b>>2];Dc(a+4|0,b+4|0)}function tr(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function tA(a){return(v[wb(a)>>2]-v[a>>2]|0)/7|0}function rY(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function py(a,b,c){return OS(a,b,v[a+16>>2]+c|0)}function oC(a,b){a=a|0;b=b|0;if(!WV(a,b)){kC(b)}}function mz(a){return B(yj(a),Bl(a))+7>>>3&65535}function my(a,b,c){return xj(a,b,v[a+12>>2]+c|0)}function l3(a,b){a=a|0;b=b|0;return kb[b|0](a)|0}function jY(a,b){a=_X(a,b);if(!a){_C(b)}return a}function gZ(a,b){a=a|0;b=b|0;if(!xD(a,b)){Pv(b)}}function f6(a,b){a=a|0;b=b|0;return+NJ(a-88|0,b)}function ei(a){return(Pf(a)|0)!=(0-Pf(a+12|0)|0)}function Yba(a){a=a|0;return z[a+4220>>2]<C(1)|0}function XW(a,b){a=a|0;b=b|0;return Vt(a,b,32)|0}function Roa(a,b,c){a=a|0;b=b|0;c=c|0;hc(b,c,48)}function RN(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function PX(a,b){a=a|0;b=b|0;if(!MX(a,b)){WC(b)}}function Oc(a,b,c){a=a|0;b=b|0;c=c|0;ZE(c);Zb(a)}function Ob(a){if($e(a)){return v[a>>2]}return a}function MA(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function Kj(a){return(v[wb(a)>>2]-v[a>>2]|0)/6|0}function Kda(a,b){a=a|0;b=b|0;jE(a,b);return a|0}function GS(a,b){Cc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function Fr(a,b){a=a|0;b=b|0;if(!fs(a,b)){Sj(b)}}function FD(a,b){a=a|0;b=b|0;if(!AD(a,b)){Sv(b)}}function ED(a,b){a=a|0;b=b|0;if(!sF(a,b)){rF(b)}}function DR(a){return(v[a+4>>2]-v[a>>2]|0)/880|0}function Al(a){a=a|0;ar(v[a+20>>2]);v[a+20>>2]=0}function xh(a,b){a=a|0;b=b|0;return Gk(a,b,4)|0}function vK(a,b){v[a+4>>2]=1;v[a>>2]=b;return a}function qx(a,b,c,d){a=QI(a,b,c,-1,-1);return a}function nv(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function hr(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function fl(a){a=a|0;return qI(v[a>>2])<<24>>24}function cn(a,b,c){v[a>>2]=b;v[a+4>>2]=(c<<1)+b}function cf(a){return(v[a+4>>2]-v[a>>2]|0)/20|0}function cba(a){a=a|0;aM(a);Iy(a);t[a+4202|0]=1}function bo(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function Xk(a){return kb[v[v[a>>2]+36>>2]](a)|0}function Tq(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function Sm(a,b,c){b=b-a|0;if(b){kh(c-b|0,a,b)}}function SU(a,b){a=a|0;b=b|0;return Gk(a,b,8)|0}function Qba(a){a=a|0;t[a+4202|0]=1;pM(a);qM(a)}function Pr(a,b){a=a|0;b=b|0;return Gk(a,b,7)|0}function On(a){return kb[v[v[a>>2]+28>>2]](a)|0}function Of(a,b){a=a|0;b=b|0;return Wc(a,b,0)|0}function Nf(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function Mk(a){return(v[a+4>>2]-v[a>>2]|0)/36|0}function Lj(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function Jm(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Je(a){return(v[a+4>>2]-v[a>>2]|0)/28|0}function Iba(a){a=a|0;t[a+4202|0]=1;kM(a);jM(a)}function I7(a,b){a=a|0;b=b|0;Ai(a,zB(wf(12),b))}function HV(a){var b=0;b=v[a>>2];Se(a);return b}function Gna(a,b,c){a=a|0;b=b|0;c=c|0;aG(a,b,c)}function Gc(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function Du(a,b){a=a|0;b=b|0;cg(a,b);return a|0}function zg(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function xf(a,b,c){if(!(w[a|0]&32)){UC(b,c,a)}}function xA(a){return(v[a+4>>2]-v[a>>2]|0)/7|0}function wi(a){a=a|0;return x[no(a)+480188>>1]}function p4(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,c,b)}function jl(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function h8(a,b){a=a|0;b=b|0;Dc(a,Hu(b,57590))}function cc(a,b,c){a=a|0;b=b|0;c=c|0;_d(a,b,c)}function bS(a,b){YR(v[a>>2],b);YR(v[a+4>>2],b)}function Zm(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function Wt(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function TR(a){IA(a);Pb(a+27|0,0,255);return a}function SC(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function Kp(a){KF(a);v[a+8>>2]=0;v[a>>2]=79600}function Ij(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function El(a,b){return(B(b,104)+a|0)+484380|0}function Dn(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,b,c)}function Bu(a){return(a>>>0<9?a:a-9|256)&65535}function xea(a){a=a|0;return Gk(a,44813,15)|0}function vW(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function uj(a){return(w[a+31|0]-1&255)>>>0<17}function tc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function sI(a){a=a|0;Gx(v[v[a>>2]-12>>2]+a|0)}function og(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function nl(a){return v[wb(a)>>2]-v[a>>2]>>11}function lm(a,b){a=a|0;b=b|0;return mI(a,b)^1}function hI(a){a=a|0;Cx(v[v[a>>2]-12>>2]+a|0)}function dH(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function ci(a,b){a=a|0;b=b|0;return gw(a,b)|0}function bka(a){a=a|0;lU(a);return v[a+16>>2]}function bY(a){t[a+12|0]=w[a+12|0]|2;return a}function al(a,b){a=a|0;b=b|0;return mI(a,b)|0}function aQ(a,b){if(!(z[a>>2]<=b)){z[a>>2]=b}}function _j(a,b){a=a|0;b=b|0;return rI(a,b)^1}function _h(a,b){a=a|0;b=b|0;return vX(a,b)|0}function Zj(a,b){a=a|0;b=b|0;return rI(a,b)|0}function Xf(a,b){a=a|0;b=b|0;return Nl(a,b)|0}function Xd(a){v[a>>2]=0;v[a+4>>2]=0;return a}function X3(a){a=a|0;NH(v[v[a>>2]-12>>2]+a|0)}function R5(a){a=a|0;uJ(v[v[a>>2]-12>>2]+a|0)}function QP(a){qP(a+20|0);pP(a+8|0);oP(a+4|0)}function Nl(a,b){a=a|0;b=b|0;return Ck(a,b)^1}function Jw(a,b){a=a|0;b=b|0;return Hu(a,b)|0}function Ipa(a,b,c,d){a=Dpa(a,b,c,d);return a}function Hl(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function Eo(a,b){a=a|0;b=b|0;return Id(a,b)|0}function Cy(a){a=a|0;v[a>>2]=56740;return a|0}function Cu(a,b){a=a|0;b=b|0;return SG(a,b)|0}function AX(a,b){a=a|0;b=b|0;_c(a,b,b- -64|0)}function wL(a){if(a){kb[v[v[a>>2]+4>>2]](a)}}function uba(a){a=a|0;return C(z[a+4220>>2])}function tu(a,b,c){a=a|0;b=b|0;c=c|0;wY(b,c)}function rA(a,b,c){a=a|0;b=b|0;c=c|0;qL(a,c)}function qB(a){return v[wb(a)>>2]-v[a>>2]>>8}function ow(a){return v[bc(a)>>2]-v[a>>2]>>1}function oB(a){return v[bc(a)>>2]-v[a>>2]>>5}function nh(a){return v[wb(a)>>2]-v[a>>2]>>5}function mg(a){return v[wb(a)>>2]-v[a>>2]>>3}function ig(a){return v[v[a+8>>2]>>2]==(a|0)}function hi(a){return v[wb(a)>>2]-v[a>>2]>>4}function fk(a){return v[bc(a)>>2]-v[a>>2]>>2}function cka(a){a=a|0;lU(a);return v[a+4>>2]}function Zna(a){a=a|0;return Gk(a,18106,3)|0}function ZU(a){return v[bc(a)>>2]-v[a>>2]>>3}function Xba(a){a=a|0;return C(z[a+4212>>2])}function Sy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function RC(a,b,c){a=a|0;b=b|0;c=c|0;Me(b,c)}function QK(a){a=a|0;return PK(v[a+24>>2])|0}function Po(a){a=a|0;dB(a+288|0);er(a+800|0)}function Mla(a){a=a|0;return Gk(a,24887,2)|0}function MF(a,b){a=a|0;b=b|0;return(b|0)<6|0}function Kw(a){return v[bc(a)>>2]-v[a>>2]>>4}function Jy(a){return C(C(a*C(7900))+C(100))}function I5(a){a=a|0;return Da(v[a+60>>2])|0}function Gn(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c)}function Gg(a){return v[wb(a)>>2]-v[a>>2]>>1}function Fja(a){a=a|0;return Gk(a,26605,6)|0}function Di(a,b,c){a=a|0;b=b|0;c=c|0;Fo(a,c)}function Ce(a){return v[wb(a)>>2]-v[a>>2]>>2}function xM(a){a=a|0;kb[v[v[a>>2]+4>>2]](a)}function xF(a,b){a=a|0;b=b|0;return Tj(b)|0}function wca(a,b,c){a=a|0;b=b|0;c=c|0;Xd(a)}function w5(a,b){a=a|0;b=b|0;return om(b)|0}function vi(a,b){a=a|0;b=b|0;return C(C(0))}function vM(a){a=a|0;return C(z[a+4208>>2])}function u_(a,b){a=a|0;b=b|0;yF(Pb(b,0,36))}function rt(a){EJ(a);v[a>>2]=78500;return a}function jm(a){a=a|0;jI(v[a>>2]);return a|0}function jg(a){return v[wb(a)>>2]-v[a>>2]|0}function gr(a){return nr(v[a>>2],v[a+4>>2])}function el(a){a=a|0;Fx(v[a>>2]);return a|0}function aS(a,b){u[a+22>>1]=b&7;MA(a);OA(a)}function YH(a){EJ(a);v[a>>2]=78572;return a}function Xca(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function Vo(a,b){return v[a>>2]<v[b>>2]?b:a}function RO(a){return a>>>0<=255&a>>>0>=251}function Pf(a){return v[a+4>>2]-v[a>>2]>>11}function NL(a){return Bi(C(QL(a)*C(32768)))}function LG(a){return v[a+16>>2]-v[a>>2]>>2}function H5(a,b){a=a|0;b=b|0;return Lh(a)|0}function Af(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function $t(a,b,c){b=b-a|0;if(b){kh(c,a,b)}}function zx(a){a=a|0;return Hh(a,465636)|0}function zf(a){return v[a+4>>2]-v[a>>2]>>3}function z_(a){a=a|0;return v[a+4>>2]!=0|0}function yx(a){a=a|0;return Hh(a,465644)|0}function y6(a,b){a=a|0;b=b|0;YQ(v[a>>2],b)}function xm(a){vb(a+36|0);Qc(a+24|0);_m(a)}function ww(a){os(a+32|0);yb(a+12|0);vb(a)}function vpa(a,b){a=a|0;b=b|0;Np(a+12|0,b)}function vf(a){return v[a+4>>2]-v[a>>2]>>4}function uc(a){return v[a+4>>2]-v[a>>2]>>1}function sp(a,b){return v[a>>2]-v[b>>2]>>1}function px(a){a=a|0;return Hh(a,465668)|0}function nD(a){a=a|0;return Hh(a,465628)|0}function lv(a,b){return v[a>>2]-v[b>>2]>>2}function kx(a){a=a|0;return Hh(a,465676)|0}function hp(a,b){a=a|0;b=b|0;return b-a>>1}function e5(a){a=a|0;return Hh(a,465440)|0}function Zk(a,b){kb[v[v[b>>2]+44>>2]](a,b)}function Yu(a){Ee(a+24|0);gc(a+12|0);gc(a)}function Yk(a,b){kb[v[v[b>>2]+32>>2]](a,b)}function Wg(a){return v[a+4>>2]-v[a>>2]>>8}function UL(a){return C(C(a*C(96))+C(-96))}function TK(a){a=a|0;return+WO(v[a+24>>2])}function T4(a){a=a|0;return Hh(a,465456)|0}function Sk(a){return v[a+8>>2]&2147483647}function O_(a,b){a=a|0;b=b|0;aG(a,b,11304)}function Nda(a,b){a=a|0;b=b|0;cg(a,b+36|0)}function Lb(a){return v[a+4>>2]-v[a>>2]>>2}function KT(a,b){return v[a>>2]+B(b,880)|0}function Ie(a){return v[a+4>>2]-v[a>>2]>>5}function Dx(a){a=a|0;return Hh(a,465620)|0}function DH(){return(v[v[22953]>>2]?4:1)|0}function Cs(a,b){kb[v[v[b>>2]+40>>2]](a,b)}function Bt(a){return(a|0)<=65535&(a|0)>=0}function $ea(a,b){a=a|0;b=b|0;Np(a+40|0,b)}function $R(a,b){t[a+21|0]=b&3;MA(a);OA(a)}function y0(a,b){a=a|0;b=b|0;cg(a,b+16|0)}function vn(a,b){return v[a>>2]+(b<<11)|0}function sf(a){v[a>>2]=v[a>>2]+2;return a}function qc(a){return v[a+4>>2]-v[a>>2]|0}function qW(a,b){return v[a>>2]+B(b,33)|0}function pja(a){a=a|0;return Gp(a+20|0)|0}function p6(a,b){a=a|0;b=b|0;WJ(a-88|0,b)}function o6(a,b){a=a|0;b=b|0;VJ(a-88|0,b)}function no(a){return v[v[a+48>>2]+12>>2]}function ly(a){a=a|0;Ct(a+8|0);return a|0}function lS(a){v[a>>2]=v[a>>2]-2;return a}function km(a){a=a|0;return lI(v[a>>2])|0}function hca(a){a=a|0;t[a+4202|0]=1;CM(a)}function hO(a,b){Im(a,A[b>>3],-A[b+8>>3])}function fK(a,b){return Jpa(a,(b|0)%32|0)}function ef(a,b){return v[a>>2]+B(b,52)|0}function dy(a){a=a|0;if(a){vJ(a);he(a,a)}}function aba(a){a=a|0;return v[a+4260>>2]}function _E(a){return(w[a+24|0]&16)>>>4|0}function _5(a,b){a=a|0;b=b|0;HJ(a-88|0,b)}function Zt(a,b){return v[a>>2]+B(b,28)|0}function Zh(a){return x[a+480190>>1]<3999}function Ws(a){a=a|0;gh(a+8|0);return a|0}function Us(a){a=a|0;gh(a+4|0);return a|0}function UI(a,b){t[a|0]=b+48;return a+1|0}function TL(a){a=a|0;Pb(a+4296|0,0,81928)}function Sd(a,b){v[a>>2]=v[b>>2];return a}function SG(a,b){return Ep(a,Ob(b),Bb(b))}function Qg(a){v[a>>2]=v[a>>2]+4;return a}function Pm(a,b){return v[a>>2]+B(b,56)|0}function Il(a,b){return v[a>>2]+B(b,24)|0}function Id(a,b){return v[a>>2]+B(b,12)|0}function Ic(a,b){a=a|0;b=b|0;bq(a,b+28|0)}function Hk(a,b){return v[a>>2]-v[b>>2]|0}function En(a,b,c){pj(a,b,b+c|0);return a}function Dg(a,b){return v[a>>2]+B(b,20)|0}function DK(a,b){a=a|0;b=b|0;cg(a,b+12|0)}function x0(a,b){a=a|0;b=b|0;Tb(a,84560)}function w0(a,b){a=a|0;b=b|0;ax(a,84568)}function vh(a,b){return v[a>>2]+(b<<5)|0}function v0(a,b){a=a|0;b=b|0;Tb(a,84588)}function u6(a){a=a|0;return ly(a-88|0)|0}function u0(a,b){a=a|0;b=b|0;ax(a,84596)}function tg(a){a=a|0;return PP(w[a|0])|0}function sc(a,b){return v[a>>2]+(b<<1)|0}function rj(a){u[a+4>>1]=65535;v[a>>2]=0}function qe(a,b){return v[a>>2]+(b<<3)|0}function pm(a){return(a|0)==32|a-9>>>0<5}function ne(a){a=a|0;return ue(w[a|0])|0}function n6(a,b){a=a|0;b=+b;UJ(a-88|0,b)}function lL(a){return(Ob(a)+Bb(a)|0)-1|0}function l6(a,b){a=a|0;b=+b;SJ(a-88|0,b)}function i6(a,b){a=a|0;b=+b;QJ(a-88|0,b)}function et(a,b){v[a+24>>2]=v[a+24>>2]+b}function ch(a,b){v[a+8>>2]=b|-2147483648}function cd(a){return v[a>>2]==v[a+4>>2]}function ad(a,b){return v[a>>2]+B(b,6)|0}function _b(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function Wi(a){return B(Vi(a),ld(a))&255}function Wca(a){a=a|0;return w[a+4201|0]}function Vca(a){a=a|0;return w[a+4202|0]}function Tc(a,b){return v[a>>2]+(b<<4)|0}function Sf(a){a=a|0;return!v[a+16>>2]|0}function Qma(a,b){a=a|0;b=b|0;Vt(a,b,17)}function NF(a,b){mc(a,b);mc(a+4|0,b+4|0)}function Mb(a,b){return v[a>>2]+(b<<2)|0}function Kl(a){a=a|0;return v[a>>2]+14|0}function KF(a){v[a+4>>2]=0;v[a>>2]=79544}function IM(a){return(w[a+24|0]&8)>>>3|0}function Gaa(a){a=a|0;return(a|0)==277|0}function Fb(a,b){return v[a>>2]!=v[b>>2]}function Cl(a,b){return v[a>>2]+(b<<8)|0}function Ck(a,b){return v[a>>2]==v[b>>2]}function un(a,b){return x[a>>1]<x[b>>1]}function qga(a,b){a=a|0;b=b|0;Vq(b+8|0)}function pi(a,b,c){Dc(a,b);Dc(a+12|0,c)}function pI(a){v[a+4>>2]=v[a+4>>2]|8192}function oY(a,b){a=a|0;b=b|0;return b|0}function nX(a,b){v[a>>2]=v[a>>2]+B(b,6)}function nS(a,b){v[a>>2]=v[a>>2]+(b<<1)}function kH(a,b){a=a|0;b=b|0;$g(a,1,45)}function jH(a,b){a=a|0;b=b|0;AI(a,1,45)}function iC(a,b){cc(a,v[b>>2],Lb(b)<<2)}function he(a,b){if(!v[a+80>>2]){Zb(b)}}function ar(a){a=a|0;if(a){Zb(a+-64|0)}}function aZ(a,b){a=a|0;b=b|0;Vt(a,b,11)}function Ye(a,b){a=a|0;b=b|0;_c(a,b,32)}function Xma(a,b){a=a|0;b=b|0;sD(a,b,8)}function QV(a,b){v[a>>2]=v[a>>2]+(b<<2)}function Ov(a,b,c){if(b){Pb(a,ah(c),b)}}function Nd(a,b){return y[a>>2]<y[b>>2]}function Naa(a){a=a|0;return-2013527448}function Mt(a,b){return z[a>>2]<z[b>>2]}function MP(a,b){return(zl(a,b)|0)!=255}function Iu(a,b){return v[a>>2]<v[b>>2]}function Ib(a){return(a<<8|a>>>8)&65535}function Aj(a,b){return u[a>>1]<u[b>>1]}function z5(a){a=a|0;return v[a+16>>2]}function wba(a){a=a|0;return-271958638}function wK(a){return a?(a|0)==2?3:2:1}function vja(a){a=a|0;return w[a+40|0]}function ue(a){return(a-1&255)>>>0<120}function uS(a,b){v[a+4>>2]=b;v[a>>2]=b}function sH(a,b,c){je(a,b);je(a+4|0,c)}function ps(a){Mk(a);SF(a);am(a);Mk(a)}function oh(a){a=+a;return lr(fe(a))|0}function m6(a){a=a|0;return+TJ(a-88|0)}function lq(a,b){a=a|0;b=b|0;II(a,b,0)}function ld(a){return w[a+34|0]&64?2:1}function lba(a){a=a|0;return-620920304}function jn(a,b){a=a|0;b=b|0;cc(a,b,7)}function j6(a){a=a|0;return+RJ(a-88|0)}function h6(a){a=a|0;return+PJ(a-88|0)}function fZ(a){a=a|0;return v[a+12>>2]}function ck(a,b){return Ob(a)+(b<<2)|0}function bba(a){a=a|0;return-275227023}function Zba(a){a=a|0;return-270114148}function Yr(a){a=a|0;return 2147483647}function Uaa(a){a=a|0;return 302837129}function RY(a){a=a|0;return v[a+24>>2]}function Pba(a){a=a|0;return-285139079}function Oi(a){return B(v[a>>2],Wi(a))}function OF(a,b){LH(a,b);v[a>>2]=90796}function Hba(a){a=a|0;return-284078960}function HE(a){wb(a);return 2147483647}function G7(a){a=a|0;return+A[a+16>>3]}function Eaa(a,b){a=a|0;b=b|0;return 3}function Daa(a,b){a=a|0;b=b|0;return 2}function Bca(a){a=a|0;return 542066252}function Aba(a){a=a|0;return-281111764}function $ia(a){a=a|0;XS(a);return a|0}function $c(a){v[v[a+8>>2]>>2]=v[a>>2]}function zt(a){a=a|0;return v[a+4>>2]}function zj(a,b){return t[a|0]<t[b|0]}function z4(a){a=a|0;return SH(a,1)|0}function wx(a){a=a|0;ys(a);return a|0}function wk(a){return v[a+1300404>>2]}function vr(a){a=a|0;return Nb(a,1)^1}function tx(a){a=a|0;if(GH(a)){Zb(a)}}function sca(a,b){a=a|0;b=b|0;Du(a,b)}function rI(a,b){return cI(a)^cI(b)^1}function pG(a,b){return w[a|0]<w[b|0]}function mI(a,b){return bI(a)^bI(b)^1}function lw(a){return w[a+21|0]>>>7|0}function ls(a,b){a=a|0;b=b|0;return 1}function ky(a){a=a|0;return v[a+8>>2]}function kp(a,b){u[a+8>>1]=b;return a}function gh(a){a=a|0;Hx(a);return a|0}function eI(a){a=a|0;wx(a);return a|0}function cp(a){return(w[a+16|0]&5)!=0}function br(a){a=a|0;aV(a);return a|0}function _ja(a){a=a|0;return MT(a)|0}
function YJ(a){v[a>>2]=59944;return a}function Xs(a,b){a=a|0;b=b|0;return-1}function Vi(a){return t[a+34|0]&1?2:1}function Ve(a,b){v[a+4>>2]=b;return a}function VQ(a){a=a|0;Ar(a);return a|0}function Qb(a){return vh(a,w[a+16|0])}function PK(a){return x[a+1074440>>1]}function OE(a){return w[a+22|0]>>>7|0}function Kla(a){a=a|0;return w[a+8|0]}function KL(a,b){a=a|0;b=b|0;return 0}function F4(a){a=a|0;return VH(a,0)|0}function E4(a){a=a|0;return VH(a,1)|0}function A4(a){a=a|0;return SH(a,0)|0}function $e(a){return w[a+11|0]>>>7|0}function zn(a){v[a+4>>2]=v[a+4>>2]+1}function z0(a){a=a|0;return t[a+9|0]}function xV(a,b){if(!lV(a,b)){QB(b)}}function wna(a){a=a|0;return wk(a)|0}function uh(a,b){a=a|0;b=b|0;uD(a,b)}function tpa(a){a=a|0;return Gp(a)|0}function qd(a,b){return vn(a+12|0,b)}function pn(a,b){uc(a);VE(a,b);uE(a)}function pfa(a){a=a|0;return dP(a)|0}function pS(a,b){Ie(a);jS(a,b);iS(a)}function kba(a){a=a|0;v[a+4224>>2]=0}function ZM(a,b,c){a=a|0;b=b|0;c=c|0}function Yi(a){return v[a+4>>2]-36|0}function Ui(a,b){Lb(a);VN(a,b);iw(a)}function Uea(a){a=a|0;return wO(a)|0}function UK(a){return v[a+4>>2]-48|0}function Tm(a,b){qc(a);_W(a,b);QS(a)}function RL(a){v[a>>2]=0;v[a+4>>2]=0}function Qr(a,b){a=a|0;b=b|0;Zv(a,b)}function Pfa(a){a=a|0;return Pk(a)|0}function PP(a){return(a+5&255)>>>0<2}function PO(a){return v[a+4>>2]-32|0}function Lea(a){a=a|0;return xi(a)|0}function JR(a,b){a=a|0;b=b|0;kD(a,b)}function IZ(a,b){a=a|0;b=b|0;Ir(a,b)}function HN(a,b){Nf(a);HO(a,b);DN(a)}function Fo(a,b){a=a|0;b=b|0;cg(a,b)}function FU(a){return v[a+4>>2]-56|0}function EC(a,b){zg(a);LW(a,b);zW(a)}function DU(a){return v[a+4>>2]-28|0}function CK(a){return v[a+4>>2]-12|0}function A0(a){a=a|0;return t[a+8|0]}function $u(a){return v[wb(a)>>2]<<5}function z1(){be(467136,Yd(465472))}function yf(a){return v[a+24620>>2]}function yZ(a){a=a|0;return gE(a)|0}function y1(){be(467152,Yd(465480))}function xga(a,b){a=a|0;b=b|0;ER(b)}function w1(){be(467168,Yd(465488))}function vg(a,b,c){return To(a,b,c)}function uD(a,b){dI(a,v[a+16>>2]|b)}function u1(){be(467184,Yd(465496))}function t1(){be(467200,Yd(465568))}function s1(){be(467208,Yd(465576))}function rga(a,b){a=a|0;b=b|0;Ee(b)}function qo(a){return v[a+4>>2]-4|0}function q4(a){a=a|0;return wf(a)|0}function oc(a,b){return v[a>>2]+b|0}function nja(a,b){a=a|0;b=b|0;ae(b)}function mu(a){return Lq(a)<<24>>24}function mn(a,b,c){if(c){kh(a,b,c)}}function k8(a){a=a|0;return se(a)|0}function hna(a,b){a=a|0;b=b|0;Ll(b)}function gc(a){TC(a);$m(a);return a}function fi(a,b,c){if(c){hc(a,b,c)}}function es(a){a=a|0;return Hd(a)|0}function ena(a,b){a=a|0;b=b|0;Bk(b)}function YE(a){a=a|0;return Fg(a)|0}function X1(){be(466896,Yd(465424))}function Wea(a,b){a=a|0;b=b|0;xm(b)}function W_(a){a=a|0;return kI(a)|0}function W1(){be(466904,Yd(465432))}function Vea(a,b){a=a|0;b=b|0;yg(b)}function V1(){be(466912,Yd(465628))}function Ur(a){t[a+2|0]=0;u[a>>1]=0}function Um(a,b){return B(b,12)+a|0}function Ub(a){return Uh(v[a+4>>2])}function U1(){be(466928,Yd(465620))}function Ts(a){a=a|0;return cp(a)|0}function T1(){be(466936,Yd(465636))}function Sca(a,b){a=a|0;b=b|0;Py(b)}function Rfa(a,b){a=a|0;b=b|0;Bo(b)}function R1(){be(466944,Yd(465644))}function QE(a){return w[a+21|0]&127}function Q1(){be(466960,Yd(465652))}function PE(a){return w[a+22|0]&127}function P1(){be(466968,Yd(465660))}function Oda(a){a=a|0;Vt(a,45942,1)}function O1(){be(466976,Yd(465668))}function N1(){be(467008,Yd(465676))}function M1(){be(467040,Yd(465440))}function LC(a,b){return oX(a,0-b|0)}function L1(){be(467048,Yd(465448))}function K1(){be(467056,Yd(465456))}function Jga(a,b){a=a|0;b=b|0;Km(b)}function J1(){be(467064,Yd(465464))}function IV(a,b){return Ne(a,0-b|0)}function I1(){be(467072,Yd(465504))}function H_(a){a=a|0;return _f(a)|0}function H1(){be(467080,Yd(465512))}function G1(){be(467088,Yd(465520))}function F_(a){a=a|0;return v[a>>2]}function F1(){be(467096,Yd(465528))}function D1(){be(467104,Yd(465536))}function Cc(a,b){v[a>>2]=b;return a}function C1(){be(467112,Yd(465544))}function B1(){be(467120,Yd(465552))}function A1(){be(467128,Yd(465560))}function $x(a){return!zd(a,91484,6)}function vd(a,b){Qo(a);Cc(a+4|0,b)}function v_(a,b){a=a|0;b=b|0;ww(b)}function ui(a){a=a|0;t[a+4202|0]=0}function sj(a,b){return(b<<13)+a|0}function se(a){return v[a>>2]+16|0}function qt(a){a=a|0;t[a+6152|0]=0}function pZ(a,b){a=a|0;b=b|0;$v(b)}function mj(a){return cd(a+36|0)^1}function mZ(a,b){a=a|0;b=b|0;Dk(b)}function mN(a,b){a=a|0;b=b|0;Qo(b)}function lZ(a,b){a=a|0;b=b|0;Ah(b)}function kZ(a,b){a=a|0;b=b|0;yb(b)}function iH(a){return Hh(a,465512)}function hH(a){return Hh(a,465504)}function fw(a,b){v[a>>2]=v[a>>2]+b}function fH(a){return Hh(a,465528)}function eo(a,b){v[a+1300464>>2]=b}function eh(a,b){v[a>>2]=v[a>>2]|b}function eH(a){return Hh(a,465520)}function cm(a){go(a);v[a>>2]=90408}function aB(a,b){a=a|0;b=b|0;Re(b)}function _s(a){return Ke(a,-1)?0:a}function Zf(a,b){Qo(a);_e(a+4|0,b)}function Zd(a){KF(a);v[a>>2]=84916}function Y5(a,b){a=a|0;b=b|0;Zb(b)}function X_(a){a=a|0;co(a,1,15191)}function Mh(a,b){_c(a,Ob(b),Bb(b))}function LZ(a,b){a=a|0;b=b|0;Ur(b)}function Gj(a,b,c){_d(a,v[b>>2],c)}function Fh(a,b){a=a|0;b=b|0;Jb(a)}function Dl(a,b){zp(a,b,v[b+4>>2])}function Dk(a){t[a|0]=0;t[a+1|0]=0}function DG(a,b){a=a|0;b=b|0;vb(b)}function yl(a,b,c){return xR(b,c)}function yk(a){v[a>>2]=0;return a}function xy(a){return a+1300408|0}function wr(a){v[a>>2]=v[a>>2]+12}function wh(a){v[a>>2]=1;return a}function vo(a){return a+1074324|0}function vV(a,b){return Gk(a,b,5)}function uu(a,b,c){return wA(b,c)}function ud(a,b){return(b<<1)+a|0}function sh(a){v[a>>2]=v[a>>2]+20}function sS(a){v[a>>2]=v[a>>2]+32}function rw(a){return t[a+24|0]&1}function pc(a,b){return Ob(a)+b|0}function pV(a,b){return(b<<4)+a|0}function pT(a,b){kB(a,b);return a}function np(a){v[a>>2]=v[a>>2]+28}function mp(a){v[a>>2]=2;return a}function lN(a,b,c){return Aj(b,c)}function k4(a){a=a|0;return 79677}function jU(a,b){return Qv(a,b,4)}function i4(a){a=a|0;return 79756}function _O(a){v[a>>2]=v[a>>2]+52}function ZK(a){v[a>>2]=v[a>>2]+24}function Yia(a){a=a|0;gB(a);Zb(a)}function Te(a){return Nf(a)&65535}function Ro(a){v[a>>2]=v[a>>2]+16}function Rb(a){return Uh(v[a>>2])}function Qia(a){a=a|0;eB(a);Zb(a)}function Q4(a){a=a|0;return 78288}function Oka(a){a=a|0;$V(a,65535)}function Ni(a,b){Me(a,b);return a}function NT(a){return v[wb(a)>>2]}function Lh(a){return a-48>>>0<10}function LD(a,b){return Qv(a,b,7)}function KD(a){return w[a+1|0]==1}function Iq(a){gc(a+4|0);return a}function I$(a){a=a|0;return 90383}function H$(a){a=a|0;return 90420}function Em(a){u[a>>1]=0;return a}function EM(a){return w[a+4232|0]}function E$(a){a=a|0;return 90952}function Dj(a,b){return(b<<2)+a|0}function By(a,b){return mO(a,b)^1}function Br(a,b){return te(a,b)^1}function AC(a,b,c){return un(b,c)}function $d(a){return v[dc(a)>>2]}function zw(a){a=a|0;ys(a);Zb(a)}function zu(a){v[a>>2]=v[a>>2]+8}function xg(a){Lb(a);wq(a);iw(a)}function wR(a){mg(a);zf(a);mg(a)}function vL(a){a=a|0;Dy(a);Zb(a)}function uF(a){am(a);Mk(a);am(a)}function sA(a){t[a|0]=0;return a}function ml(a){a=a|0;nf(a);Zb(a)}function je(a,b){v[a>>2]=v[b>>2]}function jD(a){v[a>>2]=v[a>>2]+2}function ik(a){Ce(a);Lb(a);Ce(a)}function iU(a){return w[a|0]<129}function hT(a){Mi(a);Je(a);Mi(a)}function hB(a,b,c){bT(pe(a,b),c)}function fn(a){uc(a);qw(a);uE(a)}function fN(a){Pf(a);XM(a);WM(a)}function ev(a){nh(a);Ie(a);nh(a)}function dM(a){a=a|0;Ky(a);Zb(a)}function dD(a){Lj(a);gY(a);fY(a)}function cq(a){pg(a);Gc(a);pg(a)}function aW(a,b){hc(a,b+4|0,256)}function aE(a){Vl(a);cf(a);Vl(a)}function _H(a){v[a+72>>2]=464456}function ZH(a){v[a+72>>2]=464540}function Xt(a){return RO(w[a|0])}function WH(a){a=a|0;nm(a);Zb(a)}function VX(a){dn(a);Lj(a);dn(a)}function TH(a){a=a|0;eq(a);Zb(a)}function TC(a){jg(a);qc(a);jg(a)}function Sq(a){a=a|0;Xw(a);Zb(a)}function Se(a){v[a>>2]=v[a>>2]+1}function SM(a){nl(a);Pf(a);nl(a)}function Oj(a){v[a>>2]=v[a>>2]+6}function ON(a){zg(a);MW(a);zW(a)}function M$(a,b){a=a|0;b=b|0;L()}function Lw(a){hi(a);vf(a);hi(a)}function JO(a){hk(a);Nf(a);hk(a)}function Gu(a,b){u[a>>1]=x[b>>1]}function Gr(a){return Pb(a,0,48)}function Fd(a){return v[a>>2]!=0}function F8(a){a=a|0;Cy(a);Zb(a)}function DC(a){Kj(a);zg(a);Kj(a)}function Cr(a){qc(a);dX(a);QS(a)}function Ag(a){v[a>>2]=v[a>>2]+4}function $r(a){Gg(a);uc(a);Gg(a)}function zC(a,b){return un(a,b)}function yb(a){Bc(a+12|0);Bc(a)}function xO(a,b){return uO(a,b)}function t6(a){a=a|0;XJ(a-88|0)}function pp(a,b){return fs(a,b)}function pf(a,b){return Ig(a,b)}function nr(a,b){return RV(a,b)}function kN(a,b){return Aj(a,b)}function jk(a){return!v[a+4>>2]}function bn(a,b){return oc(a,b)}function a0(a){a=a|0;vb(465732)}function _i(a,b){return a>>>b&1}function _ba(a){a=a|0;Zb(Ky(a))}function _$(a){a=a|0;Pc(465748)}function Yb(a,b){return ef(a,b)}function Y$(a){a=a|0;vb(465764)}function Xl(a,b){return EE(a,b)}function Wk(a,b,c){_c(a,b,1<<c)}function W$(a){a=a|0;Pc(465780)}function U$(a){a=a|0;vb(465796)}function Tr(a,b){return DE(a,b)}function S$(a){a=a|0;Pc(465812)}function Q$(a){a=a|0;vb(465828)}function Pw(a,b){return Vf(a,b)}function Pu(a,b){return Mb(a,b)}function Pj(a,b,c){uf(a,c,13,b)}function Pd(a,b){return vn(a,b)}function PU(a,b){return Cj(b,a)}function Ol(a){return Fv(uc(a))}function O$(a){a=a|0;Pc(465844)}function Mq(a){yR(a+12|0);CR(a)}function Ko(a){return Lm(fe(a))}function Km(a){vb(a+12|0);Ze(a)}function Kh(a){return a<<24>>24}function Hf(a){vb(a+20|0);vb(a)}function He(a){a=a|0;return a|0}function Gw(a){ns(a,nc(wf(12)))}function Ej(a,b){return vh(a,b)}function Ei(a){return Ie(a)&255}function Ds(a){a=a|0;return 127}function Dq(a){u[a+480214>>1]=0}function Bo(a){vb(a+12|0);vb(a)}function $aa(a){a=a|0;return 13}function zI(a){a=a|0;Zb(gh(a))}function vy(a,b){return b-a>>3}function uJ(a){a=a|0;Zb(nq(a))}function sP(a){_z(92224,Bd(a))}function q5(a){a=a|0;Zb(nm(a))}function o1(a){a=a|0;Zb(ZG(a))}function nu(a,b){return a<<8|b}function nM(a){a=a|0;Zb(oM(a))}function m5(a){a=a|0;Zb(eq(a))}function l_(a){a=a|0;Zb(nF(a))}function j_(a){a=a|0;Zb(uw(a))}function gka(a){a=a|0;return 9}function ec(a,b){v[a+100>>2]=b}function eM(a){a=a|0;Zb(fM(a))}function e4(a){a=a|0;Zb(wx(a))}function _0(a){a=a|0;Zb(WG(a))}function ZE(a){return a>>>0>16}function YL(a){a=a|0;Zb(ZL(a))}function XJ(a){a=a|0;Zb(ly(a))}function WS(a){return a+4896|0}function U6(a){a=a|0;Zb(rK(a))}function RV(a,b){return b-a>>2}function R0(a){a=a|0;Zb(UG(a))}function Qd(a,b){t[a|0]=w[b|0]}function QH(){return(db()|0)>0}function Q6(a){a=a|0;Zb(pK(a))}function Pt(a){return a>>>27^a}function Oba(a){a=a|0;return 6}function O5(a){a=a|0;Zb(lt(a))}function NH(a){a=a|0;Zb(ag(a))}function NG(a){a=a|0;Zb(_w(a))}function N4(a){a=a|0;Zb(eI(a))}function L4(a){a=a|0;Zb(Hx(a))}function KM(a){a=a|0;Zb(LM(a))}function Gx(a){a=a|0;Zb(Ws(a))}function G$(a){a=a|0;Zb(Xw(a))}function F$(a){a=a|0;Zb(ys(a))}function DW(a,b){_c(a,b,ye(b))}function D8(a){a=a|0;Zb(Dy(a))}function Cx(a){a=a|0;Zb(Us(a))}function CT(a){uB(Pb(a,0,880))}function C0(a){a=a|0;Zb(QG(a))}function B0(a){a=a|0;Zb(PG(a))}function AM(a){a=a|0;Zb(BM(a))}function $M(a){a=a|0;Zb(aN(a))}function $6(a){a=a|0;Zb(Ft(a))}function ze(a){a=a|0;return 1}function zR(a){Fj(a);return a}function z8(){return 19922997}function xp(a){return a>>>0<5}function xe(a){a=a|0;return 2}function wM(a){a=a|0;return 7}function wI(a){a=a|0;return-1}function vX(a,b){return b-a|0}function ok(a){return Fd(a)^1}function nc(a){Bg(a);return a}function n1(){bq(465604,aH())}function lc(a,b){return a+b|0}function kR(){return jc(36,4)}function ic(a){a=a|0;return 0}function iM(a){a=a|0;return 5}function ff(a,b){u[a+28>>1]=b}function dd(a){Jg(a);return a}function bC(){return jc(20,4)}function ai(a){return cd(a)^1}function _g(a){dd(a);return a}function Yv(a){return!v[a>>2]}function YF(a){a=a|0;return 3}function Tj(a){return jc(a,1)}function TU(a,b){cc(a,b,1108)}function SB(a,b){cc(a,b,1024)}function Rw(){return lb()<<16}function PW(){return jc(32,4)}function PS(a,b){Pb(a,0,b<<2)}function Kv(a){a=a|0;return 4}function Ku(a){return a+256|0}function JY(a,b){cc(a,b,1954)}function Gt(a,b){v[a+32>>2]=b}function Go(a,b){v[a+36>>2]=b}function GW(a){Gr(Pb(a,0,48))}function EU(a,b){uf(a,b,33,1)}function DS(){return jc(16,4)}function Co(a){nc(a);return a}function Ar(a){yk(a);return a}function $z(a){jF(a);return a}function zq(a,b){z[a+4>>2]=b}function yq(a,b){t[a+33|0]=b}function ye(a){return a+16|0}function xz(a,b){t[a+34|0]=b}function xt(a){v[a>>2]=58720}function xE(a,b){cc(a,b,497)}function wz(a,b){t[a+32|0]=b}function wq(a){VN(a,v[a>>2])}function wW(a,b){cc(a,b,128)}function vz(a,b){t[a+35|0]=b}function tm(a,b){v[a+8>>2]=b}function tC(a,b){Kj(a);Kj(a)}function ss(a){return a+20|0}function sU(a,b){cc(a,b,146)}function sR(a){rR(a,v[a>>2])}function qw(a){VE(a,v[a>>2])}function ol(a,b){Ce(a);Ce(a)}function oU(a,b){cc(a,b,608)}function nw(a,b){Gg(a);Gg(a)}function nY(a,b){cc(a,b,610)}function mX(a,b){cc(a,b,218)}function mD(a,b){cc(a,b,512)}function kX(a,b){cc(a,b,157)}function kV(a,b){cc(a,b,130)}function kS(a){jS(a,v[a>>2])}function jG(a,b){hi(a);hi(a)}function iV(a,b){cc(a,b,600)}function gp(a,b){wb(b);wb(a)}function go(a){v[a>>2]=90444}function gk(a){return a+36|0}function gY(a){ZX(a,v[a>>2])}function fd(a,b){a=a|0;b=b|0}function fX(a,b){cc(a,b,576)}function fL(a){v[a>>2]=57916}function dX(a){_W(a,v[a>>2])}function dV(a,b){cc(a,b,126)}function bc(a){return a+12|0}function aT(a,b){cc(a,b,263)}function Zw(a){return a+32|0}function ZJ(a){v[a>>2]=59920}function YT(a,b){cc(a,b,204)}function XM(a){TM(a,v[a>>2])}function U4(a){a=a|0;uD(a,1)}function TX(a,b,c){Tl(a,b,c)}function TW(a){mG(a,v[a>>2])}function SA(a,b){nh(a);nh(a)}function S6(a){a=a|0;qK(a,1)}function Rd(a){Ae(a,v[a>>2])}function RD(a,b){Vl(a);Vl(a)}function Ps(a,b){bq(a,b+4|0)}function P6(a){a=a|0;xU(a,1)}function Mr(a,b){cc(a,b,192)}function MW(a){LW(a,v[a>>2])}function MC(a,b){uf(a,b,8,2)}function KW(a,b){cc(a,b,674)}function IO(a){HO(a,v[a>>2])}function Gf(a,b){t[a+11|0]=b}function GV(a,b,c){Ay(a,b,c)}function Fw(a,b){QF(a,Bd(b))}function EJ(a){v[a>>2]=78400}function DM(a,b,c){To(a,b,c)}function Bq(a,b){z[a+8>>2]=b}function BC(a,b){jg(a);jg(a)}function Ae(a,b){v[a+4>>2]=b}function AN(a,b){hk(a);hk(a)}function $w(a,b){pg(a);pg(a)}function zD(a,b){cc(a,b,11)}function yja(a){a=a|0;CT(a)}function wv(a,b){cc(a,b,22)}function wb(a){return a+8|0}function wD(a,b){cc(a,b,17)}function uX(a,b){cc(a,b,98)}function tf(a,b){t[a+3|0]=b}function rd(a){return a+1|0}function rX(a,b){cc(a,b,48)}function rD(a,b){_c(a,b,20)}function qr(a){v[a>>2]=1848}function qC(a,b){cc(a,b,33)}function nfa(a){a=a|0;Xz(a)}function mV(a,b){cc(a,b,30)}function hd(a){return!Bb(a)}function gC(a,b){cc(a,b,40)}function fP(a){Pb(a,0,1024)}function er(a){Pb(a,0,4096)}function eD(a,b){cc(a,b,64)}function dc(a){return a+4|0}function dJ(){return 462116}function bs(a,b){cc(a,b,36)}function aw(a,b){cc(a,b,16)}function ah(a){return a&255}function _D(a,b){cc(a,b,38)}function YV(a,b){cc(a,b,52)}function YD(a,b){cc(a,b,41)}function VV(a,b){cc(a,b,80)}function UN(a){if(a){Zb(a)}}function Soa(){return 65535}function Sn(){Cn(77900);L()}function Ri(a){return a+3|0}function RR(a,b){cc(a,b,27)}function Py(a){Pb(a,0,2048)}function Pka(){return 65534}function Ox(){Cn(74965);L()}function Og(){xc(77900);L()}function OX(a,b){cc(a,b,12)}function NB(a,b){cc(a,b,32)}function Mc(){xc(74965);L()}function LE(a,b){_c(a,b,22)}function L$(){return 467408}function Jq(a){Pb(a,0,8192)}function JU(a,b){cc(a,b,96)}function IY(a){Pb(a,0,1954)}function FF(a,b){cc(a,b,10)}function Ey(a,b){AL(a,b,10)}function EB(a){v[a+12>>2]=0}function Df(a){return a+2|0}function DF(a,b){cc(a,b,14)}function Bv(a,b){cc(a,b,66)}function Bp(a,b){t[a+1|0]=b}function A8(){return 393216}function $N(a,b){cc(a,b,24)}function zW(a){Kj(a);zg(a)}function yd(a){cq(a);hF(a)}function yc(a){v[a+8>>2]=0}function yR(a){Uq(a,$d(a))}function xl(a){vA(a,$d(a))}function wE(a){Pb(a,0,497)}function uE(a){Gg(a);uc(a)}function ts(a){a=a|0;us(a)}function rk(a,b){zp(a,b,0)}function rU(a){Pb(a,0,146)}function qR(a){pg(a);Gc(a)}function pr(a){fC(a,$d(a))}function pP(a){iu(a,$d(a))}function or(a){eC(a,$d(a))}function oO(a){sz(a,$d(a))}function nka(a){a=a|0;gb=a}function nU(a){Pb(a,0,608)}function nB(a){Pb(a,0,256)}function mY(a){Pb(a,0,610)}function kd(a){aE(a);cE(a)}function jX(a){Pb(a,0,157)}function iw(a){Ce(a);Lb(a)}function iS(a){nh(a);Ie(a)}function hV(a){Pb(a,0,600)}function fY(a){dn(a);Lj(a)}function eX(a){Pb(a,0,576)}function dla(){return gb|0}function dC(a,b){cc(a,b,4)}function dB(a){Pb(a,0,512)}function cV(a){Pb(a,0,126)}function _m(a){DC(a);qv(a)}function _l(a,b,c){mF(b,c)}function _e(a,b){v[a>>2]=b}function _3(){return 80188}function Ze(a){$r(a);_r(a)}function Z3(){return 80960}function Yc(a){a=a|0;Zb(a)}function Y3(){return 82512}function Xb(a){yn(v[a>>2])}function XT(a){Pb(a,0,204)}function Wq(a){Lw(a);GR(a)}function WM(a){nl(a);Pf(a)}function WD(a,b){bi(a,2,b)}function UW(a){t[a+31|0]=0}function Rv(a,b){cc(a,b,5)}function RW(a){xC(a,$d(a))}function Qc(a){ik(a);bu(a)}function QS(a){jg(a);qc(a)}function QB(a){Pb(a,0,130)}function Op(a,b,c){hG(b,c)}function NW(a){yC(a,$d(a))}function MV(a,b){cc(a,b,2)}function JW(a){Pb(a,0,192)}function Hp(a,b){cc(a,b,8)}function FT(a){lB(a,$d(a))}function ET(a){mB(a,$d(a))}function DN(a){hk(a);Nf(a)}function BX(a,b){cc(a,b,6)}function Aq(a,b){z[a>>2]=b}function xH(a){Pb(a,0,44)}function tX(a){Pb(a,0,98)}function sX(a){Pb(a,0,48)}function lW(a){Pb(a,0,33)}function kC(a){Pb(a,0,80)}function b8(){return 2048}function as(a){Pb(a,0,36)}function _C(a){Pb(a,0,66)}function ZD(a){Pb(a,0,38)}function XV(a){Pb(a,0,52)}function XD(a){Pb(a,0,41)}function WC(a){Pb(a,0,64)}function Li(a,b){t[a|0]=b}function KU(a){Pb(a,0,96)}function mh(a){a=a|0;L()}function kB(a,b){Cc(a,b)}function bp(a,b){dI(a,b)}function bV(a,b){Ey(a,b)}function ae(a){yb(a+8|0)}function UV(a,b){QV(a,b)}function UU(a,b){SE(a,b)}function Ty(a,b){gi(a,b)}function Sl(a,b){wY(a,b)}function Qp(a,b){Qd(a,b)}function Qo(a){v[a>>2]=0}function PA(a,b){Yf(a,b)}function OY(a,b){tL(a,b)}function Ll(a){vb(a+4|0)}function IB(a,b){xU(a,b)}function Hj(a,b){Ae(a,b)}function HF(a,b){_e(a,b)}function FO(a,b){fw(a,b)}function Eq(a,b){je(a,b)}function Eh(a,b){Dh(a,b)}function ER(a){Im(a,0,0)}function Ac(a){gc(a+8|0)}function $v(a){u[a>>1]=0}function Re(a){t[a|0]=0}function Ffa(){ua();L()}function yg(a){SW(a,0)}function ri(a){oL(a,0)}function qi(a){mL(a,0)}function qA(a){RP(a,0)}function os(a){QF(a,0)}function mq(a){nL(a,0)}function gu(a){cP(a,0)}function fu(a){bP(a,0)}function Hc(a){Ge(a,0)}function Dm(a){_z(a,0)}function CO(a){nO(a,0)}function qf(a){a=a|0}function oR(a){av(a)}function iG(a){rG(a)}function hE(a){Qg(a)}function RT(a){dd(a)}function Hb(a){vb(a)}function J$(){L()}
// EMSCRIPTEN_END_FUNCS
e=w;var kb=c([null,Jm,Tb,Qt,cg,HL,co,G5,g5,dk,m4,l3,f2,Kt,Jm,i5,rZ,ln,uh,h5,$,nD,gn,UZ,Xw,Oc,Ke,RY,kn,He,Yc,MF,ls,Xea,xF,_h,rf,ZC,fd,Gb,_h,vma,Wo,mr,aB,Zg,$A,Zu,JB,gB,mh,ze,ze,Kla,Jla,zt,Ala,oja,hja,J$,eB,mh,ze,ic,ze,cka,bka,Uja,Ija,Dja,Yia,wja,Qia,vja,uja,He,mh,tj,Dga,JR,FR,Eo,Cu,sga,ja,Tq,Sq,zt,Nfa,Ffa,zfa,Tb,E5,hA,sfa,rfa,kfa,ffa,KO,rf,tq,D5,Uea,Ofa,Rea,Tea,Nea,MM,fd,KO,Ir,kD,t5,v5,Jm,nca,sba,Ir,Y9,cg,HL,y7,Bj,II,lq,Z6,T6,J6,G6,cK,B6,aH,H8,R4,B8,q6,k6,M4,e6,d8,W7,Jm,nq,uJ,S5,R5,Us,Cx,iI,hI,lt,O5,fd,Jm,L5,C5,ic,ic,p5,A5,o5,y5,n5,r5,c5,Ts,f5,B4,s4,_4,Y4,XH,a5,l4,ag,NH,a4,X3,Ws,Gx,tI,sI,G3,Cu,x3,s3,tH,Ep,Jm,E1,Fs,Fo,I2,e2,rf,Gn,Fn,DG,rf,ZC,oG,$A,Dn,c$,fd,fd,aB,b$,a$,$_,__,a3,n2,Di,Ci,Y_,dG,cG,X_,Fs,W_,U_,Jw,ts,Np,Zc,of,Q_,Bn,qs,S_,R_,P_,of,O_,V_,N_,qS,M_,qS,T_,bG,L_,K_,_F,$F,dh,Pk,Rc,TF,Nb,G_,Nk,TF,Dw,E_,Cw,_h,D_,ys,_h,u_,t_,gf,F_,p_,C_,Lp,B_,v_,Ah,gf,s_,Lp,vF,gf,Dn,Dn,o_,n_,Lp,m_,Dn,zw,zt,He,Yc,Ip,KL,A_,Yc,z_,ze,ze,zt,ky,y_,x_,w_,He,Yc,Ip,r_,Yc,ic,ze,ze,ic,ic,q_,nF,l_,Ip,k_,uw,j_,i_,h_,g_,f_,z5,e_,d_,c_,Rp,Mea,Hea,Eea,Gp,yF,ZZ,tF,DG,fd,kF,WZ,VZ,zw,rf,rf,YE,td,SZ,RZ,rf,fd,fd,fd,$A,ZC,aB,Ml,MZ,tq,QZ,NZ,LZ,fd,YE,ci,KZ,JZ,IZ,Wl,EZ,vE,on,fd,zZ,mE,Vb,xZ,wd,es,lE,wZ,H_,$b,Jc,vZ,uZ,kE,jE,iE,ug,rg,Sg,tZ,fE,eE,sZ,dE,cw,rf,qZ,_v,Wd,Xe,Fc,rf,rf,lZ,rf,pZ,oZ,fd,nZ,vE,mZ,kZ,hZ,gZ,eZ,ID,dZ,We,cZ,bZ,aZ,$Y,Ex,lM,US,_Y,oe,ZY,bw,Wv,Ed,$s,jh,of,WY,Vv,Le,Ff,MO,VY,UY,FD,ED,TY,DD,sd,Xv,Gb,Mm,Wo,sn,QY,Xr,Wc,Rr,ypa,Nv,VF,sg,Vc,Kb,Cg,of,xpa,lD,wpa,Zc,Kr,Tga,vpa,upa,Fi,tpa,GY,Mv,spa,Lv,rpa,Yda,Of,De,wm,oo,ez,qpa,EY,GM,iD,Jv,Iv,sk,of,ppa,opa,Ye,CY,npa,mpa,sY,tj,lpa,JR,FR,Eo,Cu,Tq,ipa,hpa,gpa,iY,dpa,cpa,cD,Bf,bpa,apa,$oa,_oa,Io,bB,Zoa,Yoa,Xoa,Woa,Wf,ne,it,bD,Cv,aD,Roa,Qoa,Toa,$X,Wo,sn,aY,jp,Ml,fd,Mf,PX,Noa,Ak,Koa,Joa,Voa,Ioa,me,Cf,KX,Dw,Hoa,cB,Goa,Foa,Eoa,IX,Doa,Ml,Aoa,Nv,fp,zoa,yoa,GY,xoa,Fk,woa,voa,Eg,uoa,toa,nn,kr,soa,roa,CY,qoa,poa,AX,ooa,zX,aR,RC,QC,zX,Zy,Wga,Mj,uv,hz,vq,Yt,x5,KC,foa,gX,xh,boa,aoa,Zea,Zna,lfa,tv,Cp,Yna,Xna,Wna,Fr,JE,Vna,Ju,Po,Una,Tna,doa,aX,OZ,Sna,Lo,KE,sv,Rna,of,Qna,Jc,Pna,Ona,$W,Nna,HZ,Mna,Lna,Kna,Jna,ZW,Ina,Wu,Hna,of,Gna,Fna,jw,hY,coa,of,Ena,Dna,mr,yp,Cna,Bna,Ana,Pn,LO,IC,zna,IC,IC,HC,WW,FC,bm,yna,d$,xna,wna,vna,una,tna,sna,rna,sda,VW,rf,HW,gd,dp,lna,rA,dna,Qr,qna,rf,sC,cna,pna,ona,nna,Yf,tda,afa,kda,mna,Qt,kna,jna,ina,gf,Fo,He,hna,fd,gna,fd,fd,fna,tq,ena,ur,_ma,Zma,Yma,df,Xma,Wma,Vma,Uma,Tma,Sma,sW,rW,Rma,Qma,Pma,Oma,Nma,oW,$o,bW,oC,Kma,Jma,Ima,sr,FS,Fr,Hma,Gma,Fma,Ema,OC,HS,Nl,Kl,nC,Dma,yZ,Cma,Bma,$V,_V,mC,Ama,$g,zma,Qt,Fr,yma,Fr,xma,wp,wma,of,iY,Yo,fd,OV,sma,rma,me,Dw,qma,pma,aC,oma,iv,nma,mma,lma,kma,jma,ima,nE,hma,gma,_ga,fma,ema,dma,cma,_ia,nga,lga,bma,T5,CC,U5,ama,$la,cy,dy,Yea,_la,of,YW,XW,JS,Zla,Vv,Yla,Wm,Xla,Wla,Di,Ci,Vla,Ev,gv,pj,dh,TB,Mla,Lla,Tla,vr,fd,Gla,Fla,BD,Ela,NO,Dla,Cla,FN,dp,Bla,zla,yla,xla,Zl,Yl,dv,oA,wla,vla,Jo,ula,Ul,tla,sla,OB,up,$U,nla,LB,mla,lla,Ye,Wr,kla,Al,jla,ila,dh,fla,ela,gf,cla,bla,QU,gf,Vr,ala,Zka,Yka,zk,pk,dv,Xka,$da,Wka,Wm,Yo,Tka,Ska,cD,SU,LB,Xv,Rka,Qka,Soa,Pka,Oka,Nka,_u,Mka,_u,Lka,LY,Kka,Jka,PZ,Fka,Eka,TB,Gka,vU,uU,Bka,oC,Aka,xka,wka,XS,vka,aX,oga,fR,ska,Vv,mka,lka,ED,bU,kka,jka,ika,hka,Xm,aU,fka,eka,dka,UT,_ja,Zja,Yja,Xja,Wja,Vja,Tja,Om,Zia,OT,Sja,Rja,Qja,Pja,Oja,Nja,Mja,Xga,cu,dga,kga,iga,Lja,aea,me,Kja,Jja,Hja,Gja,Fja,vr,yB,Eja,JT,oh,Cja,Bja,tT,Aja,zja,hp,yja,zT,Yo,vT,dha,rja,RU,qja,nja,Yga,kja,jja,uea,ija,gja,fja,YN,eja,tea,ZN,dja,cja,bja,Z_,gG,Zga,fv,of,efa,dfa,dT,cT,rf,fd,fB,Xia,Wia,Via,Uia,Tia,Sia,Ria,Pia,Oia,Nia,Mia,Lia,Kia,Jia,Iia,Hia,Gia,Eia,Dia,Cia,Bia,Aia,zia,yia,xia,wia,via,uia,tia,sia,ria,qia,pia,oia,nia,mia,lia,jia,iia,hia,gia,fia,eia,dia,cia,bia,aia,_ha,Zha,Yha,Xha,Wha,Vha,Uha,Tha,Sha,Rha,Qha,Pha,Oha,Nha,Mha,Lha,Kha,Jha,Iha,Hha,Gha,Fha,Eha,Dha,Cha,Bha,Aha,zha,yha,xha,wha,vha,uha,tha,sha,rha,qha,pha,oha,nha,mha,lha,kha,jha,iha,hha,gha,fha,eha,cha,aha,br,bha,mS,Si,VD,rS,Uga,Iga,Sga,Rga,Qga,Pga,Oga,oS,Nga,Mga,Lga,Kga,Du,Hga,Jga,XR,Fga,Ega,Zv,PR,Oea,Cga,Bga,xq,qz,oz,nz,GA,Aga,HR,zga,yga,rf,xga,fd,mk,uq,AR,vga,uga,wi,tga,Of,pga,rga,He,qga,fd,qt,V5,Gm,mga,bfa,Hi,$ga,Sh,eR,pja,Th,zea,jga,Dr,hga,Nv,gga,dh,Ew,fga,Wv,ega,Vfa,cR,cga,Nv,bga,aga,Ew,Sfa,cR,Yfa,Xfa,VQ,gf,$F,Gn,Fn,Cu,_F,tu,XQ,rf,He,Rfa,Lp,rf,Zm,Qfa,TZ,Ue,SY,PQ,Pfa,Uoa,OQ,NQ,MQ,LQ,KQ,JQ,IQ,HQ,GQ,FQ,EQ,DQ,CQ,BQ,AQ,zQ,yQ,xQ,wQ,vQ,uQ,tQ,sQ,rQ,qQ,pQ,oQ,nQ,mQ,lQ,kQ,jQ,iQ,hQ,gQ,fQ,eQ,dQ,cQ,bQ,Mfa,Lfa,Kfa,Jfa,Ifa,Hfa,Gfa,Efa,Dfa,Cfa,Bfa,Afa,yfa,wga,_P,Ez,yu,uR,xfa,wfa,Dz,tg,zo,Pq,vfa,ZP,Mo,lA,kA,Cm,Gz,OO,Fz,yo,ou,UP,ufa,jA,Am,XA,TP,YA,LA,Zq,Qh,tfa,iP,Vga,$ia,kO,pfa,rO,ofa,nfa,wf,mfa,jfa,J_,b_,$Z,YZ,hfa,XZ,a_,I_,_Z,ua,vca,gfa,ZO,Uz,Dea,Gga,cfa,Eda,Ida,$ea,Gda,Dda,gf,gf,Hu,_ea,IS,Wea,Vea,mja,lja,$na,_na,zka,yka,rka,qka,Mma,Lma,rla,qla,ana,$ma,Apa,zpa,noa,moa,jZ,iZ,YY,XY,hla,gla,Dka,Cka,tja,sja,fpa,epa,Poa,Ooa,DZ,CZ,BZ,AZ,Vka,Uka,Ika,Hka,Ila,Hla,bna,vW,joa,ioa,hoa,goa,kpa,jpa,Coa,Boa,$ka,_ka,sea,rea,dea,cea,Ola,Nla,aka,$ja,pla,ola,loa,koa,uka,tka,pka,oka,Moa,Loa,Ula,Qla,Pla,GZ,FZ,Cpa,Bpa,uma,tma,Sla,Rla,mh,Qea,Pea,jP,fd,Fo,fB,Lea,xu,Jea,Kea,YQ,Gea,Iea,Fea,_t,Cea,Zfa,Fm,$fa,_fa,cH,Bea,Aea,Pr,Ufa,yea,eba,SE,xea,dF,bO,kz,Wv,wea,Qy,vea,Wfa,qea,pea,cD,oea,Jr,LB,nea,mea,lea,TB,kea,dh,jea,iea,hea,gea,fea,eea,GJ,X5,W5,bea,ar,_da,Xda,pv,Vda,Uda,Tda,GC,Sda,Sf,Dh,mm,Rda,LN,Qda,Lda,Pda,Zda,Oda,Jda,Mda,Wda,Kda,az,xN,rf,uda,tq,nN,Fda,Hy,qq,Bda,Ada,zda,yda,xda,vN,Hda,sq,Yf,uN,vda,Uk,Dh,mN,rda,qda,pda,oda,nda,mda,Rf,lda,gN,wda,Cda,ida,hda,Oh,gda,fda,VM,Uca,UM,tq,tN,Tca,nN,Sca,fd,mN,fd,aN,$M,$M,_M,ic,qf,ic,ic,ic,fd,Kv,ada,bda,dda,cda,eda,vi,ls,ls,Sy,ZM,Sy,Sy,eoa,qf,vW,Yca,Xca,Wca,Vca,$ca,ui,bN,Aca,ic,ic,ze,Ry,xe,xe,ze,_ca,Zca,fd,qf,fd,qf,Qca,Cca,LM,KM,KM,Bca,ic,qf,ic,ic,ic,fd,gka,QM,Oca,Eca,Dca,Pca,vi,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Nca,ui,PM,ic,ic,ze,xe,xe,ze,OM,NM,xca,HM,nf,mh,yca,My,zca,ic,wca,ZM,uca,Fo,LL,tca,sca,rca,qca,Du,eca,Vba,Nba,Gba,zba,rba,iba,_aa,Taa,jda,Rca,pca,oca,jn,GO,BM,AM,AM,_M,ic,qf,ic,ic,ic,fd,YF,ica,jca,lca,kca,mca,vi,hca,ui,CM,ic,ic,ze,xe,xe,ze,gca,fca,zM,Ky,_ba,xM,Zba,ic,qf,ic,ic,ic,fd,wM,bca,cca,dca,vi,aca,ui,$ba,ic,ic,ze,xe,xe,fd,qf,vM,Yba,Xba,tM,Wba,sM,rM,Uba,oM,nM,nM,Pba,ic,qf,ic,ic,ic,fd,Oba,Rba,Sba,Tba,vi,Qba,ui,pM,ic,ic,ze,xe,xe,Mba,ml,ml,Hba,ic,qf,ic,ic,ic,fd,iM,Jba,Kba,Lba,vi,Iba,ui,jM,ic,ic,ze,xe,xe,Fba,fM,eM,eM,Aba,ic,qf,ic,ic,ic,fd,iM,Cba,Dba,Eba,vi,Bba,ui,gM,ic,ic,ze,xe,xe,yba,dM,dM,wba,wM,xba,vM,vba,uba,tM,tba,sM,rM,qba,ml,ml,lba,ic,qf,ic,ic,ic,fd,xe,nba,oba,pba,vi,mba,ui,kba,ic,ic,ze,xe,xe,hba,jba,ZL,YL,YL,bba,ic,qf,ic,ic,aba,fd,$aa,dba,fba,gba,vi,cba,ui,Iy,ic,ic,ze,xe,xe,fd,qf,Zaa,ml,ml,Uaa,ic,qf,ic,ic,ic,fd,YF,Waa,Xaa,Yaa,vi,Vaa,ui,WL,ic,ic,ze,xe,xe,Saa,ml,ml,Naa,ic,qf,ic,ic,ic,fd,Kv,Paa,Qaa,Raa,vi,Oaa,ui,TL,ic,ic,ze,xe,xe,A8,Laa,I8,r8,z8,y8,f8,Jw,aL,Jt,GL,a8,Baa,FL,b8,$K,_7,Z7,He,yaa,xaa,GL,Y7,V7,CL,uaa,Dy,YK,ky,WK,VK,J7,F7,G7,H7,Gy,U7,eaa,uL,T7,S7,R7,Q7,P7,O7,N7,M7,L7,K7,E7,Gy,x7,TK,SK,RK,QK,OK,NK,MK,LK,KK,JK,IK,HK,w7,ao,GK,FK,kl,kq,v7,LH,u7,s7,r7,q7,p7,AK,zK,At,o7,n7,l7,k7,j7,i7,h7,f7,d7,b7,j8,jL,iL,hL,gL,w6,v6,CL,Gy,_8,Z8,Y8,X8,W8,V8,U8,T8,S8,R8,Q8,P8,O8,N8,M8,L8,K8,J8,G8,Cy,F8,E8,vL,C8,vL,D8,It,x8,Tfa,rs,v8,u8,O6,s8,qu,n8,qfa,i8,BI,h8,N6,M6,g7,a7,Qt,e7,c7,ifa,m8,w8,q8,lz,Xf,k8,Sea,e8,rL,pL,$K,$7,c8,gf,X6,W6,l8,g8,o8,cc,X7,I7,VO,D7,C7,B7,x6,Pz,Qz,p8,QO,A7,z7,fo,DK,Nda,t7,Gi,m7,Wc,SO,gz,aja,fz,V6,R6,dP,kK,yt,kK,yt,L6,jK,y6,mh,Ft,$6,t8,He,mh,He,Yc,_6,Y6,mh,rK,U6,Ip,S6,pK,Q6,Ip,P6,Yc,K6,He,Yc,I6,H6,Yc,hK,gK,mh,Yc,F6,E6,Yc,eK,dK,Yc,D6,C6,Yc,bK,aK,Yc,A6,z6,Yc,$J,_J,ly,XJ,s6,r6,WJ,VJ,UJ,TJ,SJ,RJ,QJ,PJ,OJ,NJ,MJ,LJ,KJ,JJ,IJ,HJ,u6,t6,p6,o6,n6,m6,l6,j6,i6,h6,g6,f6,d6,c6,b6,a6,$5,_5,He,mh,He,mh,Z5,Y5,Q5,P5,I5,N5,M5,K5,J5,Ca,dJ,MH,F5,B5,TI,RI,w5,SI,tH,Ep,s5,ro,e5,d5,b5,$4,Z4,X4,Fx,W4,kia,$ha,tW,V4,ro,U4,T4,S4,gI,qf,O4,eI,nm,q5,yI,xI,wI,Xs,Xs,eq,m5,fd,Jm,yI,xI,ic,ic,l5,wI,k5,Xs,j5,Xs,Ws,Gx,tI,sI,Us,Cx,iI,hI,He,Yc,Q4,p4,o4,n4,P4,N4,Hx,L4,gh,zI,gh,zI,K4,ic,J4,I4,H4,pt,pt,zx,yx,Vs,oI,WH,G4,F4,E4,D4,TH,C4,A4,z4,y4,WH,x4,RH,w4,v4,TH,u4,RH,t4,r4,He,mh,mh,q4,f4,c4,OH,wx,Yc,k4,j4,Yc,i4,g4,h4,e4,d4,b4,ic,ic,ic,px,Jh,Ih,Ls,Zb,Ns,_j,Zj,fl,nx,el,N3,cj,Mg,L3,J3,wH,wH,E3,C3,vH,dj,A3,y3,Ic,Be,v3,$3,sx,Dx,kx,Jh,Ih,Ks,lm,al,km,gn,jm,cj,Mg,uH,dj,f3,$2,_2,W3,vx,H5,fI,V2,Ss,kn,Q2,Kn,rx,qf,x2,Es,w2,v2,u2,t2,r2,p2,o2,bl,m2,l2,j2,u5,h2,g2,b2,a2,Y1,X1,W1,V1,U1,T1,S1,R1,Q1,P1,O1,N1,M1,L1,K1,J1,I1,H1,G1,F1,D1,C1,B1,A1,z1,y1,x1,w1,v1,u1,t1,s1,r1,gx,l1,p1,N$,q1,IG,He,n1,m1,k1,_3,Y3,Z3,tx,FH,gl,EH,dq,M0,L0,JI,DH,CH,s0,r0,p0,o0,m0,l0,j0,i0,g0,f0,d0,c0,a0,ax,_$,Y$,W$,U$,S$,Q$,O$,JG,ZG,o1,xM,WG,_0,Z0,Y0,X0,W0,oY,V0,U0,T0,UG,R0,Q0,P0,O0,N0,ic,K0,J0,QG,C0,A0,z0,DK,x0,v0,PG,B0,ky,fZ,y0,w0,u0,He,Yc,Yc,j1,i1,h1,g1,f1,e1,d1,c1,oY,b1,a1,$0,Yc,VG,VG,dx,ze,ze,S0,ze,Yc,I0,H0,dx,ic,ic,G0,Kv,Yc,F0,E0,dx,ic,ic,D0,Kv,He,Yc,V3,U3,T3,He,Yc,S3,R3,Q3,Yc,P3,O3,M3,K3,I3,H3,F3,D3,B3,z3,w3,Yc,u3,t3,r3,q3,p3,o3,n3,m3,k3,j3,i3,Yc,h3,g3,e3,d3,c3,b3,Z2,Y2,Yc,X2,W2,U2,T2,S2,R2,P2,O2,He,Yc,xe,N2,M2,L2,K2,J2,H2,t0,n0,h0,V$,R$,b0,Z$,He,Yc,xe,G2,F2,E2,D2,C2,B2,q0,k0,e0,T$,P$,$$,X$,_w,NG,A2,_w,NG,z2,Yc,Ds,Ds,Fh,Fh,Fh,kH,ic,_k,_k,Yc,Ds,Ds,Fh,Fh,Fh,kH,ic,_k,_k,Yc,Yr,Yr,Fh,Fh,Fh,jH,ic,_k,_k,Yc,Yr,Yr,Fh,Fh,Fh,jH,ic,_k,_k,Yc,y2,s2,Yc,q2,k2,Yc,i2,d2,Yc,c2,$1,Yc,dH,_1,fd,Yc,dH,Z1,fd,K$,L$,M$,Yc,H$,Yc,I$,G$,F$,Sq,Sq,Sq,Sq,zw,Yc,E$,He,Yc,qf,qf,CG,v$,y$,D$,Yc,w$,z$,C$,Yc,x$,A$,B$]);function lb(){return s.byteLength/65536|0}function qb(rb){rb=rb|0;var mb=lb()|0;var nb=mb+rb|0;if(mb<nb&&nb<65536){var ob=new ArrayBuffer(B(nb,65536));var pb=new Int8Array(ob);pb.set(t);t=new Int8Array(ob);u=new Int16Array(ob);v=new Int32Array(ob);w=new Uint8Array(ob);x=new Uint16Array(ob);y=new Uint32Array(ob);z=new Float32Array(ob);A=new Float64Array(ob);s=ob;r.buffer=s;e=w}return mb}return{"va":PY,"wa":Maa,"xa":Kaa,"ya":Yc,"za":Zb,"Aa":Jaa,"Ba":Iaa,"Ca":Haa,"Da":Jt,"Ea":fd,"Fa":Gaa,"Ga":Faa,"Ha":Eaa,"Ia":ls,"Ja":Daa,"Ka":KL,"La":Caa,"Ma":He,"Na":JL,"Oa":IL,"Pa":JL,"Qa":Aaa,"Ra":s$,"Sa":r$,"Ta":q$,"Ua":zaa,"Va":EL,"Wa":waa,"Xa":DL,"Ya":vaa,"Za":taa,"_a":saa,"$a":raa,"ab":qaa,"bb":paa,"cb":oaa,"db":naa,"eb":maa,"fb":laa,"gb":kaa,"hb":jaa,"ib":iaa,"jb":haa,"kb":gaa,"lb":faa,"mb":daa,"nb":caa,"ob":baa,"pb":aaa,"qb":$9,"rb":_9,"sb":Z9,"tb":X9,"ub":W9,"vb":V9,"wb":U9,"xb":T9,"yb":S9,"zb":R9,"Ab":Q9,"Bb":P9,"Cb":O9,"Db":N9,"Eb":M9,"Fb":L9,"Gb":K9,"Hb":J9,"Ib":I9,"Jb":H9,"Kb":G9,"Lb":F9,"Mb":E9,"Nb":D9,"Ob":C9,"Pb":B9,"Qb":A9,"Rb":z9,"Sb":y9,"Tb":x9,"Ub":w9,"Vb":v9,"Wb":u9,"Xb":t9,"Yb":s9,"Zb":r9,"_b":q9,"$b":p9,"ac":o9,"bc":n9,"cc":m9,"dc":l9,"ec":k9,"fc":p$,"gc":j9,"hc":i9,"ic":h9,"jc":g9,"kc":o$,"lc":f9,"mc":e9,"nc":d9,"oc":c9,"pc":b9,"qc":a9,"rc":$8,"sc":Ad,"tc":dJ,"uc":dla,"vc":nka,"wc":xja,"xc":Fia,"yc":u$,"zc":t$,"Ac":kb,"Bc":g$,"Cc":n$,"Dc":m$,"Ec":l$,"Fc":k$,"Gc":j$,"Hc":i$,"Ic":h$,"Jc":g$,"Kc":f$,"Lc":e$}}return sb(ub)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


